// Generated by dts-bundle v0.7.3

/**
    * This method makes the EVA SDK ready for use and configures access to your back-end datastore
    * @param  {string}     authenticationToken   Your application authentication token
    * @param  {number}     applicationId         The application identifier for your store
    * @param  {string}     endPointURL           The URL for the EVA back-end store you want to use
    * @return {void}                             This method doesn't return anything
    */
export function init(authenticationToken: string, applicationId: number, endPointURL?: string): void;
/**
    * Expose the settings manager and the means to override the XMLHttpRequest provider
    */
/**
    * These are the data providers availabe in eva
    */

/**
    * This declares the known settings for the EVA SDK
    */
export interface IEvaSettings {
        userAuthenticationToken?: string;
        siteAuthenticationToken?: string;
        applicationId?: number;
        sessionId?: string;
        endPointURL: string;
        language: string;
        version: string;
        clientName: string;
}
/**
    * The settings manager provides methods to get and set EVA client options
    * @type {namespace}
    */
export namespace SettingsManager {
        /**
            * Generates a new session identifier for all future service calls
            * @return {string} The current session identifier
            */
        function generateSessionID(): string;
        /**
            * Changes the currently configured site authentication token.
            * @return {string} An authorisation token
            */
        function setSiteAuthenticationToken(token: string): string;
        /**
            * Changes the currently configured user authentication token. This token
            * will be used in favor of the site authentication token.
            * @return {string} An authorisation token
            */
        function setUserAuthenticationToken(token: string): string;
        /**
            * Return the currently configured authentication token
            * @return {string} An authorisation token
            */
        function getAuthenticationToken(): string;
        /**
            * Changes the currently configured session identifier
            * @return {string} A session identifier
            */
        function setSessionId(sessionId: string): string;
        /**
            * Return the currently configured session identifier
            * @return {string} A session identifier
            */
        function getSessionId(): string;
        /**
            * Return the currently configured end point URL
            * @return {string} An end point URL
            */
        function getEndPointURL(): string;
        /**
            * Changes the currently configured end point URL
            * @return {string} An end point URL
            */
        function setEndPointURL(URL: string): string;
        /**
            * Return the currently configured application identifier
            * @return {number} An application identifier
            */
        function getApplicationId(): number;
        /**
            * Changes the currently configured application identifier
            * @return {number} An application identifier
            */
        function setApplicationId(applicationId: number): number;
        /**
            * Returns the currently configured client language
            * @return {string} Language code (ex. nl-NL)
            */
        function getLanguage(): string;
        /**
            * Changes the currently configured client language
            * @return {string} Language code (ex. nl-NL)
            */
        function setLanguage(languageCode: string): string;
        /**
            * Returns the current client version number which is in semver format
            * @return {string} Version number (ex. 0.1.0)
            */
        function getVersion(): string;
        /**
            * Returns the current client name
            * @return {string} Client name
            */
        function getClientName(): string;
}

/**
    * For node.js or alternative platforms you can use setTransportProvider to point to an XHR alternative
    * @param  {any}    alternativeXMLHttpRequest   Platform specific or alternative XMLHttpRequest implementation
    * @return {void}                               This method does not return anything
    */
export function setTransportProvider(alternativeXMLHttpRequest: any): void;
/**
    * Create a new instance of an XMLHttpRequest object
    * @return {any} The XMLHttpRequest instance
    */
export function createTransport(): any;
/**
    * Possible XMLHttpRequest call methods
    * @type {enum}
    */
export enum EXMLHttpRequestMethod {
        GET = 0,
        POST = 1,
        PUT = 2,
        DELETE = 3,
        PATCH = 4,
}
/**
    * These are all the parameters that can be provided for an XMLHttpRequest call
    * @type {interface}
    */
export interface IXMLHttpRequestParameters {
        method: EXMLHttpRequestMethod;
        url: string;
        contentType?: string;
        headers?: any;
        data?: any;
        username?: string;
        password?: string;
}
/**
    * Any response is returned along with its HTTP responseStatus code
    * @type {interface}
    */
export interface IXMLHttpRequestResponse {
        status: number;
        response: any;
        xhr: XMLHttpRequest;
}
/**
    * Provides a wrapper for an XMLHttpRequest call
    * @type {class}
    */
export class XHR {
        appendURL(url: string, parameters: any): string;
        /**
            * Sets the XMLHttpRequest timeout to another value then the default 30 seconds
            * @param  {number} timeout The new timeout value in milliseconds
            * @return {number}         A timeout in milliseconds
            */
        setTimeout(timeout: number): number;
        /**
            * Return the current XMLHttpRequest timeout value
            * @return {number} A timeout in milliseconds
            */
        getTimeout(): number;
        /**
            * Performs an XMLHttpRequest call
            * @param  {IXMLHttpRequestParameters}  params  The call parameters
            * @return {Promise<IXMLHttpRequestResponse>} A promise that will resolve or reject depending on the call response
            */
        call(params: IXMLHttpRequestParameters): Promise<IXMLHttpRequestResponse>;
}

/**
    * Any response is returned along with its HTTP responseStatus code
    * @type {interface}
    */
export interface IEVAServiceResponse<REQ, RES> {
        request: REQ;
        response: RES;
        status: number;
        xhr: XMLHttpRequest;
}
/**
    * Wrapper class for a call to the EVA back-end
    * Ensure all proper settings are applied and handles all the type casting of
    * request and response for the XMLHttpRequest calls
    * @type {class}
    */
export class EVAService<REQ, RES> {
        /**
            * Constructor for the EVAService class
            * @param  {string} name    The name of the EVA service to call
            * @return {void}           This method returns nothing
            */
        constructor(name: string, path?: string, method?: EXMLHttpRequestMethod);
        /**
            * Convenience method to get the current session ID
            * @return {string} The current sessionID
            */
        getSessionID(): string;
        /**
            * Performs the actual call to the backend
            * @param  {REQ}        requestData The data to be sent as the body for this call
            * @return {Promise}                Return a promise that will resolve with the call response
            */
        call(requestData?: REQ, disableCache?: boolean, timeout?: number): Promise<IEVAServiceResponse<REQ, RES>>;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to an order available in EVA
    */
export class Application extends FetchableItem<EVA.Core.Services.ApplicationDto, EVA.Core.Services.GetCurrentApplication, EVA.Core.Services.GetCurrentApplicationResponse> {
        enabledPlugins: any;
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetCurrentApplication, EVA.Core.Services.GetCurrentApplicationResponse>>;
        setData(response: EVA.Core.Services.GetCurrentApplicationResponse): EVA.Core.Services.ApplicationDto;
        configuration(): Promise<IEVAServiceResponse<EVA.Core.Services.GetApplicationConfiguration, EVA.Core.Services.GetApplicationConfigurationResponse>>;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a babylon Brands (fashion) in EVA
    */
export class Brand extends FetchableItem<EVA.Core.Services.BrandDto, EVA.PIM.Core.GetBrand, EVA.PIM.Core.GetBrandResponse> {
        fetch(): Promise<IEVAServiceResponse<EVA.PIM.Core.GetBrand, EVA.PIM.Core.GetBrandResponse>>;
        create(name: string): Promise<IEVAServiceResponse<EVA.PIM.Core.GetBrand, EVA.PIM.Core.GetBrandResponse>>;
}
export class Brands extends FetchablePagedList<EVA.Core.Services.BrandDto, EVA.Core.Services.ListBrands, EVA.Core.Services.ListBrandsResponse> {
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES}        response    The response from the service call
            * @return {Array<T>}               The item details
            */
        setData(response: any): EVA.Core.Services.BrandDto[];
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.ListBrands, EVA.Core.Services.ListBrandsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListBrands, EVA.Core.Services.ListBrandsResponse>>;
}
export function searchBrands(query: string, pageSize?: number): Promise<IEVAServiceResponse<EVA.Core.Services.SearchBrands, EVA.Core.Services.SearchBrandsResponse>>;

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a babylon collections (fashion) in EVA
    */
export class Collection extends FetchableItem<EVA.Babylon.FashionCollectionDetail, EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse> {
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES} response The response from the service call
            * @return {T}            The item details
            */
        setData(response: any): EVA.Babylon.FashionCollectionDetail;
        create(collection: EVA.Babylon.CreateFashionCollectionRequestModel): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
        update(collectionDetailsToUpdate: EVA.Babylon.UpdateFashionCollection): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
        delete(): Promise<IEVAServiceResponse<EVA.Babylon.DeleteFashionCollection, EVA.Core.EmptyResponseMessage>>;
        addProducts(productIDs: Array<number>): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
        removeProduct(productID: number): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
        getProductDetails(productID: number): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionProductDetails, EVA.Babylon.GetFashionCollectionProductDetailsResponse>>;
        updateProductSequence(productID: number, sequence: number): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionProductDetails, EVA.Babylon.GetFashionCollectionProductDetailsResponse>>;
}
export class CollectionsEarnings extends FetchableItem<EVA.Babylon.FashionCollectionSummaryWithEarnings[], EVA.Babylon.GetFashionCoinEarningsForCollections, EVA.Babylon.GetFashionCoinEarningsForCollectionsResponse> {
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCoinEarningsForCollections, EVA.Babylon.GetFashionCoinEarningsForCollectionsResponse>>;
}
export class CollectionProducts extends FetchablePagedList<EVA.Babylon.FashionCollectionProductDetails, EVA.Babylon.ListProductsForCollection, EVA.Babylon.ListProductsForCollectionResponse> {
        /**
            * Sets the collection id to retrieve the product list for
            * @param  {number} collectionID        The collection identifier
            * @return {void}                       This method doesn't return anything
            */
        setCollectionID(collectionID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListProductsForCollection, EVA.Babylon.ListProductsForCollectionResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListProductsForCollection, EVA.Babylon.ListProductsForCollectionResponse>>;
}
export class CollectionCoverSheet extends FetchableItem<EVA.Babylon.CoverSheetDocument, EVA.Babylon.GetFashionCollectionCoverSheet, EVA.Babylon.GetFashionCollectionCoverSheetResponse> {
        /**
            * Sets the collection id to retrieve the cover sheet for
            * @param  {number} collectionID        The collection identifier
            * @return {void}                       This method doesn't return anything
            */
        setCollectionID(collectionID: number): void;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES} response The response from the service call
            * @return {T}            The item details
            */
        setData(response: any): EVA.Babylon.CoverSheetDocument;
        /**
            * Fetches the collection cover sheet
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionCoverSheet, EVA.Babylon.GetFashionCollectionCoverSheetResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionCoverSheet, EVA.Babylon.GetFashionCollectionCoverSheetResponse>>;
        update(coversheet: EVA.Babylon.CoverSheetDocument): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionCoverSheet, EVA.Babylon.GetFashionCollectionCoverSheetResponse>>;
        productSearch(query: string, pageSize?: number, page?: number, likedProductsPage?: number, createdProductsPage?: number): Promise<IEVAServiceResponse<EVA.Babylon.CoverSheetProductsSearch, EVA.Babylon.CoverSheetProductsSearchResponse>>;
}
export class Collections extends FetchablePagedList<EVA.Babylon.FashionCollectionDetail, EVA.Babylon.ListFashionCollectionsForUser, EVA.Babylon.ListFashionCollectionsForUserResponse> {
        /**
            * Sets the user id to retrieve the collection list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Sets the user id to retrieve the collection list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setCoverSheetFilter(enableFilter?: boolean): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForUser, EVA.Babylon.ListFashionCollectionsForUserResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForUser, EVA.Babylon.ListFashionCollectionsForUserResponse>>;
}
export class TrendingCollections extends FetchablePagedList<EVA.Babylon.FashionCollectionSummary, EVA.Babylon.ListTrendingFashionCollections, EVA.Babylon.ListTrendingFashionCollectionsResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListTrendingFashionCollections, EVA.Babylon.ListTrendingFashionCollectionsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListTrendingFashionCollections, EVA.Babylon.ListTrendingFashionCollectionsResponse>>;
}
export class TopFashionCollections extends FetchablePagedList<EVA.Babylon.FashionCollectionSummary, EVA.Babylon.GetTopFashionCollections, EVA.Babylon.GetTopFashionCollectionsResponse> {
        /**
            * Sets the user id to retrieve the collection list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Sets creation time to filter on
            * @param  {Date} time    The creation time to filter on
            * @return {void}         This method doesn't return anything
            */
        setCreationTime(time: Date): void;
        /**
            * Sets top count to filter on
            * @param  {number} count  The top count to filter on
            * @return {void}          This method doesn't return anything
            */
        setTopCount(count: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.GetTopFashionCollections, EVA.Babylon.GetTopFashionCollectionsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetTopFashionCollections, EVA.Babylon.GetTopFashionCollectionsResponse>>;
}
export class ProductCollections extends FetchablePagedList<EVA.Babylon.FashionCollectionDetail, EVA.Babylon.ListFashionCollectionsForProduct, EVA.Babylon.ListFashionCollectionsForProductResponse> {
        /**
            * Sets the user id to retrieve the collection list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Sets the user id to retrieve the collection list for
            * @param  {number} productID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setProductID(productID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForProduct, EVA.Babylon.ListFashionCollectionsForProductResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForProduct, EVA.Babylon.ListFashionCollectionsForProductResponse>>;
}

export namespace DocumentSigning {
    function getSigningCodeForOrder(orderId: number): Promise<IEVAServiceResponse<EVA.DocumentSigning.GetSigningCodeForOrder, EVA.DocumentSigning.GetSigningCodeForOrderResponse>>;
    function getSigningDataForOrder(hashId: string): Promise<IEVAServiceResponse<EVA.DocumentSigning.GetSigningDataForOrder, EVA.DocumentSigning.GetSigningDataForOrderResponse>>;
    function signOrder(signature: number[], mimeType: string, hashId: string): Promise<IEVAServiceResponse<EVA.DocumentSigning.SignOrder, EVA.Core.RequestMessageWithEmptyResponse>>;
}

export interface IEVALoginOptions {
        organizationUnitId?: number;
        confirmationToken?: string;
        identificationCode?: string;
        selectOrganizationByApplicationID?: boolean;
        publicLogin?: boolean;
        registerApiKey?: boolean;
        context?: string;
}
export interface IEVACreateCustomer {
        noAccount?: boolean;
        autoLogin?: boolean;
}
/**
    * General namespace for Users function
    */
export namespace Users {
        /**
            * Request a token (via e-mail) for a user
            *
            * @param  {string}  emailAddress the e-mail adres of the user to request the token for
            * @return {Promise}              A promise that is fulfilled when the EVA Core service responds
            */
        function requestResetPassword(emailAddress: string): Promise<IEVAServiceResponse<EVA.Core.Services.RequestPasswordResetToken, EVA.Core.EmptyResponseMessage>>;
        /**
            * Reset a user password using a token that was received in an e-mail
            *
            * @param  {string}  newPassword the new password
            * @param  {string}  token       the token to be used for this reset
            * @return {Promise}             A promise that is fulfilled when the EVA Core service responds
            */
        function resetPassword(newPassword: string, token: string): Promise<IEVAServiceResponse<EVA.Core.Services.ResetUserPassword, EVA.Core.Services.ResetUserPasswordResponse>>;
}
/**
    * Provides authentication to EVA
    *
    * id is authentication
    */
export class LoggedInUser extends FetchableItem<EVA.Core.LoggedInUserDto, EVA.Core.Services.GetCurrentUser, EVA.Core.Services.GetCurrentUserResponse> {
        orders: CustomerOrderList;
        authentication: number;
        organisationUnits: Array<EVA.Core.OrganizationUnitDto>;
        isAnonymous: boolean;
        isEmployee: boolean;
        isCustomer: boolean;
        static checkEmailAddressAvailability(emailAddress: string): Promise<any>;
        static checkNicknameAvailability(nickname: string): Promise<any>;
        /**
            * Register a new customer and autologin
            *
            * @param  {any}            customer EVA.Core.Services.CustomerDto but only EmailAddress
            * @return {Promise<any>}   A promise that is fulfilled when the EVA Core service responds
            */
        static register(customer: any, autoLogin?: boolean, noAccount?: boolean): Promise<any>;
        /**
            * Register a new customer with company
            *
            * @param  {EVA.Core.Services.CreateCustomerWithCompany} request    Create a customer with company request
            * @return {Promise<any>}                                           A promise that is fulfilled when the EVA Core service responds
            */
        static registerWithCompany(request: EVA.Core.Services.CreateCustomerWithCompany): Promise<boolean>;
        /**
            * Retrieve the company details for a user
            * @return {Promise<EVA.Core.CompanyDto>}
            */
        static getCompanyForUser(userId: number): Promise<EVA.Core.CompanyDto>;
        /**
            * Method to update a company that belongs to the logged-in user
            *
            * @param {EVA.Core.CompanyDto} company The company to update
            * @returns {Promise<boolean>} Promise that returns true if update was successful
            */
        static updateCompanyForUser(userId: number, company: EVA.Core.CompanyDto): Promise<boolean>;
        /**
            * Search for customers
            *
            * @param  {string}           query           The query to search on
            * @param  {number}           limit           The page size limit. Defaults to 15
            * @param  {number}           start           The item to start the list at. Defaults to 0 and is a 0-based index.
            * @return {Promise<any>}                     A promise that is fulfilled when the EVA Core service responds
            */
        static searchUsers(query: string, limit?: number, start?: number): Promise<any>;
        /**
            * Retrieves and updates current user data
            * @return {Promise} A promise that is fulfilled when the EVA Core service responds
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetCurrentUser, EVA.Core.Services.GetCurrentUserResponse>>;
        /**
            * @param  {any}                                  response Provide with body of the response to populate and set properly the data on CurrentUser
            * @return {EVA.Core.LoggedInUserDto}          The current LoggedInUserDto state
            */
        setData(response?: any): EVA.Core.LoggedInUserDto;
        /**
            * Return the current authentication token
            * @return {string} The current authentication token
            */
        getAuthenticationToken(): string;
        /**
            * Perform a login using email adress and password, and optional additional
            * data
            *
            * @param  {string}  login        The email address or username (nickname) to login with
            * @param  {string}  password     The password over the login
            * @param  {IEVALoginOptions?} options An optional structure with additional data for the login
            * @return {Promise}              Will resolve when succesfully logged in or rejected with the authentication result (EVA.Core.AuthenticationResults) or a general error
            */
        login(login: string, password: string, options?: IEVALoginOptions): Promise<IEVAServiceResponse<EVA.Core.Services.Login, EVA.Core.Services.LoginResponse>>;
        /**
            * Execute an explicit logout
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        logout(): Promise<IEVAServiceResponse<EVA.Core.Services.Logout, EVA.Core.Services.LogoutResponse>>;
        /**
            * Retrieves third party login options
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        getThirdPartyLoginOptions(): Promise<IEVAServiceResponse<EVA.Core.Services.GetAvailableThirdPartiesForLogin, EVA.Core.Services.GetAvailableThirdPartiesForLoginResponse>>;
        /**
            * Requests third party login.
            * Response will contain a redirect url that can be used to perform the login
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        requestThirdPartyLogin(loginRequest: EVA.Core.Services.RequestThirdPartyLogin): Promise<IEVAServiceResponse<EVA.Core.Services.RequestThirdPartyLogin, EVA.Core.Services.RequestThirdPartyLoginResponse>>;
        /**
            * Perform third party login with a token
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        authenticateWithThirdPartyLogin(loginRequest: EVA.Core.Services.AuthenticateWithThirdPartyLogin): Promise<IEVAServiceResponse<EVA.Core.Services.AuthenticateWithThirdPartyLogin, EVA.Core.Services.AuthenticateWithThirdPartyLoginResponse>>;
        /**
            * This call retrieves a paged list of orders belonging to the current user
            *
            * @param  {number}                         start           The item to start the list at. Defaults to 0 and is a 0-based index.
            * @param  {number}                         limit           The page size limit. Defaults to 15
            * @param  {EVA.Core.SortDirection}  sortDirection          The sorting direction for the list. Defaults to ascending
            * @return {Promise<customerOrderList>}                     A promise resolving when the call to the back-end has completed
            */
        getOrders(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection): Promise<CustomerOrderList>;
        /**
            * This call retrieves a single order
            * @param {number}              order_id                    The ID of the order
            * @param {boolean}             include_failed_payements    If set to true, return order even if the payment has not been completed
            * @return {Promies<Order>}                                 A promise resolving when the call to the back-end has completed
            */
        getOrder(order_id: number, include_failed_payements: boolean): Promise<Order>;
        /**
            * Checks if the user has a newsletter subscription
            * @return {boolean} Indicates if the user has a newsletter subscription
            */
        hasNewsletterSubscription(): boolean;
        /**
            * Subscribes to the Newsletter using the users current email address
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        subscribeToNewsletter(): Promise<IEVAServiceResponse<EVA.Core.Services.Subscribe, EVA.Core.Services.SubscribeResponse>>;
        /**
            * Unsubscribes from the Newsletter using the users current email address
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        unsubscribeFromNewsletter(): Promise<IEVAServiceResponse<EVA.Core.Services.Unsubscribe, EVA.Core.Services.UnsubscribeResponse>>;
        /**
            * Confirms a Newsletter subscription using the provided token
            * @param  {string}     token   The subscription confirmation token
            * @return {Promise}            A promise resolving when the call to the back-end has completed
            */
        confirmNewsletterSubscription(token: string): Promise<IEVAServiceResponse<EVA.Core.Services.ConfirmSubscribe, EVA.Core.Services.ConfirmSubscribeResponse>>;
        /**
            * Checks if the user has an SMS notification subscription
            * @return {boolean} Indicates if the user has an SMS notification subscription
            */
        hasSmsNotificationSubscription(): boolean;
        /**
            * Subscribes to the SMS Notifications using the users current email address
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        subscribeToSMSNotifications(): Promise<IEVAServiceResponse<EVA.Core.Services.Subscribe, EVA.Core.Services.SubscribeResponse>>;
        /**
            * Unsubscribes from the SMS Notifications using the users current email address
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        unsubscribeFromSMSNotifications(): Promise<IEVAServiceResponse<EVA.Core.Services.Unsubscribe, EVA.Core.Services.UnsubscribeResponse>>;
        /**
            * Update the user
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        update(): Promise<IEVAServiceResponse<EVA.Core.Services.UpdateUser, EVA.Core.Services.UpdateUserResponse>>;
        /**
            * Update the user's email address
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        updateUserEmailAddress(newEmailAddress: string): Promise<IEVAServiceResponse<EVA.Core.Services.UpdateUserEmailAddress, EVA.Core.RequestMessageWithEmptyResponse>>;
        /**
            * Change the passowrd of this user
            *
            * @param  {string}  newPassword The new password
            * @param  {string}  oldPassword The current / old password
            * @return {Promise}             A promise resolving when the call to the back-end has completed
            */
        changePassword(newPassword: string, oldPassword: string): Promise<IEVAServiceResponse<EVA.Core.Services.ChangeUserPassword, EVA.Core.Services.ChangeUserPasswordResponse>>;
}
export class User extends FetchableItem<EVA.Core.UserDto, EVA.Core.Services.GetUser, EVA.Core.Services.GetUserResponse> {
        isAnonymous: boolean;
        isEmployee: boolean;
        isCustomer: boolean;
        /**
            * Retrieves specific user data
            * @return {Promise} A promise that is fulfilled when the EVA Core service responds
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetUser, EVA.Core.Services.GetUserResponse>>;
        /**
            * @param  {any}                                  response  Service response containing the user data
            * @return {EVA.Core.UserDto}                   The user data
            */
        setData(response?: any): EVA.Core.UserDto;
}

/**
    * The orders module provides access to the order data from the EVA back-end
    * @preferred
    */
export interface IEVAProduceInvoiceOptions {
        downloadInvoice?: boolean;
        emailAddress?: string;
        invoiceId?: number;
        printInvoice?: boolean;
        remark?: string;
        stationId?: string;
}
export interface IEVAProduceDocumentsOptions {
        printInvoice?: boolean;
        emailInvoice?: boolean;
        printReceipt?: boolean;
        stationId?: number;
        orderID?: number;
        emailAddress?: string;
        remark?: string;
}
/**
    * Provides access to an order available in EVA
    */
export class Order extends FetchableItem<EVA.Core.OrderDto, EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse> {
        /**
            * The payment options for the order
            * @type {Payment}
            */
        payment: Payments;
        /**
            * This class wraps an order from EVA and the operations you can perform on it.
            * You should supply the order identifier when creating an instance of this class
            *
            * @param  {number | string}    id      The identifier of the order to retrieve
            * @return {void}                       This method doesn't return anything
            */
        constructor(id?: number | string);
        /**
            * Returns if the order state 'completed' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isCompleted(): boolean;
        /**
            * Returns if the order state 'shipped' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isShipped(): boolean;
        /**
            * Returns if the order state 'paid' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isPaid(): boolean;
        /**
            * Returns if the order state 'invoiced' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isInvoiced(): boolean;
        /**
            * Returns if the order state 'cancelled' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isCancelled(): boolean;
        /**
            * Returns the current open amount still to be paid for the order
            * @return {number}
            */
        getOpenAmount(): number;
        /**
            * Returns the total value of all the items in the order with VAT
            * @return {number} The value of the items in the order with VAT
            */
        getTotalAmountInTax(): number;
        /**
            * Return order lines by type
            * @return {Array<EVA.Core.OrderLineDto>} Array of order lines
            */
        getOrderLinesByType(orderLineType: number | EVA.Core.OrderLineTypes): Array<EVA.Core.OrderLineDto>;
        /**
            * Return the total amount of shipping costs
            * @return {number} The total value of the shipping costs
            */
        getTotalShippingAmount(inTax?: boolean): number;
        /**
            * Return the total amount of ShippingCosts
            * @return {number} The total value of the shipping costs
            */
        getTotalDiscountAmount(inTax?: boolean): number;
        /**
            * Returns the current order requirement validation data
            * @return {EVA.Core.Validation.RequiredData} The order requirement validation data
            */
        getRequirements(): EVA.Core.RequiredData;
        /**
            * Checks if there are any invalid requirements in the current order requirement validation data
            * @return {boolean} Indicates if the order requirements are all met or not
            */
        isValid(): boolean;
        /**
            * Fetches and updates the order requirement validation data
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetRequiredDataForOrder, EVA.Core.Services.GetRequiredDataForOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        validate(requiredFor?: number, storeRequirements?: boolean): Promise<IEVAServiceResponse<EVA.Core.Services.GetRequiredDataForOrder, EVA.Core.Services.GetRequiredDataForOrderResponse>>;
        /**
            * Returns the list of different organizations where orderline items are te be picked up
            * @return {number} The list of organizations
            */
        readonly stockOrganizationUnits: Array<any>;
        /**
            * Returns the list of different organizations where orderline items are te be picked up
            * @return {number} The list of organizations
            */
        readonly requestedDates: Array<any>;
        /**
            * Fetches the order details
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {EVA.Core.Services.GetOrderResponse}  response    The response from the service call
            * @return {EVA.Core.OrderDto}              The order details
            */
        setData(response: any): EVA.Core.OrderDto;
        /**
            * Attaches a customer to the order
            * @param  {LoggedInUser}       customer       The current user class that is to be set as the customer for the order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setCustomer(customer: LoggedInUser | User): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Sets the currency for the order
            * @param  {string}       currencyID       The identifier of the currency
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setCurrency(currencyID: string): Promise<{}>;
        /**
            * Attaches a customer to the order
            * @param  {LoggedInUser}       customer       The current user class that is to be set as the customer for the order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setPickupOrganizationUnit(organizationUnitID: number): Promise<IEVAServiceResponse<EVA.Core.Services.SetPickupOrganizationUnit, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Places the order. It's usually wise to call validate(...) before trying to place an order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.PlaceOrder, EVA.Core.Services.PlaceOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        placeOrder(): Promise<IEVAServiceResponse<EVA.Core.Services.PlaceOrder, EVA.Core.Services.PlaceOrderResponse>>;
        produceInvoice(options: IEVAProduceInvoiceOptions): Promise<IEVAServiceResponse<EVA.Core.Services.ProduceInvoice, EVA.Core.ResourceResponseMessage>>;
        produceDocuments(options: IEVAProduceDocumentsOptions): Promise<IEVAServiceResponse<EVA.Core.Services.ProduceDocuments, EVA.Core.Services.ProduceDocumentsResponse>>;
        /**
            * Get the download url for this order
            *
            * @return {Promise<string>} The URL to the download of this order
            */
        getDownloadUrl(): Promise<string>;
        getReturnableStatusForOrder(): Promise<IEVAServiceResponse<EVA.Core.Services.GetReturnableStatusForOrder, EVA.Core.Services.GetReturnableStatusForOrderResponse>>;
        getReturnOrdersForOrder(): Promise<IEVAServiceResponse<EVA.CRM.Core.GetReturnOrdersForOrder, EVA.CRM.Core.GetReturnOrdersForOrderResponse>>;
        createCustomerReturn(lines: Array<EVA.CRM.Core.CustomerReturnLine>): Promise<IEVAServiceResponse<EVA.CRM.Core.CreateCustomerReturn, EVA.Core.EmptyResponseMessage>>;
        /**
            * For B2B orders
            *
            * Fetches the order view details
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetConfigurableOrderView, EVA.Core.Services.GetConfigurableOrderViewResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetchOrderView(logicalLevel?: string, groupByProperty?: string): Promise<IEVAServiceResponse<EVA.Core.Services.GetConfigurableOrderView, EVA.Core.Services.GetConfigurableOrderViewResponse>>;
        /**
            * Set the order reference
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.SetCustomerReferenceOnOrder, EVA.Core.EmptyResponseMessage>>} A promise resolving when the fetch from the back-end has completed
            */
        setOrderReference(reference: string): Promise<IEVAServiceResponse<EVA.Core.Services.SetCustomerReferenceOnOrder, EVA.Core.EmptyResponseMessage>>;
        /**
            * Set the shopping basket to an existing order. Removes any existing items in the shopping cart
            * @param  {number|Order}       order       Either an order id or an order class to set as the shopping cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        attach(order: number | Order): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Clears the entire shopping basket
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the call to the back-end has completed
            */
        detach(): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Set the order reference
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.ListOrderLines, EVA.Core.Services.ListOrderLinesResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        listOrderLines(orderLineIds?: number[], start?: number, limit?: number): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrderLines, EVA.Core.Services.ListOrderLinesResponse>>;
        /**
            * Update customer address data for this order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.ListOrderLines, EVA.Core.Services.ListOrderLinesResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        copyAddressesFromCustomer(): Promise<IEVAServiceResponse<EVA.Core.Services.UpdateOrderAddresses, EVA.Core.Services.UpdateOrderAddressesResponse>>;
        /**
            * Provides access to a list of shipments for this order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.ListOrderShipments, EVA.Core.Services.ListOrderShipmentsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        listShipments(): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrderShipments, EVA.Core.Services.ListOrderShipmentsResponse>>;
        /**
            * Provides access to a list of blobs for this order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.ListBlobsForOrder, EVA.Core.Services.ListBlobsForOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        listBlobs(): Promise<IEVAServiceResponse<EVA.Core.Services.ListBlobsForOrder, EVA.Core.Services.ListBlobsForOrderResponse>>;
        /**
            * Set the billing address of the order using an AddressBook item
            *
            * @param {number} addressBookId The ID of the AddressBook item
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setBillingAddressFromAddressBook(addressBookId: number): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Set the billing address of the order using an raw address
            *
            * @param {number} address The address to set as billing address on the order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setBillingAddress(address: EVA.Core.AddressDto): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Set the shipping address of the order using an AddressBook item
            *
            * @param {number} addressBookId The ID of the AddressBook item
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the call to the back-end has completed
            */
        setShippingAddressFromAddressBook(addressBookId: number): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Set the shipping address of the order using an raw address
            *
            * @param {number} address The address to set as shipping address on the order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setShippingAddress(address: EVA.Core.AddressDto): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Sets a custom order data field
            *
            * @param {string} key The field name
            * @param {string} value The value (serialized string)
            * @returns {Promise<IEVAServiceResponse<EVA.Core.Services.SetCustomOrderData, EVA.Core.EmptyResponseMessage>>}
            * @memberof Order
            */
        setCustomOrderData(key: string, value: string): Promise<IEVAServiceResponse<EVA.Core.Services.SetCustomOrderData, EVA.Core.EmptyResponseMessage>>;
        getCustomOrderData(key: string): Promise<IEVAServiceResponse<EVA.Core.Services.GetCustomOrderData, EVA.Core.Services.GetCustomOrderDataResponse>>;
}
/**
    * Provides access to a list of customer orders available in EVA
    */
export class CustomerOrderList extends FetchablePagedList<Order, EVA.Core.Services.ListOrdersForCustomer, EVA.Core.Services.ListOrdersForCustomerResponse> {
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES} response The response from the service call
            * @return {T}            The item details
            */
        setData(response: any): Order[];
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Core.OrderDto, EVA.Core.Services.ListOrdersForCustomer, EVA.Core.Services.ListOrdersForCustomerResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrdersForCustomer, EVA.Core.Services.ListOrdersForCustomerResponse>>;
}
/**
    * Provides access to a list of customer orders available in EVA
    */
export class SearchOrderList extends FetchablePagedList<EVA.Core.OrderSearchResultItem, EVA.Core.Services.SearchOrders, EVA.Core.Services.SearchOrdersResponse> {
        /**
            * Returns the current query string
            * @return {string}       The configured query string
            */
        getQuery(): string;
        /**
            * Set the organization id to search for
            * @param  {number} query The organization id
            * @return {number}       The configured organization id
            */
        setOrganizationID(id: number): number;
        /**
            * Returns the current organization id
            * @return {number}       The configured organization id
            */
        getOrganizationID(): number;
        /**
            * Set the query to search for
            * @param  {string} query The new query string
            * @return {string}       The configured query string
            */
        setQuery(query: string): string;
        /**
            * Returns the current list of order ids
            * @return {Array<number>} The configured list of order ids
            */
        getOrderIDs(): Array<number>;
        /**
            * Adds an order ID to the list of orders to retrieve
            * @return {Array<number>} The configured list of order ids
            */
        addOrderID(id: number): Array<number>;
        /**
            * Adds an order ID to the list of orders to retrieve
            * @return {Array<number>} The configured list of order ids
            */
        setOrderIDs(ids: number[]): Array<number>;
        /**
            * Clears the configured list of order ids
            * @return {Array<number>} The configured list of order ids
            */
        clearOrderIDs(): Array<number>;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.SearchOrders, EVA.Core.Services.SearchOrdersResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.SearchOrders, EVA.Core.Services.SearchOrdersResponse>>;
}
/**
    * Provides access to a list of customer orders available in EVA
    */
export class OrdersWithReferenceList extends FetchablePagedList<EVA.Core.OrderWithReference, EVA.Core.Services.ListOrdersWithReference, EVA.Core.Services.ListOrdersWithReferenceResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Core.OrderDto, EVA.Core.Services.ListOrdersWithReference, EVA.Core.Services.ListOrdersWithReferenceResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrdersWithReference, EVA.Core.Services.ListOrdersWithReferenceResponse>>;
}

/**
    * The shopping cart module provides access to shopping cart data from the EVA back-end
    * Note that the shopping cart is bound to the current session so there is only 1 of them
    * You can regard it as the active order
    * @preferred
    */
/**
    * Provides access to the shopping cart available in EVA
    */
export class ShoppingCart extends FetchableItem<EVA.Core.OrderDto, EVA.Core.Services.GetShoppingCart, EVA.Core.ShoppingCartResponse> {
        /**
            * The payment options for the order
            * @type {Payment}
            */
        payment: Payments;
        /**
            * Indicates the order/cart is a pickup order (for a single shop)
            * @type {boolean}
            */
        isPickupOrder: boolean;
        /**
            * This class wraps the current shopping cart from EVA and the operations you can perform on it.
            *
            * @return {void} This method doesn't return anything
            */
        constructor();
        /**
            * Returns if the order state 'completed' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isCompleted(): boolean;
        /**
            * Returns if the order state 'shipped' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isShipped(): boolean;
        /**
            * Returns if the order state 'paid' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isPaid(): boolean;
        /**
            * Returns if the order state 'invoiced' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isInvoiced(): boolean;
        /**
            * Returns if the order state 'cancelled' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isCancelled(): boolean;
        /**
            * Returns the current open amount still to be paid for the shopping cart
            * @return {number}
            */
        getOpenAmount(): number;
        /**
            * Returns the total value of all the items in the shopping cart with VAT
            * @return {number} The value of the items in the shopping cart with VAT
            */
        getTotalAmountInTax(): number;
        /**
            * Returns the total value of all the items in the shopping cart without VAT
            * @return {number} The value of the items in the shopping cart without VAT
            */
        getTotalAmount(): number;
        /**
            * Return order lines by type
            * @return {Array<EVA.Core.OrderLineDto>} Array of order lines
            */
        getOrderLinesByType(orderLineType: number | EVA.Core.OrderLineTypes): Array<EVA.Core.OrderLineDto>;
        /**
            * Return the total amount of shipping costs
            * @return {number} The total value of the shipping costs
            */
        getTotalShippingAmount(inTax?: boolean): number;
        /**
            * Return the total amount of ShippingCosts
            * @return {number} The total value of the shipping costs
            */
        getTotalDiscountAmount(inTax?: boolean): number;
        /**
            * Returns the list of different organizations where orderline items are te be picked up
            * @return {number} The list of organizations
            */
        readonly stockOrganizationUnits: Array<any>;
        /**
            * Returns the list of different organizations where orderline items are te be picked up
            * @return {number} The list of organizations
            */
        readonly requestedDates: Array<any>;
        /**
            * Returns the discount invalid reasons
            * @return {number}
            */
        getMessages(): EVA.Core.DiscountInvalidReasons[];
        /**
            * Fetches the shopping cart details
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCart, EVA.Core.ShoppingCartResponse>>} A promise resolving when the call to the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCart, EVA.Core.ShoppingCartResponse>>;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {EVA.Core.ShoppingCartResponse}  response    The response from the service call
            * @return {EVA.Core.OrderDto}              The order details
            */
        setData(response: any): EVA.Core.OrderDto;
        /**
            * Adds a product to the shopping cart
            * @param  {number|Product}                 product         Either a product id or a product class to add to the shopping cart
            * @param  {number}                         quantity        Quantity to add
            * @param  {EVA.Core.LineActionTypes}       lineActionType  Line action type. Default is 4 (delivery), 1 is for reservation
            * @return {Promise}                                        A promise resolving when the call to the back-end has completed
            */
        addProduct(product: number | Product, quantity?: number, lineActionType?: EVA.Core.LineActionTypes): Promise<IEVAServiceResponse<EVA.Core.Services.AddProductToOrder, EVA.Core.Services.AddProductToOrderResponse>>;
        /**
            * Changes an order line to a stock reservation
            * @param  {number}     orderLineId     The order line id that contains the product(s) that is/are to be reserverd
            * @param  {number}     organizationID  The shop to reserve the product at
            * @return {Promise}                    A promise resolving when the call to the back-end has completed
            */
        reserveOrderLine(orderLineId: number, organizationID: number): Promise<{}>;
        /**
            * Changes an order line to be shipped
            * @param  {number}     orderLineId     The order line id that contains the product(s) that is/are to be reserverd
            * @return {Promise}                    A promise resolving when the call to the back-end has completed
            */
        shipOrderLine(orderLineId: number): Promise<{}>;
        /**
            * Changes an order line to be delivered
            * @param  {number}     orderLineId     The order line id that contains the product(s) that is/are to be reserverd
            * @return {Promise}                    A promise resolving when the call to the back-end has completed
            */
        deliverOrderLine(orderLineId: number): Promise<{}>;
        /**
            * Removes order lines from the shopping cart
            * @param  {number|Array<number>}       orderLineId     The identifier or array of identifiers of the order line(s) to remove from the shopping cart
            * @return {Promise}                                    A promise resolving when the call to the back-end has completed
            */
        cancelOrderLine(orderLineId: number | Array<number>): Promise<IEVAServiceResponse<EVA.Core.Services.CancelOrderLine, EVA.Core.Services.CancelOrderLineResponse>>;
        /**
            * Convenience methods to remove all instances of a product from the shopping  This is the more direct mirror call of addProduct
            * @param  {number|Product}     product     Either a product id or a product class to remove from the shopping cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        removeProduct(product: number | Product): Promise<IEVAServiceResponse<EVA.Core.Services.CancelOrderLine, EVA.Core.ShoppingCartResponse>>;
        /**
            * Modify the number of items for an order line
            * @param  {number}         orderLineId     The identifier of the order line to modify from the shopping cart
            * @param  {number}         quantity        The new quantity
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        modifyQuantity(orderLineId: number, quantity: number): Promise<IEVAServiceResponse<EVA.Core.Services.ModifyQuantityOrdered, EVA.Core.ShoppingCartResponse>>;
        /**
            * Clears the entire shopping basket
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCart, EVA.Core.ShoppingCartResponse>>} A promise resolving when the call to the back-end has completed
            */
        empty(): Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCart, EVA.Core.ShoppingCartResponse>>;
        /**
            * List the available shipping methods for the current cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        listShippingMethods(orderId: number, orderlineIds: Array<number>): Promise<IEVAServiceResponse<EVA.Core.Services.ListAvailableShippingMethods, EVA.Core.Services.ListAvailableShippingMethodsResponse>>;
        /**
            * Gets the shipping methods currently set to the cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        getShippingMethods(orderId: number): Promise<IEVAServiceResponse<EVA.Core.Services.GetShippingMethodsForOrder, EVA.Core.Services.GetShippingMethodsForOrderResponse>>;
        /**
            * Gets the available shipping dates of a shipping method
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        getShippingDates(): Promise<IEVAServiceResponse<EVA.Core.Services.ListAvailableShippingDates, EVA.Core.Services.ListAvailableShippingDatesResponse>>;
        /**
            * Sets the pickup organiszation unit to the cart.
            * We don't know the orderId, but the session Id will do the trick
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        setPickupOrganizationUnit(organizationUnitID: number): Promise<IEVAServiceResponse<EVA.Core.Services.SetPickupOrganizationUnit, EVA.Core.ShoppingCartResponse>>;
        /**
            * Gets the shipping methods currently set to the cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        setShippingMethod(orderId: number, orderLineId: number, shippingMethodId: number, requestDeliveryDate: Date): Promise<IEVAServiceResponse<EVA.Core.Services.SetShippingMethod, EVA.Core.ShoppingCartResponse>>;
        /**
            * Modify the number of items for an order line
            * @param  {string}         couponCode      The coupon code that needs to be added to the cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        addCouponCode(couponCode: string): Promise<IEVAServiceResponse<EVA.Core.Services.AddDiscountToOrder, EVA.Core.ShoppingCartResponse>>;
        /**
            * Retrieves the shopping cart summary information
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCartInfo, EVA.Core.Services.ShoppingCartInfoResponse>>} A promise resolving when the call to the back-end has completed
            */
        getInfo(): Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCartInfo, EVA.Core.Services.GetShoppingCartInfoResponse>>;
        /**
            * Attaches a customer to the shopping cart
            * @param  {LoggedInUser}       customer       The current user class that is to be set as the customer for the shopping cart
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setCustomer(customer: LoggedInUser | User): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Places an order for the current shopping cart contents
            * @return {Promise<Order>} A promise resolving when the call to the back-end has completed
            */
        createOrder(): Promise<Order>;
        /**
            * Set the shopping basket to an existing order. Removes any existing items in the shopping cart
            * @param  {number|Order}       order       Either an order id or an order class to set as the shopping cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        setFromOrder(order: number | Order): Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCart, EVA.Core.ShoppingCartResponse>>;
        /**
            * Attaches a fashion collection to an order line
            * @param  {number}         orderLineId     The identifier of the order line to modify from the shopping cart
            * @param  {number}         collectionId    The fashion collection identifier
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        setFashionCollectionOriginForOrderLine(orderLineID: number, collectionID: number): Promise<{}>;
}

export namespace products {
        function getProductPrices(productIds: number[]): Promise<IEVAServiceResponse<EVA.Core.Services.GetProductPrices, EVA.Core.Services.GetProductPricesResponse>>;
        function getConfigurableProductsDetails(productIds: number[], includes?: string[]): Promise<IEVAServiceResponse<EVA.Core.Services.GetConfigurableProductsDetail, EVA.Core.Services.GetConfigurableProductsDetailResponse>>;
        function getProductsDetails(productIds: number[], pageConfig?: EVA.Core.PageConfig, additionalFilters?: any): Promise<IEVAServiceResponse<EVA.Core.Services.SearchProducts, EVA.Core.Services.SearchProductsResponse>>;
}
/**
    * Provides access to a product available in EVA
    */
export class Product extends FetchableItem<EVA.Core.ProductDto, EVA.Core.Services.GetProductDetail, EVA.Core.Services.GetProductDetailResponse> {
        /**
            * Fetches the product details
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.Products.GetProductDetail, EVA.Core.Services.Products.GetProductDetailResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetProductDetail, EVA.Core.Services.GetProductDetailResponse>>;
        /**
            * Fetches the product configuration details
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetConfigurableProductDetail, EVA.Core.Services.GetConfigurableProductDetailResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        getConfigurationDetails(): Promise<IEVAServiceResponse<EVA.Core.Services.GetConfigurableProductDetail, EVA.Core.Services.GetConfigurableProductDetailResponse>>;
        /**
            * Retrieves the stock details for the product
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetStockDetailsForProduct, EVA.Core.Services.GetStockDetailsForProductResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        getStockDetails(): Promise<IEVAServiceResponse<EVA.Core.Services.GetStockDetailsForProduct, EVA.Core.Services.GetStockDetailsForProductResponse>>;
        /**
            * Retrieves the availability indication for the product
            * @param  {number}         quantityRequested           Quantity to check availability for. Defaults to 1
            * @param  {Array<number>}  organizationUnitIDs         An array of organisation id's to limit the availability check to
            * @param  {boolean}        fastestPickupShopOnly       Only return the fastest pickup option. Defaults to false
            * @param  {boolean}        includeAvailabilityTexts    Add availability text messages to the response. Defaults to false
            * @param  {boolean}        detailedShopInformation     Add detailed shop information to the response. Defaults to false
            * @return {Promise<Array<EVA.Core.ProductAvailabilityIndicationDto>>} A promise resolving when the fetch from the back-end has completed
            */
        getAvailability(quantityRequested?: number, organizationUnitIDs?: Array<number>, fastestPickupShopOnly?: boolean, includeAvailabilityTexts?: boolean, detailedShopInformation?: boolean): Promise<Array<EVA.Core.ProductAvailabilityIndication>>;
        /**
            * Retrieves the available variants (color, size, etc.) for a product
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.SearchProducts, EVA.Core.Services.SearchProductsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        getVariants(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string, additionalFilters?: any): Promise<IEVAServiceResponse<EVA.Core.Services.SearchProducts, EVA.Core.Services.SearchProductsResponse>>;
}
/**
    * Provides access to a fashion product available in EVA
    */
export class FashionProduct extends Product {
        /**
            * Convenience method to build a product image URL
            * @param  {number} productID   The product identifier
            * @param  {number} width       The output image width
            * @param  {number} height      The output image height
            * @param  {string} type        The image type (ie. png, jpg, etc)
            *
            * @return {string}             An image URL
            */
        static getProductImageUrl(productID: number, width?: number, height?: number, format?: string): string;
        create(product: EVA.Babylon.CreateFashionProduct): Promise<IEVAServiceResponse<EVA.Core.Services.GetProductDetail, EVA.Core.Services.GetProductDetailResponse>>;
        update(productDetailsToUpdate: EVA.Babylon.UpdateFashionProduct): Promise<IEVAServiceResponse<EVA.Core.Services.GetProductDetail, EVA.Core.Services.GetProductDetailResponse>>;
        delete(): Promise<IEVAServiceResponse<EVA.Babylon.DeleteFashionProduct, EVA.Core.EmptyResponseMessage>>;
        getCoverSheetImages(): Promise<IEVAServiceResponse<EVA.Babylon.GetProductImagesForCoverSheet, EVA.Babylon.GetProductImagesForCoverSheetResponse>>;
        getCreator(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionProductCreator, EVA.Babylon.GetFashionProductCreatorResponse>>;
        countCollections(): Promise<IEVAServiceResponse<EVA.Babylon.CountFashionCollectionsForProduct, EVA.Babylon.CountFashionCollectionsForProductResponse>>;
}
/**
    * Provides access to a list of products available in EVA
    */
export class ProductList extends FetchablePagedList<EVA.Core.ProductDto, EVA.Core.Services.SearchProducts, EVA.Core.Services.SearchProductsResponse> {
        /**
            * The return aggregations flag
            * @type {any}
            */
        includeAggregations: boolean;
        /**
            * The return suggestions flag
            * @type {any}
            */
        includeSuggestions: boolean;
        /**
            * Returns the current list of excluded fields
            * @return {Array<string>} The configured list of excluded product fields
            */
        getExcludedFields(): Array<string>;
        /**
            * Returns the current list of excluded fields
            * @return {Array<string>} The configured list of excluded product fields
            */
        addExcludedField(fieldName: string): Array<string>;
        /**
            * Clears the configured list of excluded fields
            * @return {Array<string>} The configured list of excluded product fields
            */
        clearExcludedFields(): Array<string>;
        /**
            * Sets the excluded fields option
            * @return {EVA.Core.ExcludedFieldOptions} The aggregation state
            */
        setExcludedFieldsOptions(option: EVA.Core.ExcludedFieldOptions): any;
        /**
            * Return the currently set excluded field option
            * @return {EVA.Core.ExcludedFieldOptions} The excluded field option value
            */
        getExcludedFieldsOption(): EVA.Core.ExcludedFieldOptions;
        /**
            * Returns the current list of included fields
            * @return {Array<string>} The configured list of included product fields
            */
        getIncludedFields(): Array<string>;
        /**
            * Returns the current list of included fields
            * @return {Array<string>} The configured list of included product fields
            */
        addIncludedField(fieldName: string): Array<string>;
        /**
            * Clears the configured list of included fields
            * @return {Array<string>} The configured list of included product fields
            */
        clearIncludedFields(): Array<string>;
        /**
            * Sets the aggregation state
            * @return {any} The aggregation state
            */
        setAggregationState(aggregationState: string): any;
        /**
            * Return the currently set aggregation state
            * @return {string} The aggregation state
            */
        getAggregationState(): string;
        /**
            * Sets the aggregation options
            * @return {any} The aggregation options
            */
        setAggregationOptions(aggregationOptions: any): any;
        /**
            * Return the currently set aggregation options
            * @return {any} The aggregation options
            */
        getAggregationOptions(): any;
        /**
            * Returns the current query string
            * @return {string}       The configured query string
            */
        getQuery(): string;
        /**
            * Set the query to search for
            * @param  {string} query The new query string
            * @return {string}       The configured query string
            */
        setQuery(query: string): string;
        /**
            * Return the aggregations that were returned with the product list
            * @return {any} The aggreations
            */
        getAggregations(): any;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {EVA.Core.Services.Products.SearchProductsResponse}  response    The response from the service call
            * @return {Array<EVA.Core.ProductDto>}                      The product items for the current page
            */
        setData(response: any): EVA.Core.ProductDto[];
        /**
            * Fetches the product list item details
            * @return {Promise<IEVAServiceResponse<EVA.Core.ProductDto, EVA.Core.Services.SearchProducts, EVA.Core.Services.SearchProductsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.SearchProducts, EVA.Core.Services.SearchProductsResponse>>;
}
/**
    * Provides access to a list of recently viewed (fashion) products available in EVA
    */
export class RecentlyViewedProductList extends FetchablePagedList<EVA.Babylon.RecentlyViewedProduct, EVA.Babylon.ListRecentlyViewedProducts, EVA.Babylon.ListRecentlyViewedProductsResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListRecentlyViewedProducts, EVA.Babylon.ListRecentlyViewedProductsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListRecentlyViewedProducts, EVA.Babylon.ListRecentlyViewedProductsResponse>>;
}
export function getFashionProductCategories(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionProductCategories, EVA.Babylon.GetFashionProductCategoriesResponse>>;

/**
    * The shops module provides access to the shops (organization unit type) data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a content page available in EVA
    */
export class Shop extends FetchableItem<EVA.Core.OrganizationUnitDto, EVA.Core.Services.GetOrganizationUnit, EVA.Core.Services.GetOrganizationUnitResponse> {
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrganizationUnit, EVA.Core.Services.GetOrganizationUnitResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrganizationUnit, EVA.Core.Services.GetOrganizationUnitResponse>>;
}
/**
    * Provides access to a list of shops available in EVA
    */
export class ShopList extends FetchablePagedList<EVA.Core.OrganizationUnitDto, EVA.Core.Services.ListOrganizationUnitsByType, EVA.Core.Services.ListOrganizationUnitsByTypeResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.CMS.Dto.OrganizationUnitDto, EVA.Core.Services.ListOrganizationUnitsByType, EVA.Core.Services.ListOrganizationUnitsByTypeResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrganizationUnitsByType, EVA.Core.Services.ListOrganizationUnitsByTypeResponse>>;
}
/**
    * Provides access to a list of shops available in EVA
    */
export class ShopProximityList extends FetchablePagedList<EVA.Core.OrganizationUnitDto, EVA.Core.Services.ListOrganizationUnitByProximity, EVA.Core.Services.ListOrganizationUnitByProximityResponse> {
        /**
            * Changes to list of shops returned to those in the closest proximity of the given location
            * @param  {number} lat The locations latitude
            * @param  {number} lng The locations longitude
            * @return {object}     The chosen location
            */
        setLocation(lat: number, lng: number): any;
        /**
            * Returns the currently chosen location to use for a proximity based shop list
            * @return {object} The currently chosen location
            */
        getLocation(): any;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.CMS.Dto.OrganizationUnitDto, EVA.Core.Services.ListOrganizationUnitByProximity, EVA.Core.Services.ListOrganizationUnitByProximityResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrganizationUnitByProximity, EVA.Core.Services.ListOrganizationUnitByProximityResponse>>;
}

export class SuggestionList extends FetchablePagedList<EVA.Core.SuggestionModel, EVA.Core.Services.GetProductSearchSuggestions, EVA.Core.Services.GetProductSearchSuggestionsResponse> {
    maxSuggestions: number;
    setQuery(query: string): string;
    setData(response: any): EVA.Core.SuggestionModel[];
    fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetProductSearchSuggestions, EVA.Core.Services.GetProductSearchSuggestionsResponse>>;
}

/**
    * The postnl module provides the means to retrieve and set a PostNL pickup location
    * @preferred
    */
export class PostNL {
        /**
            * [constructor description]
            * @param  {Order}  order The order to perform the payments for
            * @return {void}         This method doesn't return anything
            */
        constructor(order: Order | ShoppingCart);
        PostNLGetAvailablePickUpLocationsForArea(orderId: number, nw: EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaCoordinate, se: EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaCoordinate): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForArea, EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaResponse>>;
        PostNLGetAvailablePickUpLocationsForOrder(orderId: number): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForOrder, EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForOrderResponse>>;
        PostNLGetAvailableTimeframesForOrder(orderId: number, startDate: any, endDate: any): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLGetAvailableTimeframesForOrder, EVA.Carrier.PostNL.PostNLGetAvailableTimeframesForOrderResponse>>;
        PostNLGetShippingOptionsForOrder(orderId: number): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLGetShippingOptionsForOrder, EVA.Carrier.PostNL.PostNLGetShippingOptionsForOrderResponse>>;
        PostNLUpdateShippingOptionsForOrder(orderId: number, pickupLocationId: number, date?: Date, option?: EVA.Carrier.PostNL.TimeframeOptions): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLUpdateShippingOptionsForOrder, EVA.Core.EmptyResponseMessage>>;
}

/**
  * Provides access to a Rituals specific functions in EVA
  */
export namespace Rituals {
    function createCustomerReturn(orderID: number, email: string, lines: Array<EVA.Rituals.RitualsCreateCustomerReturnLineModel>): Promise<IEVAServiceResponse<EVA.Rituals.RitualsCreateCustomerReturn, EVA.Rituals.RitualsCreateCustomerReturnResponse>>;
    function getOrderForReturn(orderID: string, email: string): Promise<IEVAServiceResponse<EVA.Rituals.RitualsGetOrderForReturn, EVA.Rituals.RitualsGetOrderForReturnResponse>>;
    function getBlobsForReturn(orderID: number, email: string): Promise<IEVAServiceResponse<EVA.Rituals.RitualsGetBlobsForReturn, EVA.Rituals.RitualsGetBlobsForReturnResponse>>;
    function scanLoyaltyCard(loyaltyId: string): Promise<IEVAServiceResponse<EVA.Rituals.RitualsScanLoyaltyCard, EVA.Rituals.RitualsScanLoyaltyCardResponse>>;
}

export interface IAvailabilityWeek {
        sunday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        monday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        tuesday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        wednesday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        thursday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        friday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        saturday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        otherDays?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
}
/**
    * Provides access to a kijkshop specific functions in EVA
    */
export namespace Kijkshop {
        function setExpertForOrderLine(orderLineID: number, expertID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.SetExpertForOrderLine, EVA.Core.EmptyResponseMessage>>;
        function addProductExpertise(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijAddProductExpertise, EVA.Core.EmptyResponseMessage>>;
        function removeProductExpertise(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijRemoveProductExpertise, EVA.Core.EmptyResponseMessage>>;
        function isProductExpert(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijIsExpertOnProduct, EVA.Kijkshop.KijkBijMijIsExpertResponse>>;
        function isMultipleProductExpert(productIDs: number[]): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijIsExpertOnProducts, EVA.Kijkshop.KijkBijMijIsExpertsResponse>>;
        function getProductExperts(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijProductExperts, EVA.Kijkshop.KijkBijMijProductExpertsResponse>>;
        function getTotalExpertCount(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijTotalExpertCount, EVA.Kijkshop.KijkBijMijTotalExpertCountResponse>>;
        function payoutCredits(amount: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijPayoutCredits, EVA.Core.RequestMessageWithEmptyResponse>>;
        function scanMe(userId: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijScanMe, EVA.Core.RequestMessageWithEmptyResponse>>;
        function scanNewApp(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijScanNewApp, EVA.Core.RequestMessageWithEmptyResponse>>;
        function getExpertDetails(userIDs: number[]): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetExpertDetails, EVA.Kijkshop.KijkBijMijGetExpertDetailsResponse>>;
        function getProfile(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetProfile, EVA.Kijkshop.KijkBijMijGetProfileResponse>>;
        function updateProfile(description: string, avatarId: string, languageProficiencies: any): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijUpdateProfile, EVA.Core.RequestMessageWithEmptyResponse>>;
        function getProductsStats(productIDs: number[]): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetProductsStats, EVA.Kijkshop.KijkBijMijGetProductsStatsResponse>>;
        function likeProduct(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijLikeProduct, EVA.Core.EmptyResponseMessage>>;
        function unlikeProduct(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijUnlikeProduct, EVA.Core.EmptyResponseMessage>>;
        function likesProduct(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijLikesProduct, EVA.Kijkshop.KijkBijMijLikesProductResponse>>;
        function likesProducts(productIDs: number[]): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijLikesProducts, EVA.Kijkshop.KijkBijMijLikesProductsResponse>>;
        function likedProducts(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijLikedProducts, EVA.Kijkshop.KijkBijMijLikedProductsResponse>>;
        function getProductGroups(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkshopGetProductGroups, EVA.Kijkshop.KijkshopGetProductGroupsResponse>>;
        function getProductGroup(productGroupId: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkshopGetProductGroup, EVA.Kijkshop.KijkshopGetProductGroupResponse>>;
        function addProductGroupExpertise(productGroupID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijAddProductGroupExpertise, EVA.Core.EmptyResponseMessage>>;
        function removeProductGroupExpertise(productGroupID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijRemoveProductGroupExpertise, EVA.Core.EmptyResponseMessage>>;
        function isProductGroupExpert(productGroupID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijIsExpertOnProductGroup, EVA.Kijkshop.KijkBijMijIsExpertResponse>>;
        function isMultipleProductGroupExpert(productGroupIDs: number[]): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijIsExpertOnProductGroups, EVA.Kijkshop.KijkBijMijIsExpertsResponse>>;
        function getAvailability(userID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetAvailability, EVA.Kijkshop.KijkBijMijAvailabilityResponse>>;
        function setAvailability(availability?: IAvailabilityWeek): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijSetAvailability, EVA.Core.RequestMessageWithEmptyResponse>>;
        function callExpert(userID: number, productID: number, productGroupID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijCallExpert, EVA.Kijkshop.KijkBijMijCallResponse>>;
        function declineCall(sessionID: string): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijDeclineCall, EVA.Core.RequestMessageWithEmptyResponse>>;
        function joinCall(sessionID: string): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijJoinCall, EVA.Kijkshop.KijkBijMijCallExpert>>;
        function rateExpert(userID: number, sessionID: string, rating1: number, rating2: number, rating3: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijRateExpert, EVA.Core.EmptyResponseMessage>>;
        function rateCaller(userID: number, sessionID: string, rating: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijRateCaller, EVA.Core.EmptyResponseMessage>>;
        function reportUser(userID: number, reason: EVA.Kijkshop.KijkBijMijReportReasons, description: string): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijReportUser, EVA.Core.EmptyResponseMessage>>;
        function subscribeToNotificationType(typeID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijSubscribeToNotificationType, EVA.Core.RequestMessageWithEmptyResponse>>;
        function unsubscribeFromNotificationType(typeID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijUnsubscribeFromNotificationType, EVA.Core.RequestMessageWithEmptyResponse>>;
        function getNotificationSubscriptions(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetNotificationSubscriptions, EVA.Kijkshop.KijkBijMijNotificationSubscriptionsResponse>>;
        function getUnreadNotificationCount(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetUnreadNotificationCount, EVA.Kijkshop.KijkBijMijUnreadNotificationCountResponse>>;
        function markNotificationAsRead(id: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijMarkNotificationAsRead, EVA.Core.RequestMessageWithEmptyResponse>>;
        function deleteNotification(id: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijDeleteNotification, EVA.Core.RequestMessageWithEmptyResponse>>;
        function blockedUsers(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijBlockedUsers, EVA.Kijkshop.KijkBijMijBlockedUsersResponse>>;
        function isUserBlocked(userId: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijBlocksUser, EVA.Kijkshop.KijkBijMijBlocksUserResponse>>;
        function blockUser(userId: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijBlockUser, EVA.Core.RequestMessageWithEmptyResponse>>;
        function unblockUser(userId: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijUnblockUser, EVA.Core.RequestMessageWithEmptyResponse>>;
        function getCreditTotalsForUser(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetCreditTotalsForUser, EVA.Kijkshop.KijkBijMijGetCreditTotalsForUserResponse>>;
        function listCreditTransactions(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijListCreditTransactions, EVA.Kijkshop.KijkBijMijListCreditTransactionsResponse>>;
}
/**
    * Provides access to a list of hall of famers
    */
export class KijkBijMijHallOfFameList extends FetchablePagedList<EVA.Kijkshop.RankedUser, EVA.Kijkshop.KijkBijMijListHall, EVA.Kijkshop.KijkBijMijListHallResponse> {
        constructor(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string);
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Kijkshop.RankedUser, EVA.Kijkshop.KijkBijMijListHall, EVA.Kijkshop.KijkBijMijListHallResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijListHall, EVA.Kijkshop.KijkBijMijListHallResponse>>;
}
/**
    * Provides access to a list of content blocks available in EVA
    */
export class KijkBijMijNotificationsList extends FetchablePagedList<EVA.Kijkshop.KijkBijMijNotification, EVA.Kijkshop.KijkBijMijListNotifications, EVA.Kijkshop.KijkBijMijListNotificationsResponse> {
        constructor(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string);
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijNotification, EVA.Kijkshop.KijkBijMijListNotifications, EVA.Kijkshop.KijkBijMijListNotificationsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijListNotifications, EVA.Kijkshop.KijkBijMijListNotificationsResponse>>;
}
/**
    * Provides access to a list of product groups experts in EVA
    */
export class KijkBijMijProductGroupExperts extends FetchablePagedList<number, EVA.Kijkshop.KijkBijMijProductGroupExpertsPaged, EVA.Kijkshop.KijkBijMijProductGroupExpertsPagedResponse> {
        /**
            * Sets the product group id to retrieve the expert list for
            * @param  {number} productGroupId  The product group identifier
            * @return {void}                   This method doesn't return anything
            */
        setProductGroupId(productGroupId: number): void;
        constructor(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string);
        /**
            * Fetches the list of experts
            * @return {Promise<IEVAServiceResponse<number, EVA.Kijkshop.KijkBijMijProductGroupExpertsPaged, EVA.Kijkshop.KijkBijMijProductGroupExpertsPagedResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijProductGroupExpertsPaged, EVA.Kijkshop.KijkBijMijProductGroupExpertsPagedResponse>>;
}
/**
    * Provides access to a list of content blocks available in EVA
    */
export class KijkBijMijRatingsList extends FetchablePagedList<EVA.Kijkshop.KijkBijMijRating, EVA.Kijkshop.KijkBijMijListRatings, EVA.Kijkshop.KijkBijMijListRatingsResponse> {
        /**
            * Sets the user id to retrieve the rating list for
            * @param  {number} userId      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserId(userId: number): void;
        constructor(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string);
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijRating, EVA.Kijkshop.KijkBijMijListRatings, EVA.Kijkshop.KijkBijMijListRatingsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijListRatings, EVA.Kijkshop.KijkBijMijListRatingsResponse>>;
}

/**
    * The CMS Blocks module provides access to content management blocks from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a list of content blocks available in EVA
    */
export class ContentBlockList extends FetchablePagedList<EVA.CMS.CmsBlockDto, EVA.CMS.GetCmsBlocks, EVA.CMS.GetCmsBlocksResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.CMS.Dto.Blocks.CmsBlockDto, EVA.CMS.GetCmsBlocks, EVA.CMS.GetCmsBlocksResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.CMS.GetCmsBlocks, EVA.CMS.GetCmsBlocksResponse>>;
}

/**
    * The CMS Menu module provides access to content management menus from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a content menu available in EVA
    */
export class ContentMenu extends FetchableItem<EVA.CMS.CmsMenuDto, EVA.CMS.GetCmsMenuByIdentifier, EVA.CMS.GetCmsMenuByIdentifierResponse> {
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.CMS.GetCmsMenuByIdentifier, EVA.CMS.GetCmsMenuByIdentifierResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.CMS.GetCmsMenuByIdentifier, EVA.CMS.GetCmsMenuByIdentifierResponse>>;
}
/**
    * Provides access to a list of content menus available in EVA
    */
export class ContentMenuList extends FetchablePagedList<Array<EVA.CMS.CmsMenuDto>, EVA.CMS.ListCmsMenu, EVA.CMS.ListCmsMenuResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.CMS.CmsMenuDto, EVA.CMS.ListCmsMenu, EVA.CMS.ListCmsMenuResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.CMS.ListCmsMenu, EVA.CMS.ListCmsMenuResponse>>;
}

/**
    * The CMS Page module provides access to content management pages from the EVA back-end * @preferred
    */
/**
    * Provides access to a content page available in EVA
    */
export class ContentPage extends FetchableItem<EVA.CMS.CmsPageDto, EVA.CMS.GetCmsPage, EVA.CMS.GetCmsPageResponse> {
        /**
            * Returns the current request path
            * @return {string}       The configured request path
            */
        getRequestPath(): string;
        /**
            * Set the request path to retrieve the page for
            * @param  {string} query The new request path
            * @return {string}       The configured request path
            */
        setRequestPath(requestPath: string): string;
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.CMS.GetCmsPage, EVA.CMS.GetCmsPageResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.CMS.GetCmsPage, EVA.CMS.GetCmsPageResponse>>;
}
/**
    * Provides access to the generic content pages by path request available in EVA
    */
export function getCmsPagesByRequestPath(path: string): Promise<IEVAServiceResponse<EVA.CMS.GetCmsPagesByRequestPath, EVA.CMS.GetCmsPagesByRequestPathResponse>>;
/**
    * Provides access to a list of content pages available in EVA
    */
export class ContentPageList extends FetchablePagedList<EVA.CMS.CmsPageDto, EVA.CMS.ListCmsPages, EVA.CMS.ListCmsPagesResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.CMS.CmsPageDto, EVA.CMS.ListCmsPages, EVA.CMS.ListCmsPagesResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.CMS.ListCmsPages, EVA.CMS.ListCmsPagesResponse>>;
}

/**
    * The CMS Widget module provides access to content management widgets from the EVA back-end * @preferred
    */
/**
    * Provides access to a content widget available in EVA
    */
export class ContentWidget extends FetchableItem<EVA.CMS.CmsWidgetDto, EVA.CMS.GetCmsWidgetByID, EVA.CMS.GetCmsWidgetByIDResponse> {
        /**
            * Fetches the widget content
            * @return {Promise<IEVAServiceResponse<EVA.CMS.GetCmsWidgetByID, EVA.CMS.GetCmsWidgetByIDResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.CMS.GetCmsWidgetByID, EVA.CMS.GetCmsWidgetByIDResponse>>;
}

/**
    * The CMS Url Rewrite module provides access to CMS Url Rewrites from the EVA back-end
    *
    * @preferred
    */
export namespace CmsRewrite {
        /**
            * Check if a certain request path needs rewriting
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        function rewrite(requestPath: string): Promise<IEVAServiceResponse<EVA.CMS.RewriteUrl, EVA.CMS.RewriteUrlResponse>>;
}

/**
    * The DMS Blocks module provides access to content management blocks from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a list of content blocks available in EVA
    */
export class DmsBlockList extends FetchablePagedList<EVA.DMS.BlockDto, EVA.DMS.DmsListBlocks, EVA.DMS.DmsListBlocksResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.DMS.Dto.Blocks.BlockDto, EVA.DMS.ListBlocks, EVA.DMS.ListBlocksResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsListBlocks, EVA.DMS.DmsListBlocksResponse>>;
}

/**
    * The DMS Menu module provides access to content management menus from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a content menu available in EVA
    */
export class DmsMenu extends FetchableItem<EVA.DMS.MenuDto, EVA.DMS.DmsGetMenuByIdentifier, EVA.DMS.DmsGetMenuByIdentifierResponse> {
        /**
            * Returns the current request path
            * @return {string}       The configured request path
            */
        getRequestPath(): string;
        /**
            * Set the request path to retrieve the page for
            * @param  {string} query The new request path
            * @return {string}       The configured request path
            */
        setRequestPath(requestPath: string): string;
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.DMS.GetMenuByIdentifier, EVA.DMS.GetMenuByIdentifierResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetMenuByIdentifier, EVA.DMS.DmsGetMenuByIdentifierResponse>>;
}

/**
    * The DMS Page module provides access to content management pages from the EVA back-end * @preferred
    */
/**
    * Provides access to a content page available in EVA
    */
export class DmsPage extends FetchableItem<EVA.DMS.LivePageDto, EVA.DMS.DmsGetLivePage, EVA.DMS.DmsGetLivePageResponse> {
        /**
            * Returns the current request path
            * @return {string}       The configured request path
            */
        getRequestPath(): string;
        /**
            * Set the request path to retrieve the page for
            * @param  {string} query The new request path
            * @return {string}       The configured request path
            */
        setRequestPath(requestPath: string): string;
        /**
            * Returns the current view ID
            * @return {number}       The configured view ID
            */
        getViewId(): number;
        /**
            * Set the request path to retrieve the page by view ID
            * @param  {number} query The new view ID
            * @return {number}       The configured view ID
            */
        setViewId(viewId: number): number;
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetLivePage, EVA.DMS.DmsGetLivePageResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetLivePage, EVA.DMS.DmsGetLivePageResponse>>;
        listViews(): Promise<IEVAServiceResponse<EVA.DMS.DmsListViewsForPage, EVA.DMS.DmsListViewsForPageResponse>>;
        saveLayout(blocks: EVA.DMS.WidgetLayoutBlockDto[]): Promise<IEVAServiceResponse<EVA.DMS.DmsUpdateViewLayout, EVA.Core.EmptyResponseMessage>>;
}
/**
    * Provides access to a content page available in EVA
    */
export class DmsCompiledPage extends FetchableItem<EVA.DMS.CompiledPageDto, EVA.DMS.DmsGetCompiledPage, EVA.DMS.DmsGetCompiledPageResponse> {
        /**
            * Returns the current request path
            * @return {string}       The configured request path
            */
        getRequestPath(): string;
        /**
            * Set the request path to retrieve the page for
            * @param  {string} query The new request path
            * @return {string}       The configured request path
            */
        setRequestPath(requestPath: string): string;
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledPage, EVA.DMS.DmsGetCompiledPageResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledPage, EVA.DMS.DmsGetCompiledPageResponse>>;
}

/**
    * The DMS Url Rewrite module provides access to DMS Url Rewrites from the EVA back-end
    *
    * @preferred
    */
export namespace DmsRewrite {
        /**
            * Check if a certain request path needs rewriting
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        function rewrite(requestPath: string): Promise<IEVAServiceResponse<EVA.DMS.DmsRewriteUrl, EVA.DMS.DmsRewriteUrlResponse>>;
}

/**
    * The DMS Widget module provides access to content management widgets from the EVA back-end * @preferred
    */
/**
    * Provides access to a content widget available in EVA
    */
export class DmsWidgetType extends FetchableItem<EVA.DMS.WidgetTypeDto, EVA.DMS.DmsGetWidgetType, EVA.DMS.DmsGetWidgetTypeResponse> {
        /**
            * Fetches the widget content
            * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetWidgetType, EVA.DMS.DmsGetWidgetTypeByIDResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetWidgetType, EVA.DMS.DmsGetWidgetTypeResponse>>;
        list(): Promise<IEVAServiceResponse<EVA.DMS.DmsListWidgetTypes, EVA.DMS.DmsListWidgetTypesResponse>>;
}

/**
    * The DMS Widget module provides access to content management widgets from the EVA back-end * @preferred
    */
/**
    * Provides access to a content widget available in EVA
    */
export class DmsWidget extends FetchableItem<EVA.DMS.LiveWidgetDto, EVA.DMS.DmsGetCompiledWidgetByID, EVA.DMS.DmsGetCompiledWidgetByIDResponse> {
        /**
            * Fetches the widget content
            * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledWidgetByID, EVA.DMS.DmsGetCompiledWidgetByIDResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledWidgetByID, EVA.DMS.DmsGetCompiledWidgetByIDResponse>>;
        create(widget: EVA.DMS.WidgetDto, viewID: number): Promise<IEVAServiceResponse<EVA.DMS.DmsCreateWidget, EVA.Core.CreateResponse>>;
        /**
            * Update the widget
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        updateHtml(html: string): Promise<IEVAServiceResponse<EVA.DMS.DmsUpdateWidget, EVA.Core.EmptyResponseMessage>>;
}

/**
    * The MakeUp module provides access to advanced content management features from the EVA back-end
    * @preferred
    */
export interface MakeupGetRenderedPageByPathResponseWithContext extends EVA.Makeup.MakeupGetRenderedPageByPathResponse {
        PathContext: EVA.Makeup.PathContext;
        QueryPath: string;
}
export namespace MakeUp {
        /**
            * Provides access to a make up content map
            */
        function getPageMap(languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageMap, EVA.Makeup.MakeupGetPageMapResponse>>;
        /**
            * Provides access to a make up content page by path
            */
        function getPageByRequestPath(path: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByPath, EVA.Makeup.MakeupGetPageByPathResponse>>;
        /**
            * Provides access to a make up content page by id
            */
        function getPageByID(ID: string, languageID?: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByID, EVA.Makeup.MakeupGetPageByIdResponse>>;
        /**
            * Provides access to a rendered make up content page by path
            */
        function getRenderedPageByRequestPath(path: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetRenderedPageByPath, MakeupGetRenderedPageByPathResponseWithContext>>;
        function getRenderedPagesByPartialPath(path: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetRenderedPagesByPartialPath, EVA.Makeup.MakeupGetRenderedPagesByPartialPathResponse>>;
        /**
            * Provides access to a make up content page by id
            */
        function getRenderedPageByID(ID: string, languageID?: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetRenderedPageByID, EVA.Makeup.MakeupGetRenderedPageByIDResponse>>;
        /**
            * Provides access to create a new Makeup page
            * @param page The MakeupPageDto
            */
        function createPage(page: EVA.Makeup.PageDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByID, EVA.Makeup.MakeupGetPageByIdResponse>>;
        /**
            * Provides access to replace a MakeUp page
            * @param id   The ID of the Makeup page
            * @param page The MakeUpPageDto
            */
        function replacePage(page: EVA.Makeup.PageDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByID, EVA.Makeup.MakeupGetPageByIdResponse>>;
        /**
            * Convenience method to upsert a Makeup page
            * @param id   The ID of the Makeup page
            * @param page The MakeUpPageDto
            */
        function upsertPage(page: EVA.Makeup.PageDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByID, EVA.Makeup.MakeupGetPageByIdResponse>>;
        /**
            * Convenience method to retrieve the latest version of a makeup page
            * @param id The ID of the Makeup page
            * @param languageID The language
            */
        function getCurrentPageVersion(id: string, languageID: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetCurrentPageVersion, EVA.Makeup.MakeupGetCurrentPageVersionResponse>>;
        /**
            * Convenience method to publish a version of a Makeup page
            * @param id The ID of the Makeup page
            * @param languageID The language
            */
        function publishPageVersion(id: string, languageID: string, version: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupPublishPageVersion, EVA.Core.EmptyResponseMessage>>;
        /**
            * Provides access to delete a Makeup page
            * @param id The ID of the Makeup page
            */
        function deletePage(id: string, languageID?: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupDeletePage, EVA.Core.EmptyResponseMessage>>;
        /****************
            *    BLOCKS    *
            ****************/
        function getBlockByID(ID: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetBlockByID, EVA.Makeup.MakeupGetBlockByIDResponse>>;
        function getRenderedBlockByID(ID: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetRenderedBlockByID, EVA.Makeup.MakeupGetRenderedBlockByIDResponse>>;
        /**
            * Provides access to create a new Makeup block
            * @param block The BlockDto to create
            */
        function createBlock(block: EVA.Makeup.BlockDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetBlockByID, EVA.Makeup.MakeupGetBlockByIDResponse>>;
        /**
            * Convenience method to upsert a Makeup block
            * @param id    The ID of the Makeup block
            * @param block The MakeUpBlockDto
            */
        function upsertBlock(block: EVA.Makeup.BlockDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetBlockByID, EVA.Makeup.MakeupGetBlockByIDResponse>>;
        /**
            * Provides access to replace a MakeUp block
            * @param block The BlockDto
            */
        function replaceBlock(block: EVA.Makeup.BlockDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetBlockByID, EVA.Makeup.MakeupGetBlockByIDResponse>>;
        /**
            * Provides access to delete a Makeup block
            * @param id The ID of the Makeup block
            */
        function deleteBlock(id: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupDeleteBlock, EVA.Core.EmptyResponseMessage>>;
        /**
            * Convenience method to retrieve the latest version of a makeup block
            * @param id The ID of the Makeup block
            */
        function getCurrentBlockVersion(id: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetCurrentBlockVersion, EVA.Makeup.MakeupGetCurrentBlockVersionResponse>>;
        /**
            * Convenience method to publish a version of a Makeup block
            * @param id The ID of the Makeup block
            * @param version The version to set
            */
        function publishBlockVersion(id: string, version: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupPublishBlockVersion, EVA.Core.EmptyResponseMessage>>;
        /****************
            *    MENU      *
            ****************/
        function getMenuByID(ID: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetMenuByID, EVA.Makeup.MakeupGetMenuByIDResponse>>;
        /**
            * Provides access to create a new Makeup block
            * @param block The MenuDto to create
            */
        function createMenu(block: EVA.Makeup.MenuDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetMenuByID, EVA.Makeup.MakeupGetMenuByIDResponse>>;
        /**
            * Convenience method to upsert a Makeup block
            * @param id    The ID of the Makeup block
            * @param block The MakeUpMenuDto
            */
        function upsertMenu(block: EVA.Makeup.MenuDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetMenuByID, EVA.Makeup.MakeupGetMenuByIDResponse>>;
        /**
            * Provides access to replace a MakeUp block
            * @param menu The MenuDto
            */
        function replaceMenu(menu: EVA.Makeup.MenuDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetMenuByID, EVA.Makeup.MakeupGetMenuByIDResponse>>;
        /**
            * Provides access to delete a Makeup block
            * @param id The ID of the Makeup block
            */
        function deleteMenu(id: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupDeleteMenu, EVA.Core.EmptyResponseMessage>>;
        /****************************
            *    CONFIGURATION PROFILE *
            ****************************
            */
        function getConfigurationProfile(languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetConfigurationProfile, EVA.Makeup.MakeupGetConfigurationProfileResponse>>;
        /**
            * Provides access to replace a ConfigurationProfile
            * @param profile The ConfigurationProfile
            */
        function replaceConfigurationProfile(profile: EVA.Makeup.ConfigurationProfileDto, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetConfigurationProfile, EVA.Makeup.MakeupGetConfigurationProfileResponse>>;
}
export class MakeupListPageVersions extends FetchablePagedList<EVA.Makeup.PageVersionDto, EVA.Makeup.MakeupListPageVersions, EVA.Makeup.MakeupListPageVersionsResponse> {
        /**
            * Returns the current page identifier
            * @return {string}       The page identifier
            */
        getPageID(): string;
        /**
            * Set the make up page identifier
            * @param  {string} page_id The page identifier
            * @return {string}         The currently page identifier
            */
        setPageID(page_id: string): string;
        /**
            * Set the make up page language
            * @param  {string} page_id The page language
            * @return {string}         The currently page language
            */
        setLanguageID(languageID: string): string;
        /**
            * Returns the current page language
            * @return {string}       The page language
            */
        getLanguageID(): string;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Makeup.MakeupListPageVersions, EVA.Makeup.MakeupListPageVersionsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Makeup.MakeupListPageVersions, EVA.Makeup.MakeupListPageVersionsResponse>>;
}
export class MakeupListBlocks extends FetchablePagedList<EVA.Makeup.BlockDto, EVA.Makeup.MakeupListBlocks, EVA.Makeup.MakeupListBlocksResponse> {
        /**
            * Returns the current requested block type
            * @return {string}       The block type
            */
        getType(): string;
        /**
            * Set the block type to retrieve
            * @param  {string} type The new block type
            * @return {string}       The currently set block type
            */
        setType(type: string): string;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Makeup.MakeupListBlocks, EVA.Makeup.MakeupListBlocksResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Makeup.MakeupListBlocks, EVA.Makeup.MakeupListBlocksResponse>>;
}
export class MakeupListBlockVersions extends FetchablePagedList<EVA.Makeup.BlockDto, EVA.Makeup.MakeupListBlockVersions, EVA.Makeup.MakeupListBlockVersionsResponse> {
        /**
            * Returns the current block identifier
            * @return {string}       The block identifier
            */
        getBlockID(): string;
        /**
            * Set the make up block identifier
            * @param  {string} block_id The block identifier
            * @return {string}         The currently block identifier
            */
        setBlockID(block_id: string): string;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Makeup.MakeupListBockVersions, EVA.Makeup.MakeupListBlockVersionsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Makeup.MakeupListBlockVersions, EVA.Makeup.MakeupListBlockVersionsResponse>>;
}
export class MakeupListMenus extends FetchablePagedList<EVA.Makeup.MenuDto, EVA.Makeup.MakeupListMenus, EVA.Makeup.MakeupListMenusResponse> {
        /**
            * Returns the current language identifier
            * @return {string} The language identifier
            */
        getLanguageID(): string;
        /**
            * Set the language identifier
            * @param  {string} language The language identifier
            */
        setLanguageID(languageID: string): string;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Makeup.MakeupListMenus, EVA.Makeup.MakeupListMenusResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Makeup.MakeupListMenus, EVA.Makeup.MakeupListMenusResponse>>;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a babylon binary blobs in EVA
    */
export class Blob extends FetchableItem<EVA.Blobs.BlobDto, EVA.Blobs.GetBlobInfo, EVA.Blobs.GetBlobInfoResponse> {
        /**
            * Convenience method to build a blob image URL
            * @param  {string} guid        The blob guid
            * @param  {number} width       The output image width
            * @param  {number} height      The output image height
            * @param  {string} type        The image type (ie. png, jpg, etc)
            *
            * @return {string}             An image URL
            */
        static getImageUrl(guid: string, width?: number, height?: number, format?: string): string;
        /**
            * Sets the category to retrieve the blob info for
            * @param  {string} category    The blob category
            * @return {void}               This method doesn't return anything
            */
        setCategory(category: string): void;
        /**
            * Sets the original name to retrieve the blob info for
            * @param  {string} original name    The blob original name
            * @return {void}               This method doesn't return anything
            */
        setOriginalName(originalName: string): void;
        fetch(): Promise<IEVAServiceResponse<EVA.Blobs.GetBlobInfo, EVA.Blobs.GetBlobInfoResponse>>;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES} response The response from the service call
            * @return {T}            The item details
            */
        setData(response: any): EVA.Blobs.BlobDto;
        create(newBlobInfo: EVA.Blobs.StoreBlob): Promise<IEVAServiceResponse<EVA.Blobs.GetBlobInfo, EVA.Blobs.GetBlobInfoResponse>>;
        createEmpty(newBlobInfo: EVA.Blobs.CreateBlob): Promise<IEVAServiceResponse<EVA.Blobs.CreateBlob, string>>;
        createEmptyBlob(newBlobInfo: EVA.Blobs.CreateBlob): Promise<IEVAServiceResponse<EVA.Blobs.CreateBlob, EVA.Blobs.CreateBlobResponse>>;
        getUploadUrl(guid: string): string;
        process(imageDataBase64: string, type?: string): Promise<IEVAServiceResponse<EVA.Blobs.ProcessDocument, EVA.Blobs.ProcessDocumentResponse>>;
        destroy(): Promise<IEVAServiceResponse<EVA.Blobs.DeleteBlob, EVA.Core.EmptyResponseMessage>>;
        getImageCutoutSuggestions(): Promise<IEVAServiceResponse<EVA.Babylon.GetImageCutoutSuggestions, EVA.Babylon.GetImageCutoutSuggestionsResponse>>;
}

export namespace Barcodes {
    function parseBarcode(barcode: string): Promise<EVA.Core.Services.ParseBarcodeResponse>;
    function getProductByBarcode(barcode: string): Promise<EVA.Core.Services.GetProductByBarcodeResponse>;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a babylon social functions in EVA
    * These are the by identifier versions that can be reused by EVA SDK objects
    */
export namespace Feed {
        function getFeedByType(feedType: string, offset?: number | string, limit?: number): Promise<IEVAServiceResponse<EVA.Babylon.GetUserFeed, EVA.Babylon.GetUserFeedResponse>>;
        function getTrendingFeed(skip?: number, limit?: number, type?: EVA.Babylon.TrendingFeedTypes): Promise<IEVAServiceResponse<EVA.Babylon.GetTrendingFeed, EVA.Babylon.GetTrendingFeedResponse>>;
        function getNotificationFeed(offset?: number, limit?: number): Promise<IEVAServiceResponse<EVA.Babylon.GetNotificationFeed, EVA.Babylon.GetNotificationFeedResponse>>;
        function getUnseenNotifications(): Promise<IEVAServiceResponse<EVA.Babylon.GetNotificationFeed, EVA.Babylon.GetNotificationFeedResponse>>;
}

/**
    * Provides access to a babylon social functions in EVA
    * These are the by identifier versions that can be reused by EVA SDK objects
    */
export namespace Social {
        function getListOfLikedObjects(offset?: string, limit?: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialListLikedObjects, EVA.Babylon.SocialListLikedObjectsResponse>>;
        function getListOfProgressions(userID: number, type: EVA.Social.SocialProgressionType): Promise<IEVAServiceResponse<EVA.Social.SocialGetProgressions, EVA.Social.SocialGetProgressionsResponse>>;
        function likeProductByID(productID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeProduct, EVA.Core.EmptyResponseMessage>>;
        function unlikeProductByID(productID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeProduct, EVA.Core.EmptyResponseMessage>>;
        function shareProductWithUsers(productID: number, userIDs: Array<number>, message: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function productSharedExternally(productID: number, platform: EVA.Babylon.SocialMediaPlatform): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function listProductInteractionSummary(productID: number): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function listProductInteractionDetails(productID: number, limit?: number, offset?: string, type?: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function getProductStats(productIDs: Array<number> | number): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetProductsStats, EVA.Babylon.SocialStatsResponse>>;
        function likeCollectionByID(collectionID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeFashionCollection, EVA.Core.EmptyResponseMessage>>;
        function unlikeCollectionByID(collectionID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeFashionCollection, EVA.Core.EmptyResponseMessage>>;
        function shareCollectionWithUsers(collectionID: number, userIDs: Array<number>, message: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function collectionSharedExternally(collectionID: number, platform: EVA.Babylon.SocialMediaPlatform): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function inviteFriends(invites: Array<EVA.Babylon.InviteFriendsDto> | EVA.Babylon.InviteFriendsDto): Promise<IEVAServiceResponse<EVA.Babylon.SocialInviteFriends, EVA.Core.EmptyResponseMessage>>;
        function listCollectionInteractionSummary(collectionID: number): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function listCollectionInteractionDetails(collectionID: number, limit?: number, offset?: string, filter?: string | number): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function getCollectionStats(collectionIDs: Array<number> | number): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetFashionCollectionsStats, EVA.Babylon.SocialStatsResponse>>;
        function getCollectionStatsOverTime(collectionID: number, granularity: EVA.Babylon.CollectionStatsGranularity): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionStatsOverTime, EVA.Babylon.SocialStatsResponse>>;
        function likeUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeUser, EVA.Core.EmptyResponseMessage>>;
        function unlikeUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeUser, EVA.Core.EmptyResponseMessage>>;
        function followUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialFollowUser, EVA.Core.EmptyResponseMessage>>;
        function unfollowUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnfollowUser, EVA.Core.EmptyResponseMessage>>;
        function getAvatarURL(userID: number, size?: number, format?: string): string;
        function isFollowingUsers(userIDs: Array<number>): Promise<IEVAServiceResponse<EVA.Babylon.SocialIsFollowingUsers, EVA.Babylon.SocialIsFollowingUsersResponse>>;
        function likeUserMediaByID(userMediaID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeFashionUserMedia, EVA.Core.EmptyResponseMessage>>;
        function unlikeUserMediaByID(userMediaID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeFashionUserMedia, EVA.Core.EmptyResponseMessage>>;
        function removeCommentByID(commentID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialDeleteComment, EVA.Core.EmptyResponseMessage>>;
        function addCommentForProduct(productID: number, comment: string, mentionedUserIDs: Array<number>): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function addCommentForCollection(collectionID: number, comment: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function addCommentForUserMedia(userMediaID: number, comment: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function likeCommentByID(commentID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeComment, EVA.Core.EmptyResponseMessage>>;
        function unlikeCommentByID(commentID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeComment, EVA.Core.EmptyResponseMessage>>;
        function getStatsForFeedObjects(objects: Array<EVA.Babylon.FeedObjectDto>): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetStatsForFeedObjects, EVA.Babylon.SocialObjectStatsResponse>>;
        function blockUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.BlockUser, EVA.Core.EmptyResponseMessage>>;
        function unblockUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.UnblockUser, EVA.Core.EmptyResponseMessage>>;
        function reportContent(contentType: EVA.Babylon.SocialReportContentTypes, contentID: string, reason: EVA.Babylon.SocialReportReasons, description?: string): Promise<IEVAServiceResponse<EVA.Babylon.SocialReportContent, EVA.Core.EmptyResponseMessage>>;
        function sendPushNotificationTest(userId: number, title: string, body: string, data?: any): Promise<IEVAServiceResponse<EVA.Babylon.BabylonPushNotificationTest, EVA.Core.EmptyResponseMessage>>;
}
export class SocialProfile extends FetchableItem<EVA.Babylon.SocialUserProfile, EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse> {
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES} response The response from the service call
            * @return {T}            The item details
            */
        setData(response: any): EVA.Babylon.SocialUserProfile;
        /**
            * Fetches the social user profile details
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialUserProfile, EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>;
        /**
            * Fetches the social user profile details by nickname
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialUserProfile, EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetchByNickname(nickname: string): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetUserProfileByNickname, EVA.Babylon.SocialGetUserProfileResponse>>;
        update(userProfile: EVA.Babylon.SocialUpdateUserProfileModel): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>;
}
export class SocialFollowers extends FetchablePagedList<EVA.Babylon.Follower, EVA.Babylon.SocialListFollowers, EVA.Babylon.SocialListFollowersResponse> {
        /**
            * Sets the user id to retrieve the follower list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListFollowers, EVA.Babylon.SocialListFollowersResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListFollowers, EVA.Babylon.SocialListFollowersResponse>>;
}
export class SocialFollowing extends FetchablePagedList<EVA.Babylon.Follower, EVA.Babylon.SocialListFollowing, EVA.Babylon.SocialListFollowingResponse> {
        /**
            * Sets the user id to retrieve the following list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.Social.Services.SocialListFollowing, EVA.Babylon.Social.Services.SocialListFollowingResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListFollowing, EVA.Babylon.SocialListFollowingResponse>>;
}
export class SocialBlockedUsers extends FetchablePagedList<EVA.Babylon.BlockUser, EVA.Babylon.SocialListBlockedFollowers, EVA.Babylon.SocialListBlockedFollowersResponse> {
        /**
            * Sets the user id to retrieve the following list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.Social.Services.SocialListFollowing, EVA.Babylon.Social.Services.SocialListFollowingResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListBlockedFollowers, EVA.Babylon.SocialListBlockedFollowersResponse>>;
}
export class SocialCommentsForProduct extends FetchablePagedList<EVA.Babylon.Comment, EVA.Babylon.SocialListCommentsForProduct, EVA.Babylon.SocialListCommentsResponse> {
        /**
            * Sets the product id to retrieve the follower list for
            * @param  {number} productID       The product identifier
            * @return {void}                   This method doesn't return anything
            */
        setProductID(productID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForProduct, EVA.Babylon.SocialListCommentsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForProduct, EVA.Babylon.SocialListCommentsResponse>>;
}
export class SocialCommentsForCollection extends FetchablePagedList<EVA.Babylon.Comment, EVA.Babylon.SocialListCommentsForFashionCollection, EVA.Babylon.SocialListCommentsResponse> {
        /**
            * Sets the collection id to retrieve the comment list for
            * @param  {number} collectionID        The collection identifier
            * @return {void}                       This method doesn't return anything
            */
        setCollectionID(collectionID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionCollection, EVA.Babylon.SocialListCommentsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionCollection, EVA.Babylon.SocialListCommentsResponse>>;
}
export class SocialCommentsForUserMedia extends FetchablePagedList<EVA.Babylon.Comment, EVA.Babylon.SocialListCommentsForFashionUserMedia, EVA.Babylon.SocialListCommentsResponse> {
        /**
            * Sets the user media id to retrieve the follower list for
            * @param  {number} userMediaID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserMediaID(userMediaID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionUserMedia, EVA.Babylon.SocialListCommentsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionUserMedia, EVA.Babylon.SocialListCommentsResponse>>;
}
export class SocialProductsCreatedByUser extends FetchablePagedList<EVA.Babylon.ProductCreationByUserResult, EVA.Babylon.SocialListProductsCreationsByUser, EVA.Babylon.SocialListProductsCreationsByUserResponse> {
        /**
            * Sets the user id to retrieve the creations list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListProductsCreationsByUser, EVA.Babylon.SocialListProductsCreationsByUserResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListProductsCreationsByUser, EVA.Babylon.SocialListProductsCreationsByUserResponse>>;
}
export class SocialFacebookFriends extends FetchablePagedList<EVA.Babylon.FacebookFriend, EVA.Babylon.SocialListFacebookFriends, EVA.Babylon.SocialListFacebookFriendsResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListFacebookFriends, EVA.Babylon.SocialListFacebookFriendsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListFacebookFriends, EVA.Babylon.SocialListFacebookFriendsResponse>>;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to user media (fashion) in EVA
    */
export namespace UserMedia {
        function removeUserMediaByID(userMediaID: number): Promise<IEVAServiceResponse<EVA.Babylon.DeleteFashionUserMedia, EVA.Core.EmptyResponseMessage>>;
        function addUserMediaToProduct(productID: number, blobID: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function addUserMediaToCollection(collectionID: number, blobID: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
}
export class UserMediaForProduct extends FetchablePagedList<EVA.Babylon.FashionUserMedia, EVA.Babylon.ListFashionUserMediaForProduct, EVA.Babylon.ListFashionUserMediaResponse> {
        /**
            * Sets the product id to retrieve the user media list for
            * @param  {number} productID           The product identifier
            * @return {void}                       This method doesn't return anything
            */
        setProductID(productID: number): void;
        /**
            * Sets the user id to retrieve the user media list for a specific user
            * @param  {number} userID           The user identifier
            * @return {void}                    This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForProduct, EVA.Babylon.ListFashionUserMediaResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForProduct, EVA.Babylon.ListFashionUserMediaResponse>>;
}
export class UserMediaForCollection extends FetchablePagedList<EVA.Babylon.FashionUserMedia, EVA.Babylon.ListFashionUserMediaForCollection, EVA.Babylon.ListFashionUserMediaResponse> {
        /**
            * Sets the collection id to retrieve the user media list for
            * @param  {number} collectionID        The collection identifier
            * @return {void}                       This method doesn't return anything
            */
        setCollectionID(collectionID: number): void;
        /**
            * Sets the user id to retrieve the user media list for a specific user
            * @param  {number} userID           The user identifier
            * @return {void}                    This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForCollection, EVA.Babylon.ListFashionUserMediaResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForCollection, EVA.Babylon.ListFashionUserMediaResponse>>;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a babylon social functions in EVA
    * These are the by identifier versions that can be reused by EVA SDK objects
    */
export namespace Search {
        function quickFashionSearch(query: string, collectionSize?: number, productSize?: number, actorSize?: number, onlyAutocompleteProducts?: boolean): Promise<IEVAServiceResponse<EVA.Babylon.QuickSearchFashionItems, EVA.Babylon.QuickSearchFashionItemsResponse>>;
        function socialUserSearch(query: string, pageSize?: number, pageNr?: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUserSearch, EVA.Babylon.SocialUserSearchResponse>>;
        function socialFriendsSearch(query: string, pageSize?: number, pageNr?: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialSearchFriends, EVA.Babylon.SocialSearchFriendsResponse>>;
        function fashionCollectionSearch(query: string, pageSize?: number, pageNr?: number, supplierName?: string, sortOption?: EVA.Babylon.FashionCollectionSearchModelSortOptions): Promise<IEVAServiceResponse<EVA.Babylon.SearchFashionCollections, EVA.Babylon.SearchFashionCollectionsResponse>>;
}
/**
    * Provides access to a list of products available in EVA
    */
export class FashionProductList extends FetchablePagedList<EVA.Core.ProductDto, EVA.Babylon.SearchFashionProducts, EVA.Core.Services.SearchProductsResponse> {
        /**
            * The return aggregations flag
            * @type {any}
            */
        includeAggregations: boolean;
        /**
            * The return suggestions flag
            * @type {any}
            */
        includeSuggestions: boolean;
        /**
            * Returns the current list of excluded fields
            * @return {Array<string>} The configured list of excluded product fields
            */
        getExcludedFields(): Array<string>;
        /**
            * Returns the current list of excluded fields
            * @return {Array<string>} The configured list of excluded product fields
            */
        addExcludedField(fieldName: string): Array<string>;
        /**
            * Clears the configured list of excluded fields
            * @return {Array<string>} The configured list of excluded product fields
            */
        clearExcludedFields(): Array<string>;
        /**
            * Sets the excluded fields option
            * @return {EVA.Core.ExcludedFieldOptions} The aggregation state
            */
        setExcludedFieldsOptions(option: EVA.Core.ExcludedFieldOptions): any;
        /**
            * Return the currently set excluded field option
            * @return {EVA.Core.ExcludedFieldOptions} The excluded field option value
            */
        getExcludedFieldsOption(): EVA.Core.ExcludedFieldOptions;
        /**
            * Returns the current list of included fields
            * @return {Array<string>} The configured list of included product fields
            */
        getIncludedFields(): Array<string>;
        /**
            * Returns the current list of included fields
            * @return {Array<string>} The configured list of included product fields
            */
        addIncludedField(fieldName: string): Array<string>;
        /**
            * Clears the configured list of included fields
            * @return {Array<string>} The configured list of included product fields
            */
        clearIncludedFields(): Array<string>;
        /**
            * Sets the aggregation filters
            * @return {any} The aggregation filters
            */
        setAggregationFilters(aggregationFilters: any): any;
        /**
            * Return the currently set aggregation filters
            * @return {any} The aggregation filters
            */
        getAggregationFilters(): any;
        /**
            * Sets the aggregation options
            * @return {any} The aggregation options
            */
        setAggregationOptions(aggregationOptions: any): any;
        /**
            * Return the currently set aggregation options
            * @return {any} The aggregation options
            */
        getAggregationOptions(): any;
        /**
            * Returns the current query string
            * @return {string}       The configured query string
            */
        getQuery(): string;
        /**
            * Set the query to search for
            * @param  {string} query The new query string
            * @return {string}       The configured query string
            */
        setQuery(query: string): string;
        /**
            * Return the aggregations that were returned with the product list
            * @return {any} The aggreations
            */
        getAggregations(): any;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {EVA.Core.Services.Products.SearchProductsResponse}  response    The response from the service call
            * @return {Array<EVA.Core.ProductDto>}                                     The product items for the current page
            */
        setData(response: any): EVA.Core.ProductDto[];
        /**
            * Fetches the product list item details
            * @return {Promise<IEVAServiceResponse<EVA.Core.ProductDto, EVA.Babylon.SearchFashionProducts, EVA.Core.Services.SearchProductsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SearchFashionProducts, EVA.Core.Services.SearchProductsResponse>>;
}

/**
    * The shops module provides access to the shops (organization unit type) data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a list of shop reviews available in EVA
    */
export class ShopReviews extends FetchablePagedList<EVA.Kiyoh.ShopReview, EVA.Kiyoh.ListShopReviews, EVA.Kiyoh.ListShopReviewsResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Kiyoh.ListShopReviews, EVA.Kiyoh.ListShopReviewsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Kiyoh.ListShopReviews, EVA.Kiyoh.ListShopReviewsResponse>>;
}
/**
    * Provides access to a list of product reviews available in EVA
    */
export class ProductReviews extends FetchablePagedList<EVA.Kiyoh.ProductReview, EVA.Kiyoh.ListProductReviews, EVA.Kiyoh.ListProductReviewsResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Kiyoh.ListProductReviews, EVA.Kiyoh.ListProductReviewsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Kiyoh.ListProductReviews, EVA.Kiyoh.ListProductReviewsResponse>>;
}
export function getShopReviewStats(): Promise<IEVAServiceResponse<EVA.Kiyoh.GetShopReviewStats, EVA.Kiyoh.GetShopReviewStatsResponse>>;

/**
    * The supplier module provides access to the supplier data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to an order available in EVA
    */
export class FashionSupplier extends FetchableItem<EVA.Babylon.FashionSupplierDataDto, EVA.Babylon.GetFashionSupplierData, EVA.Babylon.GetFashionSupplierDataResponse> {
        /**
            * This class wraps an supplier from EVA and the operations you can perform on it.
            * You should supply the supplier identifier when creating an instance of this class
            *
            * @param  {number | string}    id      The identifier of the supplier to retrieve
            * @return {void}                       This method doesn't return anything
            */
        constructor(id?: number | string);
        /**
            * Fetches the order details
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.GetFashionSupplierData, EVA.Babylon.GetFashionSupplierDataResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionSupplierData, EVA.Babylon.GetFashionSupplierDataResponse>>;
        fetchForOrder(orderId: number): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionSupplierDataForOrder, EVA.Babylon.GetFashionSupplierDataForOrderResponse>>;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {EVA.Babylon.GetFashionSupplierDataResponse}  response    The response from the service call
            * @return {EVA.Babylon.FashionSupplierDataDto}                      The supplier details
            */
        setData(response: any): EVA.Babylon.FashionSupplierDataDto;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a babylon social functions in EVA
    * These are the by identifier versions that can be reused by EVA SDK objects
    */
export namespace Gamification {
        function getCoverSheetEditorCapabilities(): Promise<IEVAServiceResponse<EVA.Babylon.GetCoverSheetEditorCapabilities, EVA.Babylon.GetCoverSheetEditorCapabilitiesResponse>>;
        function getSocialGetProgressionByID(id: number): Promise<IEVAServiceResponse<EVA.Social.SocialGetProgressionByID, EVA.Social.SocialGetProgressionByIDResponse>>;
        function getSocialProgressions(userId: number, type: EVA.Social.SocialProgressionType): Promise<IEVAServiceResponse<EVA.Social.SocialGetProgressions, EVA.Social.SocialGetProgressionsResponse>>;
        function getSocialProgressionRanking(userId: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetProgressionRanking, EVA.Babylon.SocialGetProgressionRankingResponse>>;
        function getActiveFashionEvent(): Promise<IEVAServiceResponse<EVA.Babylon.GetActiveFashionEvent, EVA.Babylon.GetActiveFashionEventResponse>>;
        function getBarcodeDataForFashionEvent(): Promise<IEVAServiceResponse<EVA.Babylon.GetBarcodeDataForFashionEvent, EVA.Babylon.GetBarcodeDataForFashionEventResponse>>;
        function scanBarcodeDataForFashionEvent(data: string): Promise<IEVAServiceResponse<EVA.Babylon.ScanBarcodeForFashionEvent, EVA.Babylon.ScanBarcodeForFashionEventResponse>>;
        function getBarcodeUrlForFashionEvent(data: string, width?: number, height?: number): string;
        function getActiveFashionCollectionContests(): Promise<IEVAServiceResponse<EVA.Babylon.GetActiveFashionCollectionContests, EVA.Babylon.GetActiveFashionCollectionContestsResponse>>;
        function getFashionCoinTotalsForUser(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCoinTotalsForUser, EVA.Babylon.GetFashionCoinTotalsForUserResponse>>;
        function convertFashionCoins(amount: number, direction: EVA.Babylon.FashionCoinConversionDirection): Promise<IEVAServiceResponse<EVA.Babylon.ConvertFashionCoins, EVA.Babylon.ConvertFashionCoinsResponse>>;
}
/**
    * Provides access to a list of fashion collections for a contest available in EVA
    */
export class FashionCollectionsForContest extends FetchablePagedList<EVA.Babylon.FashionCollectionContestDto, EVA.Babylon.ListFashionCollectionsForContest, EVA.Babylon.ListFashionCollectionsForContestResponse> {
        /**
            * Sets the contest id to retrieve the fashion collection list for
            * @param  {number} contestId      The organization identifier
            * @return {void}                  This method doesn't return anything
            */
        setContestId(contestId: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.FashionCollectionContestDto, EVA.Babylon.ListFashionCollectionsForContest, EVA.Babylon.ListFashionCollectionsForContestResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForContest, EVA.Babylon.ListFashionCollectionsForContestResponse>>;
}
/**
    * Provides access to a list of fashion coin transactions
    */
export class FashionCoinTransactions extends FetchablePagedList<EVA.Babylon.FashionCollectionContestDto, EVA.Babylon.ListFashionCoinTransactions, EVA.Babylon.ListFashionCoinTransactionsResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.FashionCoinTransaction, EVA.Babylon.ListFashionCoinTransactions, EVA.Babylon.ListFashionCoinTransactionsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCoinTransactions, EVA.Babylon.ListFashionCoinTransactionsResponse>>;
}

/**
    * This module provides methods for Addresses, setting / updating addresses on specific
    * objects like customer  and order are done directly on those objects
    *
    * @preferred
    */
export class AddressBook extends FetchablePagedList<EVA.Core.Services.AddressBookDto, EVA.Core.Services.ListAddressBook, EVA.Core.Services.ListAddressBookResponse> {
        static setDefaultBillingAddress(id: number): Promise<IEVAServiceResponse<EVA.Core.Services.SetDefaultBillingAddress, EVA.Core.RequestMessageWithEmptyResponse>>;
        static setDefaultShippingAddress(id: number): Promise<IEVAServiceResponse<EVA.Core.Services.SetDefaultShippingAddress, EVA.Core.RequestMessageWithEmptyResponse>>;
        static createItem(address: EVA.Core.AddressDto, description?: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreateAddressBookItem, EVA.Core.CreateResponse>>;
        static updateItem(id: number, address: EVA.Core.AddressDto, description?: string): Promise<IEVAServiceResponse<EVA.Core.Services.UpdateAddressBookItem, EVA.Core.EmptyResponseMessage>>;
        static deleteItem(id: number): Promise<IEVAServiceResponse<EVA.Core.Services.DeleteAddressBookItem, EVA.Core.EmptyResponseMessage>>;
        constructor(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string);
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.ListAddressBook, EVA.Core.Services.ListAddressBookResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListAddressBook, EVA.Core.Services.ListAddressBookResponse>>;
}
export namespace Addresses {
        /**
            * Wrapper class for Address responses, since this is not a fetchable item
            * it's just a plain object
            */
        class Address {
                data: EVA.Core.AddressDto;
                setData(response: any): EVA.Core.AddressDto;
        }
        /**
            * Perform a lookup using zipcode and housenumber, resolve with an Address object
            *
            * @param  {string}  zipCode     zipcode to lookup
            * @param  {string}  houseNumber housenumber to lookup
            * @return {Promise}             [description]
            */
        function lookup(zipCode: string, houseNumber: string): Promise<Address>;
        /**
            * Request a list of available countries for a user to create addresses with
            * @return {Promise}
            */
        function getAvailableCountries(): Promise<EVA.Core.Services.CountryDto[]>;
        /**
            * Perform an address search using a single text string, responds with textual suggestions.
            * To get the details of the suggestion (city/street etc) a additional call
            * needs to be made to getAddressSuggestionDetails()
            *
            * @param {string}      query       The search query
            * @return {Promise}    array of found suggestions
            */
        function getAddressSuggestions(query: string): Promise<EVA.Core.AddressSuggestion[]>;
        /**
            * Retrieve the details of a suggestion
            *
            * @param {EVA.Core.AddressSuggestion}      suggestion      the address suggestion, can be retrieved using the getAddressSuggestions() function
            * @return {Promise}    the details of the address suggestion
            */
        function getAddressSuggestionDetails(suggestion: EVA.Core.AddressSuggestion): Promise<EVA.Core.AddressSuggestionDetails>;
}

/**
    * This module provides methods for newsletter subscription
    *
    * @preferred
    */
export namespace Newsletter {
        /**
            * Subscribe to the Newsletter using the provided email address
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        function subscribe(emailAddress: string): Promise<IEVAServiceResponse<EVA.Core.Services.Subscribe, EVA.Core.Services.SubscribeResponse>>;
        /**
            * Unsubscribes from the Newsletter using the provided email address
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        function unsubscribe(emailAddress: string): Promise<IEVAServiceResponse<EVA.Core.Services.Unsubscribe, EVA.Core.Services.UnsubscribeResponse>>;
        /**
            * Confirms a Newsletter subscription using the provided token
            * @param  {string}     token   The subscription confirmation token
            * @return {Promise}            A promise resolving when the call to the back-end has completed
            */
        function confirmSubscription(token: string): Promise<IEVAServiceResponse<EVA.Core.Services.ConfirmSubscribe, EVA.Core.Services.ConfirmSubscribeResponse>>;
        /**
            * Validate if a e-mail adres is subscribed to the newsletter
            *
            * @param  {string}  emailAddress The email adres that needs to be validated to have a subscription to the newsletter
            * @return {Promise}              A promise resolving when the call to the back-end has completed
            */
        function hasSubscription(emailAddress: string): Promise<IEVAServiceResponse<EVA.Core.Services.HasSubscription, EVA.Core.Services.HasSubscriptionResponse>>;
}

/**
    * The CMS Page module provides access to content management pages from the EVA back-end * @preferred
    */
/**
    * Provides access to a content menu available in EVA
    */
export class Station extends FetchableItem<EVA.Core.StationDto, EVA.Core.Services.GetStation, EVA.Core.Services.GetStationResponse> {
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetStation, EVA.Core.Services.GetStationResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetStation, EVA.Core.Services.GetStationResponse>>;
}
/**
    * Provides access to a list of stations for an organisation available in EVA
    */
export class StationList extends FetchablePagedList<EVA.Core.StationDto, EVA.Core.Services.ListStationsForOrganizationUnit, EVA.Core.Services.ListStationsForOrganizationUnitResponse> {
        /**
            * Sets the organization id to retrieve the station list for
            * @param  {number} organizationId      The organization identifier
            * @return {void}                       This method doesn't return anything
            */
        setOrganizationId(organizationId: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Core.StationDto, EVA.Core.Services.ListStationsForOrganizationUnit, EVA.Core.Services.ListStationsForOrganizationUnitResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListStationsForOrganizationUnit, EVA.Core.Services.ListStationsForOrganizationUnitResponse>>;
}

export namespace Cultures {
    function getApplicationCultures(): Promise<Array<EVA.PIM.Core.ListApplicationContentCulture>>;
}

export namespace Currencies {
    function getAvailableCurrencies(): Promise<Array<EVA.Core.Services.CurrencyDto>>;
    function setOrderCurrency(currencyID: string, orderID: number): Promise<{}>;
}

export namespace Availability {
    function getAvailabilityForProductSet(products: Array<EVA.Core.ProductQuantityDto>, organizationUnitIDs?: Array<number>, fastestPickupShopOnly?: boolean, includeAvailabilityTexts?: boolean, detailedShopInformation?: boolean): Promise<Array<EVA.Core.ProductAvailabilityIndication>>;
}

export namespace Functionalities {
    function getSupportedFunctionalities(): Promise<Array<EVA.Core.Functionalities>>;
}

export namespace ExternalContent {
    function extractUrlInformation(url: string): Promise<IEVAServiceResponse<EVA.Babylon.ExtractUrlInformation, EVA.Babylon.ExtractUrlInformationResponse>>;
}

/**
  * This module provides methods for BI reporting
  *
  * @preferred
  */
export namespace Reporting {
    function GetRankings(axis: string, measure: string, organizationUnitIDs: Array<number> | number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetRankings, EVA.BI.Reporting.GetRankingsResponse>>;
    function getRankings(organizationUnitIDs: Array<number> | number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetRankings, EVA.BI.Reporting.GetRankingsResponse>>;
    function getProductReportingOverview(organizationUnitIDs: Array<number> | number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetProductReportingOverview, EVA.BI.Reporting.GetProductReportingOverviewResponse>>;
    function getTelecomReportingOverview(organizationUnitIDs: Array<number> | number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetTelecomReportingOverview, EVA.BI.Reporting.GetTelecomReportingOverviewResponse>>;
    function getReportingCharts(organizationUnitID: number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetReportingCharts, EVA.BI.Reporting.GetReportingChartsResponse>>;
    function getOrderDetails(orderID: number): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetOrderDetails, EVA.BI.Reporting.GetOrderDetailsResponse>>;
    function getOrders(organizationUnitID: number, category: string, userID?: number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetOrders, EVA.BI.Reporting.GetOrdersResponse>>;
    function getReportingOverview(organizationUnitIDs: Array<number> | number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetReportingOverview, EVA.BI.Reporting.GetReportingOverviewResponse>>;
}

export function addPushNotificationDevice(deviceToken: string, deviceOS: string, mobileAppID: string, backendSystemID: string): Promise<IEVAServiceResponse<EVA.Core.Services.AddPushNotificationDevice, EVA.Core.EmptyResponseMessage>>;
export function removePushNotificationDevice(deviceToken: string, backendSystemID?: string): Promise<IEVAServiceResponse<EVA.Core.Services.RemovePushNotificationDevice, EVA.Core.EmptyResponseMessage>>;

export namespace Webshop {
    function sendContactFrom(type: string, properties: any): Promise<EVA.Core.Services.SendContactForm>;
}

/**
    * The base module declares reusable base classes for items, lists, etc.
    * @preferred
    */
export interface IPageInfo {
        currentPageNumber: number;
        totalNumberOfPages: number;
        totalNumberOfItems: number;
}
/**
    * Provides access to an item available on the EVA back-end
    */
export class FetchableItem<T, REQ, RES> {
        /**
            * The item detail data. This is available after a fetch from the back-end.
            * It is exposed globally so clients can bind and watch it directly for updates
            * @type {T}
            */
        data: T;
        /**
            * The unique identifier of the item. Used when retrieving an exsting item from the back-end.
            * Defaults to a number but some items use string based identifiers
            * @type {number | string}
            */
        protected _id: number | string;
        /**
            * This class wraps an item from EVA and the operations you can perform on it.
            * You should supply the item identifier when creating an instance of this class
            *
            * @param  {number | string}    id      The identifier of the item to retrieve
            * @return {void}                       This method doesn't return anything
            */
        constructor(id?: number | string);
        /**
            * Set for the id of the fetchable item. This can be overriden in a subclass so
            * additional behaviour can be implemented when setting the id
            *
            * @param  {number | string}      id An item identifier
            * @return {void}                    This item doesn't return anything
            */
        id: number | string;
        /**
            * Returns the current item identifier
            * @return {number | string} An item identifier
            */
        getId(): number | string;
        /**
            * Returns the current item details. Only available after a successful fetch
            * The details are also exposed direct as the .data attribute for easy binding
            * @return {T} The item details
            */
        getData(): T;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES} response The response from the service call
            * @return {T}            The item details
            */
        setData(response: any): T;
        /**
            * Fetches the item details from the EVA back-end
            * @param  {string}  serviceName The name of the EVA Service to call
            * @param  {REQ}     requestData The request data for service call
            * @param  {string}  path        The request path (rest-like) if not using post message
            * @return {Promise<IEVAServiceResponse<REQ, RES>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(serviceName: string, requestData: REQ, path?: string, method?: EXMLHttpRequestMethod): Promise<IEVAServiceResponse<REQ, RES>>;
}
/**
    * Provides access to a pageable list available on the EVA back-end
    */
export class FetchablePagedList<T, REQ, RES> {
        /**
            * The page item data. This is available after a fetch from the back-end.
            * It is exposed globally so clients can bind and watch it directly for updates
            * @type {Arra<T>}
            */
        data: Array<T>;
        /**
            * The page configuration instance used to instruct the EVA back-end which
            * data to fetch
            * @type {EVA.Core.PageConfig}
            */
        protected pageConfig: EVA.Core.PageConfig;
        /**
            * The current page for which the data is available
            * Only available after fetch has been called
            * @type {number}
            */
        protected currentPageNumber: number;
        /**
            * The total number of pages in the list
            * Only available after fetch has been called
            * @type {number}
            */
        protected totalNumberOfPages: number;
        /**
            * The total number of items in the list
            * Only available after fetch has been called
            * @type {number}
            */
        protected totalNumberOfItems: number;
        /**
            * The list filter applied to the list
            * This may differ from the list of requested filter in the page configuration
            * Only available after fetch has been called
            * @type {any}
            */
        protected appliedFilter: any;
        /**
            * This class wraps a paged result list from EVA and the operations you can perform on it.
            * You can optionally supply page configuration values to start somewhere other then
            * the start of the list
            *
            * @param  {number}                         start           The item to start the list at. Defaults to 0 and is a 0-based index.
            * @param  {number}                         limit           The page size limit. Defaults to 15
            * @param  {EVA.Core.SortDirection}  sortDirection   The sorting direction for the list. Defaults to ascending
            * @return {void}                                           This method doesn't return anything
            */
        constructor(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string);
        /**
            * Returns the current page size limit
            * @return {number}       The configured page size limit
            */
        getLimit(): number;
        /**
            * Set the page size limit
            * @param  {number} limit The new page size limit
            * @return {number}       The configured page size limit
            */
        setLimit(limit: number): number;
        /**
            * Return the current starting item for the list
            * @return {number}       The configured starting point for the list
            */
        getStart(): number;
        /**
            * Set the starting point for the list
            * @param  {number} start The new starting point for the list
            * @return {number}       The configured starting point for the list
            */
        setStart(start: number): number;
        /**
            * Return the current property being sorted on
            * Can be undefined which means the server decides
            * @return {string}      The configured sorting property
            */
        getSortProperty(): string;
        /**
            * Set the property to sort on
            * @param  {string} name The new sorting property
            * @return {string}      The configured sorting property
            */
        setSortProperty(name: string): string;
        /**
            * Returns the current sort direction
            * @return {string}      The configured sorting property
            */
        getSortDirection(): EVA.Core.SortDirection;
        /**
            * Sets the direction to sort the list on
            * @param  {EVA.Core.SortDirection} direction The new sort direction
            * @return {string}      The configured sorting property
            */
        setSortDirection(direction: EVA.Core.SortDirection): EVA.Core.SortDirection;
        /**
            * Set the filter that is to be applied to the list
            * @param  {any} filter The new filter structure
            * @return {any}        The configured filter
            */
        setFilter(filter: any): any;
        /**
            * Returns the current filter for the list
            * @return {any}        The configured filter
            */
        getFilter(): any;
        /**
            * Returns the current filter applied for the list
            * Only after available after fetch has been called
            * The applied filter can differ from the requested filter depending on how
            * the EVA back-end and its products are configured
            * @return {any}        The applied filter
            */
        getAppliedFilter(): any;
        /**
            * Returns all the current page configuration parameters
            * These determine which part of the list data is returned
            * @return {EVA.Core.PageConfig} The current page configuration
            */
        getPageConfiguration(): EVA.Core.PageConfig;
        /**
            * Sets all the current page configuration parameters at once
            * These determine which part of the list data is returned
            * @param  {EVA.Core.PageConfig} pageConfig The page configuration details
            * @return {EVA.Core.PageConfig}            The new page configuration details
            */
        setPageConfiguration(pageConfig: EVA.Core.PageConfig): EVA.Core.PageConfig;
        /**
            * Returns the current page information which entails the current page, total number of pages and total number of items
            * @return {IPageInfo}  The current page information
            */
        getPageInfo(): IPageInfo;
        /**
            * Returns the current page item details. Only available after a successful fetch
            * The details are also exposed direct as the .data attribute for easy binding
            * @return {Array<T>} An array of item details
            */
        getData(): T[];
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES}        response    The response from the service call
            * @return {Array<T>}               The item details
            */
        setData(response: any): T[];
        /**
            * Fetches the list of items from the EVA back-end
            * @param  {string}  serviceName The name of the EVA Service to call
            * @param  {REQ}     requestData The request data for service call
            * @return {Promise<IEVAServiceResponse<REQ, RES>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(serviceName: string, requestData: REQ, path?: string, method?: EXMLHttpRequestMethod): Promise<IEVAServiceResponse<REQ, RES>>;
}

/**
    * The payments module provides the means to pay for an order using an online payment provider
    * @preferred
    */
/**
    * Provides access to order payment methods available in EVA
    */
export class Payments {
        /**
            * [constructor description]
            * @param  {Order}  order The order to perform the payments for
            * @return {void}         This method doesn't return anything
            */
        constructor(order: Order | ShoppingCart);
        /**
            * Returns the list of available payment methods
            * @return {Promise<IEVAServiceResponse<EVA.Core.GetAvailablePaymentMethods, EVA.Core.GetAvailablePaymentMethodsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        getAvailableMethods(): Promise<IEVAServiceResponse<EVA.Core.Services.GetAvailablePaymentMethods, EVA.Core.Services.GetAvailablePaymentMethodsResponse>>;
        /**
            * Retuns the list of banks available for iDeal payments
            * @return {Promise<IEVAServiceResponse<EVA.Payment.Acapture.ListAcaptureIdealBanks, EVA.Payment.Acapture.ListAcaptureIdealBanksResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        getIdealBanks(): Promise<IEVAServiceResponse<EVA.Payment.Acapture.ListAcaptureIdealBanks, EVA.Payment.Acapture.ListAcaptureIdealBanksResponse>>;
        getMultiSafePaymentGateWays(orderId: string | number): Promise<IEVAServiceResponse<EVA.Payment.MultiSafepay.GetMultiSafepayGateways, EVA.Payment.MultiSafepay.GetMultiSafepayGatewaysResponse>>;
        /**
            * Retuns the list of user cards available
            * @return {Promise<IEVAServiceResponse<EVA.Payment.UserCard.ListUserCardsForUser, EVA.Payment.UserCard.ListUserCardsForUserResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        listUserCards(userID: number): Promise<IEVAServiceResponse<EVA.Payment.UserCard.ListUserCardsForUser, EVA.Payment.UserCard.ListUserCardsForUserResponse>>;
        /**
            * Pay for the order using a PIN terminal from ADYEN (shop/employee only)
            * @param  {string}  merchantCode     The ADYEN merchant code to use
            * @param  {number}  amount           The amount to pay
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithAdyen(merchantCode: string, amount: number): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        payWithMultiSafePay(method: string, returnUrl: string, amount?: number): any;
        /**
            * Pay for the order using iDEAL
            * @param  {string}  returnUrl     The URL to return to when the payment has completed
            * @param  {string}  idealBankName The name of the bank for the ideal payment
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithIdeal(returnUrl: string, idealBankName: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for the order using PayPal
            * @param  {string}  returnUrl     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithPaypal(returnUrl: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for the order using a MasterCard/Eurocard credit card
            * @param  {string}  returnUrl     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithMasterCard(returnUrl: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for the order using an American Express credit card
            * @param  {string}  returnUrl     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithAmericanExpress(returnUrl: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for the order using a Visa credit card
            * @param  {string}  returnUrl     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithVisa(returnUrl: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for an order with an insurance card (HFS Waardebrief)
            * @param {string}  referenceNumber The reference number for the credit payment
            * @param {string}  policyNumber    The policy number for the credit payment
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithInsuranceCreditPayment(referenceNumber: string, policyNumber: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for an order with a user card
            * @param {number}  userId          The id of the user
            * @param {number}  userCardId      The id of the userCardId
            * @param {amount}  amount          The amount that will be charged from the usercard
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithUserCard(userId: number, userCardId: number, amount: number): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for an order with Freebees
            * @param {number}  userId          The id of the user
            * @param {number}  userCardId      The id of the userCardId
            * @param {amount}  amount          The amount that will be charged from the usercard
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithFreebees(cardNumber: string, pin?: string, amount?: number, pinType?: "pin" | "password"): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for an order with Freebees
            * @param {number}  cardNumber      The freebeees card number of the user
            * @return {Promise<IEVAServiceResponse<EVA.Kijkshop.FreeBeesGetCardBalance, EVA.Kijkshop.FreeBeesGetCardBalanceResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        getFreebeesBalance(cardNumber: string): Promise<IEVAServiceResponse<EVA.Kijkshop.FreeBeesGetCardBalance, EVA.Kijkshop.FreeBeesGetCardBalanceResponse>>;
        /**
            * Get the balance of the usercard
            *
            * @param {number} cardId
            * @param {string} currencyId
            * @return {Promise<IEVAServiceResponse<EVA.Payment.UserCard.GetUserCardBalance, EVA.Payment.UserCard.GetUserCardBalanceResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        getUserCardBalance(cardId: number, currencyId?: string): Promise<IEVAServiceResponse<EVA.Payment.UserCard.GetUserCardBalance, EVA.Payment.UserCard.GetUserCardBalanceResponse>>;
        /**
            * Get the balance of a gifcard
            *
            * @param {string} cardId
            * @param {string} cardPin
            * @param {string} barcode
            * @param {string} cardType
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.CardBalanceCheck, EVA.EVA.Core.Services.CardBalanceCheckResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        cardBalanceCheck(cardId: string, cardPin?: string, barcode?: string, cardType?: string): Promise<IEVAServiceResponse<EVA.Core.Services.CardBalanceCheck, EVA.Core.Services.CardBalanceCheckResponse>>;
        cancelPendingUserCardPayment(paymentTransactionID: number): Promise<IEVAServiceResponse<EVA.Payment.UserCard.CancelPendingUserCardPayment, EVA.Core.EmptyResponseMessage>>;
        /**
            * Pay for an order with AfterPay
            * @param  {any}  properties     Optional additional properties to send
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithAfterPay(properties?: any): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Finalize a payment (usercard needs this)
            * @param {string}  paymentTransactionID    The payment transaction that is to be finalized
            * @return {Promise<IEVAServiceResponse<EVA.Core.FinalizePayment, EVA.Core.FinalizePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        finalizePayment(paymentTransactionID: number, amount: number): Promise<IEVAServiceResponse<EVA.Core.Services.FinalizePayment, EVA.Core.Services.FinalizePaymentResponse>>;
        /**
            * Pay for an order with a manual payment
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithManualPayment(): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for the order using a PIN terminal (shop/employee only)
            * @param  {string}  stationId     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithPIN(stationId: string, amountGiven: number): Promise<IEVAServiceResponse<EVA.Pin.StartTransaction, EVA.Pin.StartTransactionResponse>>;
        /**
            * Abort a payment for the order using a PIN terminal (shop/employee only)
            * @param  {string}  stationId     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Pin.CreatePinPayment, EVA.Pin.CreatePinPaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        abortPIN(stationId: string): Promise<IEVAServiceResponse<EVA.Pin.AbortTransaction, EVA.Pin.AbortTransactionResponse>>;
        /**
            * Pay for the order using a Cash drawer (shop/employee only)
            * @parm   {Order}   order         The order that is to be paid
            * @param  {string}  returnUrl     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Payment.Cash.MakeCashPayment, EVA.Payment.Cash.MakeCashPaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithCash(stationId: string, amountGiven: number): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for an order with a Media Markt method
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithMediaMarktPayment(): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for the order using Intersolve giftcards
            * @param  {string}  cardNumber     The number on the Intersolve giftcard
            * @param  {string}  [pin]          A giftcard optionally has a PIN, provide when on the card to use the card
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithIntersolve(returnUrl: string, cardNumber: string, pin?: string, amountGiven?: number): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
}

