/**
 * This module provides methods for Addresses, setting / updating addresses on specific
 * objects like customer  and order are done directly on those objects
 *
 * @preferred
 */
import { FetchablePagedList } from "./base";
import { IEVAServiceResponse } from "../service";
export declare class AddressBook extends FetchablePagedList<EVA.Core.Services.AddressBookDto, EVA.Core.Services.ListAddressBook, EVA.Core.Services.ListAddressBookResponse> {
    private userId;
    static setDefaultBillingAddress(id: number): Promise<IEVAServiceResponse<EVA.Core.Services.SetDefaultBillingAddress, EVA.Core.RequestMessageWithEmptyResponse>>;
    static setDefaultShippingAddress(id: number): Promise<IEVAServiceResponse<EVA.Core.Services.SetDefaultShippingAddress, EVA.Core.RequestMessageWithEmptyResponse>>;
    static createItem(address: EVA.Core.AddressDto, description?: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreateAddressBookItem, EVA.Core.CreateResponse>>;
    static updateItem(id: number, address: EVA.Core.AddressDto, description?: string): Promise<IEVAServiceResponse<EVA.Core.Services.UpdateAddressBookItem, EVA.Core.EmptyResponseMessage>>;
    static deleteItem(id: number): Promise<IEVAServiceResponse<EVA.Core.Services.DeleteAddressBookItem, EVA.Core.EmptyResponseMessage>>;
    constructor(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string);
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Core.Services.ListAddressBook, EVA.Core.Services.ListAddressBookResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListAddressBook, EVA.Core.Services.ListAddressBookResponse>>;
}
export declare namespace Addresses {
    /**
     * Wrapper class for Address responses, since this is not a fetchable item
     * it's just a plain object
     */
    class Address {
        data: EVA.Core.AddressDto;
        setData(response: any): EVA.Core.AddressDto;
    }
    /**
     * Perform a lookup using zipcode and housenumber, resolve with an Address object
     *
     * @param  {string}  zipCode     zipcode to lookup
     * @param  {string}  houseNumber housenumber to lookup
     * @return {Promise}             [description]
     */
    function lookup(zipCode: string, houseNumber: string): Promise<Address>;
    /**
     * Request a list of available countries for a user to create addresses with
     * @return {Promise}
     */
    function getAvailableCountries(): Promise<EVA.Core.Services.CountryDto[]>;
    /**
     * Perform an address search using a single text string, responds with textual suggestions.
     * To get the details of the suggestion (city/street etc) a additional call
     * needs to be made to getAddressSuggestionDetails()
     *
     * @param {string}      query       The search query
     * @return {Promise}    array of found suggestions
     */
    function getAddressSuggestions(query: string): Promise<EVA.Core.AddressSuggestion[]>;
    /**
     * Retrieve the details of a suggestion
     *
     * @param {EVA.Core.AddressSuggestion}      suggestion      the address suggestion, can be retrieved using the getAddressSuggestions() function
     * @return {Promise}    the details of the address suggestion
     */
    function getAddressSuggestionDetails(suggestion: EVA.Core.AddressSuggestion): Promise<EVA.Core.AddressSuggestionDetails>;
}
