/**
 * The applications module provides access to the applications data from the EVA back-end
 * @preferred
 */

import { FetchableItem          } from "./base";
import { EVAService,
         IEVAServiceResponse    } from "../service";
import * as _                     from "lodash";

/**
 * Provides access to an order available in EVA
 */
export class Application extends FetchableItem<EVA.Core.Services.ApplicationDto, EVA.Core.Services.GetCurrentApplication, EVA.Core.Services.GetCurrentApplicationResponse> {

    public enabledPlugins: any;

    public fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetCurrentApplication, EVA.Core.Services.GetCurrentApplicationResponse>> {

        // Build the request data
        //
        var requestData: EVA.Core.Services.GetCurrentApplication = <EVA.Core.Services.GetCurrentApplication>{
        };

        return super.fetch( "GetCurrentApplication", requestData );
    }

    public setData( response: EVA.Core.Services.GetCurrentApplicationResponse ): EVA.Core.Services.ApplicationDto {

        this.data = <any>response;

        let enabledPlugins: any = _.filter(
            <Array<EVA.Core.Services.ApplicationPluginConfigurationDto>>_.get( this.data, "PluginConfigurations" )
        ,   <any>{ IsEnabled: true }
        );

        this.enabledPlugins = _.keyBy( enabledPlugins, "PluginCategory" );

        return this.data;
    }

    public configuration(): Promise<IEVAServiceResponse<EVA.Core.Services.GetApplicationConfiguration, EVA.Core.Services.GetApplicationConfigurationResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Core.Services.GetApplicationConfiguration, EVA.Core.Services.GetApplicationConfigurationResponse>( "GetApplicationConfiguration" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
        };

        return service.call( requestData );
    }
}
