/**
 *
 * @preferred
 */
import { EVAService } from "../service";
import * as _         from "lodash";

export namespace Availability
{
    "use strict";

    export function getAvailabilityForProductSet( products: Array<EVA.Core.ProductQuantityDto>, organizationUnitIDs?: Array<number>, fastestPickupShopOnly: boolean = false, includeAvailabilityTexts: boolean = false, detailedShopInformation: boolean = false ): Promise<Array<EVA.Core.ProductAvailabilityIndication>>
    {
        return new Promise( ( resolve: any, reject: any ) =>
        {
            // Create our service instance
            //
            var service = new EVAService<EVA.Core.Services.GetAvailabilityIndication, EVA.Core.Services.GetAvailabilityIndicationResponse>( "GetAvailabilityIndication" );

            // Build the request data
            // The base class will add things like SessionID so to keep typescript
            // happy we're using an 'any' type object here
            //
            var requestData: any = {
                ProductIDs:               products,
                FastestPickupShopOnly:    fastestPickupShopOnly,
                OrganizationUnitIDs:      organizationUnitIDs,
                DetailedShopInformation:  detailedShopInformation,
                IncludeAvailabilityTexts: includeAvailabilityTexts
            };

            // Perform the call and capture the resulting promise
            //
            service.call( requestData )
            .then( ( result ) =>
            {
                resolve( _.get( result, "response.Products" ) || [] );
            } )
            .catch( reject );
        } );
    }
}
