/**
 * The applications module provides access to the applications data from the EVA back-end
 * @preferred
 */
import { FetchableItem } from "./base";
import { IEVAServiceResponse } from "../service";
/**
 * Provides access to a babylon binary blobs in EVA
 */
export declare class Blob extends FetchableItem<EVA.Blobs.BlobDto, EVA.Blobs.GetBlobInfo, EVA.Blobs.GetBlobInfoResponse> {
    /**
     * The optional category for the blob
     * @type {string}
     */
    private category;
    /**
     * The optional original name for the blob
     * @type {string}
     */
    private originalName;
    /**
     * Convenience method to build a blob image URL
     * @param  {string} guid        The blob guid
     * @param  {number} width       The output image width
     * @param  {number} height      The output image height
     * @param  {string} type        The image type (ie. png, jpg, etc)
     *
     * @return {string}             An image URL
     */
    static getImageUrl(guid: string, width?: number, height?: number, format?: string): string;
    /**
     * Sets the category to retrieve the blob info for
     * @param  {string} category    The blob category
     * @return {void}               This method doesn't return anything
     */
    setCategory(category: string): void;
    /**
     * Sets the original name to retrieve the blob info for
     * @param  {string} original name    The blob original name
     * @return {void}               This method doesn't return anything
     */
    setOriginalName(originalName: string): void;
    fetch(): Promise<IEVAServiceResponse<EVA.Blobs.GetBlobInfo, EVA.Blobs.GetBlobInfoResponse>>;
    /**
     * Sets the current item details using the fetched service response.
     * Extending classes should override this method to pull the details from response
     * @param  {RES} response The response from the service call
     * @return {T}            The item details
     */
    setData(response: any): EVA.Blobs.BlobDto;
    create(newBlobInfo: EVA.Blobs.StoreBlob): Promise<IEVAServiceResponse<EVA.Blobs.GetBlobInfo, EVA.Blobs.GetBlobInfoResponse>>;
    createEmpty(newBlobInfo: EVA.Blobs.CreateBlob): Promise<IEVAServiceResponse<EVA.Blobs.CreateBlob, string>>;
    createEmptyBlob(newBlobInfo: EVA.Blobs.CreateBlob): Promise<IEVAServiceResponse<EVA.Blobs.CreateBlob, EVA.Blobs.CreateBlobResponse>>;
    getUploadUrl(guid: string): string;
    process(imageDataBase64: string, type?: string): Promise<IEVAServiceResponse<EVA.Blobs.ProcessDocument, EVA.Blobs.ProcessDocumentResponse>>;
    destroy(): Promise<IEVAServiceResponse<EVA.Blobs.DeleteBlob, EVA.Core.EmptyResponseMessage>>;
    getImageCutoutSuggestions(): Promise<IEVAServiceResponse<EVA.Babylon.GetImageCutoutSuggestions, EVA.Babylon.GetImageCutoutSuggestionsResponse>>;
}
