/**
 * The CMS Menu module provides access to content management menus from the EVA back-end
 * @preferred
 */

import { FetchableItem,
         FetchablePagedList     } from "./base";
import { IEVAServiceResponse    } from "../service";

/**
 * Provides access to a content menu available in EVA
 */
export class ContentMenu extends FetchableItem<EVA.CMS.CmsMenuDto, EVA.CMS.GetCmsMenuByIdentifier, EVA.CMS.GetCmsMenuByIdentifierResponse> {
    /**
     * Fetches the page content
     * @return {Promise<IEVAServiceResponse<EVA.CMS.GetCmsMenuByIdentifier, EVA.CMS.GetCmsMenuByIdentifierResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    public fetch(): Promise<IEVAServiceResponse<EVA.CMS.GetCmsMenuByIdentifier, EVA.CMS.GetCmsMenuByIdentifierResponse>> {

        // Build the request data
        //
        var requestData: EVA.CMS.GetCmsMenuByIdentifier = <EVA.CMS.GetCmsMenuByIdentifier>{
            Identifier: this.getId()
        };

        return super.fetch( "GetCmsMenuByIdentifier", requestData );
    }
}

/**
 * Provides access to a list of content menus available in EVA
 */
export class ContentMenuList extends FetchablePagedList<Array<EVA.CMS.CmsMenuDto>, EVA.CMS.ListCmsMenu, EVA.CMS.ListCmsMenuResponse> {
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.CMS.CmsMenuDto, EVA.CMS.ListCmsMenu, EVA.CMS.ListCmsMenuResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    public fetch(): Promise<IEVAServiceResponse<EVA.CMS.ListCmsMenu, EVA.CMS.ListCmsMenuResponse>> {

        // Build the request data
        //
        var requestData: EVA.CMS.ListCmsMenu = <EVA.CMS.ListCmsMenu>{
            PageConfig: this.getPageConfiguration()
        };

        return super.fetch( "ListCmsMenu", requestData );
    }
}
