/**
 * The CMS Page module provides access to content management pages from the EVA back-end * @preferred
 */
import { FetchableItem, FetchablePagedList } from "./base";
import { IEVAServiceResponse } from "../service";
/**
 * Provides access to a content page available in EVA
 */
export declare class ContentPage extends FetchableItem<EVA.CMS.CmsPageDto, EVA.CMS.GetCmsPage, EVA.CMS.GetCmsPageResponse> {
    /**
     * The request path to retrieve the page for
     * @type {string}
     */
    private requestPath;
    /**
     * Returns the current request path
     * @return {string}       The configured request path
     */
    getRequestPath(): string;
    /**
     * Set the request path to retrieve the page for
     * @param  {string} query The new request path
     * @return {string}       The configured request path
     */
    setRequestPath(requestPath: string): string;
    /**
     * Fetches the page content
     * @return {Promise<IEVAServiceResponse<EVA.CMS.GetCmsPage, EVA.CMS.GetCmsPageResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.CMS.GetCmsPage, EVA.CMS.GetCmsPageResponse>>;
}
/**
 * Provides access to the generic content pages by path request available in EVA
 */
export declare function getCmsPagesByRequestPath(path: string): Promise<IEVAServiceResponse<EVA.CMS.GetCmsPagesByRequestPath, EVA.CMS.GetCmsPagesByRequestPathResponse>>;
/**
 * Provides access to a list of content pages available in EVA
 */
export declare class ContentPageList extends FetchablePagedList<EVA.CMS.CmsPageDto, EVA.CMS.ListCmsPages, EVA.CMS.ListCmsPagesResponse> {
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.CMS.CmsPageDto, EVA.CMS.ListCmsPages, EVA.CMS.ListCmsPagesResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.CMS.ListCmsPages, EVA.CMS.ListCmsPagesResponse>>;
}
