"use strict";
/**
 * The CMS Page module provides access to content management pages from the EVA back-end * @preferred
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var base_1 = require("./base");
var service_1 = require("../service");
/**
 * Provides access to a content page available in EVA
 */
var ContentPage = /** @class */ (function (_super) {
    __extends(ContentPage, _super);
    function ContentPage() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Returns the current request path
     * @return {string}       The configured request path
     */
    ContentPage.prototype.getRequestPath = function () {
        return this.requestPath;
    };
    /**
     * Set the request path to retrieve the page for
     * @param  {string} query The new request path
     * @return {string}       The configured request path
     */
    ContentPage.prototype.setRequestPath = function (requestPath) {
        return this.requestPath = requestPath;
    };
    /**
     * Fetches the page content
     * @return {Promise<IEVAServiceResponse<EVA.CMS.GetCmsPage, EVA.CMS.GetCmsPageResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    ContentPage.prototype.fetch = function () {
        if (this.getId()) {
            // Build the request data
            //
            var requestData = {
                ID: this.getId()
            };
            return _super.prototype.fetch.call(this, "GetCmsPage", requestData);
        }
        else {
            // Build the request data
            //
            var requestByPathData = {
                Path: this.requestPath
            };
            return _super.prototype.fetch.call(this, "GetCmsPageByRequestPath", requestByPathData);
        }
    };
    return ContentPage;
}(base_1.FetchableItem));
exports.ContentPage = ContentPage;
/**
 * Provides access to the generic content pages by path request available in EVA
 */
function getCmsPagesByRequestPath(path) {
    // Create our service instance
    //
    var service = new service_1.EVAService("GetCmsPagesByRequestPath");
    // Build the request data
    //
    var requestData = {
        Path: path,
        __response: undefined
    };
    // Perform the call and capture the resulting promise
    //
    return service.call(requestData);
}
exports.getCmsPagesByRequestPath = getCmsPagesByRequestPath;
/**
 * Provides access to a list of content pages available in EVA
 */
var ContentPageList = /** @class */ (function (_super) {
    __extends(ContentPageList, _super);
    function ContentPageList() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.CMS.CmsPageDto, EVA.CMS.ListCmsPages, EVA.CMS.ListCmsPagesResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    ContentPageList.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {
            PageConfig: this.getPageConfiguration()
        };
        return _super.prototype.fetch.call(this, "ListCmsPages", requestData);
    };
    return ContentPageList;
}(base_1.FetchablePagedList));
exports.ContentPageList = ContentPageList;
