/**
 * The applications module provides access to the applications data from the EVA back-end
 * @preferred
 */
import { FetchableItem, FetchablePagedList } from "./base";
import { IEVAServiceResponse } from "../service";
/**
 * Provides access to a babylon collections (fashion) in EVA
 */
export declare class Collection extends FetchableItem<EVA.Babylon.FashionCollectionDetail, EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse> {
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
    /**
     * Sets the current item details using the fetched service response.
     * Extending classes should override this method to pull the details from response
     * @param  {RES} response The response from the service call
     * @return {T}            The item details
     */
    setData(response: any): EVA.Babylon.FashionCollectionDetail;
    create(collection: EVA.Babylon.CreateFashionCollectionRequestModel): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
    update(collectionDetailsToUpdate: EVA.Babylon.UpdateFashionCollection): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
    delete(): Promise<IEVAServiceResponse<EVA.Babylon.DeleteFashionCollection, EVA.Core.EmptyResponseMessage>>;
    addProducts(productIDs: Array<number>): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
    removeProduct(productID: number): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
    getProductDetails(productID: number): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionProductDetails, EVA.Babylon.GetFashionCollectionProductDetailsResponse>>;
    updateProductSequence(productID: number, sequence: number): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionProductDetails, EVA.Babylon.GetFashionCollectionProductDetailsResponse>>;
}
export declare class CollectionsEarnings extends FetchableItem<EVA.Babylon.FashionCollectionSummaryWithEarnings[], EVA.Babylon.GetFashionCoinEarningsForCollections, EVA.Babylon.GetFashionCoinEarningsForCollectionsResponse> {
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCoinEarningsForCollections, EVA.Babylon.GetFashionCoinEarningsForCollectionsResponse>>;
}
export declare class CollectionProducts extends FetchablePagedList<EVA.Babylon.FashionCollectionProductDetails, EVA.Babylon.ListProductsForCollection, EVA.Babylon.ListProductsForCollectionResponse> {
    /**
     * The collection to retrieve the product list for
     * @type {number}
     */
    private collectionID;
    /**
     * Sets the collection id to retrieve the product list for
     * @param  {number} collectionID        The collection identifier
     * @return {void}                       This method doesn't return anything
     */
    setCollectionID(collectionID: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListProductsForCollection, EVA.Babylon.ListProductsForCollectionResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListProductsForCollection, EVA.Babylon.ListProductsForCollectionResponse>>;
}
export declare class CollectionCoverSheet extends FetchableItem<EVA.Babylon.CoverSheetDocument, EVA.Babylon.GetFashionCollectionCoverSheet, EVA.Babylon.GetFashionCollectionCoverSheetResponse> {
    /**
     * The collection to retrieve the cover sheet for
     * @type {number}
     */
    private collectionID;
    /**
     * Sets the collection id to retrieve the cover sheet for
     * @param  {number} collectionID        The collection identifier
     * @return {void}                       This method doesn't return anything
     */
    setCollectionID(collectionID: number): void;
    /**
     * Sets the current item details using the fetched service response.
     * Extending classes should override this method to pull the details from response
     * @param  {RES} response The response from the service call
     * @return {T}            The item details
     */
    setData(response: any): EVA.Babylon.CoverSheetDocument;
    /**
     * Fetches the collection cover sheet
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionCoverSheet, EVA.Babylon.GetFashionCollectionCoverSheetResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionCoverSheet, EVA.Babylon.GetFashionCollectionCoverSheetResponse>>;
    update(coversheet: EVA.Babylon.CoverSheetDocument): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionCoverSheet, EVA.Babylon.GetFashionCollectionCoverSheetResponse>>;
    productSearch(query: string, pageSize?: number, page?: number, likedProductsPage?: number, createdProductsPage?: number): Promise<IEVAServiceResponse<EVA.Babylon.CoverSheetProductsSearch, EVA.Babylon.CoverSheetProductsSearchResponse>>;
}
export declare class Collections extends FetchablePagedList<EVA.Babylon.FashionCollectionDetail, EVA.Babylon.ListFashionCollectionsForUser, EVA.Babylon.ListFashionCollectionsForUserResponse> {
    /**
     * The user to retrieve the collection list for
     * @type {number}
     */
    private userID;
    private filterCoverSheetExists;
    /**
     * Sets the user id to retrieve the collection list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    setUserID(userID: number): void;
    /**
     * Sets the user id to retrieve the collection list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    setCoverSheetFilter(enableFilter?: boolean): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForUser, EVA.Babylon.ListFashionCollectionsForUserResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForUser, EVA.Babylon.ListFashionCollectionsForUserResponse>>;
}
export declare class TrendingCollections extends FetchablePagedList<EVA.Babylon.FashionCollectionSummary, EVA.Babylon.ListTrendingFashionCollections, EVA.Babylon.ListTrendingFashionCollectionsResponse> {
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListTrendingFashionCollections, EVA.Babylon.ListTrendingFashionCollectionsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListTrendingFashionCollections, EVA.Babylon.ListTrendingFashionCollectionsResponse>>;
}
export declare class TopFashionCollections extends FetchablePagedList<EVA.Babylon.FashionCollectionSummary, EVA.Babylon.GetTopFashionCollections, EVA.Babylon.GetTopFashionCollectionsResponse> {
    /**
     * The user to retrieve the collection list for
     * @type {number}
     */
    private userID;
    /**
     * The creation time where you want the collection to be for
     * @type {string}
     */
    private creationTime;
    /**
     * The maximum number of items you want in your collection
     * @type {number}
     */
    private topCount;
    /**
     * Sets the user id to retrieve the collection list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    setUserID(userID: number): void;
    /**
     * Sets creation time to filter on
     * @param  {Date} time    The creation time to filter on
     * @return {void}         This method doesn't return anything
     */
    setCreationTime(time: Date): void;
    /**
     * Sets top count to filter on
     * @param  {number} count  The top count to filter on
     * @return {void}          This method doesn't return anything
     */
    setTopCount(count: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.GetTopFashionCollections, EVA.Babylon.GetTopFashionCollectionsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetTopFashionCollections, EVA.Babylon.GetTopFashionCollectionsResponse>>;
}
export declare class ProductCollections extends FetchablePagedList<EVA.Babylon.FashionCollectionDetail, EVA.Babylon.ListFashionCollectionsForProduct, EVA.Babylon.ListFashionCollectionsForProductResponse> {
    /**
     * The user to retrieve the collection list for
     * @type {number}
     */
    private userID;
    /**
     * The product to retrieve the collection list for
     * @type {number}
     */
    private productID;
    /**
     * Sets the user id to retrieve the collection list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    setUserID(userID: number): void;
    /**
     * Sets the user id to retrieve the collection list for
     * @param  {number} productID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    setProductID(productID: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForProduct, EVA.Babylon.ListFashionCollectionsForProductResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForProduct, EVA.Babylon.ListFashionCollectionsForProductResponse>>;
}
