"use strict";
/**
 * The applications module provides access to the applications data from the EVA back-end
 * @preferred
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var base_1 = require("./base");
var service_1 = require("../service");
var xhr_1 = require("../xhr");
var _ = require("lodash");
/**
 * Provides access to a babylon collections (fashion) in EVA
 */
var Collection = /** @class */ (function (_super) {
    __extends(Collection, _super);
    function Collection() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Collection.prototype.fetch = function () {
        if (this.getId() === undefined) {
            return Promise.reject({
                status: 404,
                response: "Not found"
            });
        }
        else {
            // Build the request data
            //
            var requestData = {
                CollectionID: this.getId()
            };
            return _super.prototype.fetch.call(this, "GetFashionCollectionDetailsByID", requestData, "/api/v1/fashion/collection/" + this.getId() + "/detail", xhr_1.EXMLHttpRequestMethod.GET);
        }
    };
    /**
     * Sets the current item details using the fetched service response.
     * Extending classes should override this method to pull the details from response
     * @param  {RES} response The response from the service call
     * @return {T}            The item details
     */
    Collection.prototype.setData = function (response) {
        // The default response is usually EVA.Core.GetResponse
        // An extending class will know exactly what is returned and where
        // the data for <T> can be found
        //
        return this.data = response.Collection;
    };
    Collection.prototype.create = function (collection) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            // Create the service instance
            //
            var service = new service_1.EVAService("CreateFashionCollection", "/api/v1/fashion/collection", xhr_1.EXMLHttpRequestMethod.POST);
            // Build the request data
            // The base class will add things like SessionID so keep typescript
            // happy we're using an 'any' type object here
            //
            var requestData = {
                Collection: collection
            };
            // Perform the call and capture the resulting promise
            //
            service.call(requestData)
                .then(function (createResult) {
                // Collect the ID from the response
                //
                _this.id = createResult.response.ID;
                // Return the fetch of the newly created collection
                //
                _this.fetch().then(resolve).catch(reject);
            })
                .catch(reject);
        });
    };
    Collection.prototype.update = function (collectionDetailsToUpdate) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.getId() === undefined) {
                reject({
                    status: 404,
                    response: "Not found"
                });
            }
            else {
                // Update the fashion collection
                //
                var service = new service_1.EVAService("UpdateFashionCollection", "/api/v1/fashion/collection/" + _this.getId(), xhr_1.EXMLHttpRequestMethod.PATCH);
                // Ensure collectionID is set
                //
                collectionDetailsToUpdate.CollectionID = _this.getId();
                // Perform the call and capture the resulting promise
                //
                service.call(collectionDetailsToUpdate)
                    .then(function (updateResult) {
                    // Return the fetch of the updated user profile
                    //
                    _this.fetch().then(resolve).catch(reject);
                })
                    .catch(reject);
            }
        });
    };
    Collection.prototype.delete = function () {
        if (this.getId() === undefined) {
            return Promise.reject({
                status: 404,
                response: "Not found"
            });
        }
        else {
            // Create the service instance
            //
            var callURL = "/api/v1/fashion/collection/" + this.getId();
            var service = new service_1.EVAService("DeleteFashionCollection", callURL, xhr_1.EXMLHttpRequestMethod.DELETE);
            // Build the request data
            // The base class will add things like SessionID so keep typescript
            // happy we're using an 'any' type object here
            //
            var requestData = {};
            // Perform the call and capture the resulting promise
            //
            return service.call(requestData);
        }
    };
    Collection.prototype.addProducts = function (productIDs) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.getId() === undefined) {
                reject({
                    status: 404,
                    response: "Not found"
                });
            }
            else {
                // Create the service instance
                //
                var callURL = "/api/v1/fashion/collection/" + _this.getId() + "/product";
                var service = new service_1.EVAService("AddProductsToFashionCollection", callURL, xhr_1.EXMLHttpRequestMethod.POST);
                // Build the request data
                // The base class will add things like SessionID so keep typescript
                // happy we're using an 'any' type object here
                //
                var requestData = {
                    ProductIDs: productIDs
                };
                // Perform the call and capture the resulting promise
                //
                service.call(requestData)
                    .then(function () {
                    // Return the fetch of the updated collection
                    //
                    _this.fetch().then(resolve).catch(reject);
                })
                    .catch(reject);
            }
        });
    };
    Collection.prototype.removeProduct = function (productID) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.getId() === undefined) {
                reject({
                    status: 404,
                    response: "Not found"
                });
            }
            else {
                // Create the service instance
                //
                var callURL = "/api/v1/fashion/collection/" + _this.getId() + "/product/" + productID;
                var service = new service_1.EVAService("DeleteProductFromFashionCollection", callURL, xhr_1.EXMLHttpRequestMethod.DELETE);
                // Build the request data
                // The base class will add things like SessionID so keep typescript
                // happy we're using an 'any' type object here
                //
                var requestData = {};
                // Perform the call and capture the resulting promise
                //
                service.call(requestData)
                    .then(function () {
                    // Return the fetch of the updated collection
                    //
                    _this.fetch().then(resolve).catch(reject);
                })
                    .catch(reject);
            }
        });
    };
    Collection.prototype.getProductDetails = function (productID) {
        if (this.getId() === undefined) {
            return Promise.reject({
                status: 404,
                response: "Not found"
            });
        }
        else {
            // Create the service instance
            //
            var callURL = "/api/v1/fashion/collection/" + this.getId() + "/product/" + productID;
            var service = new service_1.EVAService("GetFashionCollectionProductDetails", callURL, xhr_1.EXMLHttpRequestMethod.GET);
            // Build the request data
            // The base class will add things like SessionID so keep typescript
            // happy we're using an 'any' type object here
            //
            var requestData = {};
            // Perform the call and capture the resulting promise
            //
            return service.call(requestData);
        }
    };
    Collection.prototype.updateProductSequence = function (productID, sequence) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.getId() === undefined) {
                reject({
                    status: 404,
                    response: "Not found"
                });
            }
            else {
                // Create the service instance
                //
                var callURL = "/api/v1/fashion/collection/" + _this.getId() + "/product/" + productID + "/sequence/" + sequence;
                var service = new service_1.EVAService("UpdateFashionCollectionProductSequence", callURL, xhr_1.EXMLHttpRequestMethod.PUT);
                // Build the request data
                // The base class will add things like SessionID so keep typescript
                // happy we're using an 'any' type object here
                //
                var requestData = {};
                // Perform the call and capture the resulting promise
                //
                service.call(requestData)
                    .then(function () {
                    // Return the fetch of the updated collection
                    //
                    _this.fetch().then(resolve).catch(reject);
                })
                    .catch(reject);
            }
        });
    };
    return Collection;
}(base_1.FetchableItem));
exports.Collection = Collection;
var CollectionsEarnings = /** @class */ (function (_super) {
    __extends(CollectionsEarnings, _super);
    function CollectionsEarnings() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CollectionsEarnings.prototype.fetch = function () {
        var requestData = {
            __response: undefined
        };
        return _super.prototype.fetch.call(this, "GetFashionCoinEarningsForCollections", requestData, "/api/v1/fashion/collection/earnings", xhr_1.EXMLHttpRequestMethod.GET);
    };
    return CollectionsEarnings;
}(base_1.FetchableItem));
exports.CollectionsEarnings = CollectionsEarnings;
var CollectionProducts = /** @class */ (function (_super) {
    __extends(CollectionProducts, _super);
    function CollectionProducts() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the collection id to retrieve the product list for
     * @param  {number} collectionID        The collection identifier
     * @return {void}                       This method doesn't return anything
     */
    CollectionProducts.prototype.setCollectionID = function (collectionID) {
        this.collectionID = collectionID;
    };
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListProductsForCollection, EVA.Babylon.ListProductsForCollectionResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    CollectionProducts.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {};
        // Apply PageConfig parameters directly
        //
        _.assign(requestData, _.omit(this.getPageConfiguration(), ["Filter"]));
        return _super.prototype.fetch.call(this, "ListProductsForCollection", requestData, "/api/v1/fashion/collection/" + this.collectionID + "/product", xhr_1.EXMLHttpRequestMethod.GET);
    };
    return CollectionProducts;
}(base_1.FetchablePagedList));
exports.CollectionProducts = CollectionProducts;
var CollectionCoverSheet = /** @class */ (function (_super) {
    __extends(CollectionCoverSheet, _super);
    function CollectionCoverSheet() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the collection id to retrieve the cover sheet for
     * @param  {number} collectionID        The collection identifier
     * @return {void}                       This method doesn't return anything
     */
    CollectionCoverSheet.prototype.setCollectionID = function (collectionID) {
        this.collectionID = collectionID;
    };
    /**
     * Sets the current item details using the fetched service response.
     * Extending classes should override this method to pull the details from response
     * @param  {RES} response The response from the service call
     * @return {T}            The item details
     */
    CollectionCoverSheet.prototype.setData = function (response) {
        // The default response is usually EVA.Core.GetResponse
        // An extending class will know exactly what is returned and where
        // the data for <T> can be found
        //
        return this.data = response.CoverSheet;
    };
    /**
     * Fetches the collection cover sheet
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionCoverSheet, EVA.Babylon.GetFashionCollectionCoverSheetResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    CollectionCoverSheet.prototype.fetch = function () {
        if (this.getId() === undefined) {
            return Promise.reject({
                status: 404,
                response: "Not found"
            });
        }
        else {
            // Build the request data
            //
            var requestData = {};
            return _super.prototype.fetch.call(this, "GetFashionCollectionCoverSheet", requestData, "/api/v1/fashion/collection/" + this.getId() + "/cover_sheet", xhr_1.EXMLHttpRequestMethod.GET);
        }
    };
    CollectionCoverSheet.prototype.update = function (coversheet) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.getId() === undefined) {
                reject({
                    status: 404,
                    response: "Not found"
                });
            }
            else {
                // Update the cover sheet
                //
                var service = new service_1.EVAService("SaveFashionCollectionCoverSheet", "/api/v1/fashion/collection/" + _this.getId() + "/cover_sheet", xhr_1.EXMLHttpRequestMethod.PUT);
                var requestData = {
                    CollectionID: _this.getId(),
                    CoverSheet: coversheet
                };
                // Perform the call and capture the resulting promise
                //
                service.call(requestData)
                    .then(function (updateResult) {
                    // Return the fetch of the updated user profile
                    //
                    _this.fetch().then(resolve).catch(reject);
                })
                    .catch(reject);
            }
        });
    };
    CollectionCoverSheet.prototype.productSearch = function (query, pageSize, page, likedProductsPage, createdProductsPage) {
        // Update the cover sheet
        //
        var service = new service_1.EVAService("CoverSheetProductsSearch");
        var requestData = {
            Query: query,
            PageSize: pageSize,
            Page: page,
            LikedProductsPage: likedProductsPage,
            CreatedProductsPage: createdProductsPage
        };
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    };
    return CollectionCoverSheet;
}(base_1.FetchableItem));
exports.CollectionCoverSheet = CollectionCoverSheet;
var Collections = /** @class */ (function (_super) {
    __extends(Collections, _super);
    function Collections() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the user id to retrieve the collection list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    Collections.prototype.setUserID = function (userID) {
        this.userID = userID;
    };
    /**
     * Sets the user id to retrieve the collection list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    Collections.prototype.setCoverSheetFilter = function (enableFilter) {
        if (enableFilter === void 0) { enableFilter = true; }
        this.filterCoverSheetExists = enableFilter;
    };
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForUser, EVA.Babylon.ListFashionCollectionsForUserResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    Collections.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {};
        if (_.isBoolean(this.filterCoverSheetExists)) {
            requestData.FilterCoverSheetExists = this.filterCoverSheetExists;
        }
        // Apply PageConfig parameters directly
        //
        _.assign(requestData, _.omit(this.getPageConfiguration(), ["Filter"]));
        return _super.prototype.fetch.call(this, "ListFashionCollectionsForUser", requestData, "/api/v1/social/user/" + this.userID + "/collection", xhr_1.EXMLHttpRequestMethod.GET);
    };
    return Collections;
}(base_1.FetchablePagedList));
exports.Collections = Collections;
var TrendingCollections = /** @class */ (function (_super) {
    __extends(TrendingCollections, _super);
    function TrendingCollections() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListTrendingFashionCollections, EVA.Babylon.ListTrendingFashionCollectionsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    TrendingCollections.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {};
        // Apply PageConfig parameters directly
        //
        _.assign(requestData, _.omit(this.getPageConfiguration(), ["Filter"]));
        return _super.prototype.fetch.call(this, "ListTrendingFashionCollections", requestData, "/api/v1/fashion/collection/trending", xhr_1.EXMLHttpRequestMethod.GET);
    };
    return TrendingCollections;
}(base_1.FetchablePagedList));
exports.TrendingCollections = TrendingCollections;
var TopFashionCollections = /** @class */ (function (_super) {
    __extends(TopFashionCollections, _super);
    function TopFashionCollections() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the user id to retrieve the collection list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    TopFashionCollections.prototype.setUserID = function (userID) {
        this.userID = userID;
    };
    /**
     * Sets creation time to filter on
     * @param  {Date} time    The creation time to filter on
     * @return {void}         This method doesn't return anything
     */
    TopFashionCollections.prototype.setCreationTime = function (time) {
        this.creationTime = time.toISOString();
    };
    /**
     * Sets top count to filter on
     * @param  {number} count  The top count to filter on
     * @return {void}          This method doesn't return anything
     */
    TopFashionCollections.prototype.setTopCount = function (count) {
        this.topCount = count;
    };
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.GetTopFashionCollections, EVA.Babylon.GetTopFashionCollectionsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    TopFashionCollections.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {};
        // Check if we need to filter on user
        //
        if (this.userID) {
            requestData.UserID = this.userID;
        }
        // Check if we need to filter on creation time
        //
        if (this.creationTime) {
            requestData.CreationTime = this.creationTime;
        }
        // Checkif we need to filter on top count
        // By default we set it to 10
        //
        var topCountURI = 10;
        if (this.topCount) {
            topCountURI = this.topCount;
        }
        // Apply PageConfig parameters directly
        //
        _.assign(requestData, _.omit(this.getPageConfiguration(), ["Filter"]));
        return _super.prototype.fetch.call(this, "GetTopFashionCollections", requestData, "/api/v1/fashion/collection/top/" + topCountURI, xhr_1.EXMLHttpRequestMethod.GET);
    };
    return TopFashionCollections;
}(base_1.FetchablePagedList));
exports.TopFashionCollections = TopFashionCollections;
var ProductCollections = /** @class */ (function (_super) {
    __extends(ProductCollections, _super);
    function ProductCollections() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the user id to retrieve the collection list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    ProductCollections.prototype.setUserID = function (userID) {
        this.userID = userID;
    };
    /**
     * Sets the user id to retrieve the collection list for
     * @param  {number} productID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    ProductCollections.prototype.setProductID = function (productID) {
        this.productID = productID;
    };
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForProduct, EVA.Babylon.ListFashionCollectionsForProductResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    ProductCollections.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {
            UserID: this.userID
        };
        // Apply PageConfig parameters directly
        //
        _.assign(requestData, _.omit(this.getPageConfiguration(), ["Filter"]));
        return _super.prototype.fetch.call(this, "ListFashionCollectionsForProduct", requestData, "/api/v1/social/product/" + this.productID + "/collection", xhr_1.EXMLHttpRequestMethod.GET);
    };
    return ProductCollections;
}(base_1.FetchablePagedList));
exports.ProductCollections = ProductCollections;
