/**
 * The DMS Menu module provides access to content management menus from the EVA back-end
 * @preferred
 */

import { FetchableItem          } from "./../base";
import { IEVAServiceResponse    } from "../../service";

/**
 * Provides access to a content menu available in EVA
 */
export class DmsMenu extends FetchableItem<EVA.DMS.MenuDto, EVA.DMS.DmsGetMenuByIdentifier, EVA.DMS.DmsGetMenuByIdentifierResponse> {
    /**
     * The request path to retrieve the page for
     * @type {string}
     */
    private requestPath: string;

    /**
     * Returns the current request path
     * @return {string}       The configured request path
     */
    public getRequestPath(): string {
        return this.requestPath;
    }

    /**
     * Set the request path to retrieve the page for
     * @param  {string} query The new request path
     * @return {string}       The configured request path
     */
    public setRequestPath( requestPath: string ): string {
        return this.requestPath = requestPath;
    }

    /**
     * Fetches the page content
     * @return {Promise<IEVAServiceResponse<EVA.DMS.GetMenuByIdentifier, EVA.DMS.GetMenuByIdentifierResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    public fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetMenuByIdentifier, EVA.DMS.DmsGetMenuByIdentifierResponse>> {

        // Build the request data
        //
        var requestData: EVA.DMS.DmsGetMenuByIdentifier = <EVA.DMS.DmsGetMenuByIdentifier>{
            Path: this.requestPath
        };

        return super.fetch( "DmsGetMenuByIdentifier", requestData );
    }
}
