/**
 * The DMS Page module provides access to content management pages from the EVA back-end * @preferred
 */
import { FetchableItem } from "./../base";
import { IEVAServiceResponse } from "../../service";
/**
 * Provides access to a content page available in EVA
 */
export declare class DmsPage extends FetchableItem<EVA.DMS.LivePageDto, EVA.DMS.DmsGetLivePage, EVA.DMS.DmsGetLivePageResponse> {
    /**
     * The request path to retrieve the page for
     * @type {string}
     */
    private requestPath;
    /**
     * The view ID to retrieve the page by selected view
     * @type {number}
     */
    private viewId;
    /**
     * Returns the current request path
     * @return {string}       The configured request path
     */
    getRequestPath(): string;
    /**
     * Set the request path to retrieve the page for
     * @param  {string} query The new request path
     * @return {string}       The configured request path
     */
    setRequestPath(requestPath: string): string;
    /**
     * Returns the current view ID
     * @return {number}       The configured view ID
     */
    getViewId(): number;
    /**
     * Set the request path to retrieve the page by view ID
     * @param  {number} query The new view ID
     * @return {number}       The configured view ID
     */
    setViewId(viewId: number): number;
    /**
     * Fetches the page content
     * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetLivePage, EVA.DMS.DmsGetLivePageResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetLivePage, EVA.DMS.DmsGetLivePageResponse>>;
    listViews(): Promise<IEVAServiceResponse<EVA.DMS.DmsListViewsForPage, EVA.DMS.DmsListViewsForPageResponse>>;
    saveLayout(blocks: EVA.DMS.WidgetLayoutBlockDto[]): Promise<IEVAServiceResponse<EVA.DMS.DmsUpdateViewLayout, EVA.Core.EmptyResponseMessage>>;
}
/**
 * Provides access to a content page available in EVA
 */
export declare class DmsCompiledPage extends FetchableItem<EVA.DMS.CompiledPageDto, EVA.DMS.DmsGetCompiledPage, EVA.DMS.DmsGetCompiledPageResponse> {
    /**
     * The request path to retrieve the page for
     * @type {string}
     */
    private requestPath;
    /**
     * Returns the current request path
     * @return {string}       The configured request path
     */
    getRequestPath(): string;
    /**
     * Set the request path to retrieve the page for
     * @param  {string} query The new request path
     * @return {string}       The configured request path
     */
    setRequestPath(requestPath: string): string;
    /**
     * Fetches the page content
     * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledPage, EVA.DMS.DmsGetCompiledPageResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledPage, EVA.DMS.DmsGetCompiledPageResponse>>;
}
