"use strict";
/**
 * The DMS Page module provides access to content management pages from the EVA back-end * @preferred
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var base_1 = require("./../base");
var service_1 = require("../../service");
/**
 * Provides access to a content page available in EVA
 */
var DmsPage = /** @class */ (function (_super) {
    __extends(DmsPage, _super);
    function DmsPage() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Returns the current request path
     * @return {string}       The configured request path
     */
    DmsPage.prototype.getRequestPath = function () {
        return this.requestPath;
    };
    /**
     * Set the request path to retrieve the page for
     * @param  {string} query The new request path
     * @return {string}       The configured request path
     */
    DmsPage.prototype.setRequestPath = function (requestPath) {
        return this.requestPath = requestPath;
    };
    /**
     * Returns the current view ID
     * @return {number}       The configured view ID
     */
    DmsPage.prototype.getViewId = function () {
        return this.viewId;
    };
    /**
     * Set the request path to retrieve the page by view ID
     * @param  {number} query The new view ID
     * @return {number}       The configured view ID
     */
    DmsPage.prototype.setViewId = function (viewId) {
        return this.viewId = viewId;
    };
    /**
     * Fetches the page content
     * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetLivePage, EVA.DMS.DmsGetLivePageResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    DmsPage.prototype.fetch = function () {
        if (this.getViewId()) {
            // Build the request data
            //
            var requestData = {
                ID: this.getViewId()
            };
            return _super.prototype.fetch.call(this, "DmsGetPageByViewID", requestData);
        }
        else if (this.getId()) {
            // Build the request data
            //
            var requestData = {
                ID: this.getId()
            };
            return _super.prototype.fetch.call(this, "DmsGetLivePage", requestData);
        }
        else {
            // Build the request data
            //
            var requestByPathData = {
                Path: this.requestPath
            };
            return _super.prototype.fetch.call(this, "DmsGetLivePage", requestByPathData);
        }
    };
    DmsPage.prototype.listViews = function () {
        // Create the service instance
        //
        var service = new service_1.EVAService("DmsListViewsForPage");
        // Build the request data
        //
        var requestData = {
            ID: this._id
        };
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    };
    DmsPage.prototype.saveLayout = function (blocks) {
        // Create the service instance
        //
        var service = new service_1.EVAService("DmsUpdateViewLayout");
        // Build the request data
        //
        var requestData = {
            Blocks: blocks
        };
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    };
    return DmsPage;
}(base_1.FetchableItem));
exports.DmsPage = DmsPage;
/**
 * Provides access to a content page available in EVA
 */
var DmsCompiledPage = /** @class */ (function (_super) {
    __extends(DmsCompiledPage, _super);
    function DmsCompiledPage() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Returns the current request path
     * @return {string}       The configured request path
     */
    DmsCompiledPage.prototype.getRequestPath = function () {
        return this.requestPath;
    };
    /**
     * Set the request path to retrieve the page for
     * @param  {string} query The new request path
     * @return {string}       The configured request path
     */
    DmsCompiledPage.prototype.setRequestPath = function (requestPath) {
        return this.requestPath = requestPath;
    };
    /**
     * Fetches the page content
     * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledPage, EVA.DMS.DmsGetCompiledPageResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    DmsCompiledPage.prototype.fetch = function () {
        if (this.getId()) {
            // Build the request data
            //
            var requestData = {
                ID: this.getId()
            };
            return _super.prototype.fetch.call(this, "DmsGetCompiledPage", requestData);
        }
        else {
            // Build the request data
            //
            var requestByPathData = {
                Path: this.requestPath
            };
            return _super.prototype.fetch.call(this, "DmsGetCompiledPage", requestByPathData);
        }
    };
    return DmsCompiledPage;
}(base_1.FetchableItem));
exports.DmsCompiledPage = DmsCompiledPage;
