"use strict";
/**
 * The DMS Widget module provides access to content management widgets from the EVA back-end * @preferred
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var base_1 = require("./../base");
var service_1 = require("../../service");
/**
 * Provides access to a content widget available in EVA
 */
var DmsWidget = /** @class */ (function (_super) {
    __extends(DmsWidget, _super);
    function DmsWidget() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Fetches the widget content
     * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledWidgetByID, EVA.DMS.DmsGetCompiledWidgetByIDResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    DmsWidget.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {
            ID: this.getId()
        };
        return _super.prototype.fetch.call(this, "DmsGetCompiledWidgetByID", requestData);
    };
    DmsWidget.prototype.create = function (widget, viewID) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            // Create the service instance
            //
            var service = new service_1.EVAService("DmsCreateWidget");
            // Build the request data
            //
            var requestData = widget;
            requestData.ViewID = viewID;
            // Perform the call and capture the resulting promise
            //
            service.call(requestData)
                .then(function (createResult) {
                // Collect the ID from the response
                //
                _this.id = createResult.response.ID;
                // Return the fetch of the newly created collection
                //
                _this.fetch().then(resolve).catch(reject);
            })
                .catch(reject);
        });
    };
    /**
     * Update the widget
     *
     * @return {Promise} A promise resolving when the call to the back-end has completed
     */
    DmsWidget.prototype.updateHtml = function (html) {
        var _this = this;
        var service = new service_1.EVAService("DmsUpdateWidget");
        var requestData = {
            ID: this.id,
            Data: html
        };
        return new Promise(function (resolve, reject) {
            service.call(requestData)
                .then(function (serviceResult) {
                _this.setData(serviceResult.response);
                resolve(serviceResult);
            })
                .catch(reject);
        });
    };
    return DmsWidget;
}(base_1.FetchableItem));
exports.DmsWidget = DmsWidget;
