/**
 * The DMS Widget module provides access to content management widgets from the EVA back-end * @preferred
 */

import { FetchableItem                   } from "./../base";
import { EVAService, IEVAServiceResponse } from "../../service";

/**
 * Provides access to a content widget available in EVA
 */
export class DmsWidget extends FetchableItem<EVA.DMS.LiveWidgetDto, EVA.DMS.DmsGetCompiledWidgetByID, EVA.DMS.DmsGetCompiledWidgetByIDResponse> {
    /**
     * Fetches the widget content
     * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledWidgetByID, EVA.DMS.DmsGetCompiledWidgetByIDResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    public fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledWidgetByID, EVA.DMS.DmsGetCompiledWidgetByIDResponse>> {

        // Build the request data
        //
        var requestData: EVA.DMS.DmsGetCompiledWidgetByID = <EVA.DMS.DmsGetCompiledWidgetByID>{
            ID: this.getId()
        };

        return super.fetch( "DmsGetCompiledWidgetByID", requestData );
    }

    public create( widget: EVA.DMS.WidgetDto, viewID: number ): Promise<IEVAServiceResponse<EVA.DMS.DmsCreateWidget, EVA.Core.CreateResponse>>
    {
        return new Promise( ( resolve: any, reject: any ) =>
        {
            // Create the service instance
            //
            var service = new EVAService<EVA.DMS.DmsCreateWidget, EVA.Core.CreateResponse>( "DmsCreateWidget" );

            // Build the request data
            //
            let requestData: EVA.DMS.DmsCreateWidget = <any> widget;
            requestData.ViewID = viewID;

            // Perform the call and capture the resulting promise
            //
            service.call( requestData )
            .then( ( createResult: IEVAServiceResponse<EVA.DMS.DmsCreateWidget, EVA.Core.CreateResponse> ) =>
            {
                // Collect the ID from the response
                //
                this.id = createResult.response.ID;

                // Return the fetch of the newly created collection
                //
                this.fetch().then( resolve ).catch( reject );
            } )
            .catch( reject );
        } );
    }

    /**
     * Update the widget
     *
     * @return {Promise} A promise resolving when the call to the back-end has completed
     */
    public updateHtml( html: string ): Promise<IEVAServiceResponse<EVA.DMS.DmsUpdateWidget, EVA.Core.EmptyResponseMessage>>
    {
        var service = new EVAService<EVA.DMS.DmsUpdateWidget, EVA.Core.EmptyResponseMessage>( "DmsUpdateWidget" );

        var requestData: any = {
            ID:     this.id,
            Data:   html
        };

        return new Promise( ( resolve, reject ) => {
            service.call( requestData )
            .then( ( serviceResult ) =>
            {
                this.setData( serviceResult.response );
                resolve( serviceResult );
            } )
            .catch( reject );
        } );
    }
}
