import { EVAService, IEVAServiceResponse } from "../service";

// Expose EVA document signing services
//
export namespace DocumentSigning
{
    "use strict";

    // This service generates a QR code that can be scanned to provide
    // the possibility to sign an order with an digital autograph
    //
    export function getSigningCodeForOrder( orderId: number ): Promise<IEVAServiceResponse<EVA.DocumentSigning.GetSigningCodeForOrder, EVA.DocumentSigning.GetSigningCodeForOrderResponse>>
    {
        return new Promise( ( resolve: any, reject: any ) =>
        {
            var service = new EVAService<EVA.DocumentSigning.GetSigningCodeForOrder, EVA.DocumentSigning.GetSigningCodeForOrderResponse>( "GetSigningCodeForOrder" );

            // Construct the request object
            //
            var requestData: EVA.DocumentSigning.GetSigningCodeForOrder = {
                OrderID: orderId,
                __response: undefined
            };

            // Perform the XHR call
            //
            service.call( requestData )
            .then( ( serviceResult ) => { resolve( serviceResult.response ); } )
            .catch( ( error: any ) => { reject( error ); } );
        } );
    }

    // Retrieve the order data after you scanned the QR code
    //
    export function getSigningDataForOrder( hashId: string ): Promise<IEVAServiceResponse<EVA.DocumentSigning.GetSigningDataForOrder, EVA.DocumentSigning.GetSigningDataForOrderResponse>>
    {
        return new Promise( ( resolve: any, reject: any ) =>
        {
            var service = new EVAService<EVA.DocumentSigning.GetSigningDataForOrder, EVA.DocumentSigning.GetSigningDataForOrderResponse>( "GetSigningDataForOrder" );

            // Construct the request object
            //
            var requestData: EVA.DocumentSigning.GetSigningDataForOrder = {
                Hash: hashId,
                __response: undefined
            };

            // Perform the XHR call
            //
            service.call( requestData )
            .then( ( serviceResult ) => { resolve( serviceResult.response ); } )
            .catch( ( error: any ) => { reject( error ); } );
        } );
    }

    // Sign the order with the autograph (blob)
    //
    export function signOrder( signature: number[], mimeType: string, hashId: string ): Promise<IEVAServiceResponse<EVA.DocumentSigning.SignOrder, EVA.Core.RequestMessageWithEmptyResponse>>
    {
        return new Promise( ( resolve: any, reject: any ) =>
        {
            var service = new EVAService<EVA.DocumentSigning.SignOrder, EVA.Core.RequestMessageWithEmptyResponse>( "SignOrder" );

            // Construct the request object
            //
            var requestData: EVA.DocumentSigning.SignOrder = {
                Signature:      signature,
                MimeType:       mimeType,
                Hash:           hashId,
                __response: undefined
            };

            // Perform the XHR call
            //
            service.call( requestData )
            .then( ( serviceResult ) => { resolve( serviceResult.response ); } )
            .catch( ( error: any ) => { reject( error ); } );
        } );
    }
}
