"use strict";
/**
 * The applications module provides access to the applications data from the EVA back-end
 * @preferred
 */
Object.defineProperty(exports, "__esModule", { value: true });
var service_1 = require("../service");
var xhr_1 = require("../xhr");
/**
 * Provides access to a babylon social functions in EVA
 * These are the by identifier versions that can be reused by EVA SDK objects
 */
var Feed;
(function (Feed) {
    "use strict";
    function getFeedByType(feedType, offset, limit) {
        // Create the service instance
        //
        var callURL = "/api/v1/social/feed/user/" + feedType;
        var service = new service_1.EVAService("GetUserFeed", callURL, xhr_1.EXMLHttpRequestMethod.GET);
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {};
        if (offset) {
            requestData.OffsetID = offset;
        }
        if (limit) {
            requestData.Limit = limit;
        }
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    Feed.getFeedByType = getFeedByType;
    function getTrendingFeed(skip, limit, type) {
        if (type === void 0) { type = 0; }
        // Create the service instance
        //
        var callURL = "/api/v1/social/feed/trending";
        var service = new service_1.EVAService("GetTrendingFeed", callURL, xhr_1.EXMLHttpRequestMethod.GET);
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {};
        if (skip) {
            requestData.Offset = skip;
        }
        if (limit) {
            requestData.Limit = limit;
        }
        // Set the feed type
        // All = 0
        // Products = 1
        // Collections = 2
        //
        requestData.Type = type;
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    Feed.getTrendingFeed = getTrendingFeed;
    function getNotificationFeed(offset, limit) {
        // Create the service instance
        //
        var callURL = "/api/v1/social/feed/notification";
        var service = new service_1.EVAService("GetNotificationFeed", callURL, xhr_1.EXMLHttpRequestMethod.GET);
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {};
        if (offset) {
            requestData.OffsetID = offset;
        }
        if (limit) {
            requestData.Limit = limit;
        }
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    Feed.getNotificationFeed = getNotificationFeed;
    function getUnseenNotifications() {
        // Create the service instance
        //
        var callURL = "/api/v1/social/feed/notification/count/unseen";
        var service = new service_1.EVAService("GetNotificationFeed", callURL, xhr_1.EXMLHttpRequestMethod.GET);
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {};
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    Feed.getUnseenNotifications = getUnseenNotifications;
})(Feed = exports.Feed || (exports.Feed = {}));
