/**
 * The applications module provides access to the applications data from the EVA back-end
 * @preferred
 */

import { EVAService, IEVAServiceResponse   } from "../service";
import { EXMLHttpRequestMethod             } from "../xhr";

/**
 * Provides access to a babylon social functions in EVA
 * These are the by identifier versions that can be reused by EVA SDK objects
 */
export namespace Feed
{
    "use strict";

    export function getFeedByType( feedType: string, offset?: number|string, limit?: number ): Promise<IEVAServiceResponse<EVA.Babylon.GetUserFeed, EVA.Babylon.GetUserFeedResponse>>
    {
        // Create the service instance
        //
        var callURL: string = `/api/v1/social/feed/user/${feedType}`;

        var service = new EVAService<EVA.Babylon.GetUserFeed, EVA.Babylon.GetUserFeedResponse>( "GetUserFeed", callURL, EXMLHttpRequestMethod.GET );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {};

        if ( offset )
        {
            requestData.OffsetID = offset;
        }
        if ( limit )
        {
            requestData.Limit = limit;
        }

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getTrendingFeed( skip?: number, limit?: number, type: EVA.Babylon.TrendingFeedTypes = 0 ): Promise<IEVAServiceResponse<EVA.Babylon.GetTrendingFeed, EVA.Babylon.GetTrendingFeedResponse>>
    {
        // Create the service instance
        //
        var callURL: string = `/api/v1/social/feed/trending`;

        var service = new EVAService<EVA.Babylon.GetTrendingFeed, EVA.Babylon.GetTrendingFeedResponse>( "GetTrendingFeed", callURL, EXMLHttpRequestMethod.GET );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {};

        if ( skip )
        {
            requestData.Offset = skip;
        }
        if ( limit )
        {
            requestData.Limit = limit;
        }

        // Set the feed type
        // All = 0
        // Products = 1
        // Collections = 2
        //
        requestData.Type = type;

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getNotificationFeed( offset?: number, limit?: number ): Promise<IEVAServiceResponse<EVA.Babylon.GetNotificationFeed, EVA.Babylon.GetNotificationFeedResponse>>
    {
        // Create the service instance
        //
        var callURL: string = `/api/v1/social/feed/notification`;

        var service = new EVAService<EVA.Babylon.GetNotificationFeed, EVA.Babylon.GetNotificationFeedResponse>( "GetNotificationFeed", callURL, EXMLHttpRequestMethod.GET );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {};

        if ( offset )
        {
            requestData.OffsetID = offset;
        }
        if ( limit )
        {
            requestData.Limit = limit;
        }

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getUnseenNotifications(): Promise<IEVAServiceResponse<EVA.Babylon.GetNotificationFeed, EVA.Babylon.GetNotificationFeedResponse>>
    {
        // Create the service instance
        //
        var callURL: string = `/api/v1/social/feed/notification/count/unseen`;

        var service = new EVAService<EVA.Babylon.GetNotificationFeed, EVA.Babylon.GetNotificationFeedResponse>( "GetNotificationFeed", callURL, EXMLHttpRequestMethod.GET );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {};

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }
}
