/**
 * The applications module provides access to the applications data from the EVA back-end
 * @preferred
 */
import { FetchablePagedList } from "./base";
import { IEVAServiceResponse } from "../service";
/**
 * Provides access to a babylon social functions in EVA
 * These are the by identifier versions that can be reused by EVA SDK objects
 */
export declare namespace Gamification {
    function getCoverSheetEditorCapabilities(): Promise<IEVAServiceResponse<EVA.Babylon.GetCoverSheetEditorCapabilities, EVA.Babylon.GetCoverSheetEditorCapabilitiesResponse>>;
    function getSocialGetProgressionByID(id: number): Promise<IEVAServiceResponse<EVA.Social.SocialGetProgressionByID, EVA.Social.SocialGetProgressionByIDResponse>>;
    function getSocialProgressions(userId: number, type: EVA.Social.SocialProgressionType): Promise<IEVAServiceResponse<EVA.Social.SocialGetProgressions, EVA.Social.SocialGetProgressionsResponse>>;
    function getSocialProgressionRanking(userId: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetProgressionRanking, EVA.Babylon.SocialGetProgressionRankingResponse>>;
    function getActiveFashionEvent(): Promise<IEVAServiceResponse<EVA.Babylon.GetActiveFashionEvent, EVA.Babylon.GetActiveFashionEventResponse>>;
    function getBarcodeDataForFashionEvent(): Promise<IEVAServiceResponse<EVA.Babylon.GetBarcodeDataForFashionEvent, EVA.Babylon.GetBarcodeDataForFashionEventResponse>>;
    function scanBarcodeDataForFashionEvent(data: string): Promise<IEVAServiceResponse<EVA.Babylon.ScanBarcodeForFashionEvent, EVA.Babylon.ScanBarcodeForFashionEventResponse>>;
    function getBarcodeUrlForFashionEvent(data: string, width?: number, height?: number): string;
    function getActiveFashionCollectionContests(): Promise<IEVAServiceResponse<EVA.Babylon.GetActiveFashionCollectionContests, EVA.Babylon.GetActiveFashionCollectionContestsResponse>>;
    function getFashionCoinTotalsForUser(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCoinTotalsForUser, EVA.Babylon.GetFashionCoinTotalsForUserResponse>>;
    function convertFashionCoins(amount: number, direction: EVA.Babylon.FashionCoinConversionDirection): Promise<IEVAServiceResponse<EVA.Babylon.ConvertFashionCoins, EVA.Babylon.ConvertFashionCoinsResponse>>;
}
/**
 * Provides access to a list of fashion collections for a contest available in EVA
 */
export declare class FashionCollectionsForContest extends FetchablePagedList<EVA.Babylon.FashionCollectionContestDto, EVA.Babylon.ListFashionCollectionsForContest, EVA.Babylon.ListFashionCollectionsForContestResponse> {
    /**
     * The contest to retrieve the fashion collection list for
     * @type {number}
     */
    private contestId;
    /**
     * Sets the contest id to retrieve the fashion collection list for
     * @param  {number} contestId      The organization identifier
     * @return {void}                  This method doesn't return anything
     */
    setContestId(contestId: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.FashionCollectionContestDto, EVA.Babylon.ListFashionCollectionsForContest, EVA.Babylon.ListFashionCollectionsForContestResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForContest, EVA.Babylon.ListFashionCollectionsForContestResponse>>;
}
/**
 * Provides access to a list of fashion coin transactions
 */
export declare class FashionCoinTransactions extends FetchablePagedList<EVA.Babylon.FashionCollectionContestDto, EVA.Babylon.ListFashionCoinTransactions, EVA.Babylon.ListFashionCoinTransactionsResponse> {
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.FashionCoinTransaction, EVA.Babylon.ListFashionCoinTransactions, EVA.Babylon.ListFashionCoinTransactionsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCoinTransactions, EVA.Babylon.ListFashionCoinTransactionsResponse>>;
}
