/**
 * The applications module provides access to the applications data from the EVA back-end
 * @preferred
 */

import { FetchablePagedList                } from "./base";
import { EVAService, IEVAServiceResponse   } from "../service";
import { EXMLHttpRequestMethod             } from "../xhr";

/**
 * Provides access to a babylon social functions in EVA
 * These are the by identifier versions that can be reused by EVA SDK objects
 */
export namespace Gamification
{
    "use strict";

    export function getCoverSheetEditorCapabilities(): Promise<IEVAServiceResponse<EVA.Babylon.GetCoverSheetEditorCapabilities, EVA.Babylon.GetCoverSheetEditorCapabilitiesResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Babylon.GetCoverSheetEditorCapabilities, EVA.Babylon.GetCoverSheetEditorCapabilitiesResponse>( "GetCoverSheetEditorCapabilities" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {};

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getSocialGetProgressionByID( id: number ): Promise<IEVAServiceResponse<EVA.Social.SocialGetProgressionByID, EVA.Social.SocialGetProgressionByIDResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Social.SocialGetProgressionByID, EVA.Social.SocialGetProgressionByIDResponse>( "SocialGetProgressionByID" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
            ID: id
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getSocialProgressions( userId: number, type: EVA.Social.SocialProgressionType ): Promise<IEVAServiceResponse<EVA.Social.SocialGetProgressions, EVA.Social.SocialGetProgressionsResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Social.SocialGetProgressions, EVA.Social.SocialGetProgressionsResponse>( "SocialGetProgressions" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
            UserID: userId,
            Type:   type
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getSocialProgressionRanking( userId: number ): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetProgressionRanking, EVA.Babylon.SocialGetProgressionRankingResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Babylon.SocialGetProgressionRanking, EVA.Babylon.SocialGetProgressionRankingResponse>( "SocialGetProgressionRanking" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
            UserID: userId
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getActiveFashionEvent(): Promise<IEVAServiceResponse<EVA.Babylon.GetActiveFashionEvent, EVA.Babylon.GetActiveFashionEventResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Babylon.GetActiveFashionEvent, EVA.Babylon.GetActiveFashionEventResponse>( "GetActiveFashionEvent" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {};

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getBarcodeDataForFashionEvent(): Promise<IEVAServiceResponse<EVA.Babylon.GetBarcodeDataForFashionEvent, EVA.Babylon.GetBarcodeDataForFashionEventResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Babylon.GetBarcodeDataForFashionEvent, EVA.Babylon.GetBarcodeDataForFashionEventResponse>( "GetBarcodeDataForFashionEvent" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {};

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function scanBarcodeDataForFashionEvent( data: string ): Promise<IEVAServiceResponse<EVA.Babylon.ScanBarcodeForFashionEvent, EVA.Babylon.ScanBarcodeForFashionEventResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Babylon.ScanBarcodeForFashionEvent, EVA.Babylon.ScanBarcodeForFashionEventResponse>( "ScanBarcodeForFashionEvent" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
            Data: data
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getBarcodeUrlForFashionEvent( data: string, width: number = 500, height: number = 500 ) {
        return `https://api.frendz.nl/barcode/qr/${width}/${height}/${data}`;
    }

    export function getActiveFashionCollectionContests(): Promise<IEVAServiceResponse<EVA.Babylon.GetActiveFashionCollectionContests, EVA.Babylon.GetActiveFashionCollectionContestsResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Babylon.GetActiveFashionCollectionContests, EVA.Babylon.GetActiveFashionCollectionContestsResponse>( "GetActiveFashionCollectionContests" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Babylon.GetActiveFashionCollectionContests = {
            __response: undefined
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getFashionCoinTotalsForUser(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCoinTotalsForUser, EVA.Babylon.GetFashionCoinTotalsForUserResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Babylon.GetFashionCoinTotalsForUser, EVA.Babylon.GetFashionCoinTotalsForUserResponse>( "GetFashionCoinTotalsForUser" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Babylon.GetFashionCoinTotalsForUser = {
            __response: undefined
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function convertFashionCoins( amount: number, direction: EVA.Babylon.FashionCoinConversionDirection ): Promise<IEVAServiceResponse<EVA.Babylon.ConvertFashionCoins, EVA.Babylon.ConvertFashionCoinsResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Babylon.ConvertFashionCoins, EVA.Babylon.ConvertFashionCoinsResponse>( "ConvertFashionCoins" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Babylon.ConvertFashionCoins = {
            Amount:     amount,
            Direction:  direction,
            __response: undefined
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }
}

/**
 * Provides access to a list of fashion collections for a contest available in EVA
 */
export class FashionCollectionsForContest extends FetchablePagedList<EVA.Babylon.FashionCollectionContestDto, EVA.Babylon.ListFashionCollectionsForContest, EVA.Babylon.ListFashionCollectionsForContestResponse> {

    /**
     * The contest to retrieve the fashion collection list for
     * @type {number}
     */
    private contestId: number;

    /**
     * Sets the contest id to retrieve the fashion collection list for
     * @param  {number} contestId      The organization identifier
     * @return {void}                  This method doesn't return anything
     */
    public setContestId( contestId: number )
    {
        this.contestId = contestId;
    }

    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.FashionCollectionContestDto, EVA.Babylon.ListFashionCollectionsForContest, EVA.Babylon.ListFashionCollectionsForContestResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    public fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForContest, EVA.Babylon.ListFashionCollectionsForContestResponse>> {

        // Build the request data
        //
        var requestData: EVA.Babylon.ListFashionCollectionsForContest = {
            PageConfig: this.getPageConfiguration(),
            ContestID:  this.contestId,
            __response: undefined
        };

        return super.fetch( "ListFashionCollectionsForContest", requestData );
    }
}

/**
 * Provides access to a list of fashion coin transactions
 */
export class FashionCoinTransactions extends FetchablePagedList<EVA.Babylon.FashionCollectionContestDto, EVA.Babylon.ListFashionCoinTransactions, EVA.Babylon.ListFashionCoinTransactionsResponse> {

    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.FashionCoinTransaction, EVA.Babylon.ListFashionCoinTransactions, EVA.Babylon.ListFashionCoinTransactionsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    public fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCoinTransactions, EVA.Babylon.ListFashionCoinTransactionsResponse>> {

        // Build the request data
        //
        var requestData: EVA.Babylon.ListFashionCoinTransactions = {
            PageConfig: this.getPageConfiguration(),
            __response: undefined
        };

        return super.fetch( "ListFashionCoinTransactions", requestData );
    }
}

