/**
 * The CMS Page module provides access to content management pages from the EVA back-end * @preferred
 */
import { FetchableItem, FetchablePagedList } from "./base";
import { IEVAServiceResponse } from "../service";
/**
 * Provides access to a content menu available in EVA
 */
export declare class Station extends FetchableItem<EVA.Core.StationDto, EVA.Core.Services.GetStation, EVA.Core.Services.GetStationResponse> {
    /**
     * Fetches the page content
     * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetStation, EVA.Core.Services.GetStationResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetStation, EVA.Core.Services.GetStationResponse>>;
}
/**
 * Provides access to a list of stations for an organisation available in EVA
 */
export declare class StationList extends FetchablePagedList<EVA.Core.StationDto, EVA.Core.Services.ListStationsForOrganizationUnit, EVA.Core.Services.ListStationsForOrganizationUnitResponse> {
    /**
     * The organization to retrieve the station list for
     * @type {number}
     */
    private organizationId;
    /**
     * Sets the organization id to retrieve the station list for
     * @param  {number} organizationId      The organization identifier
     * @return {void}                       This method doesn't return anything
     */
    setOrganizationId(organizationId: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Core.StationDto, EVA.Core.Services.ListStationsForOrganizationUnit, EVA.Core.Services.ListStationsForOrganizationUnitResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListStationsForOrganizationUnit, EVA.Core.Services.ListStationsForOrganizationUnitResponse>>;
}
