/**
 * The rituals module provides access to the Rituals specific call on the EVA back-end
 * @preferred
 */

import { SettingsManager                   } from "../settings";
import { EVAService, IEVAServiceResponse   } from "../service";
import { EXMLHttpRequestMethod             } from "../xhr";
import { FetchablePagedList                } from "./base";
import * as _                                from "lodash";

export interface IAvailabilityWeek {
    sunday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
    monday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
    tuesday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
    wednesday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
    thursday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
    friday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
    saturday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
    otherDays?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
}

/**
 * Provides access to a kijkshop specific functions in EVA
 */
export namespace Kijkshop
{
    "use strict";

    ////////////////////////////////////////////////////////////////////////////
    // Orders
    ////////////////////////////////////////////////////////////////////////////
    //
    export function setExpertForOrderLine( orderLineID: number, expertID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.SetExpertForOrderLine, EVA.Core.EmptyResponseMessage>( "SetExpertForOrderLine" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.SetExpertForOrderLine  = <EVA.Kijkshop.SetExpertForOrderLine> {
            ExpertID:    expertID
        ,   OrderLineID: orderLineID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    ////////////////////////////////////////////////////////////////////////////
    // Products
    ////////////////////////////////////////////////////////////////////////////
    //
    export function addProductExpertise( productID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijAddProductExpertise, EVA.Core.EmptyResponseMessage>( "KijkBijMijAddProductExpertise" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijAddProductExpertise  = <EVA.Kijkshop.KijkBijMijAddProductExpertise> {
            ProductID: productID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function removeProductExpertise( productID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijRemoveProductExpertise, EVA.Core.EmptyResponseMessage>( "KijkBijMijRemoveProductExpertise" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijRemoveProductExpertise  = <EVA.Kijkshop.KijkBijMijRemoveProductExpertise> {
            ProductID: productID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function isProductExpert( productID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijIsExpertOnProduct, EVA.Kijkshop.KijkBijMijIsExpertResponse>( "KijkBijMijIsExpertOnProduct" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijIsExpertOnProduct  = <EVA.Kijkshop.KijkBijMijIsExpertOnProduct> {
            ProductID: productID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function isMultipleProductExpert( productIDs: number[] )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijIsExpertOnProducts, EVA.Kijkshop.KijkBijMijIsExpertsResponse>( "KijkBijMijIsExpertOnProducts" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijIsExpertOnProducts  = <EVA.Kijkshop.KijkBijMijIsExpertOnProducts> {
            ProductIDs: productIDs
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function getProductExperts( productID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijProductExperts, EVA.Kijkshop.KijkBijMijProductExpertsResponse>( "KijkBijMijProductExperts" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijProductExperts  = <EVA.Kijkshop.KijkBijMijProductExperts> {
            ProductID: productID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function getTotalExpertCount() {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijTotalExpertCount, EVA.Kijkshop.KijkBijMijTotalExpertCountResponse>( "KijkBijMijTotalExpertCount" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijTotalExpertCount  = <EVA.Kijkshop.KijkBijMijTotalExpertCount> {};

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function payoutCredits( amount: number ) {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijPayoutCredits, EVA.Core.RequestMessageWithEmptyResponse>( "KijkBijMijPayoutCredits" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijPayoutCredits  = <EVA.Kijkshop.KijkBijMijPayoutCredits> {
            Amount: amount
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function scanMe( userId: number ) {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijScanMe, EVA.Core.RequestMessageWithEmptyResponse>( "KijkBijMijScanMe" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijScanMe  = <EVA.Kijkshop.KijkBijMijScanMe> {
            ScannedUserID: userId
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function scanNewApp() {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijScanNewApp, EVA.Core.RequestMessageWithEmptyResponse>( "KijkBijMijScanNewApp" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijScanNewApp  = <EVA.Kijkshop.KijkBijMijScanNewApp> {};

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function getExpertDetails( userIDs: number[] )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijGetExpertDetails, EVA.Kijkshop.KijkBijMijGetExpertDetailsResponse>( "KijkBijMijGetExpertDetails" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijGetExpertDetails  = <EVA.Kijkshop.KijkBijMijGetExpertDetails> {
            UserIDs: userIDs
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function getProfile()
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijGetProfile, EVA.Kijkshop.KijkBijMijGetProfileResponse>( "KijkBijMijGetProfile" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijGetProfile  = <EVA.Kijkshop.KijkBijMijGetProfile> {};

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function updateProfile( description: string, avatarId: string, languageProficiencies: any )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijUpdateProfile, EVA.Core.RequestMessageWithEmptyResponse>( "KijkBijMijUpdateProfile" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijUpdateProfile  = <EVA.Kijkshop.KijkBijMijUpdateProfile> {
            AdvisorDescription: description,
            AvatarID: avatarId,
            LanguageProficiencies: languageProficiencies
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function getProductsStats( productIDs: number[] )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijGetProductsStats, EVA.Kijkshop.KijkBijMijGetProductsStatsResponse>( "KijkBijMijGetProductsStats" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijGetProductsStats  = <EVA.Kijkshop.KijkBijMijGetProductsStats> {
            ProductIDs: productIDs
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function likeProduct( productID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijLikeProduct, EVA.Core.EmptyResponseMessage>( "KijkBijMijLikeProduct" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijLikeProduct  = <EVA.Kijkshop.KijkBijMijLikeProduct> {
            ProductID: productID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function unlikeProduct( productID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijUnlikeProduct, EVA.Core.EmptyResponseMessage>( "KijkBijMijUnlikeProduct" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijUnlikeProduct  = <EVA.Kijkshop.KijkBijMijUnlikeProduct> {
            ProductID: productID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function likesProduct( productID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijLikesProduct, EVA.Kijkshop.KijkBijMijLikesProductResponse>( "KijkBijMijLikesProduct" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijLikesProduct  = <EVA.Kijkshop.KijkBijMijLikesProduct> {
            ProductID: productID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function likesProducts( productIDs: number[] )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijLikesProducts, EVA.Kijkshop.KijkBijMijLikesProductsResponse>( "KijkBijMijLikesProducts" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijLikesProducts  = <EVA.Kijkshop.KijkBijMijLikesProducts> {
            ProductIDs: productIDs
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function likedProducts()
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijLikedProducts, EVA.Kijkshop.KijkBijMijLikedProductsResponse>( "KijkBijMijLikedProducts" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijLikedProducts  = <EVA.Kijkshop.KijkBijMijLikedProducts> {
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    ////////////////////////////////////////////////////////////////////////////
    // Product groups
    ////////////////////////////////////////////////////////////////////////////
    //
    export function getProductGroups()
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkshopGetProductGroups, EVA.Kijkshop.KijkshopGetProductGroupsResponse>( "KijkshopGetProductGroups" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkshopGetProductGroups  = <EVA.Kijkshop.KijkshopGetProductGroups> {
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function getProductGroup( productGroupId: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkshopGetProductGroup, EVA.Kijkshop.KijkshopGetProductGroupResponse>( "KijkshopGetProductGroup" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkshopGetProductGroup  = <EVA.Kijkshop.KijkshopGetProductGroup> {
            ID: productGroupId
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function addProductGroupExpertise( productGroupID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijAddProductGroupExpertise, EVA.Core.EmptyResponseMessage>( "KijkBijMijAddProductGroupExpertise" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijAddProductGroupExpertise  = <EVA.Kijkshop.KijkBijMijAddProductGroupExpertise> {
            ProductGroupID: productGroupID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function removeProductGroupExpertise( productGroupID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijRemoveProductGroupExpertise, EVA.Core.EmptyResponseMessage>( "KijkBijMijRemoveProductGroupExpertise" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijRemoveProductGroupExpertise  = <EVA.Kijkshop.KijkBijMijRemoveProductGroupExpertise> {
            ProductGroupID: productGroupID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function isProductGroupExpert( productGroupID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijIsExpertOnProductGroup, EVA.Kijkshop.KijkBijMijIsExpertResponse>( "KijkBijMijIsExpertOnProductGroup" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijIsExpertOnProductGroup  = <EVA.Kijkshop.KijkBijMijIsExpertOnProductGroup> {
            ProductGroupID: productGroupID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function isMultipleProductGroupExpert( productGroupIDs: number[] )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijIsExpertOnProductGroups, EVA.Kijkshop.KijkBijMijIsExpertsResponse>( "KijkBijMijIsExpertOnProductGroups" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijIsExpertOnProductGroups  = <EVA.Kijkshop.KijkBijMijIsExpertOnProductGroups> {
            ProductGroupIDs: productGroupIDs
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function getAvailability( userID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijGetAvailability, EVA.Kijkshop.KijkBijMijAvailabilityResponse>( "KijkBijMijGetAvailability" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijGetAvailability  = <EVA.Kijkshop.KijkBijMijGetAvailability> {
            UserID: userID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function setAvailability( availability: IAvailabilityWeek = { monday: null, tuesday: null, wednesday: null, thursday: null, friday: null, saturday: null, sunday: null, otherDays: null } )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijSetAvailability, EVA.Core.RequestMessageWithEmptyResponse>( "KijkBijMijSetAvailability" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijSetAvailability  = <EVA.Kijkshop.KijkBijMijSetAvailability> {
            Monday: availability.monday,
            Tuesday: availability.tuesday,
            Wednesday: availability.wednesday,
            Thursday: availability.thursday,
            Friday: availability.friday,
            Saturday: availability.saturday,
            Sunday: availability.sunday,
            OtherDays: availability.otherDays
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    ////////////////////////////////////////////////////////////////////////////
    // Calls
    ////////////////////////////////////////////////////////////////////////////
    //
    export function callExpert( userID: number, productID: number, productGroupID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijCallExpert, EVA.Kijkshop.KijkBijMijCallResponse>( "KijkBijMijCallExpert" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijCallExpert  = <EVA.Kijkshop.KijkBijMijCallExpert> {
            UserID: userID,
            ProductID: productID,
            ProductGroupID: productGroupID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function declineCall( sessionID: string )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijDeclineCall, EVA.Core.RequestMessageWithEmptyResponse>( "KijkBijMijDeclineCall" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijDeclineCall  = <EVA.Kijkshop.KijkBijMijDeclineCall> {
            SessionID: sessionID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function joinCall( sessionID: string )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijJoinCall, EVA.Kijkshop.KijkBijMijCallExpert>( "KijkBijMijJoinCall" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijJoinCall  = <EVA.Kijkshop.KijkBijMijJoinCall> {
            SessionID: sessionID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function rateExpert( userID: number, sessionID: string, rating1: number, rating2: number, rating3: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijRateExpert, EVA.Core.EmptyResponseMessage>( "KijkBijMijRateExpert" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijRateExpert  = <EVA.Kijkshop.KijkBijMijRateExpert> {
            UserID:    userID,
            SessionID: sessionID,
            Rating1:   rating1,
            Rating2:   rating2,
            Rating3:   rating3
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function rateCaller( userID: number, sessionID: string, rating: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijRateCaller, EVA.Core.EmptyResponseMessage>( "KijkBijMijRateCaller" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijRateCaller  = <EVA.Kijkshop.KijkBijMijRateCaller> {
            UserID:    userID,
            SessionID: sessionID,
            Rating:    rating,
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function reportUser( userID: number, reason: EVA.Kijkshop.KijkBijMijReportReasons, description: string )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijReportUser, EVA.Core.EmptyResponseMessage>( "KijkBijMijReportUser" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijReportUser  = <EVA.Kijkshop.KijkBijMijReportUser> {
            UserID:            userID,
            Reason:            reason,
            ReasonDescription: description
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    ////////////////////////////////////////////////////////////////////////////
    // Notifications
    ////////////////////////////////////////////////////////////////////////////
    //
    export function subscribeToNotificationType( typeID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijSubscribeToNotificationType, EVA.Core.RequestMessageWithEmptyResponse>( "KijkBijMijSubscribeToNotificationType" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijSubscribeToNotificationType  = <EVA.Kijkshop.KijkBijMijSubscribeToNotificationType> {
            TypeID: typeID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function unsubscribeFromNotificationType( typeID: number )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijUnsubscribeFromNotificationType, EVA.Core.RequestMessageWithEmptyResponse>( "KijkBijMijUnsubscribeFromNotificationType" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijUnsubscribeFromNotificationType  = <EVA.Kijkshop.KijkBijMijUnsubscribeFromNotificationType> {
            TypeID: typeID
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function getNotificationSubscriptions() {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijGetNotificationSubscriptions, EVA.Kijkshop.KijkBijMijNotificationSubscriptionsResponse>( "KijkBijMijGetNotificationSubscriptions" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijGetNotificationSubscriptions = <EVA.Kijkshop.KijkBijMijGetNotificationSubscriptions> {};

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function getUnreadNotificationCount() {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijGetUnreadNotificationCount, EVA.Kijkshop.KijkBijMijUnreadNotificationCountResponse>( "KijkBijMijGetUnreadNotificationCount" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijGetUnreadNotificationCount = <EVA.Kijkshop.KijkBijMijGetUnreadNotificationCount> {};

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function markNotificationAsRead( id: number ) {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijMarkNotificationAsRead, EVA.Core.RequestMessageWithEmptyResponse>( "KijkBijMijMarkNotificationAsRead" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijMarkNotificationAsRead = <EVA.Kijkshop.KijkBijMijMarkNotificationAsRead> {
            ID: id
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function deleteNotification( id: number ) {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijDeleteNotification, EVA.Core.RequestMessageWithEmptyResponse>( "KijkBijMijDeleteNotification" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijDeleteNotification = <EVA.Kijkshop.KijkBijMijDeleteNotification> {
            ID: id
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function blockedUsers() {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijBlockedUsers, EVA.Kijkshop.KijkBijMijBlockedUsersResponse>( "KijkBijMijBlockedUsers" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijBlockedUsers = <EVA.Kijkshop.KijkBijMijBlockedUsers> {};

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function isUserBlocked( userId: number ) {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijBlocksUser, EVA.Kijkshop.KijkBijMijBlocksUserResponse>( "KijkBijMijBlocksUser" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijBlocksUser = <EVA.Kijkshop.KijkBijMijBlocksUser> {
            UserID: userId
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function blockUser( userId: number ) {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijBlockUser, EVA.Core.RequestMessageWithEmptyResponse>( "KijkBijMijBlockUser" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijBlockUser = <EVA.Kijkshop.KijkBijMijBlockUser> {
            UserID: userId
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function unblockUser( userId: number ) {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijUnblockUser, EVA.Core.RequestMessageWithEmptyResponse>( "KijkBijMijUnblockUser" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijUnblockUser = <EVA.Kijkshop.KijkBijMijUnblockUser> {
            UserID: userId
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    ////////////////////////////////////////////////////////////////////////////
    // Credit
    ////////////////////////////////////////////////////////////////////////////
    //
    export function getCreditTotalsForUser()
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijGetCreditTotalsForUser, EVA.Kijkshop.KijkBijMijGetCreditTotalsForUserResponse>( "KijkBijMijGetCreditTotalsForUser" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijGetCreditTotalsForUser  = <EVA.Kijkshop.KijkBijMijGetCreditTotalsForUser> {
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function listCreditTransactions()
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Kijkshop.KijkBijMijListCreditTransactions, EVA.Kijkshop.KijkBijMijListCreditTransactionsResponse>( "KijkBijMijListCreditTransactions" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Kijkshop.KijkBijMijListCreditTransactions  = <EVA.Kijkshop.KijkBijMijListCreditTransactions> {
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }
}

/**
 * Provides access to a list of hall of famers
 */
export class KijkBijMijHallOfFameList extends FetchablePagedList<EVA.Kijkshop.RankedUser, EVA.Kijkshop.KijkBijMijListHall, EVA.Kijkshop.KijkBijMijListHallResponse> {

    constructor( limit: number = 15, start: number = 0, sortDirection: EVA.Core.SortDirection = 0, sortProperty: string = null ) {
        super( limit, start, sortDirection, sortProperty );
    }
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Kijkshop.RankedUser, EVA.Kijkshop.KijkBijMijListHall, EVA.Kijkshop.KijkBijMijListHallResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    public fetch(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijListHall, EVA.Kijkshop.KijkBijMijListHallResponse>> {

        // Build the request data
        //
        var requestData: EVA.Kijkshop.KijkBijMijListHall = <EVA.Kijkshop.KijkBijMijListHall>{
            PageConfig: this.getPageConfiguration()
        };

        return super.fetch( "KijkBijMijListHall", requestData );
    }
}

/**
 * Provides access to a list of content blocks available in EVA
 */
export class KijkBijMijNotificationsList extends FetchablePagedList<EVA.Kijkshop.KijkBijMijNotification, EVA.Kijkshop.KijkBijMijListNotifications, EVA.Kijkshop.KijkBijMijListNotificationsResponse> {

    constructor( limit: number = 15, start: number = 0, sortDirection: EVA.Core.SortDirection = 0, sortProperty: string = null ) {
        super( limit, start, sortDirection, sortProperty );
    }
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijNotification, EVA.Kijkshop.KijkBijMijListNotifications, EVA.Kijkshop.KijkBijMijListNotificationsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    public fetch(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijListNotifications, EVA.Kijkshop.KijkBijMijListNotificationsResponse>> {

        // Build the request data
        //
        var requestData: EVA.Kijkshop.KijkBijMijListNotifications = <EVA.Kijkshop.KijkBijMijListNotifications>{
            PageConfig: this.getPageConfiguration()
        };

        return super.fetch( "KijkBijMijListNotifications", requestData );
    }
}

/**
 * Provides access to a list of product groups experts in EVA
 */
export class KijkBijMijProductGroupExperts extends FetchablePagedList<number, EVA.Kijkshop.KijkBijMijProductGroupExpertsPaged, EVA.Kijkshop.KijkBijMijProductGroupExpertsPagedResponse> {

    /**
     * The product group ID to retrieve the experts for
     * @type {number}
     */
    private productGroupId: number;

    /**
     * Sets the product group id to retrieve the expert list for
     * @param  {number} productGroupId  The product group identifier
     * @return {void}                   This method doesn't return anything
     */
    public setProductGroupId( productGroupId: number )
    {
        this.productGroupId = productGroupId;
    }

    constructor( limit: number = 15, start: number = 0, sortDirection: EVA.Core.SortDirection = 0, sortProperty: string = null ) {
        super( limit, start, sortDirection, sortProperty );
    }
    /**
     * Fetches the list of experts
     * @return {Promise<IEVAServiceResponse<number, EVA.Kijkshop.KijkBijMijProductGroupExpertsPaged, EVA.Kijkshop.KijkBijMijProductGroupExpertsPagedResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    public fetch(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijProductGroupExpertsPaged, EVA.Kijkshop.KijkBijMijProductGroupExpertsPagedResponse>> {

        // Build the request data
        //
        var requestData: EVA.Kijkshop.KijkBijMijProductGroupExpertsPaged = <EVA.Kijkshop.KijkBijMijProductGroupExpertsPaged>{
            ProductGroupID: this.productGroupId
        ,   PageConfig: this.getPageConfiguration()
        };

        return super.fetch( "KijkBijMijProductGroupExpertsPaged", requestData );
    }
}

/**
 * Provides access to a list of content blocks available in EVA
 */
export class KijkBijMijRatingsList extends FetchablePagedList<EVA.Kijkshop.KijkBijMijRating, EVA.Kijkshop.KijkBijMijListRatings, EVA.Kijkshop.KijkBijMijListRatingsResponse> {

        /**
         * The user to retrieve the ratings for
         * @type {number}
         */
        private userId: number;

        /**
         * Sets the user id to retrieve the rating list for
         * @param  {number} userId      The user identifier
         * @return {void}               This method doesn't return anything
         */
        public setUserId( userId: number )
        {
            this.userId = userId;
        }
        constructor( limit: number = 15, start: number = 0, sortDirection: EVA.Core.SortDirection = 0, sortProperty: string = null ) {
            super( limit, start, sortDirection, sortProperty );
        }
        /**
         * Fetches the list of items
         * @return {Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijRating, EVA.Kijkshop.KijkBijMijListRatings, EVA.Kijkshop.KijkBijMijListRatingsResponse>>} A promise resolving when the fetch from the back-end has completed
         */
        public fetch(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijListRatings, EVA.Kijkshop.KijkBijMijListRatingsResponse>> {

            // Build the request data
            //
            var requestData: EVA.Kijkshop.KijkBijMijListRatings = <EVA.Kijkshop.KijkBijMijListRatings>{
                UserID : this.userId,
                PageConfig: this.getPageConfiguration()
            };

            return super.fetch( "KijkBijMijListRatings", requestData );
        }
    }



