/**
 * The MakeUp module provides access to advanced content management features from the EVA back-end
 * @preferred
 */
import { IEVAServiceResponse } from "../service";
import { FetchablePagedList } from "./base";
export interface MakeupGetRenderedPageByPathResponseWithContext extends EVA.Makeup.MakeupGetRenderedPageByPathResponse {
    PathContext: EVA.Makeup.PathContext;
    QueryPath: string;
}
export declare namespace MakeUp {
    /***************
     *    PAGES    *
     ***************/
    /**
     * Provides access to a make up content map
     */
    function getPageMap(languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageMap, EVA.Makeup.MakeupGetPageMapResponse>>;
    /**
     * Provides access to a make up content page by path
     */
    function getPageByRequestPath(path: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByPath, EVA.Makeup.MakeupGetPageByPathResponse>>;
    /**
     * Provides access to a make up content page by id
     */
    function getPageByID(ID: string, languageID?: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByID, EVA.Makeup.MakeupGetPageByIdResponse>>;
    /**
     * Provides access to a rendered make up content page by path
     */
    function getRenderedPageByRequestPath(path: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetRenderedPageByPath, MakeupGetRenderedPageByPathResponseWithContext>>;
    function getRenderedPagesByPartialPath(path: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetRenderedPagesByPartialPath, EVA.Makeup.MakeupGetRenderedPagesByPartialPathResponse>>;
    /**
     * Provides access to a make up content page by id
     */
    function getRenderedPageByID(ID: string, languageID?: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetRenderedPageByID, EVA.Makeup.MakeupGetRenderedPageByIDResponse>>;
    /**
     * Provides access to create a new Makeup page
     * @param page The MakeupPageDto
     */
    function createPage(page: EVA.Makeup.PageDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByID, EVA.Makeup.MakeupGetPageByIdResponse>>;
    /**
     * Provides access to replace a MakeUp page
     * @param id   The ID of the Makeup page
     * @param page The MakeUpPageDto
     */
    function replacePage(page: EVA.Makeup.PageDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByID, EVA.Makeup.MakeupGetPageByIdResponse>>;
    /**
     * Convenience method to upsert a Makeup page
     * @param id   The ID of the Makeup page
     * @param page The MakeUpPageDto
     */
    function upsertPage(page: EVA.Makeup.PageDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByID, EVA.Makeup.MakeupGetPageByIdResponse>>;
    /**
     * Convenience method to retrieve the latest version of a makeup page
     * @param id The ID of the Makeup page
     * @param languageID The language
     */
    function getCurrentPageVersion(id: string, languageID: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetCurrentPageVersion, EVA.Makeup.MakeupGetCurrentPageVersionResponse>>;
    /**
     * Convenience method to publish a version of a Makeup page
     * @param id The ID of the Makeup page
     * @param languageID The language
     */
    function publishPageVersion(id: string, languageID: string, version: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupPublishPageVersion, EVA.Core.EmptyResponseMessage>>;
    /**
     * Provides access to delete a Makeup page
     * @param id The ID of the Makeup page
     */
    function deletePage(id: string, languageID?: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupDeletePage, EVA.Core.EmptyResponseMessage>>;
    /****************
     *    BLOCKS    *
     ****************/
    function getBlockByID(ID: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetBlockByID, EVA.Makeup.MakeupGetBlockByIDResponse>>;
    function getRenderedBlockByID(ID: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetRenderedBlockByID, EVA.Makeup.MakeupGetRenderedBlockByIDResponse>>;
    /**
     * Provides access to create a new Makeup block
     * @param block The BlockDto to create
     */
    function createBlock(block: EVA.Makeup.BlockDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetBlockByID, EVA.Makeup.MakeupGetBlockByIDResponse>>;
    /**
     * Convenience method to upsert a Makeup block
     * @param id    The ID of the Makeup block
     * @param block The MakeUpBlockDto
     */
    function upsertBlock(block: EVA.Makeup.BlockDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetBlockByID, EVA.Makeup.MakeupGetBlockByIDResponse>>;
    /**
     * Provides access to replace a MakeUp block
     * @param block The BlockDto
     */
    function replaceBlock(block: EVA.Makeup.BlockDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetBlockByID, EVA.Makeup.MakeupGetBlockByIDResponse>>;
    /**
     * Provides access to delete a Makeup block
     * @param id The ID of the Makeup block
     */
    function deleteBlock(id: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupDeleteBlock, EVA.Core.EmptyResponseMessage>>;
    /**
     * Convenience method to retrieve the latest version of a makeup block
     * @param id The ID of the Makeup block
     */
    function getCurrentBlockVersion(id: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetCurrentBlockVersion, EVA.Makeup.MakeupGetCurrentBlockVersionResponse>>;
    /**
     * Convenience method to publish a version of a Makeup block
     * @param id The ID of the Makeup block
     * @param version The version to set
     */
    function publishBlockVersion(id: string, version: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupPublishBlockVersion, EVA.Core.EmptyResponseMessage>>;
    /****************
     *    MENU      *
     ****************/
    function getMenuByID(ID: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetMenuByID, EVA.Makeup.MakeupGetMenuByIDResponse>>;
    /**
     * Provides access to create a new Makeup block
     * @param block The MenuDto to create
     */
    function createMenu(block: EVA.Makeup.MenuDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetMenuByID, EVA.Makeup.MakeupGetMenuByIDResponse>>;
    /**
     * Convenience method to upsert a Makeup block
     * @param id    The ID of the Makeup block
     * @param block The MakeUpMenuDto
     */
    function upsertMenu(block: EVA.Makeup.MenuDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetMenuByID, EVA.Makeup.MakeupGetMenuByIDResponse>>;
    /**
     * Provides access to replace a MakeUp block
     * @param menu The MenuDto
     */
    function replaceMenu(menu: EVA.Makeup.MenuDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetMenuByID, EVA.Makeup.MakeupGetMenuByIDResponse>>;
    /**
     * Provides access to delete a Makeup block
     * @param id The ID of the Makeup block
     */
    function deleteMenu(id: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupDeleteMenu, EVA.Core.EmptyResponseMessage>>;
    /****************************
     *    CONFIGURATION PROFILE *
     ****************************
     */
    function getConfigurationProfile(languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetConfigurationProfile, EVA.Makeup.MakeupGetConfigurationProfileResponse>>;
    /**
     * Provides access to replace a ConfigurationProfile
     * @param profile The ConfigurationProfile
     */
    function replaceConfigurationProfile(profile: EVA.Makeup.ConfigurationProfileDto, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetConfigurationProfile, EVA.Makeup.MakeupGetConfigurationProfileResponse>>;
}
export declare class MakeupListPageVersions extends FetchablePagedList<EVA.Makeup.PageVersionDto, EVA.Makeup.MakeupListPageVersions, EVA.Makeup.MakeupListPageVersionsResponse> {
    /**
     * The make up page identifier
     * @type {string}
     */
    private page_id;
    /**
     * The make up page language
     * @type {string}
     */
    private languageID;
    /**
     * Returns the current page identifier
     * @return {string}       The page identifier
     */
    getPageID(): string;
    /**
     * Set the make up page identifier
     * @param  {string} page_id The page identifier
     * @return {string}         The currently page identifier
     */
    setPageID(page_id: string): string;
    /**
     * Set the make up page language
     * @param  {string} page_id The page language
     * @return {string}         The currently page language
     */
    setLanguageID(languageID: string): string;
    /**
     * Returns the current page language
     * @return {string}       The page language
     */
    getLanguageID(): string;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Makeup.MakeupListPageVersions, EVA.Makeup.MakeupListPageVersionsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Makeup.MakeupListPageVersions, EVA.Makeup.MakeupListPageVersionsResponse>>;
}
export declare class MakeupListBlocks extends FetchablePagedList<EVA.Makeup.BlockDto, EVA.Makeup.MakeupListBlocks, EVA.Makeup.MakeupListBlocksResponse> {
    /**
     * The specifc type of blocks to retrieve
     * @type {string}
     */
    private type;
    /**
     * Returns the current requested block type
     * @return {string}       The block type
     */
    getType(): string;
    /**
     * Set the block type to retrieve
     * @param  {string} type The new block type
     * @return {string}       The currently set block type
     */
    setType(type: string): string;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Makeup.MakeupListBlocks, EVA.Makeup.MakeupListBlocksResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Makeup.MakeupListBlocks, EVA.Makeup.MakeupListBlocksResponse>>;
}
export declare class MakeupListBlockVersions extends FetchablePagedList<EVA.Makeup.BlockDto, EVA.Makeup.MakeupListBlockVersions, EVA.Makeup.MakeupListBlockVersionsResponse> {
    /**
     * The make up block identifier
     * @type {string}
     */
    private block_id;
    /**
     * Returns the current block identifier
     * @return {string}       The block identifier
     */
    getBlockID(): string;
    /**
     * Set the make up block identifier
     * @param  {string} block_id The block identifier
     * @return {string}         The currently block identifier
     */
    setBlockID(block_id: string): string;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Makeup.MakeupListBockVersions, EVA.Makeup.MakeupListBlockVersionsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Makeup.MakeupListBlockVersions, EVA.Makeup.MakeupListBlockVersionsResponse>>;
}
export declare class MakeupListMenus extends FetchablePagedList<EVA.Makeup.MenuDto, EVA.Makeup.MakeupListMenus, EVA.Makeup.MakeupListMenusResponse> {
    /**
     * The language identifier
     * @type {string}
     */
    private languageID;
    /**
     * Returns the current language identifier
     * @return {string} The language identifier
     */
    getLanguageID(): string;
    /**
     * Set the language identifier
     * @param  {string} language The language identifier
     */
    setLanguageID(languageID: string): string;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Makeup.MakeupListMenus, EVA.Makeup.MakeupListMenusResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Makeup.MakeupListMenus, EVA.Makeup.MakeupListMenusResponse>>;
}
