/**
 * This module provides methods for newsletter subscription
 *
 * @preferred
 */
import { IEVAServiceResponse } from "../service";
export declare namespace Newsletter {
    /**
     * Subscribe to the Newsletter using the provided email address
     * @return {Promise}    A promise resolving when the call to the back-end has completed
     */
    function subscribe(emailAddress: string): Promise<IEVAServiceResponse<EVA.Core.Services.Subscribe, EVA.Core.Services.SubscribeResponse>>;
    /**
     * Unsubscribes from the Newsletter using the provided email address
     * @return {Promise}    A promise resolving when the call to the back-end has completed
     */
    function unsubscribe(emailAddress: string): Promise<IEVAServiceResponse<EVA.Core.Services.Unsubscribe, EVA.Core.Services.UnsubscribeResponse>>;
    /**
     * Confirms a Newsletter subscription using the provided token
     * @param  {string}     token   The subscription confirmation token
     * @return {Promise}            A promise resolving when the call to the back-end has completed
     */
    function confirmSubscription(token: string): Promise<IEVAServiceResponse<EVA.Core.Services.ConfirmSubscribe, EVA.Core.Services.ConfirmSubscribeResponse>>;
    /**
     * Validate if a e-mail adres is subscribed to the newsletter
     *
     * @param  {string}  emailAddress The email adres that needs to be validated to have a subscription to the newsletter
     * @return {Promise}              A promise resolving when the call to the back-end has completed
     */
    function hasSubscription(emailAddress: string): Promise<IEVAServiceResponse<EVA.Core.Services.HasSubscription, EVA.Core.Services.HasSubscriptionResponse>>;
}
