"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * This module provides methods for newsletter subscription
 *
 * @preferred
 */
var service_1 = require("../service");
var Newsletter;
(function (Newsletter) {
    "use strict";
    /**
     * Subscribe to the Newsletter using the provided email address
     * @return {Promise}    A promise resolving when the call to the back-end has completed
     */
    function subscribe(emailAddress) {
        // Create the service instance
        //
        var service = new service_1.EVAService("Subscribe");
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {
            EmailAddress: emailAddress,
            Type: 1
        };
        return service.call(requestData);
    }
    Newsletter.subscribe = subscribe;
    /**
     * Unsubscribes from the Newsletter using the provided email address
     * @return {Promise}    A promise resolving when the call to the back-end has completed
     */
    function unsubscribe(emailAddress) {
        // Create the service instance
        //
        var service = new service_1.EVAService("Unsubscribe");
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {
            EmailAddress: emailAddress,
            Type: 1
        };
        return service.call(requestData);
    }
    Newsletter.unsubscribe = unsubscribe;
    /**
     * Confirms a Newsletter subscription using the provided token
     * @param  {string}     token   The subscription confirmation token
     * @return {Promise}            A promise resolving when the call to the back-end has completed
     */
    function confirmSubscription(token) {
        // Create the service instance
        //
        var service = new service_1.EVAService("ConfirmSubscribe");
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {
            Token: token,
            Type: 1
        };
        return service.call(requestData);
    }
    Newsletter.confirmSubscription = confirmSubscription;
    /**
     * Validate if a e-mail adres is subscribed to the newsletter
     *
     * @param  {string}  emailAddress The email adres that needs to be validated to have a subscription to the newsletter
     * @return {Promise}              A promise resolving when the call to the back-end has completed
     */
    function hasSubscription(emailAddress) {
        // Create the service instance
        //
        var service = new service_1.EVAService("HasSubscription");
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {
            EmailAddress: emailAddress,
            Type: 1
        };
        return service.call(requestData);
    }
    Newsletter.hasSubscription = hasSubscription;
})(Newsletter = exports.Newsletter || (exports.Newsletter = {}));
