/**
 * This module provides methods for newsletter subscription
 *
 * @preferred
 */
import { EVAService, IEVAServiceResponse } from "../service";

export namespace Newsletter
{
    "use strict";

    /**
     * Subscribe to the Newsletter using the provided email address
     * @return {Promise}    A promise resolving when the call to the back-end has completed
     */
    export function subscribe( emailAddress: string ): Promise<IEVAServiceResponse<EVA.Core.Services.Subscribe, EVA.Core.Services.SubscribeResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Core.Services.Subscribe, EVA.Core.Services.SubscribeResponse>( "Subscribe" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
            EmailAddress: emailAddress,
            Type:         1
        };

        return service.call( requestData );
    }

    /**
     * Unsubscribes from the Newsletter using the provided email address
     * @return {Promise}    A promise resolving when the call to the back-end has completed
     */
    export function unsubscribe( emailAddress: string ): Promise<IEVAServiceResponse<EVA.Core.Services.Unsubscribe, EVA.Core.Services.UnsubscribeResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Core.Services.Unsubscribe, EVA.Core.Services.UnsubscribeResponse>( "Unsubscribe" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
            EmailAddress: emailAddress,
            Type:         1
        };

        return service.call( requestData );
    }

    /**
     * Confirms a Newsletter subscription using the provided token
     * @param  {string}     token   The subscription confirmation token
     * @return {Promise}            A promise resolving when the call to the back-end has completed
     */
    export function confirmSubscription( token: string ): Promise<IEVAServiceResponse<EVA.Core.Services.ConfirmSubscribe, EVA.Core.Services.ConfirmSubscribeResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Core.Services.ConfirmSubscribe, EVA.Core.Services.ConfirmSubscribeResponse>( "ConfirmSubscribe" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
            Token:  token,
            Type:   1
        };

        return service.call( requestData );
    }

    /**
     * Validate if a e-mail adres is subscribed to the newsletter
     *
     * @param  {string}  emailAddress The email adres that needs to be validated to have a subscription to the newsletter
     * @return {Promise}              A promise resolving when the call to the back-end has completed
     */
    export function hasSubscription( emailAddress: string ): Promise<IEVAServiceResponse<EVA.Core.Services.HasSubscription, EVA.Core.Services.HasSubscriptionResponse>>
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Core.Services.HasSubscription, EVA.Core.Services.HasSubscriptionResponse>( "HasSubscription" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
            EmailAddress: emailAddress,
            Type:         1
        };

        return service.call( requestData );
    }
}
