/**
 * The postnl module provides the means to retrieve and set a PostNL pickup location
 * @preferred
 */
import { EVAService, IEVAServiceResponse    } from "../service";
import { ShoppingCart                       } from "./shopping-cart";
import { Order                              } from "./orders";

import { XHR, EXMLHttpRequestMethod         } from "../xhr";
import * as _                                 from "lodash";

export class PostNL {

    /**
     * The order to perform the payments for
     * @type {Order}
     */
    private order: Order|ShoppingCart;

    /**
     * [constructor description]
     * @param  {Order}  order The order to perform the payments for
     * @return {void}         This method doesn't return anything
     */
    constructor( order: Order|ShoppingCart )
    {
        this.order = order;
    }

    public PostNLGetAvailablePickUpLocationsForArea( orderId: number, nw: EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaCoordinate, se: EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaCoordinate  ): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForArea, EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaResponse>>
    {
        // Create our service instance
        //
        var service = new EVAService<EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForArea, EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaResponse>( "PostNLGetAvailablePickUpLocationsForArea" );

        // Build the request data
        // The base class will add things like SessionID so to keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
            OrderID:         orderId,
            NorthWest:       nw,
            SouthEast:       se
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    public PostNLGetAvailablePickUpLocationsForOrder( orderId: number ): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForOrder, EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForOrderResponse>>
    {
        // Create our service instance
        //
        var service = new EVAService<EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForOrder, EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForOrderResponse>( "PostNLGetAvailablePickUpLocationsForOrder" );

        // Build the request data
        // The base class will add things like SessionID so to keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
            OrderID:         orderId
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    public PostNLGetAvailableTimeframesForOrder( orderId: number, startDate: any, endDate: any ): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLGetAvailableTimeframesForOrder, EVA.Carrier.PostNL.PostNLGetAvailableTimeframesForOrderResponse>>
    {
        // Create our service instance
        //
        var service = new EVAService<EVA.Carrier.PostNL.PostNLGetAvailableTimeframesForOrder, EVA.Carrier.PostNL.PostNLGetAvailableTimeframesForOrderResponse>( "PostNLGetAvailableTimeframesForOrder" );

        // Build the request data
        // The base class will add things like SessionID so to keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
            OrderID:         orderId,
            StartDate:       startDate,
            EndDate:         endDate
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    public PostNLGetShippingOptionsForOrder( orderId: number ): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLGetShippingOptionsForOrder, EVA.Carrier.PostNL.PostNLGetShippingOptionsForOrderResponse>>
    {
        // Create our service instance
        //
        var service = new EVAService<EVA.Carrier.PostNL.PostNLGetShippingOptionsForOrder, EVA.Carrier.PostNL.PostNLGetShippingOptionsForOrderResponse>( "PostNLGetShippingOptionsForOrder" );

        // Build the request data
        // The base class will add things like SessionID so to keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
            OrderID:         orderId
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    public PostNLUpdateShippingOptionsForOrder( orderId: number, pickupLocationId: number, date?: Date, option?: EVA.Carrier.PostNL.TimeframeOptions ): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLUpdateShippingOptionsForOrder, EVA.Core.EmptyResponseMessage>>
    {
        // Create our service instance
        //
        var service = new EVAService<EVA.Carrier.PostNL.PostNLUpdateShippingOptionsForOrder, EVA.Core.EmptyResponseMessage>( "PostNLUpdateShippingOptionsForOrder" );

        // Build the request data
        // The base class will add things like SessionID so to keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: any = {
            OrderID:            orderId,
            PickUpLocationID:   pickupLocationId,
            Date:               date,
            TimeframeOptions:   option
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }
}
