/**
 * This module provides methods for BI reporting
 *
 * @preferred
 */
import { EVAService,
         IEVAServiceResponse } from "../service";
import * as _                  from "lodash";

export namespace Reporting
{
    "use strict";

    export function GetRankings( axis: string, measure: string, organizationUnitIDs: Array<number>|number, fromDate?: string, toDate?: string ): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetRankings, EVA.BI.Reporting.GetRankingsResponse>>
    {
        var service = new EVAService<EVA.BI.Reporting.GetRankings, EVA.BI.Reporting.GetRankingsResponse>( "GetRankings" );

        if ( _.isNumber( organizationUnitIDs ) )
        {
            organizationUnitIDs = <Array<number>>[ organizationUnitIDs ];
        }

        var requestData: EVA.BI.Reporting.GetRankings = <EVA.BI.Reporting.GetRankings>{
            OrganizationUnits:  organizationUnitIDs,
            FromDate:           fromDate,
            ToDate:             toDate,
            Axis:               axis,
            Measure:            measure,
            __response:         null
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getRankings( organizationUnitIDs: Array<number>|number, fromDate?: string, toDate?: string ): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetRankings, EVA.BI.Reporting.GetRankingsResponse>>
    {
        var service = new EVAService<EVA.BI.Reporting.GetRankings, EVA.BI.Reporting.GetRankingsResponse>( "GetRankings" );

        if ( _.isNumber( organizationUnitIDs ) )
        {
            organizationUnitIDs = <Array<number>>[ organizationUnitIDs ];
        }

        var requestData: EVA.BI.Reporting.GetRankings = <EVA.BI.Reporting.GetRankings>{
            OrganizationUnits:  organizationUnitIDs,
            FromDate:           fromDate,
            ToDate:             toDate
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getProductReportingOverview( organizationUnitIDs: Array<number>|number, fromDate?: string, toDate?: string ): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetProductReportingOverview, EVA.BI.Reporting.GetProductReportingOverviewResponse>>
    {
        var service = new EVAService<EVA.BI.Reporting.GetProductReportingOverview, EVA.BI.Reporting.GetProductReportingOverviewResponse>( "GetProductReportingOverview" );

        if ( _.isNumber( organizationUnitIDs ) )
        {
            organizationUnitIDs = <Array<number>>[ organizationUnitIDs ];
        }

        var requestData: EVA.BI.Reporting.GetProductReportingOverview = <EVA.BI.Reporting.GetProductReportingOverview>{
            OrganizationUnits:  organizationUnitIDs,
            FromDate:           fromDate,
            ToDate:             toDate
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getTelecomReportingOverview( organizationUnitIDs: Array<number>|number, fromDate?: string, toDate?: string ): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetTelecomReportingOverview, EVA.BI.Reporting.GetTelecomReportingOverviewResponse>>
    {
        var service = new EVAService<EVA.BI.Reporting.GetTelecomReportingOverview, EVA.BI.Reporting.GetTelecomReportingOverviewResponse>( "GetTelecomReportingOverview" );

        if ( _.isNumber( organizationUnitIDs ) )
        {
            organizationUnitIDs = <Array<number>>[ organizationUnitIDs ];
        }

        var requestData: EVA.BI.Reporting.GetTelecomReportingOverview = <EVA.BI.Reporting.GetTelecomReportingOverview>{
            OrganizationUnits:  organizationUnitIDs,
            FromDate:           fromDate,
            ToDate:             toDate
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getReportingCharts( organizationUnitID: number, fromDate?: string, toDate?: string ): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetReportingCharts, EVA.BI.Reporting.GetReportingChartsResponse>>
    {
        var service = new EVAService<EVA.BI.Reporting.GetReportingCharts, EVA.BI.Reporting.GetReportingChartsResponse>( "GetReportingCharts" );

        var requestData: EVA.BI.Reporting.GetReportingCharts = <EVA.BI.Reporting.GetReportingCharts>{
            OrganizationUnitID: organizationUnitID,
            FromDate:           fromDate,
            ToDate:             toDate
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getOrderDetails( orderID: number ): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetOrderDetails, EVA.BI.Reporting.GetOrderDetailsResponse>>
    {
        var service = new EVAService<EVA.BI.Reporting.GetOrderDetails, EVA.BI.Reporting.GetOrderDetailsResponse>( "GetOrderDetails" );

        var requestData: EVA.BI.Reporting.GetOrderDetails = <EVA.BI.Reporting.GetOrderDetails>{
            OrderID:            orderID
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getOrders( organizationUnitID: number, category: string, userID?: number, fromDate?: string, toDate?: string ): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetOrders, EVA.BI.Reporting.GetOrdersResponse>>
    {
        var service = new EVAService<EVA.BI.Reporting.GetOrders, EVA.BI.Reporting.GetOrdersResponse>( "GetOrders" );

        var requestData: EVA.BI.Reporting.GetOrders = <EVA.BI.Reporting.GetOrders>{
            UserID:             userID,
            OrganizationUnitID: organizationUnitID,
            FromDate:           fromDate,
            ToDate:             toDate,
            Category:           category
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }

    export function getReportingOverview( organizationUnitIDs: Array<number>|number, fromDate?: string, toDate?: string ): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetReportingOverview, EVA.BI.Reporting.GetReportingOverviewResponse>>
    {
        var service = new EVAService<EVA.BI.Reporting.GetReportingOverview, EVA.BI.Reporting.GetReportingOverviewResponse>( "GetReportingOverview" );

        if ( _.isNumber( organizationUnitIDs ) )
        {
            organizationUnitIDs = <Array<number>>[ organizationUnitIDs ];
        }

        var requestData: EVA.BI.Reporting.GetReportingOverview = <EVA.BI.Reporting.GetReportingOverview>{
            OrganizationUnits:  organizationUnitIDs,
            FromDate:           fromDate,
            ToDate:             toDate
        };

        // Perform the call and capture the resulting promise
        //
        return service.call( requestData );
    }
}
