/**
 * The shops module provides access to the shops (organization unit type) data from the EVA back-end
 * @preferred
 */

import { FetchablePagedList                 } from "./base";
import { EVAService, IEVAServiceResponse    } from "../service";

/**
 * Provides access to a list of shop reviews available in EVA
 */
export class ShopReviews extends FetchablePagedList<EVA.Kiyoh.ShopReview, EVA.Kiyoh.ListShopReviews, EVA.Kiyoh.ListShopReviewsResponse>
{
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Kiyoh.ListShopReviews, EVA.Kiyoh.ListShopReviewsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    public fetch(): Promise<IEVAServiceResponse<EVA.Kiyoh.ListShopReviews, EVA.Kiyoh.ListShopReviewsResponse>>
    {
        // Build the request data
        //
        var requestData: EVA.Kiyoh.ListShopReviews = <EVA.Kiyoh.ListShopReviews> {
            PageConfig:  this.getPageConfiguration()
        };

        return super.fetch( "ListShopReviews", requestData );
    }
}

/**
 * Provides access to a list of product reviews available in EVA
 */
export class ProductReviews extends FetchablePagedList<EVA.Kiyoh.ProductReview, EVA.Kiyoh.ListProductReviews, EVA.Kiyoh.ListProductReviewsResponse>
{
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Kiyoh.ListProductReviews, EVA.Kiyoh.ListProductReviewsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    public fetch(): Promise<IEVAServiceResponse<EVA.Kiyoh.ListProductReviews, EVA.Kiyoh.ListProductReviewsResponse>>
    {
        // Build the request data
        //
        var requestData: EVA.Kiyoh.ListProductReviews = <EVA.Kiyoh.ListProductReviews> {
            PageConfig:  this.getPageConfiguration()
        };

        return super.fetch( "ListProductReviews", requestData );
    }
}

export function getShopReviewStats()
{
    "use strict";

    // Create the service instance
    //
    var service = new EVAService<EVA.Kiyoh.GetShopReviewStats, EVA.Kiyoh.GetShopReviewStatsResponse>( "GetShopReviewStats" );

    // Build the request data
    // The base class will add things like SessionID so keep typescript
    // happy we're using an 'any' type object here
    //
    var requestData: any = {
    };

    // Perform the call and capture the resulting promise
    //
    return service.call( requestData );
}
