/**
 * The rituals module provides access to the Rituals specific call on the EVA back-end
 * @preferred
 */

import { SettingsManager                   } from "../settings";
import { EVAService, IEVAServiceResponse   } from "../service";
import { EXMLHttpRequestMethod             } from "../xhr";
import * as _                                from "lodash";

/**
 * Provides access to a Rituals specific functions in EVA
 */
export namespace Rituals
{
    "use strict";

    export function createCustomerReturn( orderID: number, email: string, lines: Array<EVA.Rituals.RitualsCreateCustomerReturnLineModel> )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Rituals.RitualsCreateCustomerReturn, EVA.Rituals.RitualsCreateCustomerReturnResponse>( "RitualsCreateCustomerReturn" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Rituals.RitualsCreateCustomerReturn  = <EVA.Rituals.RitualsCreateCustomerReturn> {
            OrderID: orderID,
            Email:   email,
            Lines:   lines
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function getOrderForReturn( orderID: string, email: string )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Rituals.RitualsGetOrderForReturn, EVA.Rituals.RitualsGetOrderForReturnResponse>( "RitualsGetOrderForReturn" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Rituals.RitualsGetOrderForReturn  = <EVA.Rituals.RitualsGetOrderForReturn> {
            OrderID: orderID,
            Email:   email,
            __response: undefined
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function getBlobsForReturn( orderID: number, email: string )
    {
        // Create the service instance
        //
        var service = new EVAService<EVA.Rituals.RitualsGetBlobsForReturn, EVA.Rituals.RitualsGetBlobsForReturnResponse>( "RitualsGetBlobsForReturn" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Rituals.RitualsGetBlobsForReturn  = <EVA.Rituals.RitualsGetBlobsForReturn> {
            OrderID: orderID,
            Email:   email
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }

    export function scanLoyaltyCard( loyaltyId: string ) {
        // Create the service instance
        //
        var service = new EVAService<EVA.Rituals.RitualsScanLoyaltyCard, EVA.Rituals.RitualsScanLoyaltyCardResponse>( "RitualsScanLoyaltyCard" );

        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData: EVA.Rituals.RitualsScanLoyaltyCard  = <EVA.Rituals.RitualsScanLoyaltyCard> {
            LoyaltyID: loyaltyId
        };

        // Perform the call and return resulting promise
        //
        return service.call( requestData );
    }
}
