/**
 * The applications module provides access to the applications data from the EVA back-end
 * @preferred
 */
import { FetchablePagedList } from "./base";
import { IEVAServiceResponse } from "../service";
/**
 * Provides access to a babylon social functions in EVA
 * These are the by identifier versions that can be reused by EVA SDK objects
 */
export declare namespace Search {
    function quickFashionSearch(query: string, collectionSize?: number, productSize?: number, actorSize?: number, onlyAutocompleteProducts?: boolean): Promise<IEVAServiceResponse<EVA.Babylon.QuickSearchFashionItems, EVA.Babylon.QuickSearchFashionItemsResponse>>;
    function socialUserSearch(query: string, pageSize?: number, pageNr?: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUserSearch, EVA.Babylon.SocialUserSearchResponse>>;
    function socialFriendsSearch(query: string, pageSize?: number, pageNr?: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialSearchFriends, EVA.Babylon.SocialSearchFriendsResponse>>;
    function fashionCollectionSearch(query: string, pageSize?: number, pageNr?: number, supplierName?: string, sortOption?: EVA.Babylon.FashionCollectionSearchModelSortOptions): Promise<IEVAServiceResponse<EVA.Babylon.SearchFashionCollections, EVA.Babylon.SearchFashionCollectionsResponse>>;
}
/**
 * Provides access to a list of products available in EVA
 */
export declare class FashionProductList extends FetchablePagedList<EVA.Core.ProductDto, EVA.Babylon.SearchFashionProducts, EVA.Core.Services.SearchProductsResponse> {
    /**
     * The return aggregations flag
     * @type {any}
     */
    includeAggregations: boolean;
    /**
     * The return suggestions flag
     * @type {any}
     */
    includeSuggestions: boolean;
    /**
     * The query string to search for in the products catalog
     * @type {string}
     */
    private query;
    /**
     * The list of fields to exclude from the products in the list response
     * @type {Array<string>}
     */
    private excludedFields;
    /**
     * The options for the list of fields to exclude from the products in the list response
     * @type {Array<string>}
     */
    private excludedFieldsOption;
    /**
     * The list of fields to include in the products in the list response
     * @type {Array<string>}
     */
    private includedFields;
    /**
     * The collection of aggregation filters to search for in the products catalog
     * @type {any}
     */
    private aggregationFilters;
    /**
     * The aggregation guid
     * @type {string}
     */
    private aggregationState;
    /**
     * The returned aggregations
     * @type {any}
     */
    private aggregations;
    /**
     * The collection of aggregation options to apply to the search in the products catalog
     * @type {any}
     */
    private aggregationOptions;
    /**
     * Returns the current list of excluded fields
     * @return {Array<string>} The configured list of excluded product fields
     */
    getExcludedFields(): Array<string>;
    /**
     * Returns the current list of excluded fields
     * @return {Array<string>} The configured list of excluded product fields
     */
    addExcludedField(fieldName: string): Array<string>;
    /**
     * Clears the configured list of excluded fields
     * @return {Array<string>} The configured list of excluded product fields
     */
    clearExcludedFields(): Array<string>;
    /**
     * Sets the excluded fields option
     * @return {EVA.Core.ExcludedFieldOptions} The aggregation state
     */
    setExcludedFieldsOptions(option: EVA.Core.ExcludedFieldOptions): any;
    /**
     * Return the currently set excluded field option
     * @return {EVA.Core.ExcludedFieldOptions} The excluded field option value
     */
    getExcludedFieldsOption(): EVA.Core.ExcludedFieldOptions;
    /**
     * Returns the current list of included fields
     * @return {Array<string>} The configured list of included product fields
     */
    getIncludedFields(): Array<string>;
    /**
     * Returns the current list of included fields
     * @return {Array<string>} The configured list of included product fields
     */
    addIncludedField(fieldName: string): Array<string>;
    /**
     * Clears the configured list of included fields
     * @return {Array<string>} The configured list of included product fields
     */
    clearIncludedFields(): Array<string>;
    /**
     * Sets the aggregation filters
     * @return {any} The aggregation filters
     */
    setAggregationFilters(aggregationFilters: any): any;
    /**
     * Return the currently set aggregation filters
     * @return {any} The aggregation filters
     */
    getAggregationFilters(): any;
    /**
     * Sets the aggregation options
     * @return {any} The aggregation options
     */
    setAggregationOptions(aggregationOptions: any): any;
    /**
     * Return the currently set aggregation options
     * @return {any} The aggregation options
     */
    getAggregationOptions(): any;
    /**
     * Returns the current query string
     * @return {string}       The configured query string
     */
    getQuery(): string;
    /**
     * Set the query to search for
     * @param  {string} query The new query string
     * @return {string}       The configured query string
     */
    setQuery(query: string): string;
    /**
     * Return the aggregations that were returned with the product list
     * @return {any} The aggreations
     */
    getAggregations(): any;
    /**
     * Sets the current item details using the fetched service response.
     * Extending classes should override this method to pull the details from response
     * @param  {EVA.Core.Services.Products.SearchProductsResponse}  response    The response from the service call
     * @return {Array<EVA.Core.ProductDto>}                                     The product items for the current page
     */
    setData(response: any): EVA.Core.ProductDto[];
    /**
     * Fetches the product list item details
     * @return {Promise<IEVAServiceResponse<EVA.Core.ProductDto, EVA.Babylon.SearchFashionProducts, EVA.Core.Services.SearchProductsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SearchFashionProducts, EVA.Core.Services.SearchProductsResponse>>;
}
