"use strict";
/**
 * The applications module provides access to the applications data from the EVA back-end
 * @preferred
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var base_1 = require("./base");
var service_1 = require("../service");
var xhr_1 = require("../xhr");
var _ = require("lodash");
/**
 * Provides access to a babylon social functions in EVA
 * These are the by identifier versions that can be reused by EVA SDK objects
 */
var Search;
(function (Search) {
    "use strict";
    function quickFashionSearch(query, collectionSize, productSize, actorSize, onlyAutocompleteProducts) {
        if (onlyAutocompleteProducts === void 0) { onlyAutocompleteProducts = false; }
        // Create the service instance
        //
        var callURL = "/api/v1/fashion/quicksearch";
        var service = new service_1.EVAService("QuickSearchFashionItems", callURL, xhr_1.EXMLHttpRequestMethod.POST);
        var requestData = {
            FashionCollectionSize: collectionSize,
            ProductSize: productSize,
            ActorSize: actorSize,
            Query: query,
            OnlyAutocompleteProducts: onlyAutocompleteProducts
        };
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    Search.quickFashionSearch = quickFashionSearch;
    function socialUserSearch(query, pageSize, pageNr) {
        // Create the service instance
        //
        var callURL = "/api/v1/social/user/search";
        var service = new service_1.EVAService("SocialUserSearch", callURL, xhr_1.EXMLHttpRequestMethod.POST);
        var requestData = {
            Page: pageNr,
            PageSize: pageSize,
            Query: query
        };
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    Search.socialUserSearch = socialUserSearch;
    function socialFriendsSearch(query, pageSize, pageNr) {
        // Create the service instance
        //
        var callURL = "/api/v1/social/user/friends/search";
        var service = new service_1.EVAService("SocialSearchFriends", callURL, xhr_1.EXMLHttpRequestMethod.POST);
        var requestData = {
            Page: pageNr,
            PageSize: pageSize,
            Query: query
        };
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    Search.socialFriendsSearch = socialFriendsSearch;
    function fashionCollectionSearch(query, pageSize, pageNr, supplierName, sortOption) {
        // Create the service instance
        //
        var callURL = "/api/v1/fashion/collection/search";
        var service = new service_1.EVAService("SearchFashionCollections", callURL, xhr_1.EXMLHttpRequestMethod.POST);
        var requestData = {
            Page: pageNr,
            PageSize: pageSize,
            Query: query,
            SupplierName: supplierName,
            SortOptions: sortOption
        };
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    Search.fashionCollectionSearch = fashionCollectionSearch;
})(Search = exports.Search || (exports.Search = {}));
/**
 * Provides access to a list of products available in EVA
 */
var FashionProductList = /** @class */ (function (_super) {
    __extends(FashionProductList, _super);
    function FashionProductList() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        /**
         * The return aggregations flag
         * @type {any}
         */
        _this.includeAggregations = true;
        /**
         * The return suggestions flag
         * @type {any}
         */
        _this.includeSuggestions = false;
        /**
         * The query string to search for in the products catalog
         * @type {string}
         */
        _this.query = "";
        /**
         * The list of fields to exclude from the products in the list response
         * @type {Array<string>}
         */
        _this.excludedFields = [];
        /**
         * The list of fields to include in the products in the list response
         * @type {Array<string>}
         */
        _this.includedFields = [];
        return _this;
    }
    /**
     * Returns the current list of excluded fields
     * @return {Array<string>} The configured list of excluded product fields
     */
    FashionProductList.prototype.getExcludedFields = function () {
        return this.excludedFields;
    };
    /**
     * Returns the current list of excluded fields
     * @return {Array<string>} The configured list of excluded product fields
     */
    FashionProductList.prototype.addExcludedField = function (fieldName) {
        this.excludedFields.push(fieldName);
        return this.excludedFields;
    };
    /**
     * Clears the configured list of excluded fields
     * @return {Array<string>} The configured list of excluded product fields
     */
    FashionProductList.prototype.clearExcludedFields = function () {
        return this.excludedFields = [];
    };
    /**
     * Sets the excluded fields option
     * @return {EVA.Core.ExcludedFieldOptions} The aggregation state
     */
    FashionProductList.prototype.setExcludedFieldsOptions = function (option) {
        return this.excludedFieldsOption = option;
    };
    /**
     * Return the currently set excluded field option
     * @return {EVA.Core.ExcludedFieldOptions} The excluded field option value
     */
    FashionProductList.prototype.getExcludedFieldsOption = function () {
        return this.excludedFieldsOption;
    };
    /**
     * Returns the current list of included fields
     * @return {Array<string>} The configured list of included product fields
     */
    FashionProductList.prototype.getIncludedFields = function () {
        return this.includedFields;
    };
    /**
     * Returns the current list of included fields
     * @return {Array<string>} The configured list of included product fields
     */
    FashionProductList.prototype.addIncludedField = function (fieldName) {
        if (!_.isArray(this.includedFields)) {
            this.includedFields = [];
        }
        this.includedFields.push(fieldName);
        return this.includedFields;
    };
    /**
     * Clears the configured list of included fields
     * @return {Array<string>} The configured list of included product fields
     */
    FashionProductList.prototype.clearIncludedFields = function () {
        return this.includedFields = [];
    };
    /**
     * Sets the aggregation filters
     * @return {any} The aggregation filters
     */
    FashionProductList.prototype.setAggregationFilters = function (aggregationFilters) {
        return this.aggregationFilters = aggregationFilters;
    };
    /**
     * Return the currently set aggregation filters
     * @return {any} The aggregation filters
     */
    FashionProductList.prototype.getAggregationFilters = function () {
        return this.aggregationFilters;
    };
    /**
     * Sets the aggregation options
     * @return {any} The aggregation options
     */
    FashionProductList.prototype.setAggregationOptions = function (aggregationOptions) {
        return this.aggregationOptions = aggregationOptions;
    };
    /**
     * Return the currently set aggregation options
     * @return {any} The aggregation options
     */
    FashionProductList.prototype.getAggregationOptions = function () {
        return this.aggregationOptions;
    };
    /**
     * Returns the current query string
     * @return {string}       The configured query string
     */
    FashionProductList.prototype.getQuery = function () {
        return this.query;
    };
    /**
     * Set the query to search for
     * @param  {string} query The new query string
     * @return {string}       The configured query string
     */
    FashionProductList.prototype.setQuery = function (query) {
        return this.query = query;
    };
    /**
     * Return the aggregations that were returned with the product list
     * @return {any} The aggreations
     */
    FashionProductList.prototype.getAggregations = function () {
        return this.aggregations;
    };
    /**
     * Sets the current item details using the fetched service response.
     * Extending classes should override this method to pull the details from response
     * @param  {EVA.Core.Services.Products.SearchProductsResponse}  response    The response from the service call
     * @return {Array<EVA.Core.ProductDto>}                                     The product items for the current page
     */
    FashionProductList.prototype.setData = function (response) {
        // The default response is usually EVA.Core.PagedResultGeneric
        // An extending class will know exactly what is returned and where
        // the data for <T> can be found
        //
        // Store the paging response information
        //
        this.currentPageNumber = response.Page;
        this.totalNumberOfPages = Math.ceil(response.Total / response.PageSize);
        this.totalNumberOfItems = response.Total;
        this.appliedFilter = response.Filters;
        // Store the aggregations
        //
        this.aggregations = response.Aggregations;
        this.aggregationState = response.AggregationState;
        this.aggregationFilters = response.AggregationFilters;
        // Set and return the page items
        //
        return this.data = response.Products;
    };
    /**
     * Fetches the product list item details
     * @return {Promise<IEVAServiceResponse<EVA.Core.ProductDto, EVA.Babylon.SearchFashionProducts, EVA.Core.Services.SearchProductsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    FashionProductList.prototype.fetch = function () {
        // Ensure we have a sane page configuration
        //
        if (_.isEmpty(this.pageConfig)) {
            this.pageConfig = {
                Start: 0,
                Limit: 10,
                Filter: {},
                SortProperty: undefined,
                SortDirection: undefined
            };
        }
        // The SearchProduct calls works similar to a paged request but the page
        // configuration details are placed in seperate fields
        //
        var sortField = {
            FieldName: this.pageConfig.SortProperty,
            Direction: this.pageConfig.SortDirection
        };
        // Build the request data
        //
        var requestData = {
            Page: Math.floor(this.pageConfig.Start / this.pageConfig.Limit) + 1,
            PageSize: this.pageConfig.Limit,
            Filters: this.pageConfig.Filter,
            Sort: [sortField],
            IncludedFields: this.includedFields,
            ExcludedFields: this.excludedFields,
            IncludeAggregations: this.includeAggregations,
            IncludeSuggestions: this.includeSuggestions,
            ExcludedFieldsOption: this.excludedFieldsOption,
            AggregationFilters: this.aggregationFilters,
            AggregationState: this.aggregationState,
            AggregationOptions: this.aggregationOptions,
            Query: this.query || "",
            __response: undefined
        };
        return _super.prototype.fetch.call(this, "SearchFashionProducts", requestData);
    };
    return FashionProductList;
}(base_1.FetchablePagedList));
exports.FashionProductList = FashionProductList;
