/**
 * The shops module provides access to the shops (organization unit type) data from the EVA back-end
 * @preferred
 */
import { FetchableItem, FetchablePagedList } from "./base";
import { IEVAServiceResponse } from "../service";
/**
 * Provides access to a content page available in EVA
 */
export declare class Shop extends FetchableItem<EVA.Core.OrganizationUnitDto, EVA.Core.Services.GetOrganizationUnit, EVA.Core.Services.GetOrganizationUnitResponse> {
    /**
     * Fetches the page content
     * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrganizationUnit, EVA.Core.Services.GetOrganizationUnitResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrganizationUnit, EVA.Core.Services.GetOrganizationUnitResponse>>;
}
/**
 * Provides access to a list of shops available in EVA
 */
export declare class ShopList extends FetchablePagedList<EVA.Core.OrganizationUnitDto, EVA.Core.Services.ListOrganizationUnitsByType, EVA.Core.Services.ListOrganizationUnitsByTypeResponse> {
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.CMS.Dto.OrganizationUnitDto, EVA.Core.Services.ListOrganizationUnitsByType, EVA.Core.Services.ListOrganizationUnitsByTypeResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrganizationUnitsByType, EVA.Core.Services.ListOrganizationUnitsByTypeResponse>>;
}
/**
 * Provides access to a list of shops available in EVA
 */
export declare class ShopProximityList extends FetchablePagedList<EVA.Core.OrganizationUnitDto, EVA.Core.Services.ListOrganizationUnitByProximity, EVA.Core.Services.ListOrganizationUnitByProximityResponse> {
    /**
     * Optional location to use for the shop list (proximity search)
     * @type {string}
     */
    private location;
    /**
     * Changes to list of shops returned to those in the closest proximity of the given location
     * @param  {number} lat The locations latitude
     * @param  {number} lng The locations longitude
     * @return {object}     The chosen location
     */
    setLocation(lat: number, lng: number): any;
    /**
     * Returns the currently chosen location to use for a proximity based shop list
     * @return {object} The currently chosen location
     */
    getLocation(): any;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.CMS.Dto.OrganizationUnitDto, EVA.Core.Services.ListOrganizationUnitByProximity, EVA.Core.Services.ListOrganizationUnitByProximityResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrganizationUnitByProximity, EVA.Core.Services.ListOrganizationUnitByProximityResponse>>;
}
