import { FetchableItem, FetchablePagedList } from "./base";
import { IEVAServiceResponse } from "../service";
/**
 * Provides access to a babylon social functions in EVA
 * These are the by identifier versions that can be reused by EVA SDK objects
 */
export declare namespace Social {
    function getListOfLikedObjects(offset?: string, limit?: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialListLikedObjects, EVA.Babylon.SocialListLikedObjectsResponse>>;
    function getListOfProgressions(userID: number, type: EVA.Social.SocialProgressionType): Promise<IEVAServiceResponse<EVA.Social.SocialGetProgressions, EVA.Social.SocialGetProgressionsResponse>>;
    function likeProductByID(productID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeProduct, EVA.Core.EmptyResponseMessage>>;
    function unlikeProductByID(productID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeProduct, EVA.Core.EmptyResponseMessage>>;
    function shareProductWithUsers(productID: number, userIDs: Array<number>, message: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
    function productSharedExternally(productID: number, platform: EVA.Babylon.SocialMediaPlatform): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
    function listProductInteractionSummary(productID: number): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
    function listProductInteractionDetails(productID: number, limit?: number, offset?: string, type?: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
    function getProductStats(productIDs: Array<number> | number): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetProductsStats, EVA.Babylon.SocialStatsResponse>>;
    function likeCollectionByID(collectionID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeFashionCollection, EVA.Core.EmptyResponseMessage>>;
    function unlikeCollectionByID(collectionID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeFashionCollection, EVA.Core.EmptyResponseMessage>>;
    function shareCollectionWithUsers(collectionID: number, userIDs: Array<number>, message: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
    function collectionSharedExternally(collectionID: number, platform: EVA.Babylon.SocialMediaPlatform): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
    function inviteFriends(invites: Array<EVA.Babylon.InviteFriendsDto> | EVA.Babylon.InviteFriendsDto): Promise<IEVAServiceResponse<EVA.Babylon.SocialInviteFriends, EVA.Core.EmptyResponseMessage>>;
    function listCollectionInteractionSummary(collectionID: number): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
    function listCollectionInteractionDetails(collectionID: number, limit?: number, offset?: string, filter?: string | number): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
    function getCollectionStats(collectionIDs: Array<number> | number): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetFashionCollectionsStats, EVA.Babylon.SocialStatsResponse>>;
    function getCollectionStatsOverTime(collectionID: number, granularity: EVA.Babylon.CollectionStatsGranularity): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionStatsOverTime, EVA.Babylon.SocialStatsResponse>>;
    function likeUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeUser, EVA.Core.EmptyResponseMessage>>;
    function unlikeUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeUser, EVA.Core.EmptyResponseMessage>>;
    function followUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialFollowUser, EVA.Core.EmptyResponseMessage>>;
    function unfollowUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnfollowUser, EVA.Core.EmptyResponseMessage>>;
    function getAvatarURL(userID: number, size?: number, format?: string): string;
    function isFollowingUsers(userIDs: Array<number>): Promise<IEVAServiceResponse<EVA.Babylon.SocialIsFollowingUsers, EVA.Babylon.SocialIsFollowingUsersResponse>>;
    function likeUserMediaByID(userMediaID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeFashionUserMedia, EVA.Core.EmptyResponseMessage>>;
    function unlikeUserMediaByID(userMediaID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeFashionUserMedia, EVA.Core.EmptyResponseMessage>>;
    function removeCommentByID(commentID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialDeleteComment, EVA.Core.EmptyResponseMessage>>;
    function addCommentForProduct(productID: number, comment: string, mentionedUserIDs: Array<number>): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
    function addCommentForCollection(collectionID: number, comment: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
    function addCommentForUserMedia(userMediaID: number, comment: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
    function likeCommentByID(commentID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeComment, EVA.Core.EmptyResponseMessage>>;
    function unlikeCommentByID(commentID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeComment, EVA.Core.EmptyResponseMessage>>;
    function getStatsForFeedObjects(objects: Array<EVA.Babylon.FeedObjectDto>): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetStatsForFeedObjects, EVA.Babylon.SocialObjectStatsResponse>>;
    function blockUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.BlockUser, EVA.Core.EmptyResponseMessage>>;
    function unblockUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.UnblockUser, EVA.Core.EmptyResponseMessage>>;
    function reportContent(contentType: EVA.Babylon.SocialReportContentTypes, contentID: string, reason: EVA.Babylon.SocialReportReasons, description?: string): Promise<IEVAServiceResponse<EVA.Babylon.SocialReportContent, EVA.Core.EmptyResponseMessage>>;
    function sendPushNotificationTest(userId: number, title: string, body: string, data?: any): Promise<IEVAServiceResponse<EVA.Babylon.BabylonPushNotificationTest, EVA.Core.EmptyResponseMessage>>;
}
export declare class SocialProfile extends FetchableItem<EVA.Babylon.SocialUserProfile, EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse> {
    /**
     * Sets the current item details using the fetched service response.
     * Extending classes should override this method to pull the details from response
     * @param  {RES} response The response from the service call
     * @return {T}            The item details
     */
    setData(response: any): EVA.Babylon.SocialUserProfile;
    /**
     * Fetches the social user profile details
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialUserProfile, EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>;
    /**
     * Fetches the social user profile details by nickname
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialUserProfile, EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetchByNickname(nickname: string): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetUserProfileByNickname, EVA.Babylon.SocialGetUserProfileResponse>>;
    update(userProfile: EVA.Babylon.SocialUpdateUserProfileModel): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>;
}
export declare class SocialFollowers extends FetchablePagedList<EVA.Babylon.Follower, EVA.Babylon.SocialListFollowers, EVA.Babylon.SocialListFollowersResponse> {
    /**
     * The user to retrieve the follower list for
     * @type {number}
     */
    private userID;
    /**
     * Sets the user id to retrieve the follower list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    setUserID(userID: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListFollowers, EVA.Babylon.SocialListFollowersResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListFollowers, EVA.Babylon.SocialListFollowersResponse>>;
}
export declare class SocialFollowing extends FetchablePagedList<EVA.Babylon.Follower, EVA.Babylon.SocialListFollowing, EVA.Babylon.SocialListFollowingResponse> {
    /**
     * The user to retrieve the following list for
     * @type {number}
     */
    private userID;
    /**
     * Sets the user id to retrieve the following list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    setUserID(userID: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.Social.Services.SocialListFollowing, EVA.Babylon.Social.Services.SocialListFollowingResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListFollowing, EVA.Babylon.SocialListFollowingResponse>>;
}
export declare class SocialBlockedUsers extends FetchablePagedList<EVA.Babylon.BlockUser, EVA.Babylon.SocialListBlockedFollowers, EVA.Babylon.SocialListBlockedFollowersResponse> {
    /**
     * The user to retrieve the following list for
     * @type {number}
     */
    private userID;
    /**
     * Sets the user id to retrieve the following list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    setUserID(userID: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.Social.Services.SocialListFollowing, EVA.Babylon.Social.Services.SocialListFollowingResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListBlockedFollowers, EVA.Babylon.SocialListBlockedFollowersResponse>>;
}
export declare class SocialCommentsForProduct extends FetchablePagedList<EVA.Babylon.Comment, EVA.Babylon.SocialListCommentsForProduct, EVA.Babylon.SocialListCommentsResponse> {
    /**
     * The product to retrieve the comment list for
     * @type {number}
     */
    private productID;
    /**
     * Sets the product id to retrieve the follower list for
     * @param  {number} productID       The product identifier
     * @return {void}                   This method doesn't return anything
     */
    setProductID(productID: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForProduct, EVA.Babylon.SocialListCommentsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForProduct, EVA.Babylon.SocialListCommentsResponse>>;
}
export declare class SocialCommentsForCollection extends FetchablePagedList<EVA.Babylon.Comment, EVA.Babylon.SocialListCommentsForFashionCollection, EVA.Babylon.SocialListCommentsResponse> {
    /**
     * The collection to retrieve the comment list for
     * @type {number}
     */
    private collectionID;
    /**
     * Sets the collection id to retrieve the comment list for
     * @param  {number} collectionID        The collection identifier
     * @return {void}                       This method doesn't return anything
     */
    setCollectionID(collectionID: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionCollection, EVA.Babylon.SocialListCommentsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionCollection, EVA.Babylon.SocialListCommentsResponse>>;
}
export declare class SocialCommentsForUserMedia extends FetchablePagedList<EVA.Babylon.Comment, EVA.Babylon.SocialListCommentsForFashionUserMedia, EVA.Babylon.SocialListCommentsResponse> {
    /**
     * The user media to retrieve the comment list for
     * @type {number}
     */
    private userMediaID;
    /**
     * Sets the user media id to retrieve the follower list for
     * @param  {number} userMediaID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    setUserMediaID(userMediaID: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionUserMedia, EVA.Babylon.SocialListCommentsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionUserMedia, EVA.Babylon.SocialListCommentsResponse>>;
}
export declare class SocialProductsCreatedByUser extends FetchablePagedList<EVA.Babylon.ProductCreationByUserResult, EVA.Babylon.SocialListProductsCreationsByUser, EVA.Babylon.SocialListProductsCreationsByUserResponse> {
    /**
     * The user to retrieve the creations list for
     * @type {number}
     */
    private userID;
    /**
     * Sets the user id to retrieve the creations list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    setUserID(userID: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListProductsCreationsByUser, EVA.Babylon.SocialListProductsCreationsByUserResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListProductsCreationsByUser, EVA.Babylon.SocialListProductsCreationsByUserResponse>>;
}
export declare class SocialFacebookFriends extends FetchablePagedList<EVA.Babylon.FacebookFriend, EVA.Babylon.SocialListFacebookFriends, EVA.Babylon.SocialListFacebookFriendsResponse> {
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListFacebookFriends, EVA.Babylon.SocialListFacebookFriendsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListFacebookFriends, EVA.Babylon.SocialListFacebookFriendsResponse>>;
}
