"use strict";
/**
 * The applications module provides access to the applications data from the EVA back-end
 * @preferred
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var settings_1 = require("../settings");
var base_1 = require("./base");
var service_1 = require("../service");
var xhr_1 = require("../xhr");
var _ = require("lodash");
/**
 * Provides access to a babylon social functions in EVA
 * These are the by identifier versions that can be reused by EVA SDK objects
 */
var Social;
(function (Social) {
    "use strict";
    // Reusable social action method
    //
    function socialAction(itemID, type, action, requestData, requestMethod) {
        if (requestData === void 0) { requestData = {}; }
        if (requestMethod === void 0) { requestMethod = xhr_1.EXMLHttpRequestMethod.POST; }
        // Create the service instance
        //
        var callURL = "/api/v1/social/" + type + "/" + itemID + "/" + action;
        var service = new service_1.EVAService("SocialAction", callURL, requestMethod);
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    function socialRequest(itemID, type, action, requestData) {
        if (requestData === void 0) { requestData = {}; }
        // Create the service instance
        //
        var callURL = "/api/v1/social/" + type + "/" + itemID + "/" + action;
        var service = new service_1.EVAService("SocialAction", callURL, xhr_1.EXMLHttpRequestMethod.GET);
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    function getListOfLikedObjects(offset, limit) {
        // Create the service instance
        //
        // var callURL: string = `/api/v1/social/user/profile/liked`;
        // var service = new EVAService<EVA.Babylon.SocialListLikedObjects, EVA.Babylon.SocialListLikedObjectsResponse>( "SocialListLikedObjects", callURL, EXMLHttpRequestMethod.GET );
        if (limit === void 0) { limit = 10; }
        var service = new service_1.EVAService("SocialListLikedObjects");
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {
            PageConfig: {}
        };
        if (offset) {
            requestData.PageConfig.Offset = offset;
        }
        if (limit) {
            requestData.PageConfig.Limit = limit;
        }
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    Social.getListOfLikedObjects = getListOfLikedObjects;
    function getListOfProgressions(userID, type) {
        // Create the service instance
        //
        var service = new service_1.EVAService("SocialGetProgressions");
        var requestData = {
            Type: type,
            UserID: userID,
            __response: undefined
        };
        return service.call(requestData);
    }
    Social.getListOfProgressions = getListOfProgressions;
    ////////////////////////////////////////////////////////////////////////////
    // Product
    ////////////////////////////////////////////////////////////////////////////
    //
    function likeProductByID(productID) {
        return socialAction(productID, "product", "like");
    }
    Social.likeProductByID = likeProductByID;
    function unlikeProductByID(productID) {
        return socialAction(productID, "product", "unlike");
    }
    Social.unlikeProductByID = unlikeProductByID;
    function shareProductWithUsers(productID, userIDs, message) {
        var requestData = {
            ProductID: productID,
            UserIDs: userIDs,
            Message: message
        };
        return socialAction(productID, "product", "share", requestData);
    }
    Social.shareProductWithUsers = shareProductWithUsers;
    function productSharedExternally(productID, platform) {
        var requestData = {
            ProductID: productID,
            Platform: platform
        };
        return socialAction(productID, "product", "share/" + platform, requestData);
    }
    Social.productSharedExternally = productSharedExternally;
    function listProductInteractionSummary(productID) {
        return socialRequest(productID, "product", "interaction/summary");
    }
    Social.listProductInteractionSummary = listProductInteractionSummary;
    function listProductInteractionDetails(productID, limit, offset, type) {
        var requestData = {};
        var interactionTypeFilter = "";
        if (limit !== undefined) {
            requestData.limit = limit;
        }
        if (offset !== undefined) {
            requestData.offset = offset;
        }
        if (type !== undefined) {
            interactionTypeFilter = "/" + type;
        }
        return socialRequest(productID, "product", "interaction/detail" + interactionTypeFilter, requestData);
    }
    Social.listProductInteractionDetails = listProductInteractionDetails;
    function getProductStats(productIDs) {
        var service = new service_1.EVAService("SocialGetProductsStats");
        if (_.isNumber(productIDs)) {
            productIDs = [productIDs];
        }
        var requestData = {
            ProductIDs: productIDs
        };
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    Social.getProductStats = getProductStats;
    ////////////////////////////////////////////////////////////////////////////
    // Collection
    ////////////////////////////////////////////////////////////////////////////
    //
    function likeCollectionByID(collectionID) {
        return socialAction(collectionID, "collection", "like");
    }
    Social.likeCollectionByID = likeCollectionByID;
    function unlikeCollectionByID(collectionID) {
        return socialAction(collectionID, "collection", "unlike");
    }
    Social.unlikeCollectionByID = unlikeCollectionByID;
    function shareCollectionWithUsers(collectionID, userIDs, message) {
        var requestData = {
            CollectionID: collectionID,
            UserIDs: userIDs,
            Message: message
        };
        return socialAction(collectionID, "collection", "share", requestData);
    }
    Social.shareCollectionWithUsers = shareCollectionWithUsers;
    function collectionSharedExternally(collectionID, platform) {
        var requestData = {
            CollectionID: collectionID,
            Platform: platform
        };
        return socialAction(collectionID, "collection", "share/" + platform, requestData);
    }
    Social.collectionSharedExternally = collectionSharedExternally;
    function inviteFriends(invites) {
        var service = new service_1.EVAService("SocialInviteFriends");
        if (!_.isArray(invites)) {
            invites = [invites];
        }
        var requestData = {
            Invites: invites
        };
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    Social.inviteFriends = inviteFriends;
    function listCollectionInteractionSummary(collectionID) {
        return socialRequest(collectionID, "collection", "interaction/summary");
    }
    Social.listCollectionInteractionSummary = listCollectionInteractionSummary;
    function listCollectionInteractionDetails(collectionID, limit, offset, filter) {
        var requestData = {};
        if (limit !== undefined) {
            requestData.limit = limit;
        }
        if (offset !== undefined) {
            requestData.offset = offset;
        }
        var interactionType = "interaction/detail";
        if (filter) {
            switch (filter) {
                case "like":
                case "likes":
                case "liked":
                    {
                        filter = 1;
                    }
                    break;
                case "comment":
                case "comments":
                case "commented":
                    {
                        filter = 2;
                    }
                    break;
                case "clip":
                case "clips":
                case "clipped":
                    {
                        filter = 3;
                    }
                    break;
                default:
                    {
                        // NOOP
                    }
                    break;
            }
            interactionType += "/" + filter;
        }
        return socialRequest(collectionID, "collection", interactionType, requestData);
    }
    Social.listCollectionInteractionDetails = listCollectionInteractionDetails;
    function getCollectionStats(collectionIDs) {
        var service = new service_1.EVAService("SocialGetFashionCollectionsStats");
        if (_.isNumber(collectionIDs)) {
            collectionIDs = [collectionIDs];
        }
        var requestData = {
            CollectionIDs: collectionIDs
        };
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    Social.getCollectionStats = getCollectionStats;
    function getCollectionStatsOverTime(collectionID, granularity) {
        var service = new service_1.EVAService("GetFashionCollectionStatsOverTime");
        var requestData = {
            CollectionID: collectionID,
            Granularity: granularity
        };
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    Social.getCollectionStatsOverTime = getCollectionStatsOverTime;
    ////////////////////////////////////////////////////////////////////////////
    // User
    ////////////////////////////////////////////////////////////////////////////
    //
    function likeUserByID(userID) {
        return socialAction(userID, "user", "like");
    }
    Social.likeUserByID = likeUserByID;
    function unlikeUserByID(userID) {
        return socialAction(userID, "user", "unlike");
    }
    Social.unlikeUserByID = unlikeUserByID;
    function followUserByID(userID) {
        return socialAction(userID, "user", "follow");
    }
    Social.followUserByID = followUserByID;
    function unfollowUserByID(userID) {
        return socialAction(userID, "user", "unfollow");
    }
    Social.unfollowUserByID = unfollowUserByID;
    function getAvatarURL(userID, size, format) {
        if (size === void 0) { size = 100; }
        if (format === void 0) { format = "png"; }
        return settings_1.SettingsManager.getEndPointURL() + ("/user/avatar/" + size + "/" + userID + "." + format);
    }
    Social.getAvatarURL = getAvatarURL;
    function isFollowingUsers(userIDs) {
        // Create the service instance
        //
        var callURL = "/api/v1/social/user/following";
        var service = new service_1.EVAService("SocialIsFollowingUsers", callURL, xhr_1.EXMLHttpRequestMethod.POST);
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {
            UserIDs: userIDs
        };
        // Perform the call and return resulting promise
        //
        return service.call(requestData);
    }
    Social.isFollowingUsers = isFollowingUsers;
    ////////////////////////////////////////////////////////////////////////////
    // UserMedia
    ////////////////////////////////////////////////////////////////////////////
    //
    function likeUserMediaByID(userMediaID) {
        return socialAction(userMediaID, "user_media", "like");
    }
    Social.likeUserMediaByID = likeUserMediaByID;
    function unlikeUserMediaByID(userMediaID) {
        return socialAction(userMediaID, "user_media", "unlike");
    }
    Social.unlikeUserMediaByID = unlikeUserMediaByID;
    ////////////////////////////////////////////////////////////////////////////
    // Comments
    ////////////////////////////////////////////////////////////////////////////
    //
    function removeCommentByID(commentID) {
        // Create the service instance
        //
        var callURL = "/api/v1/social/comment/" + commentID;
        var service = new service_1.EVAService("SocialDeleteComment", callURL, xhr_1.EXMLHttpRequestMethod.DELETE);
        // Perform the call and capture the resulting promise
        //
        return service.call();
    }
    Social.removeCommentByID = removeCommentByID;
    function addCommentForProduct(productID, comment, mentionedUserIDs) {
        return socialAction(productID, "product", "comment", { CommentText: comment, MentionedUserIDs: mentionedUserIDs });
    }
    Social.addCommentForProduct = addCommentForProduct;
    function addCommentForCollection(collectionID, comment) {
        return socialAction(collectionID, "collection", "comment", { CommentText: comment });
    }
    Social.addCommentForCollection = addCommentForCollection;
    function addCommentForUserMedia(userMediaID, comment) {
        return socialAction(userMediaID, "user_media", "comment", { CommentText: comment });
    }
    Social.addCommentForUserMedia = addCommentForUserMedia;
    function likeCommentByID(commentID) {
        return socialAction(commentID, "comment", "like");
    }
    Social.likeCommentByID = likeCommentByID;
    function unlikeCommentByID(commentID) {
        return socialAction(commentID, "comment", "unlike");
    }
    Social.unlikeCommentByID = unlikeCommentByID;
    ////////////////////////////////////////////////////////////////////////////
    // Stats
    ////////////////////////////////////////////////////////////////////////////
    //
    function getStatsForFeedObjects(objects) {
        // Create the service instance
        //
        var callURL = "/api/v1/social/feed/stats";
        var service = new service_1.EVAService("SocialGetStatsForFeedObjects", callURL, xhr_1.EXMLHttpRequestMethod.POST);
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {
            ObjectIDs: objects
        };
        // Perform the call and return resulting promise
        //
        return service.call(requestData);
    }
    Social.getStatsForFeedObjects = getStatsForFeedObjects;
    ////////////////////////////////////////////////////////////////////////////
    // Abuse
    ////////////////////////////////////////////////////////////////////////////
    //
    function blockUserByID(userID) {
        // Create the service instance
        //
        var callURL = "/api/v1/social/user/block_list";
        var service = new service_1.EVAService("BlockUser", callURL, xhr_1.EXMLHttpRequestMethod.POST);
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {
            UserID: userID
        };
        // Perform the call and return resulting promise
        //
        return service.call(requestData);
    }
    Social.blockUserByID = blockUserByID;
    function unblockUserByID(userID) {
        // Create the service instance
        //
        var callURL = "/api/v1/social/user/block_list/" + userID;
        var service = new service_1.EVAService("UnblockUser", callURL, xhr_1.EXMLHttpRequestMethod.DELETE);
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {};
        // Perform the call and return resulting promise
        //
        return service.call(requestData);
    }
    Social.unblockUserByID = unblockUserByID;
    function reportContent(contentType, contentID, reason, description) {
        // Create the service instance
        //
        var service = new service_1.EVAService("SocialReportContent");
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {
            Type: contentType,
            Reason: reason,
            ID: contentID,
            Description: description
        };
        // Perform the call and return resulting promise
        //
        return service.call(requestData);
    }
    Social.reportContent = reportContent;
    ////////////////////////////////////////////////////////////////////////////
    // Testing
    ////////////////////////////////////////////////////////////////////////////
    //
    function sendPushNotificationTest(userId, title, body, data) {
        // Create the service instance
        //
        var service = new service_1.EVAService("BabylonPushNotificationTest");
        // Build the request data
        // The base class will add things like SessionID so keep typescript
        // happy we're using an 'any' type object here
        //
        var requestData = {
            UserID: userId,
            Title: title,
            Body: body,
            Data: data
        };
        // Perform the call and return resulting promise
        //
        return service.call(requestData);
    }
    Social.sendPushNotificationTest = sendPushNotificationTest;
})(Social = exports.Social || (exports.Social = {}));
var SocialProfile = /** @class */ (function (_super) {
    __extends(SocialProfile, _super);
    function SocialProfile() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the current item details using the fetched service response.
     * Extending classes should override this method to pull the details from response
     * @param  {RES} response The response from the service call
     * @return {T}            The item details
     */
    SocialProfile.prototype.setData = function (response) {
        // The default response is usually EVA.Core.GetResponse
        // An extending class will know exactly what is returned and where
        // the data for <T> can be found
        //
        return this.data = response.Profile;
    };
    /**
     * Fetches the social user profile details
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialUserProfile, EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    SocialProfile.prototype.fetch = function () {
        if (this.getId() === undefined) {
            return Promise.reject({
                status: 404,
                response: "Not found"
            });
        }
        else {
            // Build the request data
            //
            var requestData = {
                UserID: this.getId()
            };
            return _super.prototype.fetch.call(this, "SocialGetUserProfile", requestData, "/api/v1/social/user/" + this.getId() + "/profile", xhr_1.EXMLHttpRequestMethod.GET);
        }
    };
    /**
     * Fetches the social user profile details by nickname
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialUserProfile, EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    SocialProfile.prototype.fetchByNickname = function (nickname) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            // Build the request data
            //
            var requestData = {
                Nickname: nickname
            };
            // Perform the call and capture the resulting promise
            //
            var service = new service_1.EVAService("SocialGetUserProfileByNickname");
            service.call(requestData)
                .then(function (fetchResult) {
                _this.id = fetchResult.response.Profile.UserID;
                _this.setData(fetchResult.response);
                resolve(fetchResult);
            })
                .catch(reject);
        });
    };
    SocialProfile.prototype.update = function (userProfile) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.getId() === undefined) {
                reject({
                    status: 404,
                    response: "Not found"
                });
            }
            else {
                // Update the user profile
                //
                var service = new service_1.EVAService("SocialUpdateUserProfile", "/api/v1/social/user/" + _this.getId() + "/profile", xhr_1.EXMLHttpRequestMethod.PATCH);
                // Build the request data
                // The base class will add things like SessionID so keep typescript
                // happy we're using an 'any' type object here
                //
                var requestData = {
                    Profile: userProfile
                };
                // Perform the call and capture the resulting promise
                //
                service.call(requestData)
                    .then(function (updateResult) {
                    // Return the fetch of the updated user profile
                    //
                    _this.fetch().then(resolve).catch(reject);
                })
                    .catch(reject);
            }
        });
    };
    return SocialProfile;
}(base_1.FetchableItem));
exports.SocialProfile = SocialProfile;
var SocialFollowers = /** @class */ (function (_super) {
    __extends(SocialFollowers, _super);
    function SocialFollowers() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the user id to retrieve the follower list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    SocialFollowers.prototype.setUserID = function (userID) {
        this.userID = userID;
    };
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListFollowers, EVA.Babylon.SocialListFollowersResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    SocialFollowers.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {};
        // Apply PageConfig parameters directly
        //
        _.assign(requestData, _.omit(this.getPageConfiguration(), ["Filter"]));
        return _super.prototype.fetch.call(this, "SocialListFollowers", requestData, "/api/v1/social/user/" + this.userID + "/followers", xhr_1.EXMLHttpRequestMethod.GET);
    };
    return SocialFollowers;
}(base_1.FetchablePagedList));
exports.SocialFollowers = SocialFollowers;
var SocialFollowing = /** @class */ (function (_super) {
    __extends(SocialFollowing, _super);
    function SocialFollowing() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the user id to retrieve the following list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    SocialFollowing.prototype.setUserID = function (userID) {
        this.userID = userID;
    };
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.Social.Services.SocialListFollowing, EVA.Babylon.Social.Services.SocialListFollowingResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    SocialFollowing.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {};
        // Apply PageConfig parameters directly
        //
        _.assign(requestData, _.omit(this.getPageConfiguration(), ["Filter"]));
        return _super.prototype.fetch.call(this, "SocialListFollowing", requestData, "/api/v1/social/user/" + this.userID + "/following", xhr_1.EXMLHttpRequestMethod.GET);
    };
    return SocialFollowing;
}(base_1.FetchablePagedList));
exports.SocialFollowing = SocialFollowing;
var SocialBlockedUsers = /** @class */ (function (_super) {
    __extends(SocialBlockedUsers, _super);
    function SocialBlockedUsers() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the user id to retrieve the following list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    SocialBlockedUsers.prototype.setUserID = function (userID) {
        this.userID = userID;
    };
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.Social.Services.SocialListFollowing, EVA.Babylon.Social.Services.SocialListFollowingResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    SocialBlockedUsers.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {};
        // Apply PageConfig parameters directly
        //
        _.assign(requestData, _.omit(this.getPageConfiguration(), ["Filter"]));
        return _super.prototype.fetch.call(this, "SocialListBlockedFollowers", requestData, "/api/v1/social/user/block_list", xhr_1.EXMLHttpRequestMethod.GET);
    };
    return SocialBlockedUsers;
}(base_1.FetchablePagedList));
exports.SocialBlockedUsers = SocialBlockedUsers;
var SocialCommentsForProduct = /** @class */ (function (_super) {
    __extends(SocialCommentsForProduct, _super);
    function SocialCommentsForProduct() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the product id to retrieve the follower list for
     * @param  {number} productID       The product identifier
     * @return {void}                   This method doesn't return anything
     */
    SocialCommentsForProduct.prototype.setProductID = function (productID) {
        this.productID = productID;
    };
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForProduct, EVA.Babylon.SocialListCommentsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    SocialCommentsForProduct.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {};
        // Apply PageConfig parameters directly
        //
        _.assign(requestData, _.omit(this.getPageConfiguration(), ["Filter"]));
        return _super.prototype.fetch.call(this, "SocialListCommentsForProduct", requestData, "/api/v1/social/product/" + this.productID + "/comment", xhr_1.EXMLHttpRequestMethod.GET);
    };
    return SocialCommentsForProduct;
}(base_1.FetchablePagedList));
exports.SocialCommentsForProduct = SocialCommentsForProduct;
var SocialCommentsForCollection = /** @class */ (function (_super) {
    __extends(SocialCommentsForCollection, _super);
    function SocialCommentsForCollection() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the collection id to retrieve the comment list for
     * @param  {number} collectionID        The collection identifier
     * @return {void}                       This method doesn't return anything
     */
    SocialCommentsForCollection.prototype.setCollectionID = function (collectionID) {
        this.collectionID = collectionID;
    };
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionCollection, EVA.Babylon.SocialListCommentsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    SocialCommentsForCollection.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {};
        // Apply PageConfig parameters directly
        //
        _.assign(requestData, _.omit(this.getPageConfiguration(), ["Filter"]));
        return _super.prototype.fetch.call(this, "SocialListCommentsForFashionCollection", requestData, "/api/v1/social/collection/" + this.collectionID + "/comment", xhr_1.EXMLHttpRequestMethod.GET);
    };
    return SocialCommentsForCollection;
}(base_1.FetchablePagedList));
exports.SocialCommentsForCollection = SocialCommentsForCollection;
var SocialCommentsForUserMedia = /** @class */ (function (_super) {
    __extends(SocialCommentsForUserMedia, _super);
    function SocialCommentsForUserMedia() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the user media id to retrieve the follower list for
     * @param  {number} userMediaID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    SocialCommentsForUserMedia.prototype.setUserMediaID = function (userMediaID) {
        this.userMediaID = userMediaID;
    };
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionUserMedia, EVA.Babylon.SocialListCommentsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    SocialCommentsForUserMedia.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {};
        // Apply PageConfig parameters directly
        //
        _.assign(requestData, _.omit(this.getPageConfiguration(), ["Filter"]));
        return _super.prototype.fetch.call(this, "SocialListCommentsForFashionUserMedia", requestData, "/api/v1/social/user_media/" + this.userMediaID + "/comment", xhr_1.EXMLHttpRequestMethod.GET);
    };
    return SocialCommentsForUserMedia;
}(base_1.FetchablePagedList));
exports.SocialCommentsForUserMedia = SocialCommentsForUserMedia;
var SocialProductsCreatedByUser = /** @class */ (function (_super) {
    __extends(SocialProductsCreatedByUser, _super);
    function SocialProductsCreatedByUser() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the user id to retrieve the creations list for
     * @param  {number} userID      The user identifier
     * @return {void}               This method doesn't return anything
     */
    SocialProductsCreatedByUser.prototype.setUserID = function (userID) {
        this.userID = userID;
    };
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListProductsCreationsByUser, EVA.Babylon.SocialListProductsCreationsByUserResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    SocialProductsCreatedByUser.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {
            PageConfig: this.getPageConfiguration(),
            UserID: this.userID
        };
        return _super.prototype.fetch.call(this, "SocialListProductsCreationsByUser", requestData);
    };
    return SocialProductsCreatedByUser;
}(base_1.FetchablePagedList));
exports.SocialProductsCreatedByUser = SocialProductsCreatedByUser;
var SocialFacebookFriends = /** @class */ (function (_super) {
    __extends(SocialFacebookFriends, _super);
    function SocialFacebookFriends() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListFacebookFriends, EVA.Babylon.SocialListFacebookFriendsResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    SocialFacebookFriends.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {
            PageConfig: this.getPageConfiguration()
        };
        return _super.prototype.fetch.call(this, "SocialListFacebookFriends", requestData);
    };
    return SocialFacebookFriends;
}(base_1.FetchablePagedList));
exports.SocialFacebookFriends = SocialFacebookFriends;
