/**
 * The supplier module provides access to the supplier data from the EVA back-end
 * @preferred
 */
import { FetchableItem } from "./base";
import { IEVAServiceResponse } from "../service";
/**
 * Provides access to an order available in EVA
 */
export declare class FashionSupplier extends FetchableItem<EVA.Babylon.FashionSupplierDataDto, EVA.Babylon.GetFashionSupplierData, EVA.Babylon.GetFashionSupplierDataResponse> {
    /**
     * This class wraps an supplier from EVA and the operations you can perform on it.
     * You should supply the supplier identifier when creating an instance of this class
     *
     * @param  {number | string}    id      The identifier of the supplier to retrieve
     * @return {void}                       This method doesn't return anything
     */
    constructor(id?: number | string);
    /**
     * Fetches the order details
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.GetFashionSupplierData, EVA.Babylon.GetFashionSupplierDataResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionSupplierData, EVA.Babylon.GetFashionSupplierDataResponse>>;
    fetchForOrder(orderId: number): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionSupplierDataForOrder, EVA.Babylon.GetFashionSupplierDataForOrderResponse>>;
    /**
     * Sets the current item details using the fetched service response.
     * Extending classes should override this method to pull the details from response
     * @param  {EVA.Babylon.GetFashionSupplierDataResponse}  response    The response from the service call
     * @return {EVA.Babylon.FashionSupplierDataDto}                      The supplier details
     */
    setData(response: any): EVA.Babylon.FashionSupplierDataDto;
}
