"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * The supplier module provides access to the supplier data from the EVA back-end
 * @preferred
 */
var base_1 = require("./base");
var service_1 = require("../service");
/**
 * Provides access to an order available in EVA
 */
var FashionSupplier = /** @class */ (function (_super) {
    __extends(FashionSupplier, _super);
    /**
     * This class wraps an supplier from EVA and the operations you can perform on it.
     * You should supply the supplier identifier when creating an instance of this class
     *
     * @param  {number | string}    id      The identifier of the supplier to retrieve
     * @return {void}                       This method doesn't return anything
     */
    function FashionSupplier(id) {
        return _super.call(this, id) || this;
    }
    /**
     * Fetches the order details
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.GetFashionSupplierData, EVA.Babylon.GetFashionSupplierDataResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    FashionSupplier.prototype.fetch = function () {
        // Build the request data
        //
        var requestOrderData = {
            SupplierID: this.getId()
        };
        return _super.prototype.fetch.call(this, "GetFashionSupplierData", requestOrderData);
    };
    FashionSupplier.prototype.fetchForOrder = function (orderId) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var service = new service_1.EVAService("GetFashionSupplierDataForOrder");
            var requestData = {
                OrderID: orderId
            };
            service.call(requestData)
                .then(function (result) {
                // Populate supplier data from response
                //
                _this.setData(result.response);
                resolve(result);
            })
                .catch(reject);
        });
    };
    /**
     * Sets the current item details using the fetched service response.
     * Extending classes should override this method to pull the details from response
     * @param  {EVA.Babylon.GetFashionSupplierDataResponse}  response    The response from the service call
     * @return {EVA.Babylon.FashionSupplierDataDto}                      The supplier details
     */
    FashionSupplier.prototype.setData = function (response) {
        // Set the supplier data
        //
        this.data = response.SupplierData;
        return this.data;
    };
    return FashionSupplier;
}(base_1.FetchableItem));
exports.FashionSupplier = FashionSupplier;
