/**
 * The applications module provides access to the applications data from the EVA back-end
 * @preferred
 */
import { FetchablePagedList } from "./base";
import { IEVAServiceResponse } from "../service";
/**
 * Provides access to user media (fashion) in EVA
 */
export declare namespace UserMedia {
    function removeUserMediaByID(userMediaID: number): Promise<IEVAServiceResponse<EVA.Babylon.DeleteFashionUserMedia, EVA.Core.EmptyResponseMessage>>;
    function addUserMediaToProduct(productID: number, blobID: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
    function addUserMediaToCollection(collectionID: number, blobID: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
}
export declare class UserMediaForProduct extends FetchablePagedList<EVA.Babylon.FashionUserMedia, EVA.Babylon.ListFashionUserMediaForProduct, EVA.Babylon.ListFashionUserMediaResponse> {
    /**
     * The product to retrieve the user media list for
     * @type {number}
     */
    private productID;
    private userID;
    /**
     * Sets the product id to retrieve the user media list for
     * @param  {number} productID           The product identifier
     * @return {void}                       This method doesn't return anything
     */
    setProductID(productID: number): void;
    /**
     * Sets the user id to retrieve the user media list for a specific user
     * @param  {number} userID           The user identifier
     * @return {void}                    This method doesn't return anything
     */
    setUserID(userID: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForProduct, EVA.Babylon.ListFashionUserMediaResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForProduct, EVA.Babylon.ListFashionUserMediaResponse>>;
}
export declare class UserMediaForCollection extends FetchablePagedList<EVA.Babylon.FashionUserMedia, EVA.Babylon.ListFashionUserMediaForCollection, EVA.Babylon.ListFashionUserMediaResponse> {
    /**
     * The collection to retrieve the user media list for
     * @type {number}
     */
    private collectionID;
    private userID;
    /**
     * Sets the collection id to retrieve the user media list for
     * @param  {number} collectionID        The collection identifier
     * @return {void}                       This method doesn't return anything
     */
    setCollectionID(collectionID: number): void;
    /**
     * Sets the user id to retrieve the user media list for a specific user
     * @param  {number} userID           The user identifier
     * @return {void}                    This method doesn't return anything
     */
    setUserID(userID: number): void;
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForCollection, EVA.Babylon.ListFashionUserMediaResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForCollection, EVA.Babylon.ListFashionUserMediaResponse>>;
}
