"use strict";
/**
 * The applications module provides access to the applications data from the EVA back-end
 * @preferred
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var base_1 = require("./base");
var service_1 = require("../service");
var xhr_1 = require("../xhr");
var _ = require("lodash");
/**
 * Provides access to user media (fashion) in EVA
 */
var UserMedia;
(function (UserMedia) {
    "use strict";
    function removeUserMediaByID(userMediaID) {
        // Create the service instance
        //
        var callURL = "/api/v1/fashion/user_media/" + userMediaID;
        var service = new service_1.EVAService("DeleteFashionUserMedia", callURL, xhr_1.EXMLHttpRequestMethod.DELETE);
        // Perform the call and capture the resulting promise
        //
        return service.call();
    }
    UserMedia.removeUserMediaByID = removeUserMediaByID;
    function addUserMediaToProduct(productID, blobID) {
        // Create the service instance
        //
        var callURL = "/api/v1/fashion/product/" + productID + "/user_media";
        var service = new service_1.EVAService("SocialAction", callURL, xhr_1.EXMLHttpRequestMethod.POST);
        var requestData = {
            ProductID: productID,
            BlobID: blobID
        };
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    UserMedia.addUserMediaToProduct = addUserMediaToProduct;
    function addUserMediaToCollection(collectionID, blobID) {
        // Create the service instance
        //
        var callURL = "/api/v1/fashion/collection/" + collectionID + "/user_media";
        var service = new service_1.EVAService("SocialAction", callURL, xhr_1.EXMLHttpRequestMethod.POST);
        var requestData = {
            CollectionID: collectionID,
            BlobID: blobID
        };
        // Perform the call and capture the resulting promise
        //
        return service.call(requestData);
    }
    UserMedia.addUserMediaToCollection = addUserMediaToCollection;
})(UserMedia = exports.UserMedia || (exports.UserMedia = {}));
var UserMediaForProduct = /** @class */ (function (_super) {
    __extends(UserMediaForProduct, _super);
    function UserMediaForProduct() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the product id to retrieve the user media list for
     * @param  {number} productID           The product identifier
     * @return {void}                       This method doesn't return anything
     */
    UserMediaForProduct.prototype.setProductID = function (productID) {
        this.productID = productID;
    };
    /**
     * Sets the user id to retrieve the user media list for a specific user
     * @param  {number} userID           The user identifier
     * @return {void}                    This method doesn't return anything
     */
    UserMediaForProduct.prototype.setUserID = function (userID) {
        this.userID = userID;
    };
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForProduct, EVA.Babylon.ListFashionUserMediaResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    UserMediaForProduct.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {};
        var queryString = this.userID ? "?UserID=" + this.userID : "";
        // Apply PageConfig parameters directly
        //
        _.assign(requestData, _.omit(this.getPageConfiguration(), ["Filter"]));
        return _super.prototype.fetch.call(this, "ListFashionUserMediaForProduct", requestData, "/api/v1/fashion/product/" + this.productID + "/user_media" + queryString, xhr_1.EXMLHttpRequestMethod.GET);
    };
    return UserMediaForProduct;
}(base_1.FetchablePagedList));
exports.UserMediaForProduct = UserMediaForProduct;
var UserMediaForCollection = /** @class */ (function (_super) {
    __extends(UserMediaForCollection, _super);
    function UserMediaForCollection() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Sets the collection id to retrieve the user media list for
     * @param  {number} collectionID        The collection identifier
     * @return {void}                       This method doesn't return anything
     */
    UserMediaForCollection.prototype.setCollectionID = function (collectionID) {
        this.collectionID = collectionID;
    };
    /**
     * Sets the user id to retrieve the user media list for a specific user
     * @param  {number} userID           The user identifier
     * @return {void}                    This method doesn't return anything
     */
    UserMediaForCollection.prototype.setUserID = function (userID) {
        this.userID = userID;
    };
    /**
     * Fetches the list of items
     * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForCollection, EVA.Babylon.ListFashionUserMediaResponse>>} A promise resolving when the fetch from the back-end has completed
     */
    UserMediaForCollection.prototype.fetch = function () {
        // Build the request data
        //
        var requestData = {};
        var queryString = this.userID ? "?UserID=" + this.userID : "";
        // Apply PageConfig parameters directly
        //
        _.assign(requestData, _.omit(this.getPageConfiguration(), ["Filter"]));
        return _super.prototype.fetch.call(this, "ListFashionUserMediaForCollection", requestData, "/api/v1/fashion/collection/" + this.collectionID + "/user_media" + queryString, xhr_1.EXMLHttpRequestMethod.GET);
    };
    return UserMediaForCollection;
}(base_1.FetchablePagedList));
exports.UserMediaForCollection = UserMediaForCollection;
