/**
 * This method makes the EVA SDK ready for use and configures access to your back-end datastore
 * @param  {string}     authenticationToken   Your application authentication token
 * @param  {number}     applicationId         The application identifier for your store
 * @param  {string}     endPointURL           The URL for the EVA back-end store you want to use
 * @return {void}                             This method doesn't return anything
 */
export declare function init(authenticationToken: string, applicationId: number, endPointURL?: string): void;
/**
 * Expose the settings manager and the means to override the XMLHttpRequest provider
 */
export { SettingsManager as settings } from "./settings";
export { setTransportProvider, XHR } from "./xhr";
export { IEVAServiceResponse, EVAService } from "./service";
/**
 * These are the data providers availabe in eva
 */
export { Application } from "./data/applications";
export { Brand, Brands, searchBrands } from "./data/brands";
export { Collection, CollectionProducts } from "./data/collections";
export { CollectionCoverSheet, TrendingCollections } from "./data/collections";
export { TopFashionCollections, CollectionsEarnings } from "./data/collections";
export { Collections, ProductCollections } from "./data/collections";
export { DocumentSigning } from "./data/document-signing";
export { LoggedInUser, Users as users, User } from "./data/user";
export { Order, SearchOrderList, CustomerOrderList, OrdersWithReferenceList } from "./data/orders";
export { IEVAProduceDocumentsOptions } from "./data/orders";
export { ShoppingCart } from "./data/shopping-cart";
export { products } from "./data/products";
export { Product, ProductList, RecentlyViewedProductList } from "./data/products";
export { FashionProduct, getFashionProductCategories } from "./data/products";
export { Shop, ShopList, ShopProximityList } from "./data/shops";
export { SuggestionList } from "./data/suggestions";
export { PostNL } from "./data/postnl";
export { Rituals } from "./data/rituals";
export { Kijkshop, KijkBijMijNotificationsList, KijkBijMijHallOfFameList, KijkBijMijRatingsList, KijkBijMijProductGroupExperts } from "./data/kijkshop";
export { ContentBlockList } from "./data/cms-blocks";
export { ContentMenu, ContentMenuList } from "./data/cms-menus";
export { ContentPage, ContentPageList } from "./data/cms-pages";
export { getCmsPagesByRequestPath } from "./data/cms-pages";
export { ContentWidget } from "./data/cms-widgets";
export { CmsRewrite } from "./data/cms-rewrite";
export { DmsBlockList } from "./data/dms/dms-blocks";
export { DmsMenu } from "./data/dms/dms-menus";
export { DmsPage, DmsCompiledPage } from "./data/dms/dms-pages";
export { DmsRewrite } from "./data/dms/dms-rewrite";
export { DmsWidgetType } from "./data/dms/dms-widget-types";
export { DmsWidget } from "./data/dms/dms-widgets";
export { MakeUp, MakeupListBlocks, MakeupListMenus, MakeupListBlockVersions, MakeupListPageVersions, MakeupGetRenderedPageByPathResponseWithContext } from "./data/make-up";
export { Blob } from "./data/blob";
export { Barcodes } from "./data/barcodes";
export { Feed } from "./data/feed";
export { Social, SocialProfile } from "./data/social";
export { SocialFollowers, SocialFollowing } from "./data/social";
export { SocialCommentsForProduct } from "./data/social";
export { SocialCommentsForCollection } from "./data/social";
export { SocialCommentsForUserMedia } from "./data/social";
export { SocialProductsCreatedByUser } from "./data/social";
export { SocialBlockedUsers } from "./data/social";
export { SocialFacebookFriends } from "./data/social";
export { UserMedia } from "./data/user-media";
export { UserMediaForProduct, UserMediaForCollection } from "./data/user-media";
export { Search, FashionProductList } from "./data/search";
export { ShopReviews, ProductReviews, getShopReviewStats } from "./data/reviews";
export { FashionSupplier } from "./data/supplier";
export { Gamification, FashionCoinTransactions, FashionCollectionsForContest } from "./data/gamification";
export { AddressBook, Addresses as addresses } from "./data/addresses";
export { Newsletter as newsletter } from "./data/newsletter";
export { Station, StationList } from "./data/infrastructure";
export { Cultures } from "./data/cultures";
export { Currencies } from "./data/currencies";
export { Availability } from "./data/availability";
export { Functionalities } from "./data/functionalities";
export { ExternalContent } from "./data/external-content";
export { Reporting } from "./data/reporting";
export { addPushNotificationDevice } from "./data/notification";
export { removePushNotificationDevice } from "./data/notification";
export { Webshop } from "./data/webshop";
