"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * The EVA SDK provides functional access to the back-end API services.
 * To start using the SDK you must call the initialise method at least once and provide the following:
 * - Your authentication token
 * - Your application id
 * - The EVA endpoint URL to use
 *
 * This information should have been provided to you by your EVA platform provider
 *
 * @preferred
 */
var settings_1 = require("./settings");
// Polyfill promise support
// This will update the global Promise implementation as needed
//
require("es6-promise/auto");
/**
 * This method makes the EVA SDK ready for use and configures access to your back-end datastore
 * @param  {string}     authenticationToken   Your application authentication token
 * @param  {number}     applicationId         The application identifier for your store
 * @param  {string}     endPointURL           The URL for the EVA back-end store you want to use
 * @return {void}                             This method doesn't return anything
 */
function init(authenticationToken, applicationId, endPointURL) {
    "use strict";
    if (endPointURL === void 0) { endPointURL = "https://eva.newblack.io"; }
    settings_1.SettingsManager.setSiteAuthenticationToken(authenticationToken);
    settings_1.SettingsManager.setApplicationId(applicationId);
    settings_1.SettingsManager.setEndPointURL(endPointURL);
}
exports.init = init;
/**
 * Expose the settings manager and the means to override the XMLHttpRequest provider
 */
var settings_2 = require("./settings");
exports.settings = settings_2.SettingsManager;
var xhr_1 = require("./xhr");
exports.setTransportProvider = xhr_1.setTransportProvider;
exports.XHR = xhr_1.XHR;
var service_1 = require("./service");
exports.EVAService = service_1.EVAService;
/**
 * These are the data providers availabe in eva
 */
var applications_1 = require("./data/applications");
exports.Application = applications_1.Application;
var brands_1 = require("./data/brands");
exports.Brand = brands_1.Brand;
exports.Brands = brands_1.Brands;
exports.searchBrands = brands_1.searchBrands;
var collections_1 = require("./data/collections");
exports.Collection = collections_1.Collection;
exports.CollectionProducts = collections_1.CollectionProducts;
var collections_2 = require("./data/collections");
exports.CollectionCoverSheet = collections_2.CollectionCoverSheet;
exports.TrendingCollections = collections_2.TrendingCollections;
var collections_3 = require("./data/collections");
exports.TopFashionCollections = collections_3.TopFashionCollections;
exports.CollectionsEarnings = collections_3.CollectionsEarnings;
var collections_4 = require("./data/collections");
exports.Collections = collections_4.Collections;
exports.ProductCollections = collections_4.ProductCollections;
var document_signing_1 = require("./data/document-signing");
exports.DocumentSigning = document_signing_1.DocumentSigning;
var user_1 = require("./data/user");
exports.LoggedInUser = user_1.LoggedInUser;
exports.users = user_1.Users;
exports.User = user_1.User;
var orders_1 = require("./data/orders");
exports.Order = orders_1.Order;
exports.SearchOrderList = orders_1.SearchOrderList;
exports.CustomerOrderList = orders_1.CustomerOrderList;
exports.OrdersWithReferenceList = orders_1.OrdersWithReferenceList;
var shopping_cart_1 = require("./data/shopping-cart");
exports.ShoppingCart = shopping_cart_1.ShoppingCart;
var products_1 = require("./data/products");
exports.products = products_1.products;
var products_2 = require("./data/products");
exports.Product = products_2.Product;
exports.ProductList = products_2.ProductList;
exports.RecentlyViewedProductList = products_2.RecentlyViewedProductList;
var products_3 = require("./data/products");
exports.FashionProduct = products_3.FashionProduct;
exports.getFashionProductCategories = products_3.getFashionProductCategories;
var shops_1 = require("./data/shops");
exports.Shop = shops_1.Shop;
exports.ShopList = shops_1.ShopList;
exports.ShopProximityList = shops_1.ShopProximityList;
var suggestions_1 = require("./data/suggestions");
exports.SuggestionList = suggestions_1.SuggestionList;
var postnl_1 = require("./data/postnl");
exports.PostNL = postnl_1.PostNL;
var rituals_1 = require("./data/rituals");
exports.Rituals = rituals_1.Rituals;
var kijkshop_1 = require("./data/kijkshop");
exports.Kijkshop = kijkshop_1.Kijkshop;
exports.KijkBijMijNotificationsList = kijkshop_1.KijkBijMijNotificationsList;
exports.KijkBijMijHallOfFameList = kijkshop_1.KijkBijMijHallOfFameList;
exports.KijkBijMijRatingsList = kijkshop_1.KijkBijMijRatingsList;
exports.KijkBijMijProductGroupExperts = kijkshop_1.KijkBijMijProductGroupExperts;
// CMS
//
var cms_blocks_1 = require("./data/cms-blocks");
exports.ContentBlockList = cms_blocks_1.ContentBlockList;
var cms_menus_1 = require("./data/cms-menus");
exports.ContentMenu = cms_menus_1.ContentMenu;
exports.ContentMenuList = cms_menus_1.ContentMenuList;
var cms_pages_1 = require("./data/cms-pages");
exports.ContentPage = cms_pages_1.ContentPage;
exports.ContentPageList = cms_pages_1.ContentPageList;
var cms_pages_2 = require("./data/cms-pages");
exports.getCmsPagesByRequestPath = cms_pages_2.getCmsPagesByRequestPath;
var cms_widgets_1 = require("./data/cms-widgets");
exports.ContentWidget = cms_widgets_1.ContentWidget;
var cms_rewrite_1 = require("./data/cms-rewrite");
exports.CmsRewrite = cms_rewrite_1.CmsRewrite;
// DMS
//
var dms_blocks_1 = require("./data/dms/dms-blocks");
exports.DmsBlockList = dms_blocks_1.DmsBlockList;
var dms_menus_1 = require("./data/dms/dms-menus");
exports.DmsMenu = dms_menus_1.DmsMenu;
var dms_pages_1 = require("./data/dms/dms-pages");
exports.DmsPage = dms_pages_1.DmsPage;
exports.DmsCompiledPage = dms_pages_1.DmsCompiledPage;
var dms_rewrite_1 = require("./data/dms/dms-rewrite");
exports.DmsRewrite = dms_rewrite_1.DmsRewrite;
var dms_widget_types_1 = require("./data/dms/dms-widget-types");
exports.DmsWidgetType = dms_widget_types_1.DmsWidgetType;
var dms_widgets_1 = require("./data/dms/dms-widgets");
exports.DmsWidget = dms_widgets_1.DmsWidget;
// MakeUp
//
var make_up_1 = require("./data/make-up");
exports.MakeUp = make_up_1.MakeUp;
exports.MakeupListBlocks = make_up_1.MakeupListBlocks;
exports.MakeupListMenus = make_up_1.MakeupListMenus;
exports.MakeupListBlockVersions = make_up_1.MakeupListBlockVersions;
exports.MakeupListPageVersions = make_up_1.MakeupListPageVersions;
var blob_1 = require("./data/blob");
exports.Blob = blob_1.Blob;
var barcodes_1 = require("./data/barcodes");
exports.Barcodes = barcodes_1.Barcodes;
var feed_1 = require("./data/feed");
exports.Feed = feed_1.Feed;
var social_1 = require("./data/social");
exports.Social = social_1.Social;
exports.SocialProfile = social_1.SocialProfile;
var social_2 = require("./data/social");
exports.SocialFollowers = social_2.SocialFollowers;
exports.SocialFollowing = social_2.SocialFollowing;
var social_3 = require("./data/social");
exports.SocialCommentsForProduct = social_3.SocialCommentsForProduct;
var social_4 = require("./data/social");
exports.SocialCommentsForCollection = social_4.SocialCommentsForCollection;
var social_5 = require("./data/social");
exports.SocialCommentsForUserMedia = social_5.SocialCommentsForUserMedia;
var social_6 = require("./data/social");
exports.SocialProductsCreatedByUser = social_6.SocialProductsCreatedByUser;
var social_7 = require("./data/social");
exports.SocialBlockedUsers = social_7.SocialBlockedUsers;
var social_8 = require("./data/social");
exports.SocialFacebookFriends = social_8.SocialFacebookFriends;
var user_media_1 = require("./data/user-media");
exports.UserMedia = user_media_1.UserMedia;
var user_media_2 = require("./data/user-media");
exports.UserMediaForProduct = user_media_2.UserMediaForProduct;
exports.UserMediaForCollection = user_media_2.UserMediaForCollection;
var search_1 = require("./data/search");
exports.Search = search_1.Search;
exports.FashionProductList = search_1.FashionProductList;
var reviews_1 = require("./data/reviews");
exports.ShopReviews = reviews_1.ShopReviews;
exports.ProductReviews = reviews_1.ProductReviews;
exports.getShopReviewStats = reviews_1.getShopReviewStats;
var supplier_1 = require("./data/supplier");
exports.FashionSupplier = supplier_1.FashionSupplier;
var gamification_1 = require("./data/gamification");
exports.Gamification = gamification_1.Gamification;
exports.FashionCoinTransactions = gamification_1.FashionCoinTransactions;
exports.FashionCollectionsForContest = gamification_1.FashionCollectionsForContest;
var addresses_1 = require("./data/addresses");
exports.AddressBook = addresses_1.AddressBook;
exports.addresses = addresses_1.Addresses;
var newsletter_1 = require("./data/newsletter");
exports.newsletter = newsletter_1.Newsletter;
var infrastructure_1 = require("./data/infrastructure");
exports.Station = infrastructure_1.Station;
exports.StationList = infrastructure_1.StationList;
var cultures_1 = require("./data/cultures");
exports.Cultures = cultures_1.Cultures;
var currencies_1 = require("./data/currencies");
exports.Currencies = currencies_1.Currencies;
var availability_1 = require("./data/availability");
exports.Availability = availability_1.Availability;
var functionalities_1 = require("./data/functionalities");
exports.Functionalities = functionalities_1.Functionalities;
var external_content_1 = require("./data/external-content");
exports.ExternalContent = external_content_1.ExternalContent;
// BI Reporting
//
var reporting_1 = require("./data/reporting");
exports.Reporting = reporting_1.Reporting;
var notification_1 = require("./data/notification");
exports.addPushNotificationDevice = notification_1.addPushNotificationDevice;
var notification_2 = require("./data/notification");
exports.removePushNotificationDevice = notification_2.removePushNotificationDevice;
var webshop_1 = require("./data/webshop");
exports.Webshop = webshop_1.Webshop;
