import { EXMLHttpRequestMethod  } from "./xhr";
import * as _                     from "lodash";

export interface IServiceCache {
    ts: number;
    serviceName: string;
    path: string;
    method: EXMLHttpRequestMethod;
    callData: string;
    promise: Promise<any>;

}

let cachedServicePromises: Array<IServiceCache> = [];

// The cache timeout in miliseconds
//
let cacheTimeout: number = 3000;

export namespace serviceCache {
    "use strict";

    function setCacheTimeout( newCacheTimeout: number )
    {
        cacheTimeout = newCacheTimeout;
    }

    export function flush( serviceName?: string )
    {
        if ( serviceName )
        {
            _.remove( cachedServicePromises, { serviceName: serviceName } );
        }
        else
        {
            cachedServicePromises = [];
        }
    }

    function prune()
    {
        // Calculate the time limit
        //
        let limit_ts: number = +( new Date() ) - cacheTimeout;

        _.remove( cachedServicePromises, ( cacheEntry ) =>
        {
            // Remove all entries older then time limit
            //
            return cacheEntry.ts < limit_ts;
        } );
    }

    export function get( serviceName: string, requestData: any, method: EXMLHttpRequestMethod, path: string ): Promise<any>|undefined
    {
        // First prune the cache
        //
        prune();

        let callData   = JSON.stringify( requestData );
        let cacheEntry = _.find( cachedServicePromises, {
            serviceName: serviceName
        ,   path:        path
        ,   method:      method
        ,   callData:    callData
        } );

        return <Promise<any>|undefined> _.get( cacheEntry, "promise" );
    }

    export function add( serviceName: string, requestData: any, method: EXMLHttpRequestMethod, path: string, promise: Promise<any> )
    {
        // First prune the cache
        //
        prune();

        // Add the new promise
        //
        let cacheEntry: IServiceCache = {
            ts:          +( new Date() )
        ,   serviceName: serviceName
        ,   promise:     promise
        ,   path:        path
        ,   method:      method
        ,   callData:    JSON.stringify( requestData )
        };

        cachedServicePromises.push( cacheEntry );
    }
}

