import { EXMLHttpRequestMethod } from "./xhr";
/**
 * Any response is returned along with its HTTP responseStatus code
 * @type {interface}
 */
export interface IEVAServiceResponse<REQ, RES> {
    request: REQ;
    response: RES;
    status: number;
    xhr: XMLHttpRequest;
}
/**
 * Wrapper class for a call to the EVA back-end
 * Ensure all proper settings are applied and handles all the type casting of
 * request and response for the XMLHttpRequest calls
 * @type {class}
 */
export declare class EVAService<REQ, RES> {
    /**
     * Contains the name of the EVA service
     * @type {string}
     */
    private name;
    /**
     * Contains the path of the EVA service
     * @type {string}
     */
    private path;
    /**
     * Contains the request method of the EVA service
     * @type {EXMLHttpRequestMethod}
     */
    private method;
    /**
     * Constructor for the EVAService class
     * @param  {string} name    The name of the EVA service to call
     * @return {void}           This method returns nothing
     */
    constructor(name: string, path?: string, method?: EXMLHttpRequestMethod);
    /**
     * Convenience method to get the current session ID
     * @return {string} The current sessionID
     */
    getSessionID(): string;
    /**
     * Performs the actual call to the backend
     * @param  {REQ}        requestData The data to be sent as the body for this call
     * @return {Promise}                Return a promise that will resolve with the call response
     */
    call(requestData?: REQ, disableCache?: boolean, timeout?: number): Promise<IEVAServiceResponse<REQ, RES>>;
}
