/**
 * This declares the known settings for the EVA SDK
 */
export interface IEvaSettings {
    userAuthenticationToken?: string;
    siteAuthenticationToken?: string;
    applicationId?: number;
    sessionId?: string;
    endPointURL: string;
    language: string;
    version: string;
    clientName: string;
}
/**
 * The settings manager provides methods to get and set EVA client options
 * @type {namespace}
 */
export declare namespace SettingsManager {
    /**
     * Generates a new session identifier for all future service calls
     * @return {string} The current session identifier
     */
    function generateSessionID(): string;
    /**
     * Changes the currently configured site authentication token.
     * @return {string} An authorisation token
     */
    function setSiteAuthenticationToken(token: string): string;
    /**
     * Changes the currently configured user authentication token. This token
     * will be used in favor of the site authentication token.
     * @return {string} An authorisation token
     */
    function setUserAuthenticationToken(token: string): string;
    /**
     * Return the currently configured authentication token
     * @return {string} An authorisation token
     */
    function getAuthenticationToken(): string;
    /**
     * Changes the currently configured session identifier
     * @return {string} A session identifier
     */
    function setSessionId(sessionId: string): string;
    /**
     * Return the currently configured session identifier
     * @return {string} A session identifier
     */
    function getSessionId(): string;
    /**
     * Return the currently configured end point URL
     * @return {string} An end point URL
     */
    function getEndPointURL(): string;
    /**
     * Changes the currently configured end point URL
     * @return {string} An end point URL
     */
    function setEndPointURL(URL: string): string;
    /**
     * Return the currently configured application identifier
     * @return {number} An application identifier
     */
    function getApplicationId(): number;
    /**
     * Changes the currently configured application identifier
     * @return {number} An application identifier
     */
    function setApplicationId(applicationId: number): number;
    /**
     * Returns the currently configured client language
     * @return {string} Language code (ex. nl-NL)
     */
    function getLanguage(): string;
    /**
     * Changes the currently configured client language
     * @return {string} Language code (ex. nl-NL)
     */
    function setLanguage(languageCode: string): string;
    /**
     * Returns the current client version number which is in semver format
     * @return {string} Version number (ex. 0.1.0)
     */
    function getVersion(): string;
    /**
     * Returns the current client name
     * @return {string} Client name
     */
    function getClientName(): string;
}
