/**
 * For node.js or alternative platforms you can use setTransportProvider to point to an XHR alternative
 * @param  {any}    alternativeXMLHttpRequest   Platform specific or alternative XMLHttpRequest implementation
 * @return {void}                               This method does not return anything
 */
export declare function setTransportProvider(alternativeXMLHttpRequest: any): void;
/**
 * Create a new instance of an XMLHttpRequest object
 * @return {any} The XMLHttpRequest instance
 */
export declare function createTransport(): any;
/**
 * Possible XMLHttpRequest call methods
 * @type {enum}
 */
export declare enum EXMLHttpRequestMethod {
    GET = 0,
    POST = 1,
    PUT = 2,
    DELETE = 3,
    PATCH = 4,
}
/**
 * These are all the parameters that can be provided for an XMLHttpRequest call
 * @type {interface}
 */
export interface IXMLHttpRequestParameters {
    method: EXMLHttpRequestMethod;
    url: string;
    contentType?: string;
    headers?: any;
    data?: any;
    username?: string;
    password?: string;
}
/**
 * Any response is returned along with its HTTP responseStatus code
 * @type {interface}
 */
export interface IXMLHttpRequestResponse {
    status: number;
    response: any;
    xhr: XMLHttpRequest;
}
/**
 * Provides a wrapper for an XMLHttpRequest call
 * @type {class}
 */
export declare class XHR {
    /**
     * The timeout value for an XMLHttpRequest call
     * @type {number}
     */
    private timeout;
    /**
     * Private fallback timer to ensure a timeout always occurs
     * @type {any}
     */
    private timer;
    /**
     * The XMLHttpRequest instance used for the call
     * @type {any}
     */
    private xhr;
    appendURL(url: string, parameters: any): string;
    /**
     * Sets the XMLHttpRequest timeout to another value then the default 30 seconds
     * @param  {number} timeout The new timeout value in milliseconds
     * @return {number}         A timeout in milliseconds
     */
    setTimeout(timeout: number): number;
    /**
     * Return the current XMLHttpRequest timeout value
     * @return {number} A timeout in milliseconds
     */
    getTimeout(): number;
    /**
     * Performs an XMLHttpRequest call
     * @param  {IXMLHttpRequestParameters}  params  The call parameters
     * @return {Promise<IXMLHttpRequestResponse>} A promise that will resolve or reject depending on the call response
     */
    call(params: IXMLHttpRequestParameters): Promise<IXMLHttpRequestResponse>;
}
