// Generated by dts-bundle v0.7.3

/**
    * This method makes the EVA SDK ready for use and configures access to your back-end datastore
    * @param  {string}     authenticationToken   Your application authentication token
    * @param  {number}     applicationId         The application identifier for your store
    * @param  {string}     endPointURL           The URL for the EVA back-end store you want to use
    * @return {void}                             This method doesn't return anything
    */
export function init(authenticationToken: string, applicationId: number, endPointURL?: string): void;
/**
    * Expose the settings manager and the means to override the XMLHttpRequest provider
    */
/**
    * These are the data providers availabe in eva
    */

/**
    * This declares the known settings for the EVA SDK
    */
export interface IEvaSettings {
        userAuthenticationToken?: string;
        siteAuthenticationToken?: string;
        applicationId?: number;
        sessionId?: string;
        endPointURL: string;
        language: string;
        version: string;
        clientName: string;
}
/**
    * The settings manager provides methods to get and set EVA client options
    * @type {namespace}
    */
export namespace SettingsManager {
        /**
            * Generates a new session identifier for all future service calls
            * @return {string} The current session identifier
            */
        function generateSessionID(): string;
        /**
            * Changes the currently configured site authentication token.
            * @return {string} An authorisation token
            */
        function setSiteAuthenticationToken(token: string): string;
        /**
            * Changes the currently configured user authentication token. This token
            * will be used in favor of the site authentication token.
            * @return {string} An authorisation token
            */
        function setUserAuthenticationToken(token: string): string;
        /**
            * Return the currently configured authentication token
            * @return {string} An authorisation token
            */
        function getAuthenticationToken(): string;
        /**
            * Changes the currently configured session identifier
            * @return {string} A session identifier
            */
        function setSessionId(sessionId: string): string;
        /**
            * Return the currently configured session identifier
            * @return {string} A session identifier
            */
        function getSessionId(): string;
        /**
            * Return the currently configured end point URL
            * @return {string} An end point URL
            */
        function getEndPointURL(): string;
        /**
            * Changes the currently configured end point URL
            * @return {string} An end point URL
            */
        function setEndPointURL(URL: string): string;
        /**
            * Return the currently configured application identifier
            * @return {number} An application identifier
            */
        function getApplicationId(): number;
        /**
            * Changes the currently configured application identifier
            * @return {number} An application identifier
            */
        function setApplicationId(applicationId: number): number;
        /**
            * Returns the currently configured client language
            * @return {string} Language code (ex. nl-NL)
            */
        function getLanguage(): string;
        /**
            * Changes the currently configured client language
            * @return {string} Language code (ex. nl-NL)
            */
        function setLanguage(languageCode: string): string;
        /**
            * Returns the current client version number which is in semver format
            * @return {string} Version number (ex. 0.1.0)
            */
        function getVersion(): string;
        /**
            * Returns the current client name
            * @return {string} Client name
            */
        function getClientName(): string;
}

/**
    * For node.js or alternative platforms you can use setTransportProvider to point to an XHR alternative
    * @param  {any}    alternativeXMLHttpRequest   Platform specific or alternative XMLHttpRequest implementation
    * @return {void}                               This method does not return anything
    */
export function setTransportProvider(alternativeXMLHttpRequest: any): void;
/**
    * Create a new instance of an XMLHttpRequest object
    * @return {any} The XMLHttpRequest instance
    */
export function createTransport(): any;
/**
    * Possible XMLHttpRequest call methods
    * @type {enum}
    */
export enum EXMLHttpRequestMethod {
        GET = 0,
        POST = 1,
        PUT = 2,
        DELETE = 3,
        PATCH = 4,
}
/**
    * These are all the parameters that can be provided for an XMLHttpRequest call
    * @type {interface}
    */
export interface IXMLHttpRequestParameters {
        method: EXMLHttpRequestMethod;
        url: string;
        contentType?: string;
        headers?: any;
        data?: any;
        username?: string;
        password?: string;
}
/**
    * Any response is returned along with its HTTP responseStatus code
    * @type {interface}
    */
export interface IXMLHttpRequestResponse {
        status: number;
        response: any;
        xhr: XMLHttpRequest;
}
/**
    * Provides a wrapper for an XMLHttpRequest call
    * @type {class}
    */
export class XHR {
        appendURL(url: string, parameters: any): string;
        /**
            * Sets the XMLHttpRequest timeout to another value then the default 30 seconds
            * @param  {number} timeout The new timeout value in milliseconds
            * @return {number}         A timeout in milliseconds
            */
        setTimeout(timeout: number): number;
        /**
            * Return the current XMLHttpRequest timeout value
            * @return {number} A timeout in milliseconds
            */
        getTimeout(): number;
        /**
            * Performs an XMLHttpRequest call
            * @param  {IXMLHttpRequestParameters}  params  The call parameters
            * @return {Promise<IXMLHttpRequestResponse>} A promise that will resolve or reject depending on the call response
            */
        call(params: IXMLHttpRequestParameters): Promise<IXMLHttpRequestResponse>;
}

/**
    * Any response is returned along with its HTTP responseStatus code
    * @type {interface}
    */
export interface IEVAServiceResponse<REQ, RES> {
        request: REQ;
        response: RES;
        status: number;
        xhr: XMLHttpRequest;
}
/**
    * Wrapper class for a call to the EVA back-end
    * Ensure all proper settings are applied and handles all the type casting of
    * request and response for the XMLHttpRequest calls
    * @type {class}
    */
export class EVAService<REQ, RES> {
        /**
            * Constructor for the EVAService class
            * @param  {string} name    The name of the EVA service to call
            * @return {void}           This method returns nothing
            */
        constructor(name: string, path?: string, method?: EXMLHttpRequestMethod);
        /**
            * Convenience method to get the current session ID
            * @return {string} The current sessionID
            */
        getSessionID(): string;
        /**
            * Performs the actual call to the backend
            * @param  {REQ}        requestData The data to be sent as the body for this call
            * @return {Promise}                Return a promise that will resolve with the call response
            */
        call(requestData?: REQ, disableCache?: boolean, timeout?: number): Promise<IEVAServiceResponse<REQ, RES>>;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to an order available in EVA
    */
export class Application extends FetchableItem<EVA.Core.Services.ApplicationDto, EVA.Core.Services.GetCurrentApplication, EVA.Core.Services.GetCurrentApplicationResponse> {
        enabledPlugins: any;
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetCurrentApplication, EVA.Core.Services.GetCurrentApplicationResponse>>;
        setData(response: EVA.Core.Services.GetCurrentApplicationResponse): EVA.Core.Services.ApplicationDto;
        configuration(): Promise<IEVAServiceResponse<EVA.Core.Services.GetApplicationConfiguration, EVA.Core.Services.GetApplicationConfigurationResponse>>;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a babylon Brands (fashion) in EVA
    */
export class Brand extends FetchableItem<EVA.Core.Services.BrandDto, EVA.PIM.Core.GetBrand, EVA.PIM.Core.GetBrandResponse> {
        fetch(): Promise<IEVAServiceResponse<EVA.PIM.Core.GetBrand, EVA.PIM.Core.GetBrandResponse>>;
        create(name: string): Promise<IEVAServiceResponse<EVA.PIM.Core.GetBrand, EVA.PIM.Core.GetBrandResponse>>;
}
export class Brands extends FetchablePagedList<EVA.Core.Services.BrandDto, EVA.Core.Services.ListBrands, EVA.Core.Services.ListBrandsResponse> {
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES}        response    The response from the service call
            * @return {Array<T>}               The item details
            */
        setData(response: any): EVA.Core.Services.BrandDto[];
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.ListBrands, EVA.Core.Services.ListBrandsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListBrands, EVA.Core.Services.ListBrandsResponse>>;
}
export function searchBrands(query: string, pageSize?: number): Promise<IEVAServiceResponse<EVA.Core.Services.SearchBrands, EVA.Core.Services.SearchBrandsResponse>>;

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a babylon collections (fashion) in EVA
    */
export class Collection extends FetchableItem<EVA.Babylon.FashionCollectionDetail, EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse> {
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES} response The response from the service call
            * @return {T}            The item details
            */
        setData(response: any): EVA.Babylon.FashionCollectionDetail;
        create(collection: EVA.Babylon.CreateFashionCollectionRequestModel): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
        update(collectionDetailsToUpdate: EVA.Babylon.UpdateFashionCollection): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
        delete(): Promise<IEVAServiceResponse<EVA.Babylon.DeleteFashionCollection, EVA.Core.EmptyResponseMessage>>;
        addProducts(productIDs: Array<number>): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
        removeProduct(productID: number): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionDetailsByID, EVA.Babylon.GetFashionCollectionDetailsByIdResponse>>;
        getProductDetails(productID: number): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionProductDetails, EVA.Babylon.GetFashionCollectionProductDetailsResponse>>;
        updateProductSequence(productID: number, sequence: number): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionProductDetails, EVA.Babylon.GetFashionCollectionProductDetailsResponse>>;
}
export class CollectionsEarnings extends FetchableItem<EVA.Babylon.FashionCollectionSummaryWithEarnings[], EVA.Babylon.GetFashionCoinEarningsForCollections, EVA.Babylon.GetFashionCoinEarningsForCollectionsResponse> {
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCoinEarningsForCollections, EVA.Babylon.GetFashionCoinEarningsForCollectionsResponse>>;
}
export class CollectionProducts extends FetchablePagedList<EVA.Babylon.FashionCollectionProductDetails, EVA.Babylon.ListProductsForCollection, EVA.Babylon.ListProductsForCollectionResponse> {
        /**
            * Sets the collection id to retrieve the product list for
            * @param  {number} collectionID        The collection identifier
            * @return {void}                       This method doesn't return anything
            */
        setCollectionID(collectionID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListProductsForCollection, EVA.Babylon.ListProductsForCollectionResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListProductsForCollection, EVA.Babylon.ListProductsForCollectionResponse>>;
}
export class CollectionCoverSheet extends FetchableItem<EVA.Babylon.CoverSheetDocument, EVA.Babylon.GetFashionCollectionCoverSheet, EVA.Babylon.GetFashionCollectionCoverSheetResponse> {
        /**
            * Sets the collection id to retrieve the cover sheet for
            * @param  {number} collectionID        The collection identifier
            * @return {void}                       This method doesn't return anything
            */
        setCollectionID(collectionID: number): void;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES} response The response from the service call
            * @return {T}            The item details
            */
        setData(response: any): EVA.Babylon.CoverSheetDocument;
        /**
            * Fetches the collection cover sheet
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionCoverSheet, EVA.Babylon.GetFashionCollectionCoverSheetResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionCoverSheet, EVA.Babylon.GetFashionCollectionCoverSheetResponse>>;
        update(coversheet: EVA.Babylon.CoverSheetDocument): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionCoverSheet, EVA.Babylon.GetFashionCollectionCoverSheetResponse>>;
        productSearch(query: string, pageSize?: number, page?: number, likedProductsPage?: number, createdProductsPage?: number): Promise<IEVAServiceResponse<EVA.Babylon.CoverSheetProductsSearch, EVA.Babylon.CoverSheetProductsSearchResponse>>;
}
export class Collections extends FetchablePagedList<EVA.Babylon.FashionCollectionDetail, EVA.Babylon.ListFashionCollectionsForUser, EVA.Babylon.ListFashionCollectionsForUserResponse> {
        /**
            * Sets the user id to retrieve the collection list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Sets the user id to retrieve the collection list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setCoverSheetFilter(enableFilter?: boolean): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForUser, EVA.Babylon.ListFashionCollectionsForUserResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForUser, EVA.Babylon.ListFashionCollectionsForUserResponse>>;
}
export class TrendingCollections extends FetchablePagedList<EVA.Babylon.FashionCollectionSummary, EVA.Babylon.ListTrendingFashionCollections, EVA.Babylon.ListTrendingFashionCollectionsResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListTrendingFashionCollections, EVA.Babylon.ListTrendingFashionCollectionsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListTrendingFashionCollections, EVA.Babylon.ListTrendingFashionCollectionsResponse>>;
}
export class TopFashionCollections extends FetchablePagedList<EVA.Babylon.FashionCollectionSummary, EVA.Babylon.GetTopFashionCollections, EVA.Babylon.GetTopFashionCollectionsResponse> {
        /**
            * Sets the user id to retrieve the collection list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Sets creation time to filter on
            * @param  {Date} time    The creation time to filter on
            * @return {void}         This method doesn't return anything
            */
        setCreationTime(time: Date): void;
        /**
            * Sets top count to filter on
            * @param  {number} count  The top count to filter on
            * @return {void}          This method doesn't return anything
            */
        setTopCount(count: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.GetTopFashionCollections, EVA.Babylon.GetTopFashionCollectionsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetTopFashionCollections, EVA.Babylon.GetTopFashionCollectionsResponse>>;
}
export class ProductCollections extends FetchablePagedList<EVA.Babylon.FashionCollectionDetail, EVA.Babylon.ListFashionCollectionsForProduct, EVA.Babylon.ListFashionCollectionsForProductResponse> {
        /**
            * Sets the user id to retrieve the collection list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Sets the user id to retrieve the collection list for
            * @param  {number} productID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setProductID(productID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForProduct, EVA.Babylon.ListFashionCollectionsForProductResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForProduct, EVA.Babylon.ListFashionCollectionsForProductResponse>>;
}

export namespace DocumentSigning {
    function getSigningCodeForOrder(orderId: number): Promise<IEVAServiceResponse<EVA.DocumentSigning.GetSigningCodeForOrder, EVA.DocumentSigning.GetSigningCodeForOrderResponse>>;
    function getSigningDataForOrder(hashId: string): Promise<IEVAServiceResponse<EVA.DocumentSigning.GetSigningDataForOrder, EVA.DocumentSigning.GetSigningDataForOrderResponse>>;
    function signOrder(signature: number[], mimeType: string, hashId: string): Promise<IEVAServiceResponse<EVA.DocumentSigning.SignOrder, EVA.Core.RequestMessageWithEmptyResponse>>;
}

export interface IEVALoginOptions {
        organizationUnitId?: number;
        confirmationToken?: string;
        identificationCode?: string;
        selectOrganizationByApplicationID?: boolean;
        publicLogin?: boolean;
        registerApiKey?: boolean;
        context?: string;
}
export interface IEVACreateCustomer {
        noAccount?: boolean;
        autoLogin?: boolean;
}
/**
    * General namespace for Users function
    */
export namespace Users {
        /**
            * Request a token (via e-mail) for a user
            *
            * @param  {string}  emailAddress the e-mail adres of the user to request the token for
            * @return {Promise}              A promise that is fulfilled when the EVA Core service responds
            */
        function requestResetPassword(emailAddress: string): Promise<IEVAServiceResponse<EVA.Core.Services.RequestPasswordResetToken, EVA.Core.EmptyResponseMessage>>;
        /**
            * Reset a user password using a token that was received in an e-mail
            *
            * @param  {string}  newPassword the new password
            * @param  {string}  token       the token to be used for this reset
            * @return {Promise}             A promise that is fulfilled when the EVA Core service responds
            */
        function resetPassword(newPassword: string, token: string): Promise<IEVAServiceResponse<EVA.Core.Services.ResetUserPassword, EVA.Core.Services.ResetUserPasswordResponse>>;
}
/**
    * Provides authentication to EVA
    *
    * id is authentication
    */
export class LoggedInUser extends FetchableItem<EVA.Core.LoggedInUserDto, EVA.Core.Services.GetCurrentUser, EVA.Core.Services.GetCurrentUserResponse> {
        orders: CustomerOrderList;
        authentication: number;
        organisationUnits: Array<EVA.Core.OrganizationUnitDto>;
        isAnonymous: boolean;
        isEmployee: boolean;
        isCustomer: boolean;
        static checkEmailAddressAvailability(emailAddress: string): Promise<any>;
        static checkNicknameAvailability(nickname: string): Promise<any>;
        /**
            * Register a new customer and autologin
            *
            * @param  {any}            customer EVA.Core.Services.CustomerDto but only EmailAddress
            * @return {Promise<any>}   A promise that is fulfilled when the EVA Core service responds
            */
        static register(customer: any, autoLogin?: boolean, noAccount?: boolean): Promise<any>;
        /**
            * Register a new customer with company
            *
            * @param  {EVA.Core.Services.CreateCustomerWithCompany} request    Create a customer with company request
            * @return {Promise<any>}                                           A promise that is fulfilled when the EVA Core service responds
            */
        static registerWithCompany(request: EVA.Core.Services.CreateCustomerWithCompany): Promise<boolean>;
        /**
            * Retrieve the company details for a user
            * @return {Promise<EVA.Core.CompanyDto>}
            */
        static getCompanyForUser(userId: number): Promise<EVA.Core.CompanyDto>;
        /**
            * Method to update a company that belongs to the logged-in user
            *
            * @param {EVA.Core.CompanyDto} company The company to update
            * @returns {Promise<boolean>} Promise that returns true if update was successful
            */
        static updateCompanyForUser(userId: number, company: EVA.Core.CompanyDto): Promise<boolean>;
        /**
            * Search for customers
            *
            * @param  {string}           query           The query to search on
            * @param  {number}           limit           The page size limit. Defaults to 15
            * @param  {number}           start           The item to start the list at. Defaults to 0 and is a 0-based index.
            * @return {Promise<any>}                     A promise that is fulfilled when the EVA Core service responds
            */
        static searchUsers(query: string, limit?: number, start?: number): Promise<any>;
        /**
            * Retrieves and updates current user data
            * @return {Promise} A promise that is fulfilled when the EVA Core service responds
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetCurrentUser, EVA.Core.Services.GetCurrentUserResponse>>;
        /**
            * @param  {any}                                  response Provide with body of the response to populate and set properly the data on CurrentUser
            * @return {EVA.Core.LoggedInUserDto}          The current LoggedInUserDto state
            */
        setData(response?: any): EVA.Core.LoggedInUserDto;
        /**
            * Return the current authentication token
            * @return {string} The current authentication token
            */
        getAuthenticationToken(): string;
        /**
            * Perform a login using email adress and password, and optional additional
            * data
            *
            * @param  {string}  login        The email address or username (nickname) to login with
            * @param  {string}  password     The password over the login
            * @param  {IEVALoginOptions?} options An optional structure with additional data for the login
            * @return {Promise}              Will resolve when succesfully logged in or rejected with the authentication result (EVA.Core.AuthenticationResults) or a general error
            */
        login(login: string, password: string, options?: IEVALoginOptions): Promise<IEVAServiceResponse<EVA.Core.Services.Login, EVA.Core.Services.LoginResponse>>;
        /**
            * Execute an explicit logout
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        logout(): Promise<IEVAServiceResponse<EVA.Core.Services.Logout, EVA.Core.Services.LogoutResponse>>;
        /**
            * Retrieves third party login options
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        getThirdPartyLoginOptions(): Promise<IEVAServiceResponse<EVA.Core.Services.GetAvailableThirdPartiesForLogin, EVA.Core.Services.GetAvailableThirdPartiesForLoginResponse>>;
        /**
            * Requests third party login.
            * Response will contain a redirect url that can be used to perform the login
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        requestThirdPartyLogin(loginRequest: EVA.Core.Services.RequestThirdPartyLogin): Promise<IEVAServiceResponse<EVA.Core.Services.RequestThirdPartyLogin, EVA.Core.Services.RequestThirdPartyLoginResponse>>;
        /**
            * Perform third party login with a token
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        authenticateWithThirdPartyLogin(loginRequest: EVA.Core.Services.AuthenticateWithThirdPartyLogin): Promise<IEVAServiceResponse<EVA.Core.Services.AuthenticateWithThirdPartyLogin, EVA.Core.Services.AuthenticateWithThirdPartyLoginResponse>>;
        /**
            * This call retrieves a paged list of orders belonging to the current user
            *
            * @param  {number}                         start           The item to start the list at. Defaults to 0 and is a 0-based index.
            * @param  {number}                         limit           The page size limit. Defaults to 15
            * @param  {EVA.Core.SortDirection}  sortDirection          The sorting direction for the list. Defaults to ascending
            * @return {Promise<customerOrderList>}                     A promise resolving when the call to the back-end has completed
            */
        getOrders(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection): Promise<CustomerOrderList>;
        /**
            * This call retrieves a single order
            * @param {number}              order_id                    The ID of the order
            * @param {boolean}             include_failed_payements    If set to true, return order even if the payment has not been completed
            * @return {Promies<Order>}                                 A promise resolving when the call to the back-end has completed
            */
        getOrder(order_id: number, include_failed_payements: boolean): Promise<Order>;
        /**
            * Checks if the user has a newsletter subscription
            * @return {boolean} Indicates if the user has a newsletter subscription
            */
        hasNewsletterSubscription(): boolean;
        /**
            * Subscribes to the Newsletter using the users current email address
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        subscribeToNewsletter(): Promise<IEVAServiceResponse<EVA.Core.Services.Subscribe, EVA.Core.Services.SubscribeResponse>>;
        /**
            * Unsubscribes from the Newsletter using the users current email address
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        unsubscribeFromNewsletter(): Promise<IEVAServiceResponse<EVA.Core.Services.Unsubscribe, EVA.Core.Services.UnsubscribeResponse>>;
        /**
            * Confirms a Newsletter subscription using the provided token
            * @param  {string}     token   The subscription confirmation token
            * @return {Promise}            A promise resolving when the call to the back-end has completed
            */
        confirmNewsletterSubscription(token: string): Promise<IEVAServiceResponse<EVA.Core.Services.ConfirmSubscribe, EVA.Core.Services.ConfirmSubscribeResponse>>;
        /**
            * Checks if the user has an SMS notification subscription
            * @return {boolean} Indicates if the user has an SMS notification subscription
            */
        hasSmsNotificationSubscription(): boolean;
        /**
            * Subscribes to the SMS Notifications using the users current email address
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        subscribeToSMSNotifications(): Promise<IEVAServiceResponse<EVA.Core.Services.Subscribe, EVA.Core.Services.SubscribeResponse>>;
        /**
            * Unsubscribes from the SMS Notifications using the users current email address
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        unsubscribeFromSMSNotifications(): Promise<IEVAServiceResponse<EVA.Core.Services.Unsubscribe, EVA.Core.Services.UnsubscribeResponse>>;
        /**
            * Update the user
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        update(): Promise<IEVAServiceResponse<EVA.Core.Services.UpdateUser, EVA.Core.Services.UpdateUserResponse>>;
        /**
            * Update the user's email address
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        updateUserEmailAddress(newEmailAddress: string): Promise<IEVAServiceResponse<EVA.Core.Services.UpdateUserEmailAddress, EVA.Core.RequestMessageWithEmptyResponse>>;
        /**
            * Change the passowrd of this user
            *
            * @param  {string}  newPassword The new password
            * @param  {string}  oldPassword The current / old password
            * @return {Promise}             A promise resolving when the call to the back-end has completed
            */
        changePassword(newPassword: string, oldPassword: string): Promise<IEVAServiceResponse<EVA.Core.Services.ChangeUserPassword, EVA.Core.Services.ChangeUserPasswordResponse>>;
}
export class User extends FetchableItem<EVA.Core.UserDto, EVA.Core.Services.GetUser, EVA.Core.Services.GetUserResponse> {
        isAnonymous: boolean;
        isEmployee: boolean;
        isCustomer: boolean;
        /**
            * Retrieves specific user data
            * @return {Promise} A promise that is fulfilled when the EVA Core service responds
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetUser, EVA.Core.Services.GetUserResponse>>;
        /**
            * @param  {any}                                  response  Service response containing the user data
            * @return {EVA.Core.UserDto}                   The user data
            */
        setData(response?: any): EVA.Core.UserDto;
}

/**
    * The orders module provides access to the order data from the EVA back-end
    * @preferred
    */
export interface IEVAProduceInvoiceOptions {
        downloadInvoice?: boolean;
        emailAddress?: string;
        invoiceId?: number;
        printInvoice?: boolean;
        remark?: string;
        stationId?: string;
}
export interface IEVAProduceDocumentsOptions {
        printInvoice?: boolean;
        emailInvoice?: boolean;
        printReceipt?: boolean;
        stationId?: number;
        orderID?: number;
        emailAddress?: string;
        remark?: string;
}
/**
    * Provides access to an order available in EVA
    */
export class Order extends FetchableItem<EVA.Core.OrderDto, EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse> {
        /**
            * The payment options for the order
            * @type {Payment}
            */
        payment: Payments;
        /**
            * This class wraps an order from EVA and the operations you can perform on it.
            * You should supply the order identifier when creating an instance of this class
            *
            * @param  {number | string}    id      The identifier of the order to retrieve
            * @return {void}                       This method doesn't return anything
            */
        constructor(id?: number | string);
        /**
            * Returns if the order state 'completed' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isCompleted(): boolean;
        /**
            * Returns if the order state 'shipped' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isShipped(): boolean;
        /**
            * Returns if the order state 'paid' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isPaid(): boolean;
        /**
            * Returns if the order state 'invoiced' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isInvoiced(): boolean;
        /**
            * Returns if the order state 'cancelled' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isCancelled(): boolean;
        /**
            * Returns the current open amount still to be paid for the order
            * @return {number}
            */
        getOpenAmount(): number;
        /**
            * Returns the total value of all the items in the order with VAT
            * @return {number} The value of the items in the order with VAT
            */
        getTotalAmountInTax(): number;
        /**
            * Return order lines by type
            * @return {Array<EVA.Core.OrderLineDto>} Array of order lines
            */
        getOrderLinesByType(orderLineType: number | EVA.Core.OrderLineTypes): Array<EVA.Core.OrderLineDto>;
        /**
            * Return the total amount of shipping costs
            * @return {number} The total value of the shipping costs
            */
        getTotalShippingAmount(inTax?: boolean): number;
        /**
            * Return the total amount of ShippingCosts
            * @return {number} The total value of the shipping costs
            */
        getTotalDiscountAmount(inTax?: boolean): number;
        /**
            * Returns the current order requirement validation data
            * @return {EVA.Core.Validation.RequiredData} The order requirement validation data
            */
        getRequirements(): EVA.Core.RequiredData;
        /**
            * Checks if there are any invalid requirements in the current order requirement validation data
            * @return {boolean} Indicates if the order requirements are all met or not
            */
        isValid(): boolean;
        /**
            * Fetches and updates the order requirement validation data
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetRequiredDataForOrder, EVA.Core.Services.GetRequiredDataForOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        validate(requiredFor?: number, storeRequirements?: boolean): Promise<IEVAServiceResponse<EVA.Core.Services.GetRequiredDataForOrder, EVA.Core.Services.GetRequiredDataForOrderResponse>>;
        /**
            * Returns the list of different organizations where orderline items are te be picked up
            * @return {number} The list of organizations
            */
        readonly stockOrganizationUnits: Array<any>;
        /**
            * Returns the list of different organizations where orderline items are te be picked up
            * @return {number} The list of organizations
            */
        readonly requestedDates: Array<any>;
        /**
            * Fetches the order details
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {EVA.Core.Services.GetOrderResponse}  response    The response from the service call
            * @return {EVA.Core.OrderDto}              The order details
            */
        setData(response: any): EVA.Core.OrderDto;
        /**
            * Attaches a customer to the order
            * @param  {LoggedInUser}       customer       The current user class that is to be set as the customer for the order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setCustomer(customer: LoggedInUser | User): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Sets the currency for the order
            * @param  {string}       currencyID       The identifier of the currency
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setCurrency(currencyID: string): Promise<{}>;
        /**
            * Attaches a customer to the order
            * @param  {LoggedInUser}       customer       The current user class that is to be set as the customer for the order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setPickupOrganizationUnit(organizationUnitID: number): Promise<IEVAServiceResponse<EVA.Core.Services.SetPickupOrganizationUnit, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Places the order. It's usually wise to call validate(...) before trying to place an order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.PlaceOrder, EVA.Core.Services.PlaceOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        placeOrder(): Promise<IEVAServiceResponse<EVA.Core.Services.PlaceOrder, EVA.Core.Services.PlaceOrderResponse>>;
        produceInvoice(options: IEVAProduceInvoiceOptions): Promise<IEVAServiceResponse<EVA.Core.Services.ProduceInvoice, EVA.Core.ResourceResponseMessage>>;
        produceDocuments(options: IEVAProduceDocumentsOptions): Promise<IEVAServiceResponse<EVA.Core.Services.ProduceDocuments, EVA.Core.Services.ProduceDocumentsResponse>>;
        /**
            * Get the download url for this order
            *
            * @return {Promise<string>} The URL to the download of this order
            */
        getDownloadUrl(): Promise<string>;
        getReturnableStatusForOrder(): Promise<IEVAServiceResponse<EVA.Core.Services.GetReturnableStatusForOrder, EVA.Core.Services.GetReturnableStatusForOrderResponse>>;
        getReturnOrdersForOrder(): Promise<IEVAServiceResponse<EVA.CRM.Core.GetReturnOrdersForOrder, EVA.CRM.Core.GetReturnOrdersForOrderResponse>>;
        createCustomerReturn(lines: Array<EVA.CRM.Core.CustomerReturnLine>): Promise<IEVAServiceResponse<EVA.CRM.Core.CreateCustomerReturn, EVA.Core.EmptyResponseMessage>>;
        /**
            * For B2B orders
            *
            * Fetches the order view details
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetConfigurableOrderView, EVA.Core.Services.GetConfigurableOrderViewResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetchOrderView(logicalLevel?: string, groupByProperty?: string): Promise<IEVAServiceResponse<EVA.Core.Services.GetConfigurableOrderView, EVA.Core.Services.GetConfigurableOrderViewResponse>>;
        /**
            * Set the order reference
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.SetCustomerReferenceOnOrder, EVA.Core.EmptyResponseMessage>>} A promise resolving when the fetch from the back-end has completed
            */
        setOrderReference(reference: string): Promise<IEVAServiceResponse<EVA.Core.Services.SetCustomerReferenceOnOrder, EVA.Core.EmptyResponseMessage>>;
        /**
            * Set the shopping basket to an existing order. Removes any existing items in the shopping cart
            * @param  {number|Order}       order       Either an order id or an order class to set as the shopping cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        attach(order: number | Order): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Clears the entire shopping basket
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the call to the back-end has completed
            */
        detach(): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Set the order reference
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.ListOrderLines, EVA.Core.Services.ListOrderLinesResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        listOrderLines(orderLineIds?: number[], start?: number, limit?: number): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrderLines, EVA.Core.Services.ListOrderLinesResponse>>;
        /**
            * Update customer address data for this order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.ListOrderLines, EVA.Core.Services.ListOrderLinesResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        copyAddressesFromCustomer(): Promise<IEVAServiceResponse<EVA.Core.Services.UpdateOrderAddresses, EVA.Core.Services.UpdateOrderAddressesResponse>>;
        /**
            * Provides access to a list of shipments for this order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.ListOrderShipments, EVA.Core.Services.ListOrderShipmentsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        listShipments(): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrderShipments, EVA.Core.Services.ListOrderShipmentsResponse>>;
        /**
            * Provides access to a list of blobs for this order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.ListBlobsForOrder, EVA.Core.Services.ListBlobsForOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        listBlobs(): Promise<IEVAServiceResponse<EVA.Core.Services.ListBlobsForOrder, EVA.Core.Services.ListBlobsForOrderResponse>>;
        /**
            * Set the billing address of the order using an AddressBook item
            *
            * @param {number} addressBookId The ID of the AddressBook item
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setBillingAddressFromAddressBook(addressBookId: number): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Set the billing address of the order using an raw address
            *
            * @param {number} address The address to set as billing address on the order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setBillingAddress(address: EVA.Core.AddressDto): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Set the shipping address of the order using an AddressBook item
            *
            * @param {number} addressBookId The ID of the AddressBook item
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the call to the back-end has completed
            */
        setShippingAddressFromAddressBook(addressBookId: number): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Set the shipping address of the order using an raw address
            *
            * @param {number} address The address to set as shipping address on the order
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setShippingAddress(address: EVA.Core.AddressDto): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Sets a custom order data field
            *
            * @param {string} key The field name
            * @param {string} value The value (serialized string)
            * @returns {Promise<IEVAServiceResponse<EVA.Core.Services.SetCustomOrderData, EVA.Core.EmptyResponseMessage>>}
            * @memberof Order
            */
        setCustomOrderData(key: string, value: string): Promise<IEVAServiceResponse<EVA.Core.Services.SetCustomOrderData, EVA.Core.EmptyResponseMessage>>;
        getCustomOrderData(key: string): Promise<IEVAServiceResponse<EVA.Core.Services.GetCustomOrderData, EVA.Core.Services.GetCustomOrderDataResponse>>;
}
/**
    * Provides access to a list of customer orders available in EVA
    */
export class CustomerOrderList extends FetchablePagedList<Order, EVA.Core.Services.ListOrdersForCustomer, EVA.Core.Services.ListOrdersForCustomerResponse> {
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES} response The response from the service call
            * @return {T}            The item details
            */
        setData(response: any): Order[];
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Core.OrderDto, EVA.Core.Services.ListOrdersForCustomer, EVA.Core.Services.ListOrdersForCustomerResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrdersForCustomer, EVA.Core.Services.ListOrdersForCustomerResponse>>;
}
/**
    * Provides access to a list of customer orders available in EVA
    */
export class SearchOrderList extends FetchablePagedList<EVA.Core.OrderSearchResultItem, EVA.Core.Services.SearchOrders, EVA.Core.Services.SearchOrdersResponse> {
        /**
            * Returns the current query string
            * @return {string}       The configured query string
            */
        getQuery(): string;
        /**
            * Set the organization id to search for
            * @param  {number} query The organization id
            * @return {number}       The configured organization id
            */
        setOrganizationID(id: number): number;
        /**
            * Returns the current organization id
            * @return {number}       The configured organization id
            */
        getOrganizationID(): number;
        /**
            * Set the query to search for
            * @param  {string} query The new query string
            * @return {string}       The configured query string
            */
        setQuery(query: string): string;
        /**
            * Returns the current list of order ids
            * @return {Array<number>} The configured list of order ids
            */
        getOrderIDs(): Array<number>;
        /**
            * Adds an order ID to the list of orders to retrieve
            * @return {Array<number>} The configured list of order ids
            */
        addOrderID(id: number): Array<number>;
        /**
            * Adds an order ID to the list of orders to retrieve
            * @return {Array<number>} The configured list of order ids
            */
        setOrderIDs(ids: number[]): Array<number>;
        /**
            * Clears the configured list of order ids
            * @return {Array<number>} The configured list of order ids
            */
        clearOrderIDs(): Array<number>;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.SearchOrders, EVA.Core.Services.SearchOrdersResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.SearchOrders, EVA.Core.Services.SearchOrdersResponse>>;
}
/**
    * Provides access to a list of customer orders available in EVA
    */
export class OrdersWithReferenceList extends FetchablePagedList<EVA.Core.OrderWithReference, EVA.Core.Services.ListOrdersWithReference, EVA.Core.Services.ListOrdersWithReferenceResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Core.OrderDto, EVA.Core.Services.ListOrdersWithReference, EVA.Core.Services.ListOrdersWithReferenceResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrdersWithReference, EVA.Core.Services.ListOrdersWithReferenceResponse>>;
}

/**
    * The shopping cart module provides access to shopping cart data from the EVA back-end
    * Note that the shopping cart is bound to the current session so there is only 1 of them
    * You can regard it as the active order
    * @preferred
    */
/**
    * Provides access to the shopping cart available in EVA
    */
export class ShoppingCart extends FetchableItem<EVA.Core.OrderDto, EVA.Core.Services.GetShoppingCart, EVA.Core.ShoppingCartResponse> {
        /**
            * The payment options for the order
            * @type {Payment}
            */
        payment: Payments;
        /**
            * Indicates the order/cart is a pickup order (for a single shop)
            * @type {boolean}
            */
        isPickupOrder: boolean;
        /**
            * This class wraps the current shopping cart from EVA and the operations you can perform on it.
            *
            * @return {void} This method doesn't return anything
            */
        constructor();
        /**
            * Returns if the order state 'completed' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isCompleted(): boolean;
        /**
            * Returns if the order state 'shipped' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isShipped(): boolean;
        /**
            * Returns if the order state 'paid' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isPaid(): boolean;
        /**
            * Returns if the order state 'invoiced' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isInvoiced(): boolean;
        /**
            * Returns if the order state 'cancelled' applies to the order
            * @return {boolean} Indicates the state is active
            */
        isCancelled(): boolean;
        /**
            * Returns the current open amount still to be paid for the shopping cart
            * @return {number}
            */
        getOpenAmount(): number;
        /**
            * Returns the total value of all the items in the shopping cart with VAT
            * @return {number} The value of the items in the shopping cart with VAT
            */
        getTotalAmountInTax(): number;
        /**
            * Returns the total value of all the items in the shopping cart without VAT
            * @return {number} The value of the items in the shopping cart without VAT
            */
        getTotalAmount(): number;
        /**
            * Return order lines by type
            * @return {Array<EVA.Core.OrderLineDto>} Array of order lines
            */
        getOrderLinesByType(orderLineType: number | EVA.Core.OrderLineTypes): Array<EVA.Core.OrderLineDto>;
        /**
            * Return the total amount of shipping costs
            * @return {number} The total value of the shipping costs
            */
        getTotalShippingAmount(inTax?: boolean): number;
        /**
            * Return the total amount of ShippingCosts
            * @return {number} The total value of the shipping costs
            */
        getTotalDiscountAmount(inTax?: boolean): number;
        /**
            * Returns the list of different organizations where orderline items are te be picked up
            * @return {number} The list of organizations
            */
        readonly stockOrganizationUnits: Array<any>;
        /**
            * Returns the list of different organizations where orderline items are te be picked up
            * @return {number} The list of organizations
            */
        readonly requestedDates: Array<any>;
        /**
            * Returns the discount invalid reasons
            * @return {number}
            */
        getMessages(): EVA.Core.DiscountInvalidReasons[];
        /**
            * Fetches the shopping cart details
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCart, EVA.Core.ShoppingCartResponse>>} A promise resolving when the call to the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCart, EVA.Core.ShoppingCartResponse>>;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {EVA.Core.ShoppingCartResponse}  response    The response from the service call
            * @return {EVA.Core.OrderDto}              The order details
            */
        setData(response: any): EVA.Core.OrderDto;
        /**
            * Adds a product to the shopping cart
            * @param  {number|Product}                 product         Either a product id or a product class to add to the shopping cart
            * @param  {number}                         quantity        Quantity to add
            * @param  {EVA.Core.LineActionTypes}       lineActionType  Line action type. Default is 4 (delivery), 1 is for reservation
            * @return {Promise}                                        A promise resolving when the call to the back-end has completed
            */
        addProduct(product: number | Product, quantity?: number, lineActionType?: EVA.Core.LineActionTypes): Promise<IEVAServiceResponse<EVA.Core.Services.AddProductToOrder, EVA.Core.Services.AddProductToOrderResponse>>;
        /**
            * Changes an order line to a stock reservation
            * @param  {number}     orderLineId     The order line id that contains the product(s) that is/are to be reserverd
            * @param  {number}     organizationID  The shop to reserve the product at
            * @return {Promise}                    A promise resolving when the call to the back-end has completed
            */
        reserveOrderLine(orderLineId: number, organizationID: number): Promise<{}>;
        /**
            * Changes an order line to be shipped
            * @param  {number}     orderLineId     The order line id that contains the product(s) that is/are to be reserverd
            * @return {Promise}                    A promise resolving when the call to the back-end has completed
            */
        shipOrderLine(orderLineId: number): Promise<{}>;
        /**
            * Changes an order line to be delivered
            * @param  {number}     orderLineId     The order line id that contains the product(s) that is/are to be reserverd
            * @return {Promise}                    A promise resolving when the call to the back-end has completed
            */
        deliverOrderLine(orderLineId: number): Promise<{}>;
        /**
            * Removes order lines from the shopping cart
            * @param  {number|Array<number>}       orderLineId     The identifier or array of identifiers of the order line(s) to remove from the shopping cart
            * @return {Promise}                                    A promise resolving when the call to the back-end has completed
            */
        cancelOrderLine(orderLineId: number | Array<number>): Promise<IEVAServiceResponse<EVA.Core.Services.CancelOrderLine, EVA.Core.Services.CancelOrderLineResponse>>;
        /**
            * Convenience methods to remove all instances of a product from the shopping  This is the more direct mirror call of addProduct
            * @param  {number|Product}     product     Either a product id or a product class to remove from the shopping cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        removeProduct(product: number | Product): Promise<IEVAServiceResponse<EVA.Core.Services.CancelOrderLine, EVA.Core.ShoppingCartResponse>>;
        /**
            * Modify the number of items for an order line
            * @param  {number}         orderLineId     The identifier of the order line to modify from the shopping cart
            * @param  {number}         quantity        The new quantity
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        modifyQuantity(orderLineId: number, quantity: number): Promise<IEVAServiceResponse<EVA.Core.Services.ModifyQuantityOrdered, EVA.Core.ShoppingCartResponse>>;
        /**
            * Clears the entire shopping basket
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCart, EVA.Core.ShoppingCartResponse>>} A promise resolving when the call to the back-end has completed
            */
        empty(): Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCart, EVA.Core.ShoppingCartResponse>>;
        /**
            * List the available shipping methods for the current cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        listShippingMethods(orderId: number, orderlineIds: Array<number>): Promise<IEVAServiceResponse<EVA.Core.Services.ListAvailableShippingMethods, EVA.Core.Services.ListAvailableShippingMethodsResponse>>;
        /**
            * Gets the shipping methods currently set to the cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        getShippingMethods(orderId: number): Promise<IEVAServiceResponse<EVA.Core.Services.GetShippingMethodsForOrder, EVA.Core.Services.GetShippingMethodsForOrderResponse>>;
        /**
            * Gets the available shipping dates of a shipping method
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        getShippingDates(): Promise<IEVAServiceResponse<EVA.Core.Services.ListAvailableShippingDates, EVA.Core.Services.ListAvailableShippingDatesResponse>>;
        /**
            * Sets the pickup organiszation unit to the cart.
            * We don't know the orderId, but the session Id will do the trick
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        setPickupOrganizationUnit(organizationUnitID: number): Promise<IEVAServiceResponse<EVA.Core.Services.SetPickupOrganizationUnit, EVA.Core.ShoppingCartResponse>>;
        /**
            * Gets the shipping methods currently set to the cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        setShippingMethod(orderId: number, orderLineId: number, shippingMethodId: number, requestDeliveryDate: Date): Promise<IEVAServiceResponse<EVA.Core.Services.SetShippingMethod, EVA.Core.ShoppingCartResponse>>;
        /**
            * Modify the number of items for an order line
            * @param  {string}         couponCode      The coupon code that needs to be added to the cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        addCouponCode(couponCode: string): Promise<IEVAServiceResponse<EVA.Core.Services.AddDiscountToOrder, EVA.Core.ShoppingCartResponse>>;
        /**
            * Retrieves the shopping cart summary information
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCartInfo, EVA.Core.Services.ShoppingCartInfoResponse>>} A promise resolving when the call to the back-end has completed
            */
        getInfo(): Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCartInfo, EVA.Core.Services.GetShoppingCartInfoResponse>>;
        /**
            * Attaches a customer to the shopping cart
            * @param  {LoggedInUser}       customer       The current user class that is to be set as the customer for the shopping cart
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        setCustomer(customer: LoggedInUser | User): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrder, EVA.Core.Services.GetOrderResponse>>;
        /**
            * Places an order for the current shopping cart contents
            * @return {Promise<Order>} A promise resolving when the call to the back-end has completed
            */
        createOrder(): Promise<Order>;
        /**
            * Set the shopping basket to an existing order. Removes any existing items in the shopping cart
            * @param  {number|Order}       order       Either an order id or an order class to set as the shopping cart
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        setFromOrder(order: number | Order): Promise<IEVAServiceResponse<EVA.Core.Services.GetShoppingCart, EVA.Core.ShoppingCartResponse>>;
        /**
            * Attaches a fashion collection to an order line
            * @param  {number}         orderLineId     The identifier of the order line to modify from the shopping cart
            * @param  {number}         collectionId    The fashion collection identifier
            * @return {Promise}                        A promise resolving when the call to the back-end has completed
            */
        setFashionCollectionOriginForOrderLine(orderLineID: number, collectionID: number): Promise<{}>;
}

export namespace products {
        function getProductPrices(productIds: number[]): Promise<IEVAServiceResponse<EVA.Core.Services.GetProductPrices, EVA.Core.Services.GetProductPricesResponse>>;
        function getConfigurableProductsDetails(productIds: number[], includes?: string[]): Promise<IEVAServiceResponse<EVA.Core.Services.GetConfigurableProductsDetail, EVA.Core.Services.GetConfigurableProductsDetailResponse>>;
        function getProductsDetails(productIds: number[], pageConfig?: EVA.Core.PageConfig, additionalFilters?: any): Promise<IEVAServiceResponse<EVA.Core.Services.SearchProducts, EVA.Core.Services.SearchProductsResponse>>;
}
/**
    * Provides access to a product available in EVA
    */
export class Product extends FetchableItem<EVA.Core.ProductDto, EVA.Core.Services.GetProductDetail, EVA.Core.Services.GetProductDetailResponse> {
        /**
            * Fetches the product details
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.Products.GetProductDetail, EVA.Core.Services.Products.GetProductDetailResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetProductDetail, EVA.Core.Services.GetProductDetailResponse>>;
        /**
            * Fetches the product configuration details
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetConfigurableProductDetail, EVA.Core.Services.GetConfigurableProductDetailResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        getConfigurationDetails(): Promise<IEVAServiceResponse<EVA.Core.Services.GetConfigurableProductDetail, EVA.Core.Services.GetConfigurableProductDetailResponse>>;
        /**
            * Retrieves the stock details for the product
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetStockDetailsForProduct, EVA.Core.Services.GetStockDetailsForProductResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        getStockDetails(): Promise<IEVAServiceResponse<EVA.Core.Services.GetStockDetailsForProduct, EVA.Core.Services.GetStockDetailsForProductResponse>>;
        /**
            * Retrieves the availability indication for the product
            * @param  {number}         quantityRequested           Quantity to check availability for. Defaults to 1
            * @param  {Array<number>}  organizationUnitIDs         An array of organisation id's to limit the availability check to
            * @param  {boolean}        fastestPickupShopOnly       Only return the fastest pickup option. Defaults to false
            * @param  {boolean}        includeAvailabilityTexts    Add availability text messages to the response. Defaults to false
            * @param  {boolean}        detailedShopInformation     Add detailed shop information to the response. Defaults to false
            * @return {Promise<Array<EVA.Core.ProductAvailabilityIndicationDto>>} A promise resolving when the fetch from the back-end has completed
            */
        getAvailability(quantityRequested?: number, organizationUnitIDs?: Array<number>, fastestPickupShopOnly?: boolean, includeAvailabilityTexts?: boolean, detailedShopInformation?: boolean): Promise<Array<EVA.Core.ProductAvailabilityIndication>>;
        /**
            * Retrieves the available variants (color, size, etc.) for a product
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.SearchProducts, EVA.Core.Services.SearchProductsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        getVariants(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string, additionalFilters?: any): Promise<IEVAServiceResponse<EVA.Core.Services.SearchProducts, EVA.Core.Services.SearchProductsResponse>>;
}
/**
    * Provides access to a fashion product available in EVA
    */
export class FashionProduct extends Product {
        /**
            * Convenience method to build a product image URL
            * @param  {number} productID   The product identifier
            * @param  {number} width       The output image width
            * @param  {number} height      The output image height
            * @param  {string} type        The image type (ie. png, jpg, etc)
            *
            * @return {string}             An image URL
            */
        static getProductImageUrl(productID: number, width?: number, height?: number, format?: string): string;
        create(product: EVA.Babylon.CreateFashionProduct): Promise<IEVAServiceResponse<EVA.Core.Services.GetProductDetail, EVA.Core.Services.GetProductDetailResponse>>;
        update(productDetailsToUpdate: EVA.Babylon.UpdateFashionProduct): Promise<IEVAServiceResponse<EVA.Core.Services.GetProductDetail, EVA.Core.Services.GetProductDetailResponse>>;
        delete(): Promise<IEVAServiceResponse<EVA.Babylon.DeleteFashionProduct, EVA.Core.EmptyResponseMessage>>;
        getCoverSheetImages(): Promise<IEVAServiceResponse<EVA.Babylon.GetProductImagesForCoverSheet, EVA.Babylon.GetProductImagesForCoverSheetResponse>>;
        getCreator(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionProductCreator, EVA.Babylon.GetFashionProductCreatorResponse>>;
        countCollections(): Promise<IEVAServiceResponse<EVA.Babylon.CountFashionCollectionsForProduct, EVA.Babylon.CountFashionCollectionsForProductResponse>>;
}
/**
    * Provides access to a list of products available in EVA
    */
export class ProductList extends FetchablePagedList<EVA.Core.ProductDto, EVA.Core.Services.SearchProducts, EVA.Core.Services.SearchProductsResponse> {
        /**
            * The return aggregations flag
            * @type {any}
            */
        includeAggregations: boolean;
        /**
            * The return suggestions flag
            * @type {any}
            */
        includeSuggestions: boolean;
        /**
            * Returns the current list of excluded fields
            * @return {Array<string>} The configured list of excluded product fields
            */
        getExcludedFields(): Array<string>;
        /**
            * Returns the current list of excluded fields
            * @return {Array<string>} The configured list of excluded product fields
            */
        addExcludedField(fieldName: string): Array<string>;
        /**
            * Clears the configured list of excluded fields
            * @return {Array<string>} The configured list of excluded product fields
            */
        clearExcludedFields(): Array<string>;
        /**
            * Sets the excluded fields option
            * @return {EVA.Core.ExcludedFieldOptions} The aggregation state
            */
        setExcludedFieldsOptions(option: EVA.Core.ExcludedFieldOptions): any;
        /**
            * Return the currently set excluded field option
            * @return {EVA.Core.ExcludedFieldOptions} The excluded field option value
            */
        getExcludedFieldsOption(): EVA.Core.ExcludedFieldOptions;
        /**
            * Returns the current list of included fields
            * @return {Array<string>} The configured list of included product fields
            */
        getIncludedFields(): Array<string>;
        /**
            * Returns the current list of included fields
            * @return {Array<string>} The configured list of included product fields
            */
        addIncludedField(fieldName: string): Array<string>;
        /**
            * Clears the configured list of included fields
            * @return {Array<string>} The configured list of included product fields
            */
        clearIncludedFields(): Array<string>;
        /**
            * Sets the aggregation state
            * @return {any} The aggregation state
            */
        setAggregationState(aggregationState: string): any;
        /**
            * Return the currently set aggregation state
            * @return {string} The aggregation state
            */
        getAggregationState(): string;
        /**
            * Sets the aggregation options
            * @return {any} The aggregation options
            */
        setAggregationOptions(aggregationOptions: any): any;
        /**
            * Return the currently set aggregation options
            * @return {any} The aggregation options
            */
        getAggregationOptions(): any;
        /**
            * Returns the current query string
            * @return {string}       The configured query string
            */
        getQuery(): string;
        /**
            * Set the query to search for
            * @param  {string} query The new query string
            * @return {string}       The configured query string
            */
        setQuery(query: string): string;
        /**
            * Return the aggregations that were returned with the product list
            * @return {any} The aggreations
            */
        getAggregations(): any;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {EVA.Core.Services.Products.SearchProductsResponse}  response    The response from the service call
            * @return {Array<EVA.Core.ProductDto>}                      The product items for the current page
            */
        setData(response: any): EVA.Core.ProductDto[];
        /**
            * Fetches the product list item details
            * @return {Promise<IEVAServiceResponse<EVA.Core.ProductDto, EVA.Core.Services.SearchProducts, EVA.Core.Services.SearchProductsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.SearchProducts, EVA.Core.Services.SearchProductsResponse>>;
}
/**
    * Provides access to a list of recently viewed (fashion) products available in EVA
    */
export class RecentlyViewedProductList extends FetchablePagedList<EVA.Babylon.RecentlyViewedProduct, EVA.Babylon.ListRecentlyViewedProducts, EVA.Babylon.ListRecentlyViewedProductsResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListRecentlyViewedProducts, EVA.Babylon.ListRecentlyViewedProductsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListRecentlyViewedProducts, EVA.Babylon.ListRecentlyViewedProductsResponse>>;
}
export function getFashionProductCategories(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionProductCategories, EVA.Babylon.GetFashionProductCategoriesResponse>>;

/**
    * The shops module provides access to the shops (organization unit type) data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a content page available in EVA
    */
export class Shop extends FetchableItem<EVA.Core.OrganizationUnitDto, EVA.Core.Services.GetOrganizationUnit, EVA.Core.Services.GetOrganizationUnitResponse> {
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetOrganizationUnit, EVA.Core.Services.GetOrganizationUnitResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetOrganizationUnit, EVA.Core.Services.GetOrganizationUnitResponse>>;
}
/**
    * Provides access to a list of shops available in EVA
    */
export class ShopList extends FetchablePagedList<EVA.Core.OrganizationUnitDto, EVA.Core.Services.ListOrganizationUnitsByType, EVA.Core.Services.ListOrganizationUnitsByTypeResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.CMS.Dto.OrganizationUnitDto, EVA.Core.Services.ListOrganizationUnitsByType, EVA.Core.Services.ListOrganizationUnitsByTypeResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrganizationUnitsByType, EVA.Core.Services.ListOrganizationUnitsByTypeResponse>>;
}
/**
    * Provides access to a list of shops available in EVA
    */
export class ShopProximityList extends FetchablePagedList<EVA.Core.OrganizationUnitDto, EVA.Core.Services.ListOrganizationUnitByProximity, EVA.Core.Services.ListOrganizationUnitByProximityResponse> {
        /**
            * Changes to list of shops returned to those in the closest proximity of the given location
            * @param  {number} lat The locations latitude
            * @param  {number} lng The locations longitude
            * @return {object}     The chosen location
            */
        setLocation(lat: number, lng: number): any;
        /**
            * Returns the currently chosen location to use for a proximity based shop list
            * @return {object} The currently chosen location
            */
        getLocation(): any;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.CMS.Dto.OrganizationUnitDto, EVA.Core.Services.ListOrganizationUnitByProximity, EVA.Core.Services.ListOrganizationUnitByProximityResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListOrganizationUnitByProximity, EVA.Core.Services.ListOrganizationUnitByProximityResponse>>;
}

export class SuggestionList extends FetchablePagedList<EVA.Core.SuggestionModel, EVA.Core.Services.GetProductSearchSuggestions, EVA.Core.Services.GetProductSearchSuggestionsResponse> {
    maxSuggestions: number;
    setQuery(query: string): string;
    setData(response: any): EVA.Core.SuggestionModel[];
    fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetProductSearchSuggestions, EVA.Core.Services.GetProductSearchSuggestionsResponse>>;
}

/**
    * The postnl module provides the means to retrieve and set a PostNL pickup location
    * @preferred
    */
export class PostNL {
        /**
            * [constructor description]
            * @param  {Order}  order The order to perform the payments for
            * @return {void}         This method doesn't return anything
            */
        constructor(order: Order | ShoppingCart);
        PostNLGetAvailablePickUpLocationsForArea(orderId: number, nw: EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaCoordinate, se: EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaCoordinate): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForArea, EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaResponse>>;
        PostNLGetAvailablePickUpLocationsForOrder(orderId: number): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForOrder, EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForOrderResponse>>;
        PostNLGetAvailableTimeframesForOrder(orderId: number, startDate: any, endDate: any): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLGetAvailableTimeframesForOrder, EVA.Carrier.PostNL.PostNLGetAvailableTimeframesForOrderResponse>>;
        PostNLGetShippingOptionsForOrder(orderId: number): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLGetShippingOptionsForOrder, EVA.Carrier.PostNL.PostNLGetShippingOptionsForOrderResponse>>;
        PostNLUpdateShippingOptionsForOrder(orderId: number, pickupLocationId: number, date?: Date, option?: EVA.Carrier.PostNL.TimeframeOptions): Promise<IEVAServiceResponse<EVA.Carrier.PostNL.PostNLUpdateShippingOptionsForOrder, EVA.Core.EmptyResponseMessage>>;
}

/**
  * Provides access to a Rituals specific functions in EVA
  */
export namespace Rituals {
    function createCustomerReturn(orderID: number, email: string, lines: Array<EVA.Rituals.RitualsCreateCustomerReturnLineModel>): Promise<IEVAServiceResponse<EVA.Rituals.RitualsCreateCustomerReturn, EVA.Rituals.RitualsCreateCustomerReturnResponse>>;
    function getOrderForReturn(orderID: string, email: string): Promise<IEVAServiceResponse<EVA.Rituals.RitualsGetOrderForReturn, EVA.Rituals.RitualsGetOrderForReturnResponse>>;
    function getBlobsForReturn(orderID: number, email: string): Promise<IEVAServiceResponse<EVA.Rituals.RitualsGetBlobsForReturn, EVA.Rituals.RitualsGetBlobsForReturnResponse>>;
    function scanLoyaltyCard(loyaltyId: string): Promise<IEVAServiceResponse<EVA.Rituals.RitualsScanLoyaltyCard, EVA.Rituals.RitualsScanLoyaltyCardResponse>>;
}

export interface IAvailabilityWeek {
        sunday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        monday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        tuesday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        wednesday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        thursday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        friday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        saturday?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
        otherDays?: EVA.Kijkshop.KijkBijMijAvailabilitySlot[];
}
/**
    * Provides access to a kijkshop specific functions in EVA
    */
export namespace Kijkshop {
        function setExpertForOrderLine(orderLineID: number, expertID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.SetExpertForOrderLine, EVA.Core.EmptyResponseMessage>>;
        function addProductExpertise(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijAddProductExpertise, EVA.Core.EmptyResponseMessage>>;
        function removeProductExpertise(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijRemoveProductExpertise, EVA.Core.EmptyResponseMessage>>;
        function isProductExpert(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijIsExpertOnProduct, EVA.Kijkshop.KijkBijMijIsExpertResponse>>;
        function isMultipleProductExpert(productIDs: number[]): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijIsExpertOnProducts, EVA.Kijkshop.KijkBijMijIsExpertsResponse>>;
        function getProductExperts(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijProductExperts, EVA.Kijkshop.KijkBijMijProductExpertsResponse>>;
        function getTotalExpertCount(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijTotalExpertCount, EVA.Kijkshop.KijkBijMijTotalExpertCountResponse>>;
        function payoutCredits(amount: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijPayoutCredits, EVA.Core.RequestMessageWithEmptyResponse>>;
        function scanMe(userId: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijScanMe, EVA.Core.RequestMessageWithEmptyResponse>>;
        function scanNewApp(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijScanNewApp, EVA.Core.RequestMessageWithEmptyResponse>>;
        function getExpertDetails(userIDs: number[]): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetExpertDetails, EVA.Kijkshop.KijkBijMijGetExpertDetailsResponse>>;
        function getProfile(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetProfile, EVA.Kijkshop.KijkBijMijGetProfileResponse>>;
        function updateProfile(description: string, avatarId: string, languageProficiencies: any): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijUpdateProfile, EVA.Core.RequestMessageWithEmptyResponse>>;
        function getProductsStats(productIDs: number[]): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetProductsStats, EVA.Kijkshop.KijkBijMijGetProductsStatsResponse>>;
        function likeProduct(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijLikeProduct, EVA.Core.EmptyResponseMessage>>;
        function unlikeProduct(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijUnlikeProduct, EVA.Core.EmptyResponseMessage>>;
        function likesProduct(productID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijLikesProduct, EVA.Kijkshop.KijkBijMijLikesProductResponse>>;
        function likesProducts(productIDs: number[]): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijLikesProducts, EVA.Kijkshop.KijkBijMijLikesProductsResponse>>;
        function likedProducts(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijLikedProducts, EVA.Kijkshop.KijkBijMijLikedProductsResponse>>;
        function getProductGroups(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkshopGetProductGroups, EVA.Kijkshop.KijkshopGetProductGroupsResponse>>;
        function getProductGroup(productGroupId: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkshopGetProductGroup, EVA.Kijkshop.KijkshopGetProductGroupResponse>>;
        function addProductGroupExpertise(productGroupID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijAddProductGroupExpertise, EVA.Core.EmptyResponseMessage>>;
        function removeProductGroupExpertise(productGroupID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijRemoveProductGroupExpertise, EVA.Core.EmptyResponseMessage>>;
        function isProductGroupExpert(productGroupID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijIsExpertOnProductGroup, EVA.Kijkshop.KijkBijMijIsExpertResponse>>;
        function isMultipleProductGroupExpert(productGroupIDs: number[]): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijIsExpertOnProductGroups, EVA.Kijkshop.KijkBijMijIsExpertsResponse>>;
        function getAvailability(userID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetAvailability, EVA.Kijkshop.KijkBijMijAvailabilityResponse>>;
        function setAvailability(availability?: IAvailabilityWeek): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijSetAvailability, EVA.Core.RequestMessageWithEmptyResponse>>;
        function callExpert(userID: number, productID: number, productGroupID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijCallExpert, EVA.Kijkshop.KijkBijMijCallResponse>>;
        function declineCall(sessionID: string): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijDeclineCall, EVA.Core.RequestMessageWithEmptyResponse>>;
        function joinCall(sessionID: string): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijJoinCall, EVA.Kijkshop.KijkBijMijCallExpert>>;
        function rateExpert(userID: number, sessionID: string, rating1: number, rating2: number, rating3: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijRateExpert, EVA.Core.EmptyResponseMessage>>;
        function rateCaller(userID: number, sessionID: string, rating: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijRateCaller, EVA.Core.EmptyResponseMessage>>;
        function reportUser(userID: number, reason: EVA.Kijkshop.KijkBijMijReportReasons, description: string): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijReportUser, EVA.Core.EmptyResponseMessage>>;
        function subscribeToNotificationType(typeID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijSubscribeToNotificationType, EVA.Core.RequestMessageWithEmptyResponse>>;
        function unsubscribeFromNotificationType(typeID: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijUnsubscribeFromNotificationType, EVA.Core.RequestMessageWithEmptyResponse>>;
        function getNotificationSubscriptions(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetNotificationSubscriptions, EVA.Kijkshop.KijkBijMijNotificationSubscriptionsResponse>>;
        function getUnreadNotificationCount(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetUnreadNotificationCount, EVA.Kijkshop.KijkBijMijUnreadNotificationCountResponse>>;
        function markNotificationAsRead(id: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijMarkNotificationAsRead, EVA.Core.RequestMessageWithEmptyResponse>>;
        function deleteNotification(id: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijDeleteNotification, EVA.Core.RequestMessageWithEmptyResponse>>;
        function blockedUsers(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijBlockedUsers, EVA.Kijkshop.KijkBijMijBlockedUsersResponse>>;
        function isUserBlocked(userId: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijBlocksUser, EVA.Kijkshop.KijkBijMijBlocksUserResponse>>;
        function blockUser(userId: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijBlockUser, EVA.Core.RequestMessageWithEmptyResponse>>;
        function unblockUser(userId: number): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijUnblockUser, EVA.Core.RequestMessageWithEmptyResponse>>;
        function getCreditTotalsForUser(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijGetCreditTotalsForUser, EVA.Kijkshop.KijkBijMijGetCreditTotalsForUserResponse>>;
        function listCreditTransactions(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijListCreditTransactions, EVA.Kijkshop.KijkBijMijListCreditTransactionsResponse>>;
}
/**
    * Provides access to a list of hall of famers
    */
export class KijkBijMijHallOfFameList extends FetchablePagedList<EVA.Kijkshop.RankedUser, EVA.Kijkshop.KijkBijMijListHall, EVA.Kijkshop.KijkBijMijListHallResponse> {
        constructor(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string);
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Kijkshop.RankedUser, EVA.Kijkshop.KijkBijMijListHall, EVA.Kijkshop.KijkBijMijListHallResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijListHall, EVA.Kijkshop.KijkBijMijListHallResponse>>;
}
/**
    * Provides access to a list of content blocks available in EVA
    */
export class KijkBijMijNotificationsList extends FetchablePagedList<EVA.Kijkshop.KijkBijMijNotification, EVA.Kijkshop.KijkBijMijListNotifications, EVA.Kijkshop.KijkBijMijListNotificationsResponse> {
        constructor(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string);
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijNotification, EVA.Kijkshop.KijkBijMijListNotifications, EVA.Kijkshop.KijkBijMijListNotificationsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijListNotifications, EVA.Kijkshop.KijkBijMijListNotificationsResponse>>;
}
/**
    * Provides access to a list of product groups experts in EVA
    */
export class KijkBijMijProductGroupExperts extends FetchablePagedList<number, EVA.Kijkshop.KijkBijMijProductGroupExpertsPaged, EVA.Kijkshop.KijkBijMijProductGroupExpertsPagedResponse> {
        /**
            * Sets the product group id to retrieve the expert list for
            * @param  {number} productGroupId  The product group identifier
            * @return {void}                   This method doesn't return anything
            */
        setProductGroupId(productGroupId: number): void;
        constructor(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string);
        /**
            * Fetches the list of experts
            * @return {Promise<IEVAServiceResponse<number, EVA.Kijkshop.KijkBijMijProductGroupExpertsPaged, EVA.Kijkshop.KijkBijMijProductGroupExpertsPagedResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijProductGroupExpertsPaged, EVA.Kijkshop.KijkBijMijProductGroupExpertsPagedResponse>>;
}
/**
    * Provides access to a list of content blocks available in EVA
    */
export class KijkBijMijRatingsList extends FetchablePagedList<EVA.Kijkshop.KijkBijMijRating, EVA.Kijkshop.KijkBijMijListRatings, EVA.Kijkshop.KijkBijMijListRatingsResponse> {
        /**
            * Sets the user id to retrieve the rating list for
            * @param  {number} userId      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserId(userId: number): void;
        constructor(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string);
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijRating, EVA.Kijkshop.KijkBijMijListRatings, EVA.Kijkshop.KijkBijMijListRatingsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Kijkshop.KijkBijMijListRatings, EVA.Kijkshop.KijkBijMijListRatingsResponse>>;
}

/**
    * The CMS Blocks module provides access to content management blocks from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a list of content blocks available in EVA
    */
export class ContentBlockList extends FetchablePagedList<EVA.CMS.CmsBlockDto, EVA.CMS.GetCmsBlocks, EVA.CMS.GetCmsBlocksResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.CMS.Dto.Blocks.CmsBlockDto, EVA.CMS.GetCmsBlocks, EVA.CMS.GetCmsBlocksResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.CMS.GetCmsBlocks, EVA.CMS.GetCmsBlocksResponse>>;
}

/**
    * The CMS Menu module provides access to content management menus from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a content menu available in EVA
    */
export class ContentMenu extends FetchableItem<EVA.CMS.CmsMenuDto, EVA.CMS.GetCmsMenuByIdentifier, EVA.CMS.GetCmsMenuByIdentifierResponse> {
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.CMS.GetCmsMenuByIdentifier, EVA.CMS.GetCmsMenuByIdentifierResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.CMS.GetCmsMenuByIdentifier, EVA.CMS.GetCmsMenuByIdentifierResponse>>;
}
/**
    * Provides access to a list of content menus available in EVA
    */
export class ContentMenuList extends FetchablePagedList<Array<EVA.CMS.CmsMenuDto>, EVA.CMS.ListCmsMenu, EVA.CMS.ListCmsMenuResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.CMS.CmsMenuDto, EVA.CMS.ListCmsMenu, EVA.CMS.ListCmsMenuResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.CMS.ListCmsMenu, EVA.CMS.ListCmsMenuResponse>>;
}

/**
    * The CMS Page module provides access to content management pages from the EVA back-end * @preferred
    */
/**
    * Provides access to a content page available in EVA
    */
export class ContentPage extends FetchableItem<EVA.CMS.CmsPageDto, EVA.CMS.GetCmsPage, EVA.CMS.GetCmsPageResponse> {
        /**
            * Returns the current request path
            * @return {string}       The configured request path
            */
        getRequestPath(): string;
        /**
            * Set the request path to retrieve the page for
            * @param  {string} query The new request path
            * @return {string}       The configured request path
            */
        setRequestPath(requestPath: string): string;
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.CMS.GetCmsPage, EVA.CMS.GetCmsPageResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.CMS.GetCmsPage, EVA.CMS.GetCmsPageResponse>>;
}
/**
    * Provides access to the generic content pages by path request available in EVA
    */
export function getCmsPagesByRequestPath(path: string): Promise<IEVAServiceResponse<EVA.CMS.GetCmsPagesByRequestPath, EVA.CMS.GetCmsPagesByRequestPathResponse>>;
/**
    * Provides access to a list of content pages available in EVA
    */
export class ContentPageList extends FetchablePagedList<EVA.CMS.CmsPageDto, EVA.CMS.ListCmsPages, EVA.CMS.ListCmsPagesResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.CMS.CmsPageDto, EVA.CMS.ListCmsPages, EVA.CMS.ListCmsPagesResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.CMS.ListCmsPages, EVA.CMS.ListCmsPagesResponse>>;
}

/**
    * The CMS Widget module provides access to content management widgets from the EVA back-end * @preferred
    */
/**
    * Provides access to a content widget available in EVA
    */
export class ContentWidget extends FetchableItem<EVA.CMS.CmsWidgetDto, EVA.CMS.GetCmsWidgetByID, EVA.CMS.GetCmsWidgetByIDResponse> {
        /**
            * Fetches the widget content
            * @return {Promise<IEVAServiceResponse<EVA.CMS.GetCmsWidgetByID, EVA.CMS.GetCmsWidgetByIDResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.CMS.GetCmsWidgetByID, EVA.CMS.GetCmsWidgetByIDResponse>>;
}

/**
    * The CMS Url Rewrite module provides access to CMS Url Rewrites from the EVA back-end
    *
    * @preferred
    */
export namespace CmsRewrite {
        /**
            * Check if a certain request path needs rewriting
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        function rewrite(requestPath: string): Promise<IEVAServiceResponse<EVA.CMS.RewriteUrl, EVA.CMS.RewriteUrlResponse>>;
}

/**
    * The DMS Blocks module provides access to content management blocks from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a list of content blocks available in EVA
    */
export class DmsBlockList extends FetchablePagedList<EVA.DMS.BlockDto, EVA.DMS.DmsListBlocks, EVA.DMS.DmsListBlocksResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.DMS.Dto.Blocks.BlockDto, EVA.DMS.ListBlocks, EVA.DMS.ListBlocksResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsListBlocks, EVA.DMS.DmsListBlocksResponse>>;
}

/**
    * The DMS Menu module provides access to content management menus from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a content menu available in EVA
    */
export class DmsMenu extends FetchableItem<EVA.DMS.MenuDto, EVA.DMS.DmsGetMenuByIdentifier, EVA.DMS.DmsGetMenuByIdentifierResponse> {
        /**
            * Returns the current request path
            * @return {string}       The configured request path
            */
        getRequestPath(): string;
        /**
            * Set the request path to retrieve the page for
            * @param  {string} query The new request path
            * @return {string}       The configured request path
            */
        setRequestPath(requestPath: string): string;
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.DMS.GetMenuByIdentifier, EVA.DMS.GetMenuByIdentifierResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetMenuByIdentifier, EVA.DMS.DmsGetMenuByIdentifierResponse>>;
}

/**
    * The DMS Page module provides access to content management pages from the EVA back-end * @preferred
    */
/**
    * Provides access to a content page available in EVA
    */
export class DmsPage extends FetchableItem<EVA.DMS.LivePageDto, EVA.DMS.DmsGetLivePage, EVA.DMS.DmsGetLivePageResponse> {
        /**
            * Returns the current request path
            * @return {string}       The configured request path
            */
        getRequestPath(): string;
        /**
            * Set the request path to retrieve the page for
            * @param  {string} query The new request path
            * @return {string}       The configured request path
            */
        setRequestPath(requestPath: string): string;
        /**
            * Returns the current view ID
            * @return {number}       The configured view ID
            */
        getViewId(): number;
        /**
            * Set the request path to retrieve the page by view ID
            * @param  {number} query The new view ID
            * @return {number}       The configured view ID
            */
        setViewId(viewId: number): number;
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetLivePage, EVA.DMS.DmsGetLivePageResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetLivePage, EVA.DMS.DmsGetLivePageResponse>>;
        listViews(): Promise<IEVAServiceResponse<EVA.DMS.DmsListViewsForPage, EVA.DMS.DmsListViewsForPageResponse>>;
        saveLayout(blocks: EVA.DMS.WidgetLayoutBlockDto[]): Promise<IEVAServiceResponse<EVA.DMS.DmsUpdateViewLayout, EVA.Core.EmptyResponseMessage>>;
}
/**
    * Provides access to a content page available in EVA
    */
export class DmsCompiledPage extends FetchableItem<EVA.DMS.CompiledPageDto, EVA.DMS.DmsGetCompiledPage, EVA.DMS.DmsGetCompiledPageResponse> {
        /**
            * Returns the current request path
            * @return {string}       The configured request path
            */
        getRequestPath(): string;
        /**
            * Set the request path to retrieve the page for
            * @param  {string} query The new request path
            * @return {string}       The configured request path
            */
        setRequestPath(requestPath: string): string;
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledPage, EVA.DMS.DmsGetCompiledPageResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledPage, EVA.DMS.DmsGetCompiledPageResponse>>;
}

/**
    * The DMS Url Rewrite module provides access to DMS Url Rewrites from the EVA back-end
    *
    * @preferred
    */
export namespace DmsRewrite {
        /**
            * Check if a certain request path needs rewriting
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        function rewrite(requestPath: string): Promise<IEVAServiceResponse<EVA.DMS.DmsRewriteUrl, EVA.DMS.DmsRewriteUrlResponse>>;
}

/**
    * The DMS Widget module provides access to content management widgets from the EVA back-end * @preferred
    */
/**
    * Provides access to a content widget available in EVA
    */
export class DmsWidgetType extends FetchableItem<EVA.DMS.WidgetTypeDto, EVA.DMS.DmsGetWidgetType, EVA.DMS.DmsGetWidgetTypeResponse> {
        /**
            * Fetches the widget content
            * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetWidgetType, EVA.DMS.DmsGetWidgetTypeByIDResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetWidgetType, EVA.DMS.DmsGetWidgetTypeResponse>>;
        list(): Promise<IEVAServiceResponse<EVA.DMS.DmsListWidgetTypes, EVA.DMS.DmsListWidgetTypesResponse>>;
}

/**
    * The DMS Widget module provides access to content management widgets from the EVA back-end * @preferred
    */
/**
    * Provides access to a content widget available in EVA
    */
export class DmsWidget extends FetchableItem<EVA.DMS.LiveWidgetDto, EVA.DMS.DmsGetCompiledWidgetByID, EVA.DMS.DmsGetCompiledWidgetByIDResponse> {
        /**
            * Fetches the widget content
            * @return {Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledWidgetByID, EVA.DMS.DmsGetCompiledWidgetByIDResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.DMS.DmsGetCompiledWidgetByID, EVA.DMS.DmsGetCompiledWidgetByIDResponse>>;
        create(widget: EVA.DMS.WidgetDto, viewID: number): Promise<IEVAServiceResponse<EVA.DMS.DmsCreateWidget, EVA.Core.CreateResponse>>;
        /**
            * Update the widget
            *
            * @return {Promise} A promise resolving when the call to the back-end has completed
            */
        updateHtml(html: string): Promise<IEVAServiceResponse<EVA.DMS.DmsUpdateWidget, EVA.Core.EmptyResponseMessage>>;
}

/**
    * The MakeUp module provides access to advanced content management features from the EVA back-end
    * @preferred
    */
export interface MakeupGetRenderedPageByPathResponseWithContext extends EVA.Makeup.MakeupGetRenderedPageByPathResponse {
        PathContext: EVA.Makeup.PathContext;
        QueryPath: string;
}
export namespace MakeUp {
        /**
            * Provides access to a make up content map
            */
        function getPageMap(languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageMap, EVA.Makeup.MakeupGetPageMapResponse>>;
        /**
            * Provides access to a make up content page by path
            */
        function getPageByRequestPath(path: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByPath, EVA.Makeup.MakeupGetPageByPathResponse>>;
        /**
            * Provides access to a make up content page by id
            */
        function getPageByID(ID: string, languageID?: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByID, EVA.Makeup.MakeupGetPageByIdResponse>>;
        /**
            * Provides access to a rendered make up content page by path
            */
        function getRenderedPageByRequestPath(path: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetRenderedPageByPath, MakeupGetRenderedPageByPathResponseWithContext>>;
        function getRenderedPagesByPartialPath(path: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetRenderedPagesByPartialPath, EVA.Makeup.MakeupGetRenderedPagesByPartialPathResponse>>;
        /**
            * Provides access to a make up content page by id
            */
        function getRenderedPageByID(ID: string, languageID?: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetRenderedPageByID, EVA.Makeup.MakeupGetRenderedPageByIDResponse>>;
        /**
            * Provides access to create a new Makeup page
            * @param page The MakeupPageDto
            */
        function createPage(page: EVA.Makeup.PageDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByID, EVA.Makeup.MakeupGetPageByIdResponse>>;
        /**
            * Provides access to replace a MakeUp page
            * @param id   The ID of the Makeup page
            * @param page The MakeUpPageDto
            */
        function replacePage(page: EVA.Makeup.PageDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByID, EVA.Makeup.MakeupGetPageByIdResponse>>;
        /**
            * Convenience method to upsert a Makeup page
            * @param id   The ID of the Makeup page
            * @param page The MakeUpPageDto
            */
        function upsertPage(page: EVA.Makeup.PageDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetPageByID, EVA.Makeup.MakeupGetPageByIdResponse>>;
        /**
            * Convenience method to retrieve the latest version of a makeup page
            * @param id The ID of the Makeup page
            * @param languageID The language
            */
        function getCurrentPageVersion(id: string, languageID: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetCurrentPageVersion, EVA.Makeup.MakeupGetCurrentPageVersionResponse>>;
        /**
            * Convenience method to publish a version of a Makeup page
            * @param id The ID of the Makeup page
            * @param languageID The language
            */
        function publishPageVersion(id: string, languageID: string, version: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupPublishPageVersion, EVA.Core.EmptyResponseMessage>>;
        /**
            * Provides access to delete a Makeup page
            * @param id The ID of the Makeup page
            */
        function deletePage(id: string, languageID?: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupDeletePage, EVA.Core.EmptyResponseMessage>>;
        /****************
            *    BLOCKS    *
            ****************/
        function getBlockByID(ID: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetBlockByID, EVA.Makeup.MakeupGetBlockByIDResponse>>;
        function getRenderedBlockByID(ID: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetRenderedBlockByID, EVA.Makeup.MakeupGetRenderedBlockByIDResponse>>;
        /**
            * Provides access to create a new Makeup block
            * @param block The BlockDto to create
            */
        function createBlock(block: EVA.Makeup.BlockDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetBlockByID, EVA.Makeup.MakeupGetBlockByIDResponse>>;
        /**
            * Convenience method to upsert a Makeup block
            * @param id    The ID of the Makeup block
            * @param block The MakeUpBlockDto
            */
        function upsertBlock(block: EVA.Makeup.BlockDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetBlockByID, EVA.Makeup.MakeupGetBlockByIDResponse>>;
        /**
            * Provides access to replace a MakeUp block
            * @param block The BlockDto
            */
        function replaceBlock(block: EVA.Makeup.BlockDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetBlockByID, EVA.Makeup.MakeupGetBlockByIDResponse>>;
        /**
            * Provides access to delete a Makeup block
            * @param id The ID of the Makeup block
            */
        function deleteBlock(id: string, version?: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupDeleteBlock, EVA.Core.EmptyResponseMessage>>;
        /**
            * Convenience method to retrieve the latest version of a makeup block
            * @param id The ID of the Makeup block
            */
        function getCurrentBlockVersion(id: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetCurrentBlockVersion, EVA.Makeup.MakeupGetCurrentBlockVersionResponse>>;
        /**
            * Convenience method to publish a version of a Makeup block
            * @param id The ID of the Makeup block
            * @param version The version to set
            */
        function publishBlockVersion(id: string, version: number): Promise<IEVAServiceResponse<EVA.Makeup.MakeupPublishBlockVersion, EVA.Core.EmptyResponseMessage>>;
        /****************
            *    MENU      *
            ****************/
        function getMenuByID(ID: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetMenuByID, EVA.Makeup.MakeupGetMenuByIDResponse>>;
        /**
            * Provides access to create a new Makeup block
            * @param block The MenuDto to create
            */
        function createMenu(block: EVA.Makeup.MenuDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetMenuByID, EVA.Makeup.MakeupGetMenuByIDResponse>>;
        /**
            * Convenience method to upsert a Makeup block
            * @param id    The ID of the Makeup block
            * @param block The MakeUpMenuDto
            */
        function upsertMenu(block: EVA.Makeup.MenuDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetMenuByID, EVA.Makeup.MakeupGetMenuByIDResponse>>;
        /**
            * Provides access to replace a MakeUp block
            * @param menu The MenuDto
            */
        function replaceMenu(menu: EVA.Makeup.MenuDto): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetMenuByID, EVA.Makeup.MakeupGetMenuByIDResponse>>;
        /**
            * Provides access to delete a Makeup block
            * @param id The ID of the Makeup block
            */
        function deleteMenu(id: string, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupDeleteMenu, EVA.Core.EmptyResponseMessage>>;
        /****************************
            *    CONFIGURATION PROFILE *
            ****************************
            */
        function getConfigurationProfile(languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetConfigurationProfile, EVA.Makeup.MakeupGetConfigurationProfileResponse>>;
        /**
            * Provides access to replace a ConfigurationProfile
            * @param profile The ConfigurationProfile
            */
        function replaceConfigurationProfile(profile: EVA.Makeup.ConfigurationProfileDto, languageID?: string): Promise<IEVAServiceResponse<EVA.Makeup.MakeupGetConfigurationProfile, EVA.Makeup.MakeupGetConfigurationProfileResponse>>;
}
export class MakeupListPageVersions extends FetchablePagedList<EVA.Makeup.PageVersionDto, EVA.Makeup.MakeupListPageVersions, EVA.Makeup.MakeupListPageVersionsResponse> {
        /**
            * Returns the current page identifier
            * @return {string}       The page identifier
            */
        getPageID(): string;
        /**
            * Set the make up page identifier
            * @param  {string} page_id The page identifier
            * @return {string}         The currently page identifier
            */
        setPageID(page_id: string): string;
        /**
            * Set the make up page language
            * @param  {string} page_id The page language
            * @return {string}         The currently page language
            */
        setLanguageID(languageID: string): string;
        /**
            * Returns the current page language
            * @return {string}       The page language
            */
        getLanguageID(): string;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Makeup.MakeupListPageVersions, EVA.Makeup.MakeupListPageVersionsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Makeup.MakeupListPageVersions, EVA.Makeup.MakeupListPageVersionsResponse>>;
}
export class MakeupListBlocks extends FetchablePagedList<EVA.Makeup.BlockDto, EVA.Makeup.MakeupListBlocks, EVA.Makeup.MakeupListBlocksResponse> {
        /**
            * Returns the current requested block type
            * @return {string}       The block type
            */
        getType(): string;
        /**
            * Set the block type to retrieve
            * @param  {string} type The new block type
            * @return {string}       The currently set block type
            */
        setType(type: string): string;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Makeup.MakeupListBlocks, EVA.Makeup.MakeupListBlocksResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Makeup.MakeupListBlocks, EVA.Makeup.MakeupListBlocksResponse>>;
}
export class MakeupListBlockVersions extends FetchablePagedList<EVA.Makeup.BlockDto, EVA.Makeup.MakeupListBlockVersions, EVA.Makeup.MakeupListBlockVersionsResponse> {
        /**
            * Returns the current block identifier
            * @return {string}       The block identifier
            */
        getBlockID(): string;
        /**
            * Set the make up block identifier
            * @param  {string} block_id The block identifier
            * @return {string}         The currently block identifier
            */
        setBlockID(block_id: string): string;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Makeup.MakeupListBockVersions, EVA.Makeup.MakeupListBlockVersionsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Makeup.MakeupListBlockVersions, EVA.Makeup.MakeupListBlockVersionsResponse>>;
}
export class MakeupListMenus extends FetchablePagedList<EVA.Makeup.MenuDto, EVA.Makeup.MakeupListMenus, EVA.Makeup.MakeupListMenusResponse> {
        /**
            * Returns the current language identifier
            * @return {string} The language identifier
            */
        getLanguageID(): string;
        /**
            * Set the language identifier
            * @param  {string} language The language identifier
            */
        setLanguageID(languageID: string): string;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Makeup.MakeupListMenus, EVA.Makeup.MakeupListMenusResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Makeup.MakeupListMenus, EVA.Makeup.MakeupListMenusResponse>>;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a babylon binary blobs in EVA
    */
export class Blob extends FetchableItem<EVA.Blobs.BlobDto, EVA.Blobs.GetBlobInfo, EVA.Blobs.GetBlobInfoResponse> {
        /**
            * Convenience method to build a blob image URL
            * @param  {string} guid        The blob guid
            * @param  {number} width       The output image width
            * @param  {number} height      The output image height
            * @param  {string} type        The image type (ie. png, jpg, etc)
            *
            * @return {string}             An image URL
            */
        static getImageUrl(guid: string, width?: number, height?: number, format?: string): string;
        /**
            * Sets the category to retrieve the blob info for
            * @param  {string} category    The blob category
            * @return {void}               This method doesn't return anything
            */
        setCategory(category: string): void;
        /**
            * Sets the original name to retrieve the blob info for
            * @param  {string} original name    The blob original name
            * @return {void}               This method doesn't return anything
            */
        setOriginalName(originalName: string): void;
        fetch(): Promise<IEVAServiceResponse<EVA.Blobs.GetBlobInfo, EVA.Blobs.GetBlobInfoResponse>>;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES} response The response from the service call
            * @return {T}            The item details
            */
        setData(response: any): EVA.Blobs.BlobDto;
        create(newBlobInfo: EVA.Blobs.StoreBlob): Promise<IEVAServiceResponse<EVA.Blobs.GetBlobInfo, EVA.Blobs.GetBlobInfoResponse>>;
        createEmpty(newBlobInfo: EVA.Blobs.CreateBlob): Promise<IEVAServiceResponse<EVA.Blobs.CreateBlob, string>>;
        createEmptyBlob(newBlobInfo: EVA.Blobs.CreateBlob): Promise<IEVAServiceResponse<EVA.Blobs.CreateBlob, EVA.Blobs.CreateBlobResponse>>;
        getUploadUrl(guid: string): string;
        process(imageDataBase64: string, type?: string): Promise<IEVAServiceResponse<EVA.Blobs.ProcessDocument, EVA.Blobs.ProcessDocumentResponse>>;
        destroy(): Promise<IEVAServiceResponse<EVA.Blobs.DeleteBlob, EVA.Core.EmptyResponseMessage>>;
        getImageCutoutSuggestions(): Promise<IEVAServiceResponse<EVA.Babylon.GetImageCutoutSuggestions, EVA.Babylon.GetImageCutoutSuggestionsResponse>>;
}

export namespace Barcodes {
    function parseBarcode(barcode: string): Promise<EVA.Core.Services.ParseBarcodeResponse>;
    function getProductByBarcode(barcode: string): Promise<EVA.Core.Services.GetProductByBarcodeResponse>;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a babylon social functions in EVA
    * These are the by identifier versions that can be reused by EVA SDK objects
    */
export namespace Feed {
        function getFeedByType(feedType: string, offset?: number | string, limit?: number): Promise<IEVAServiceResponse<EVA.Babylon.GetUserFeed, EVA.Babylon.GetUserFeedResponse>>;
        function getTrendingFeed(skip?: number, limit?: number, type?: EVA.Babylon.TrendingFeedTypes): Promise<IEVAServiceResponse<EVA.Babylon.GetTrendingFeed, EVA.Babylon.GetTrendingFeedResponse>>;
        function getNotificationFeed(offset?: number, limit?: number): Promise<IEVAServiceResponse<EVA.Babylon.GetNotificationFeed, EVA.Babylon.GetNotificationFeedResponse>>;
        function getUnseenNotifications(): Promise<IEVAServiceResponse<EVA.Babylon.GetNotificationFeed, EVA.Babylon.GetNotificationFeedResponse>>;
}

/**
    * Provides access to a babylon social functions in EVA
    * These are the by identifier versions that can be reused by EVA SDK objects
    */
export namespace Social {
        function getListOfLikedObjects(offset?: string, limit?: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialListLikedObjects, EVA.Babylon.SocialListLikedObjectsResponse>>;
        function getListOfProgressions(userID: number, type: EVA.Social.SocialProgressionType): Promise<IEVAServiceResponse<EVA.Social.SocialGetProgressions, EVA.Social.SocialGetProgressionsResponse>>;
        function likeProductByID(productID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeProduct, EVA.Core.EmptyResponseMessage>>;
        function unlikeProductByID(productID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeProduct, EVA.Core.EmptyResponseMessage>>;
        function shareProductWithUsers(productID: number, userIDs: Array<number>, message: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function productSharedExternally(productID: number, platform: EVA.Babylon.SocialMediaPlatform): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function listProductInteractionSummary(productID: number): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function listProductInteractionDetails(productID: number, limit?: number, offset?: string, type?: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function getProductStats(productIDs: Array<number> | number): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetProductsStats, EVA.Babylon.SocialStatsResponse>>;
        function likeCollectionByID(collectionID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeFashionCollection, EVA.Core.EmptyResponseMessage>>;
        function unlikeCollectionByID(collectionID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeFashionCollection, EVA.Core.EmptyResponseMessage>>;
        function shareCollectionWithUsers(collectionID: number, userIDs: Array<number>, message: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function collectionSharedExternally(collectionID: number, platform: EVA.Babylon.SocialMediaPlatform): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function inviteFriends(invites: Array<EVA.Babylon.InviteFriendsDto> | EVA.Babylon.InviteFriendsDto): Promise<IEVAServiceResponse<EVA.Babylon.SocialInviteFriends, EVA.Core.EmptyResponseMessage>>;
        function listCollectionInteractionSummary(collectionID: number): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function listCollectionInteractionDetails(collectionID: number, limit?: number, offset?: string, filter?: string | number): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function getCollectionStats(collectionIDs: Array<number> | number): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetFashionCollectionsStats, EVA.Babylon.SocialStatsResponse>>;
        function getCollectionStatsOverTime(collectionID: number, granularity: EVA.Babylon.CollectionStatsGranularity): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCollectionStatsOverTime, EVA.Babylon.SocialStatsResponse>>;
        function likeUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeUser, EVA.Core.EmptyResponseMessage>>;
        function unlikeUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeUser, EVA.Core.EmptyResponseMessage>>;
        function followUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialFollowUser, EVA.Core.EmptyResponseMessage>>;
        function unfollowUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnfollowUser, EVA.Core.EmptyResponseMessage>>;
        function getAvatarURL(userID: number, size?: number, format?: string): string;
        function isFollowingUsers(userIDs: Array<number>): Promise<IEVAServiceResponse<EVA.Babylon.SocialIsFollowingUsers, EVA.Babylon.SocialIsFollowingUsersResponse>>;
        function likeUserMediaByID(userMediaID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeFashionUserMedia, EVA.Core.EmptyResponseMessage>>;
        function unlikeUserMediaByID(userMediaID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeFashionUserMedia, EVA.Core.EmptyResponseMessage>>;
        function removeCommentByID(commentID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialDeleteComment, EVA.Core.EmptyResponseMessage>>;
        function addCommentForProduct(productID: number, comment: string, mentionedUserIDs: Array<number>): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function addCommentForCollection(collectionID: number, comment: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function addCommentForUserMedia(userMediaID: number, comment: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function likeCommentByID(commentID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialLikeComment, EVA.Core.EmptyResponseMessage>>;
        function unlikeCommentByID(commentID: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUnlikeComment, EVA.Core.EmptyResponseMessage>>;
        function getStatsForFeedObjects(objects: Array<EVA.Babylon.FeedObjectDto>): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetStatsForFeedObjects, EVA.Babylon.SocialObjectStatsResponse>>;
        function blockUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.BlockUser, EVA.Core.EmptyResponseMessage>>;
        function unblockUserByID(userID: number): Promise<IEVAServiceResponse<EVA.Babylon.UnblockUser, EVA.Core.EmptyResponseMessage>>;
        function reportContent(contentType: EVA.Babylon.SocialReportContentTypes, contentID: string, reason: EVA.Babylon.SocialReportReasons, description?: string): Promise<IEVAServiceResponse<EVA.Babylon.SocialReportContent, EVA.Core.EmptyResponseMessage>>;
        function sendPushNotificationTest(userId: number, title: string, body: string, data?: any): Promise<IEVAServiceResponse<EVA.Babylon.BabylonPushNotificationTest, EVA.Core.EmptyResponseMessage>>;
}
export class SocialProfile extends FetchableItem<EVA.Babylon.SocialUserProfile, EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse> {
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES} response The response from the service call
            * @return {T}            The item details
            */
        setData(response: any): EVA.Babylon.SocialUserProfile;
        /**
            * Fetches the social user profile details
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialUserProfile, EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>;
        /**
            * Fetches the social user profile details by nickname
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialUserProfile, EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetchByNickname(nickname: string): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetUserProfileByNickname, EVA.Babylon.SocialGetUserProfileResponse>>;
        update(userProfile: EVA.Babylon.SocialUpdateUserProfileModel): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetUserProfile, EVA.Babylon.SocialGetUserProfileResponse>>;
}
export class SocialFollowers extends FetchablePagedList<EVA.Babylon.Follower, EVA.Babylon.SocialListFollowers, EVA.Babylon.SocialListFollowersResponse> {
        /**
            * Sets the user id to retrieve the follower list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListFollowers, EVA.Babylon.SocialListFollowersResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListFollowers, EVA.Babylon.SocialListFollowersResponse>>;
}
export class SocialFollowing extends FetchablePagedList<EVA.Babylon.Follower, EVA.Babylon.SocialListFollowing, EVA.Babylon.SocialListFollowingResponse> {
        /**
            * Sets the user id to retrieve the following list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.Social.Services.SocialListFollowing, EVA.Babylon.Social.Services.SocialListFollowingResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListFollowing, EVA.Babylon.SocialListFollowingResponse>>;
}
export class SocialBlockedUsers extends FetchablePagedList<EVA.Babylon.BlockUser, EVA.Babylon.SocialListBlockedFollowers, EVA.Babylon.SocialListBlockedFollowersResponse> {
        /**
            * Sets the user id to retrieve the following list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.Social.Services.SocialListFollowing, EVA.Babylon.Social.Services.SocialListFollowingResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListBlockedFollowers, EVA.Babylon.SocialListBlockedFollowersResponse>>;
}
export class SocialCommentsForProduct extends FetchablePagedList<EVA.Babylon.Comment, EVA.Babylon.SocialListCommentsForProduct, EVA.Babylon.SocialListCommentsResponse> {
        /**
            * Sets the product id to retrieve the follower list for
            * @param  {number} productID       The product identifier
            * @return {void}                   This method doesn't return anything
            */
        setProductID(productID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForProduct, EVA.Babylon.SocialListCommentsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForProduct, EVA.Babylon.SocialListCommentsResponse>>;
}
export class SocialCommentsForCollection extends FetchablePagedList<EVA.Babylon.Comment, EVA.Babylon.SocialListCommentsForFashionCollection, EVA.Babylon.SocialListCommentsResponse> {
        /**
            * Sets the collection id to retrieve the comment list for
            * @param  {number} collectionID        The collection identifier
            * @return {void}                       This method doesn't return anything
            */
        setCollectionID(collectionID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionCollection, EVA.Babylon.SocialListCommentsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionCollection, EVA.Babylon.SocialListCommentsResponse>>;
}
export class SocialCommentsForUserMedia extends FetchablePagedList<EVA.Babylon.Comment, EVA.Babylon.SocialListCommentsForFashionUserMedia, EVA.Babylon.SocialListCommentsResponse> {
        /**
            * Sets the user media id to retrieve the follower list for
            * @param  {number} userMediaID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserMediaID(userMediaID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionUserMedia, EVA.Babylon.SocialListCommentsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListCommentsForFashionUserMedia, EVA.Babylon.SocialListCommentsResponse>>;
}
export class SocialProductsCreatedByUser extends FetchablePagedList<EVA.Babylon.ProductCreationByUserResult, EVA.Babylon.SocialListProductsCreationsByUser, EVA.Babylon.SocialListProductsCreationsByUserResponse> {
        /**
            * Sets the user id to retrieve the creations list for
            * @param  {number} userID      The user identifier
            * @return {void}               This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListProductsCreationsByUser, EVA.Babylon.SocialListProductsCreationsByUserResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListProductsCreationsByUser, EVA.Babylon.SocialListProductsCreationsByUserResponse>>;
}
export class SocialFacebookFriends extends FetchablePagedList<EVA.Babylon.FacebookFriend, EVA.Babylon.SocialListFacebookFriends, EVA.Babylon.SocialListFacebookFriendsResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.SocialListFacebookFriends, EVA.Babylon.SocialListFacebookFriendsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SocialListFacebookFriends, EVA.Babylon.SocialListFacebookFriendsResponse>>;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to user media (fashion) in EVA
    */
export namespace UserMedia {
        function removeUserMediaByID(userMediaID: number): Promise<IEVAServiceResponse<EVA.Babylon.DeleteFashionUserMedia, EVA.Core.EmptyResponseMessage>>;
        function addUserMediaToProduct(productID: number, blobID: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
        function addUserMediaToCollection(collectionID: number, blobID: string): Promise<IEVAServiceResponse<any, EVA.Core.EmptyResponseMessage>>;
}
export class UserMediaForProduct extends FetchablePagedList<EVA.Babylon.FashionUserMedia, EVA.Babylon.ListFashionUserMediaForProduct, EVA.Babylon.ListFashionUserMediaResponse> {
        /**
            * Sets the product id to retrieve the user media list for
            * @param  {number} productID           The product identifier
            * @return {void}                       This method doesn't return anything
            */
        setProductID(productID: number): void;
        /**
            * Sets the user id to retrieve the user media list for a specific user
            * @param  {number} userID           The user identifier
            * @return {void}                    This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForProduct, EVA.Babylon.ListFashionUserMediaResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForProduct, EVA.Babylon.ListFashionUserMediaResponse>>;
}
export class UserMediaForCollection extends FetchablePagedList<EVA.Babylon.FashionUserMedia, EVA.Babylon.ListFashionUserMediaForCollection, EVA.Babylon.ListFashionUserMediaResponse> {
        /**
            * Sets the collection id to retrieve the user media list for
            * @param  {number} collectionID        The collection identifier
            * @return {void}                       This method doesn't return anything
            */
        setCollectionID(collectionID: number): void;
        /**
            * Sets the user id to retrieve the user media list for a specific user
            * @param  {number} userID           The user identifier
            * @return {void}                    This method doesn't return anything
            */
        setUserID(userID: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForCollection, EVA.Babylon.ListFashionUserMediaResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionUserMediaForCollection, EVA.Babylon.ListFashionUserMediaResponse>>;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a babylon social functions in EVA
    * These are the by identifier versions that can be reused by EVA SDK objects
    */
export namespace Search {
        function quickFashionSearch(query: string, collectionSize?: number, productSize?: number, actorSize?: number, onlyAutocompleteProducts?: boolean): Promise<IEVAServiceResponse<EVA.Babylon.QuickSearchFashionItems, EVA.Babylon.QuickSearchFashionItemsResponse>>;
        function socialUserSearch(query: string, pageSize?: number, pageNr?: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialUserSearch, EVA.Babylon.SocialUserSearchResponse>>;
        function socialFriendsSearch(query: string, pageSize?: number, pageNr?: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialSearchFriends, EVA.Babylon.SocialSearchFriendsResponse>>;
        function fashionCollectionSearch(query: string, pageSize?: number, pageNr?: number, supplierName?: string, sortOption?: EVA.Babylon.FashionCollectionSearchModelSortOptions): Promise<IEVAServiceResponse<EVA.Babylon.SearchFashionCollections, EVA.Babylon.SearchFashionCollectionsResponse>>;
}
/**
    * Provides access to a list of products available in EVA
    */
export class FashionProductList extends FetchablePagedList<EVA.Core.ProductDto, EVA.Babylon.SearchFashionProducts, EVA.Core.Services.SearchProductsResponse> {
        /**
            * The return aggregations flag
            * @type {any}
            */
        includeAggregations: boolean;
        /**
            * The return suggestions flag
            * @type {any}
            */
        includeSuggestions: boolean;
        /**
            * Returns the current list of excluded fields
            * @return {Array<string>} The configured list of excluded product fields
            */
        getExcludedFields(): Array<string>;
        /**
            * Returns the current list of excluded fields
            * @return {Array<string>} The configured list of excluded product fields
            */
        addExcludedField(fieldName: string): Array<string>;
        /**
            * Clears the configured list of excluded fields
            * @return {Array<string>} The configured list of excluded product fields
            */
        clearExcludedFields(): Array<string>;
        /**
            * Sets the excluded fields option
            * @return {EVA.Core.ExcludedFieldOptions} The aggregation state
            */
        setExcludedFieldsOptions(option: EVA.Core.ExcludedFieldOptions): any;
        /**
            * Return the currently set excluded field option
            * @return {EVA.Core.ExcludedFieldOptions} The excluded field option value
            */
        getExcludedFieldsOption(): EVA.Core.ExcludedFieldOptions;
        /**
            * Returns the current list of included fields
            * @return {Array<string>} The configured list of included product fields
            */
        getIncludedFields(): Array<string>;
        /**
            * Returns the current list of included fields
            * @return {Array<string>} The configured list of included product fields
            */
        addIncludedField(fieldName: string): Array<string>;
        /**
            * Clears the configured list of included fields
            * @return {Array<string>} The configured list of included product fields
            */
        clearIncludedFields(): Array<string>;
        /**
            * Sets the aggregation filters
            * @return {any} The aggregation filters
            */
        setAggregationFilters(aggregationFilters: any): any;
        /**
            * Return the currently set aggregation filters
            * @return {any} The aggregation filters
            */
        getAggregationFilters(): any;
        /**
            * Sets the aggregation options
            * @return {any} The aggregation options
            */
        setAggregationOptions(aggregationOptions: any): any;
        /**
            * Return the currently set aggregation options
            * @return {any} The aggregation options
            */
        getAggregationOptions(): any;
        /**
            * Returns the current query string
            * @return {string}       The configured query string
            */
        getQuery(): string;
        /**
            * Set the query to search for
            * @param  {string} query The new query string
            * @return {string}       The configured query string
            */
        setQuery(query: string): string;
        /**
            * Return the aggregations that were returned with the product list
            * @return {any} The aggreations
            */
        getAggregations(): any;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {EVA.Core.Services.Products.SearchProductsResponse}  response    The response from the service call
            * @return {Array<EVA.Core.ProductDto>}                                     The product items for the current page
            */
        setData(response: any): EVA.Core.ProductDto[];
        /**
            * Fetches the product list item details
            * @return {Promise<IEVAServiceResponse<EVA.Core.ProductDto, EVA.Babylon.SearchFashionProducts, EVA.Core.Services.SearchProductsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.SearchFashionProducts, EVA.Core.Services.SearchProductsResponse>>;
}

/**
    * The shops module provides access to the shops (organization unit type) data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a list of shop reviews available in EVA
    */
export class ShopReviews extends FetchablePagedList<EVA.Kiyoh.ShopReview, EVA.Kiyoh.ListShopReviews, EVA.Kiyoh.ListShopReviewsResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Kiyoh.ListShopReviews, EVA.Kiyoh.ListShopReviewsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Kiyoh.ListShopReviews, EVA.Kiyoh.ListShopReviewsResponse>>;
}
/**
    * Provides access to a list of product reviews available in EVA
    */
export class ProductReviews extends FetchablePagedList<EVA.Kiyoh.ProductReview, EVA.Kiyoh.ListProductReviews, EVA.Kiyoh.ListProductReviewsResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Kiyoh.ListProductReviews, EVA.Kiyoh.ListProductReviewsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Kiyoh.ListProductReviews, EVA.Kiyoh.ListProductReviewsResponse>>;
}
export function getShopReviewStats(): Promise<IEVAServiceResponse<EVA.Kiyoh.GetShopReviewStats, EVA.Kiyoh.GetShopReviewStatsResponse>>;

/**
    * The supplier module provides access to the supplier data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to an order available in EVA
    */
export class FashionSupplier extends FetchableItem<EVA.Babylon.FashionSupplierDataDto, EVA.Babylon.GetFashionSupplierData, EVA.Babylon.GetFashionSupplierDataResponse> {
        /**
            * This class wraps an supplier from EVA and the operations you can perform on it.
            * You should supply the supplier identifier when creating an instance of this class
            *
            * @param  {number | string}    id      The identifier of the supplier to retrieve
            * @return {void}                       This method doesn't return anything
            */
        constructor(id?: number | string);
        /**
            * Fetches the order details
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.GetFashionSupplierData, EVA.Babylon.GetFashionSupplierDataResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionSupplierData, EVA.Babylon.GetFashionSupplierDataResponse>>;
        fetchForOrder(orderId: number): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionSupplierDataForOrder, EVA.Babylon.GetFashionSupplierDataForOrderResponse>>;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {EVA.Babylon.GetFashionSupplierDataResponse}  response    The response from the service call
            * @return {EVA.Babylon.FashionSupplierDataDto}                      The supplier details
            */
        setData(response: any): EVA.Babylon.FashionSupplierDataDto;
}

/**
    * The applications module provides access to the applications data from the EVA back-end
    * @preferred
    */
/**
    * Provides access to a babylon social functions in EVA
    * These are the by identifier versions that can be reused by EVA SDK objects
    */
export namespace Gamification {
        function getCoverSheetEditorCapabilities(): Promise<IEVAServiceResponse<EVA.Babylon.GetCoverSheetEditorCapabilities, EVA.Babylon.GetCoverSheetEditorCapabilitiesResponse>>;
        function getSocialGetProgressionByID(id: number): Promise<IEVAServiceResponse<EVA.Social.SocialGetProgressionByID, EVA.Social.SocialGetProgressionByIDResponse>>;
        function getSocialProgressions(userId: number, type: EVA.Social.SocialProgressionType): Promise<IEVAServiceResponse<EVA.Social.SocialGetProgressions, EVA.Social.SocialGetProgressionsResponse>>;
        function getSocialProgressionRanking(userId: number): Promise<IEVAServiceResponse<EVA.Babylon.SocialGetProgressionRanking, EVA.Babylon.SocialGetProgressionRankingResponse>>;
        function getActiveFashionEvent(): Promise<IEVAServiceResponse<EVA.Babylon.GetActiveFashionEvent, EVA.Babylon.GetActiveFashionEventResponse>>;
        function getBarcodeDataForFashionEvent(): Promise<IEVAServiceResponse<EVA.Babylon.GetBarcodeDataForFashionEvent, EVA.Babylon.GetBarcodeDataForFashionEventResponse>>;
        function scanBarcodeDataForFashionEvent(data: string): Promise<IEVAServiceResponse<EVA.Babylon.ScanBarcodeForFashionEvent, EVA.Babylon.ScanBarcodeForFashionEventResponse>>;
        function getBarcodeUrlForFashionEvent(data: string, width?: number, height?: number): string;
        function getActiveFashionCollectionContests(): Promise<IEVAServiceResponse<EVA.Babylon.GetActiveFashionCollectionContests, EVA.Babylon.GetActiveFashionCollectionContestsResponse>>;
        function getFashionCoinTotalsForUser(): Promise<IEVAServiceResponse<EVA.Babylon.GetFashionCoinTotalsForUser, EVA.Babylon.GetFashionCoinTotalsForUserResponse>>;
        function convertFashionCoins(amount: number, direction: EVA.Babylon.FashionCoinConversionDirection): Promise<IEVAServiceResponse<EVA.Babylon.ConvertFashionCoins, EVA.Babylon.ConvertFashionCoinsResponse>>;
}
/**
    * Provides access to a list of fashion collections for a contest available in EVA
    */
export class FashionCollectionsForContest extends FetchablePagedList<EVA.Babylon.FashionCollectionContestDto, EVA.Babylon.ListFashionCollectionsForContest, EVA.Babylon.ListFashionCollectionsForContestResponse> {
        /**
            * Sets the contest id to retrieve the fashion collection list for
            * @param  {number} contestId      The organization identifier
            * @return {void}                  This method doesn't return anything
            */
        setContestId(contestId: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.FashionCollectionContestDto, EVA.Babylon.ListFashionCollectionsForContest, EVA.Babylon.ListFashionCollectionsForContestResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCollectionsForContest, EVA.Babylon.ListFashionCollectionsForContestResponse>>;
}
/**
    * Provides access to a list of fashion coin transactions
    */
export class FashionCoinTransactions extends FetchablePagedList<EVA.Babylon.FashionCollectionContestDto, EVA.Babylon.ListFashionCoinTransactions, EVA.Babylon.ListFashionCoinTransactionsResponse> {
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Babylon.FashionCoinTransaction, EVA.Babylon.ListFashionCoinTransactions, EVA.Babylon.ListFashionCoinTransactionsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Babylon.ListFashionCoinTransactions, EVA.Babylon.ListFashionCoinTransactionsResponse>>;
}

/**
    * This module provides methods for Addresses, setting / updating addresses on specific
    * objects like customer  and order are done directly on those objects
    *
    * @preferred
    */
export class AddressBook extends FetchablePagedList<EVA.Core.Services.AddressBookDto, EVA.Core.Services.ListAddressBook, EVA.Core.Services.ListAddressBookResponse> {
        static setDefaultBillingAddress(id: number): Promise<IEVAServiceResponse<EVA.Core.Services.SetDefaultBillingAddress, EVA.Core.RequestMessageWithEmptyResponse>>;
        static setDefaultShippingAddress(id: number): Promise<IEVAServiceResponse<EVA.Core.Services.SetDefaultShippingAddress, EVA.Core.RequestMessageWithEmptyResponse>>;
        static createItem(address: EVA.Core.AddressDto, description?: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreateAddressBookItem, EVA.Core.CreateResponse>>;
        static updateItem(id: number, address: EVA.Core.AddressDto, description?: string): Promise<IEVAServiceResponse<EVA.Core.Services.UpdateAddressBookItem, EVA.Core.EmptyResponseMessage>>;
        static deleteItem(id: number): Promise<IEVAServiceResponse<EVA.Core.Services.DeleteAddressBookItem, EVA.Core.EmptyResponseMessage>>;
        constructor(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string);
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.ListAddressBook, EVA.Core.Services.ListAddressBookResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListAddressBook, EVA.Core.Services.ListAddressBookResponse>>;
}
export namespace Addresses {
        /**
            * Wrapper class for Address responses, since this is not a fetchable item
            * it's just a plain object
            */
        class Address {
                data: EVA.Core.AddressDto;
                setData(response: any): EVA.Core.AddressDto;
        }
        /**
            * Perform a lookup using zipcode and housenumber, resolve with an Address object
            *
            * @param  {string}  zipCode     zipcode to lookup
            * @param  {string}  houseNumber housenumber to lookup
            * @return {Promise}             [description]
            */
        function lookup(zipCode: string, houseNumber: string): Promise<Address>;
        /**
            * Request a list of available countries for a user to create addresses with
            * @return {Promise}
            */
        function getAvailableCountries(): Promise<EVA.Core.Services.CountryDto[]>;
        /**
            * Perform an address search using a single text string, responds with textual suggestions.
            * To get the details of the suggestion (city/street etc) a additional call
            * needs to be made to getAddressSuggestionDetails()
            *
            * @param {string}      query       The search query
            * @return {Promise}    array of found suggestions
            */
        function getAddressSuggestions(query: string): Promise<EVA.Core.AddressSuggestion[]>;
        /**
            * Retrieve the details of a suggestion
            *
            * @param {EVA.Core.AddressSuggestion}      suggestion      the address suggestion, can be retrieved using the getAddressSuggestions() function
            * @return {Promise}    the details of the address suggestion
            */
        function getAddressSuggestionDetails(suggestion: EVA.Core.AddressSuggestion): Promise<EVA.Core.AddressSuggestionDetails>;
}

/**
    * This module provides methods for newsletter subscription
    *
    * @preferred
    */
export namespace Newsletter {
        /**
            * Subscribe to the Newsletter using the provided email address
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        function subscribe(emailAddress: string): Promise<IEVAServiceResponse<EVA.Core.Services.Subscribe, EVA.Core.Services.SubscribeResponse>>;
        /**
            * Unsubscribes from the Newsletter using the provided email address
            * @return {Promise}    A promise resolving when the call to the back-end has completed
            */
        function unsubscribe(emailAddress: string): Promise<IEVAServiceResponse<EVA.Core.Services.Unsubscribe, EVA.Core.Services.UnsubscribeResponse>>;
        /**
            * Confirms a Newsletter subscription using the provided token
            * @param  {string}     token   The subscription confirmation token
            * @return {Promise}            A promise resolving when the call to the back-end has completed
            */
        function confirmSubscription(token: string): Promise<IEVAServiceResponse<EVA.Core.Services.ConfirmSubscribe, EVA.Core.Services.ConfirmSubscribeResponse>>;
        /**
            * Validate if a e-mail adres is subscribed to the newsletter
            *
            * @param  {string}  emailAddress The email adres that needs to be validated to have a subscription to the newsletter
            * @return {Promise}              A promise resolving when the call to the back-end has completed
            */
        function hasSubscription(emailAddress: string): Promise<IEVAServiceResponse<EVA.Core.Services.HasSubscription, EVA.Core.Services.HasSubscriptionResponse>>;
}

/**
    * The CMS Page module provides access to content management pages from the EVA back-end * @preferred
    */
/**
    * Provides access to a content menu available in EVA
    */
export class Station extends FetchableItem<EVA.Core.StationDto, EVA.Core.Services.GetStation, EVA.Core.Services.GetStationResponse> {
        /**
            * Fetches the page content
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.GetStation, EVA.Core.Services.GetStationResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.GetStation, EVA.Core.Services.GetStationResponse>>;
}
/**
    * Provides access to a list of stations for an organisation available in EVA
    */
export class StationList extends FetchablePagedList<EVA.Core.StationDto, EVA.Core.Services.ListStationsForOrganizationUnit, EVA.Core.Services.ListStationsForOrganizationUnitResponse> {
        /**
            * Sets the organization id to retrieve the station list for
            * @param  {number} organizationId      The organization identifier
            * @return {void}                       This method doesn't return anything
            */
        setOrganizationId(organizationId: number): void;
        /**
            * Fetches the list of items
            * @return {Promise<IEVAServiceResponse<EVA.Core.StationDto, EVA.Core.Services.ListStationsForOrganizationUnit, EVA.Core.Services.ListStationsForOrganizationUnitResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(): Promise<IEVAServiceResponse<EVA.Core.Services.ListStationsForOrganizationUnit, EVA.Core.Services.ListStationsForOrganizationUnitResponse>>;
}

export namespace Cultures {
    function getApplicationCultures(): Promise<Array<EVA.PIM.Core.ListApplicationContentCulture>>;
}

export namespace Currencies {
    function getAvailableCurrencies(): Promise<Array<EVA.Core.Services.CurrencyDto>>;
    function setOrderCurrency(currencyID: string, orderID: number): Promise<{}>;
}

export namespace Availability {
    function getAvailabilityForProductSet(products: Array<EVA.Core.ProductQuantityDto>, organizationUnitIDs?: Array<number>, fastestPickupShopOnly?: boolean, includeAvailabilityTexts?: boolean, detailedShopInformation?: boolean): Promise<Array<EVA.Core.ProductAvailabilityIndication>>;
}

export namespace Functionalities {
    function getSupportedFunctionalities(): Promise<Array<EVA.Core.Functionalities>>;
}

export namespace ExternalContent {
    function extractUrlInformation(url: string): Promise<IEVAServiceResponse<EVA.Babylon.ExtractUrlInformation, EVA.Babylon.ExtractUrlInformationResponse>>;
}

/**
  * This module provides methods for BI reporting
  *
  * @preferred
  */
export namespace Reporting {
    function GetRankings(axis: string, measure: string, organizationUnitIDs: Array<number> | number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetRankings, EVA.BI.Reporting.GetRankingsResponse>>;
    function getRankings(organizationUnitIDs: Array<number> | number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetRankings, EVA.BI.Reporting.GetRankingsResponse>>;
    function getProductReportingOverview(organizationUnitIDs: Array<number> | number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetProductReportingOverview, EVA.BI.Reporting.GetProductReportingOverviewResponse>>;
    function getTelecomReportingOverview(organizationUnitIDs: Array<number> | number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetTelecomReportingOverview, EVA.BI.Reporting.GetTelecomReportingOverviewResponse>>;
    function getReportingCharts(organizationUnitID: number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetReportingCharts, EVA.BI.Reporting.GetReportingChartsResponse>>;
    function getOrderDetails(orderID: number): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetOrderDetails, EVA.BI.Reporting.GetOrderDetailsResponse>>;
    function getOrders(organizationUnitID: number, category: string, userID?: number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetOrders, EVA.BI.Reporting.GetOrdersResponse>>;
    function getReportingOverview(organizationUnitIDs: Array<number> | number, fromDate?: string, toDate?: string): Promise<IEVAServiceResponse<EVA.BI.Reporting.GetReportingOverview, EVA.BI.Reporting.GetReportingOverviewResponse>>;
}

export function addPushNotificationDevice(deviceToken: string, deviceOS: string, mobileAppID: string, backendSystemID: string): Promise<IEVAServiceResponse<EVA.Core.Services.AddPushNotificationDevice, EVA.Core.EmptyResponseMessage>>;
export function removePushNotificationDevice(deviceToken: string, backendSystemID?: string): Promise<IEVAServiceResponse<EVA.Core.Services.RemovePushNotificationDevice, EVA.Core.EmptyResponseMessage>>;

export namespace Webshop {
    function sendContactFrom(type: string, properties: any): Promise<EVA.Core.Services.SendContactForm>;
}

/**
    * The base module declares reusable base classes for items, lists, etc.
    * @preferred
    */
export interface IPageInfo {
        currentPageNumber: number;
        totalNumberOfPages: number;
        totalNumberOfItems: number;
}
/**
    * Provides access to an item available on the EVA back-end
    */
export class FetchableItem<T, REQ, RES> {
        /**
            * The item detail data. This is available after a fetch from the back-end.
            * It is exposed globally so clients can bind and watch it directly for updates
            * @type {T}
            */
        data: T;
        /**
            * The unique identifier of the item. Used when retrieving an exsting item from the back-end.
            * Defaults to a number but some items use string based identifiers
            * @type {number | string}
            */
        protected _id: number | string;
        /**
            * This class wraps an item from EVA and the operations you can perform on it.
            * You should supply the item identifier when creating an instance of this class
            *
            * @param  {number | string}    id      The identifier of the item to retrieve
            * @return {void}                       This method doesn't return anything
            */
        constructor(id?: number | string);
        /**
            * Set for the id of the fetchable item. This can be overriden in a subclass so
            * additional behaviour can be implemented when setting the id
            *
            * @param  {number | string}      id An item identifier
            * @return {void}                    This item doesn't return anything
            */
        id: number | string;
        /**
            * Returns the current item identifier
            * @return {number | string} An item identifier
            */
        getId(): number | string;
        /**
            * Returns the current item details. Only available after a successful fetch
            * The details are also exposed direct as the .data attribute for easy binding
            * @return {T} The item details
            */
        getData(): T;
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES} response The response from the service call
            * @return {T}            The item details
            */
        setData(response: any): T;
        /**
            * Fetches the item details from the EVA back-end
            * @param  {string}  serviceName The name of the EVA Service to call
            * @param  {REQ}     requestData The request data for service call
            * @param  {string}  path        The request path (rest-like) if not using post message
            * @return {Promise<IEVAServiceResponse<REQ, RES>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(serviceName: string, requestData: REQ, path?: string, method?: EXMLHttpRequestMethod): Promise<IEVAServiceResponse<REQ, RES>>;
}
/**
    * Provides access to a pageable list available on the EVA back-end
    */
export class FetchablePagedList<T, REQ, RES> {
        /**
            * The page item data. This is available after a fetch from the back-end.
            * It is exposed globally so clients can bind and watch it directly for updates
            * @type {Arra<T>}
            */
        data: Array<T>;
        /**
            * The page configuration instance used to instruct the EVA back-end which
            * data to fetch
            * @type {EVA.Core.PageConfig}
            */
        protected pageConfig: EVA.Core.PageConfig;
        /**
            * The current page for which the data is available
            * Only available after fetch has been called
            * @type {number}
            */
        protected currentPageNumber: number;
        /**
            * The total number of pages in the list
            * Only available after fetch has been called
            * @type {number}
            */
        protected totalNumberOfPages: number;
        /**
            * The total number of items in the list
            * Only available after fetch has been called
            * @type {number}
            */
        protected totalNumberOfItems: number;
        /**
            * The list filter applied to the list
            * This may differ from the list of requested filter in the page configuration
            * Only available after fetch has been called
            * @type {any}
            */
        protected appliedFilter: any;
        /**
            * This class wraps a paged result list from EVA and the operations you can perform on it.
            * You can optionally supply page configuration values to start somewhere other then
            * the start of the list
            *
            * @param  {number}                         start           The item to start the list at. Defaults to 0 and is a 0-based index.
            * @param  {number}                         limit           The page size limit. Defaults to 15
            * @param  {EVA.Core.SortDirection}  sortDirection   The sorting direction for the list. Defaults to ascending
            * @return {void}                                           This method doesn't return anything
            */
        constructor(limit?: number, start?: number, sortDirection?: EVA.Core.SortDirection, sortProperty?: string);
        /**
            * Returns the current page size limit
            * @return {number}       The configured page size limit
            */
        getLimit(): number;
        /**
            * Set the page size limit
            * @param  {number} limit The new page size limit
            * @return {number}       The configured page size limit
            */
        setLimit(limit: number): number;
        /**
            * Return the current starting item for the list
            * @return {number}       The configured starting point for the list
            */
        getStart(): number;
        /**
            * Set the starting point for the list
            * @param  {number} start The new starting point for the list
            * @return {number}       The configured starting point for the list
            */
        setStart(start: number): number;
        /**
            * Return the current property being sorted on
            * Can be undefined which means the server decides
            * @return {string}      The configured sorting property
            */
        getSortProperty(): string;
        /**
            * Set the property to sort on
            * @param  {string} name The new sorting property
            * @return {string}      The configured sorting property
            */
        setSortProperty(name: string): string;
        /**
            * Returns the current sort direction
            * @return {string}      The configured sorting property
            */
        getSortDirection(): EVA.Core.SortDirection;
        /**
            * Sets the direction to sort the list on
            * @param  {EVA.Core.SortDirection} direction The new sort direction
            * @return {string}      The configured sorting property
            */
        setSortDirection(direction: EVA.Core.SortDirection): EVA.Core.SortDirection;
        /**
            * Set the filter that is to be applied to the list
            * @param  {any} filter The new filter structure
            * @return {any}        The configured filter
            */
        setFilter(filter: any): any;
        /**
            * Returns the current filter for the list
            * @return {any}        The configured filter
            */
        getFilter(): any;
        /**
            * Returns the current filter applied for the list
            * Only after available after fetch has been called
            * The applied filter can differ from the requested filter depending on how
            * the EVA back-end and its products are configured
            * @return {any}        The applied filter
            */
        getAppliedFilter(): any;
        /**
            * Returns all the current page configuration parameters
            * These determine which part of the list data is returned
            * @return {EVA.Core.PageConfig} The current page configuration
            */
        getPageConfiguration(): EVA.Core.PageConfig;
        /**
            * Sets all the current page configuration parameters at once
            * These determine which part of the list data is returned
            * @param  {EVA.Core.PageConfig} pageConfig The page configuration details
            * @return {EVA.Core.PageConfig}            The new page configuration details
            */
        setPageConfiguration(pageConfig: EVA.Core.PageConfig): EVA.Core.PageConfig;
        /**
            * Returns the current page information which entails the current page, total number of pages and total number of items
            * @return {IPageInfo}  The current page information
            */
        getPageInfo(): IPageInfo;
        /**
            * Returns the current page item details. Only available after a successful fetch
            * The details are also exposed direct as the .data attribute for easy binding
            * @return {Array<T>} An array of item details
            */
        getData(): T[];
        /**
            * Sets the current item details using the fetched service response.
            * Extending classes should override this method to pull the details from response
            * @param  {RES}        response    The response from the service call
            * @return {Array<T>}               The item details
            */
        setData(response: any): T[];
        /**
            * Fetches the list of items from the EVA back-end
            * @param  {string}  serviceName The name of the EVA Service to call
            * @param  {REQ}     requestData The request data for service call
            * @return {Promise<IEVAServiceResponse<REQ, RES>>} A promise resolving when the fetch from the back-end has completed
            */
        fetch(serviceName: string, requestData: REQ, path?: string, method?: EXMLHttpRequestMethod): Promise<IEVAServiceResponse<REQ, RES>>;
}

/**
    * The payments module provides the means to pay for an order using an online payment provider
    * @preferred
    */
/**
    * Provides access to order payment methods available in EVA
    */
export class Payments {
        /**
            * [constructor description]
            * @param  {Order}  order The order to perform the payments for
            * @return {void}         This method doesn't return anything
            */
        constructor(order: Order | ShoppingCart);
        /**
            * Returns the list of available payment methods
            * @return {Promise<IEVAServiceResponse<EVA.Core.GetAvailablePaymentMethods, EVA.Core.GetAvailablePaymentMethodsResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        getAvailableMethods(): Promise<IEVAServiceResponse<EVA.Core.Services.GetAvailablePaymentMethods, EVA.Core.Services.GetAvailablePaymentMethodsResponse>>;
        /**
            * Retuns the list of banks available for iDeal payments
            * @return {Promise<IEVAServiceResponse<EVA.Payment.Acapture.ListAcaptureIdealBanks, EVA.Payment.Acapture.ListAcaptureIdealBanksResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        getIdealBanks(): Promise<IEVAServiceResponse<EVA.Payment.Acapture.ListAcaptureIdealBanks, EVA.Payment.Acapture.ListAcaptureIdealBanksResponse>>;
        getMultiSafePaymentGateWays(orderId: string | number): Promise<IEVAServiceResponse<EVA.Payment.MultiSafepay.GetMultiSafepayGateways, EVA.Payment.MultiSafepay.GetMultiSafepayGatewaysResponse>>;
        /**
            * Retuns the list of user cards available
            * @return {Promise<IEVAServiceResponse<EVA.Payment.UserCard.ListUserCardsForUser, EVA.Payment.UserCard.ListUserCardsForUserResponse>>} A promise resolving when the fetch from the back-end has completed
            */
        listUserCards(userID: number): Promise<IEVAServiceResponse<EVA.Payment.UserCard.ListUserCardsForUser, EVA.Payment.UserCard.ListUserCardsForUserResponse>>;
        /**
            * Pay for the order using a PIN terminal from ADYEN (shop/employee only)
            * @param  {string}  merchantCode     The ADYEN merchant code to use
            * @param  {number}  amount           The amount to pay
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithAdyen(merchantCode: string, amount: number): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        payWithMultiSafePay(method: string, returnUrl: string, amount?: number): any;
        /**
            * Pay for the order using iDEAL
            * @param  {string}  returnUrl     The URL to return to when the payment has completed
            * @param  {string}  idealBankName The name of the bank for the ideal payment
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithIdeal(returnUrl: string, idealBankName: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for the order using PayPal
            * @param  {string}  returnUrl     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithPaypal(returnUrl: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for the order using a MasterCard/Eurocard credit card
            * @param  {string}  returnUrl     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithMasterCard(returnUrl: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for the order using an American Express credit card
            * @param  {string}  returnUrl     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithAmericanExpress(returnUrl: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for the order using a Visa credit card
            * @param  {string}  returnUrl     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithVisa(returnUrl: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for an order with an insurance card (HFS Waardebrief)
            * @param {string}  referenceNumber The reference number for the credit payment
            * @param {string}  policyNumber    The policy number for the credit payment
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithInsuranceCreditPayment(referenceNumber: string, policyNumber: string): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for an order with a user card
            * @param {number}  userId          The id of the user
            * @param {number}  userCardId      The id of the userCardId
            * @param {amount}  amount          The amount that will be charged from the usercard
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithUserCard(userId: number, userCardId: number, amount: number): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for an order with Freebees
            * @param {number}  userId          The id of the user
            * @param {number}  userCardId      The id of the userCardId
            * @param {amount}  amount          The amount that will be charged from the usercard
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithFreebees(cardNumber: string, pin?: string, amount?: number, pinType?: "pin" | "password"): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for an order with Freebees
            * @param {number}  cardNumber      The freebeees card number of the user
            * @return {Promise<IEVAServiceResponse<EVA.Kijkshop.FreeBeesGetCardBalance, EVA.Kijkshop.FreeBeesGetCardBalanceResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        getFreebeesBalance(cardNumber: string): Promise<IEVAServiceResponse<EVA.Kijkshop.FreeBeesGetCardBalance, EVA.Kijkshop.FreeBeesGetCardBalanceResponse>>;
        /**
            * Get the balance of the usercard
            *
            * @param {number} cardId
            * @param {string} currencyId
            * @return {Promise<IEVAServiceResponse<EVA.Payment.UserCard.GetUserCardBalance, EVA.Payment.UserCard.GetUserCardBalanceResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        getUserCardBalance(cardId: number, currencyId?: string): Promise<IEVAServiceResponse<EVA.Payment.UserCard.GetUserCardBalance, EVA.Payment.UserCard.GetUserCardBalanceResponse>>;
        /**
            * Get the balance of a gifcard
            *
            * @param {string} cardId
            * @param {string} cardPin
            * @param {string} barcode
            * @param {string} cardType
            * @return {Promise<IEVAServiceResponse<EVA.Core.Services.CardBalanceCheck, EVA.EVA.Core.Services.CardBalanceCheckResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        cardBalanceCheck(cardId: string, cardPin?: string, barcode?: string, cardType?: string): Promise<IEVAServiceResponse<EVA.Core.Services.CardBalanceCheck, EVA.Core.Services.CardBalanceCheckResponse>>;
        cancelPendingUserCardPayment(paymentTransactionID: number): Promise<IEVAServiceResponse<EVA.Payment.UserCard.CancelPendingUserCardPayment, EVA.Core.EmptyResponseMessage>>;
        /**
            * Pay for an order with AfterPay
            * @param  {any}  properties     Optional additional properties to send
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithAfterPay(properties?: any): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Finalize a payment (usercard needs this)
            * @param {string}  paymentTransactionID    The payment transaction that is to be finalized
            * @return {Promise<IEVAServiceResponse<EVA.Core.FinalizePayment, EVA.Core.FinalizePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        finalizePayment(paymentTransactionID: number, amount: number): Promise<IEVAServiceResponse<EVA.Core.Services.FinalizePayment, EVA.Core.Services.FinalizePaymentResponse>>;
        /**
            * Pay for an order with a manual payment
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithManualPayment(): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for the order using a PIN terminal (shop/employee only)
            * @param  {string}  stationId     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithPIN(stationId: string, amountGiven: number): Promise<IEVAServiceResponse<EVA.Pin.StartTransaction, EVA.Pin.StartTransactionResponse>>;
        /**
            * Abort a payment for the order using a PIN terminal (shop/employee only)
            * @param  {string}  stationId     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Pin.CreatePinPayment, EVA.Pin.CreatePinPaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        abortPIN(stationId: string): Promise<IEVAServiceResponse<EVA.Pin.AbortTransaction, EVA.Pin.AbortTransactionResponse>>;
        /**
            * Pay for the order using a Cash drawer (shop/employee only)
            * @parm   {Order}   order         The order that is to be paid
            * @param  {string}  returnUrl     The URL to return to when the payment has completed
            * @return {Promise<IEVAServiceResponse<EVA.Payment.Cash.MakeCashPayment, EVA.Payment.Cash.MakeCashPaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithCash(stationId: string, amountGiven: number): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for an order with a Media Markt method
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithMediaMarktPayment(): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
        /**
            * Pay for the order using Intersolve giftcards
            * @param  {string}  cardNumber     The number on the Intersolve giftcard
            * @param  {string}  [pin]          A giftcard optionally has a PIN, provide when on the card to use the card
            * @return {Promise<IEVAServiceResponse<EVA.Core.CreatePayment, EVA.Core.CreatePaymentResponse>>}   A promise resolving when the fetch from the back-end has completed
            */
        payWithIntersolve(returnUrl: string, cardNumber: string, pin?: string, amountGiven?: number): Promise<IEVAServiceResponse<EVA.Core.Services.CreatePayment, EVA.Core.Services.CreatePaymentResponse>>;
}


/* tslint:disable */
declare module EVA.Adcurve {
  
  export class SearchTaxonomy extends EVA.Core.PagedResultRequest<EVA.Adcurve.SearchTaxonomyResponse> {
    __response : EVA.Adcurve.SearchTaxonomyResponse;
  }
  
  export class SearchTaxonomyResponse extends EVA.Core.PagedResultResponse<EVA.Adcurve.Taxonomy> {
  }
  
  export class Taxonomy {
    ID : number; // Int32
    Name : string; 
  }
  
}
/* tslint:disable */
declare module EVA.Authentication.SingleSignOn {
  
  export class GenerateSingleSignOnToken extends EVA.Core.RequestMessageGeneric<EVA.Authentication.SingleSignOn.GenerateSingleSignOnTokenResponse> {
    __response : EVA.Authentication.SingleSignOn.GenerateSingleSignOnTokenResponse;
  }
  
  export class GenerateSingleSignOnTokenResponse extends EVA.Core.ResponseMessage {
    Token : string; 
  }
  
}
/* tslint:disable */
declare module EVA.BI.Reporting {
  
  export enum ReportStyle {
    Daily = 0,
    Weekly = 1,
    Monthly = 2,
  }
  
  export class GetOrderDetails extends EVA.Core.RequestMessageGeneric<EVA.BI.Reporting.GetOrderDetailsResponse> {
    OrderID : number; // Int32
    __response : EVA.BI.Reporting.GetOrderDetailsResponse;
  }
  
  export class GetOrderDetailsResponse extends EVA.Core.ResponseMessage {
    Data : any; 
  }
  
  export class GetOrders extends EVA.Core.RequestMessageGeneric<EVA.BI.Reporting.GetOrdersResponse> {
    UserID : number; // Int32, nullable
    OrganizationUnitID : number; // Int32
    FromDate : string; // DateTime, nullable
    ToDate : string; // DateTime, nullable
    Offset : number; // Int32, nullable
    Category : string; 
    __response : EVA.BI.Reporting.GetOrdersResponse;
  }
  
  export class GetOrdersResponse extends EVA.Core.ResponseMessage {
    Orders : EVA.BI.Reporting.OrderOverview[]; 
    Offset : number; // Int32, nullable
  }
  
  export class OrderOverview {
    sales : number; // Decimal
    salesType : string; 
    date : string; // DateTime
    name : string; 
    order_id : number; // Int32
    sales_in_tax : number; // Decimal
    time : any; // TimeSpan
    contract_count : number; // Int32
    margin : number; // Decimal
    insurable_lines : number; // Int32
    gross_margin_percentage : number; // Decimal
    product_id : number; // Int32, nullable
  }
  
  export class GetReportingOverview extends EVA.Core.RequestMessageGeneric<EVA.BI.Reporting.GetReportingOverviewResponse> {
    OrganizationUnits : number[]; 
    FromDate : string; // DateTime, nullable
    ToDate : string; // DateTime, nullable
    __response : EVA.BI.Reporting.GetReportingOverviewResponse;
  }
  
  export class GetReportingOverviewResponse extends EVA.Core.ResponseMessage {
    ResponseID : number; // Int32
    Data : any; 
  }
  
  export class GetProductReportingOverview extends EVA.Core.RequestMessageGeneric<EVA.BI.Reporting.GetProductReportingOverviewResponse> {
    OrganizationUnits : number[]; 
    FromDate : string; // DateTime, nullable
    ToDate : string; // DateTime, nullable
    __response : EVA.BI.Reporting.GetProductReportingOverviewResponse;
  }
  
  export class GetProductReportingOverviewResponse extends EVA.Core.ResponseMessage {
    ResponseID : number; // Int32
    Data : any; 
  }
  
  export class GetRankings extends EVA.Core.RequestMessageGeneric<EVA.BI.Reporting.GetRankingsResponse> {
    OrganizationUnits : number[]; 
    FromDate : string; // DateTime, nullable
    ToDate : string; // DateTime, nullable
    __response : EVA.BI.Reporting.GetRankingsResponse;
  }
  
  export class GetRankingsResponse extends EVA.Core.ResponseMessage {
    Rankings : EVA.BI.Reporting.ReportOverview[]; 
  }
  
  export class ReportOverview implements EVA.BI.Reporting.IPopulateNames {
    id : number; // Int32
    applicationId : number; // Int32
    organizationUnitId : number; // Int32
    name : string; 
    groupingId : number[]; 
    type : number; // Int32
    loss : number; // Decimal, nullable
    sales : number; // Decimal
    apple_sales : number; // Decimal
    visitors : number; // Int32, nullable
    visitor_value : number; // Decimal, nullable
    people_outside : number; // Int32
    outside_conversion : number; // Decimal
    order_count : number; // Int32
    conversion_rate : number; // Decimal, nullable
    margin : number; // Decimal
    insurance_rate : number; // Decimal
    insurable_lines : number; // Decimal
    units_sold : number; // Int32
    telco_lines : number; // Int32
    contract_count : number; // Int32
    sales_per_type : EVA.BI.Reporting.SalesPerType[]; 
    task_data : EVA.BI.Reporting.TaskInfo[]; 
    budget : EVA.BI.Reporting.BudgetInfo; 
    kpis : EVA.BI.Reporting.KpiInfo[]; 
    worked_hours : number; // Decimal
    cpus : number; // Int32
    fullName : string; 
    service_sales : number; // Decimal, nullable
    margin_percentage : number; // Decimal
    productivity : number; // Decimal
    sales_minutes : number; // Decimal
    budget_rate : number; // Decimal
    average_order_value : number; // Decimal
    attach_rate : number; // Decimal
    photo : number; // Int32
    my_organizations : boolean; 
    drillDown : boolean; 
    telecom : any; 
    margin_per_unit : number; // Decimal, nullable
  }
  
  export class SalesPerType {
    sales : number; // Decimal
    sales_percentage : number; // Decimal
    salesType : string; 
  }
  
  export class TaskInfo {
    type : string; 
    groupingId : number; // Int32
    count : number; // Int32
  }
  
  export class BudgetInfo {
    service : number; // Decimal
    sales : number; // Decimal
    margin : number; // Decimal
    shop_to_web_rate : number; // Decimal
    worked_hours : number; // Decimal
    insurance_rate : number; // Decimal
    telco : number; // Int32
    conversion_rate : number; // Decimal, nullable
    units_per_order : number; // Decimal, nullable
    margin_per_unit : number; // Decimal, nullable
    units_sold : number; // Decimal, nullable
    quantity_sold : number; // Decimal, nullable
    post_pay : number; // Decimal, nullable
    attach_rate : number; // Decimal
  }
  
  export class KpiInfo {
    type : string; 
    name : string; 
    formula : string; 
  }
  
  export interface IPopulateNames {
    id : number; // Int32
    organizationUnitId : number; // Int32
    name : string; 
    type : number; // Int32
  }
  
  export class GetReportingCharts extends EVA.Core.RequestMessageGeneric<EVA.BI.Reporting.GetReportingChartsResponse> {
    OrganizationUnitID : number; // Int32
    FromDate : string; // DateTime, nullable
    ToDate : string; // DateTime, nullable
    __response : EVA.BI.Reporting.GetReportingChartsResponse;
  }
  
  export class GetReportingChartsResponse extends EVA.Core.ResponseMessage {
    Data : any; 
  }
  
  export class GetStockOverview extends EVA.Core.RequestMessageGeneric<EVA.BI.Reporting.GetStockOverviewResponse> {
    OrganizationUnits : number[]; 
    ToDate : string; // DateTime, nullable
    Axis : string; 
    Measure : string; 
    __response : EVA.BI.Reporting.GetStockOverviewResponse;
  }
  
  export class GetStockOverviewResponse extends EVA.Core.ResponseMessage {
    ResponseID : number; // Int32
    Data : any; 
  }
  
  export class GetTelecomReportingOverview extends EVA.Core.RequestMessageGeneric<EVA.BI.Reporting.GetTelecomReportingOverviewResponse> {
    OrganizationUnits : number[]; 
    FromDate : string; // DateTime, nullable
    ToDate : string; // DateTime, nullable
    __response : EVA.BI.Reporting.GetTelecomReportingOverviewResponse;
  }
  
  export class GetTelecomReportingOverviewResponse extends EVA.Core.ResponseMessage {
    ResponseID : number; // Int32
    Data : any; 
  }
  
  export class GetDailyStats extends EVA.Core.RequestMessageGeneric<EVA.BI.Reporting.GetDailyStatsResponse> {
    __response : EVA.BI.Reporting.GetDailyStatsResponse;
  }
  
  export class GetDailyStatsResponse extends EVA.Core.ResponseMessage {
    Orders : number; // Int32
    Exported : number; // Int32
    Shipped : number; // Int32
    Products : number; // Int32
  }
  
  export class GetOrderCounts extends EVA.Core.RequestMessageGeneric<EVA.BI.Reporting.GetOrderCountsResponse> {
    StartDate : string; // DateTime, nullable
    EndDate : string; // DateTime, nullable
    __response : EVA.BI.Reporting.GetOrderCountsResponse;
  }
  
  export class GetOrderCountsResponse extends EVA.Core.ResponseMessage {
    Days : EVA.BI.Reporting.GetOrderCountsResponseDayWithCount[]; 
  }
  
  export class GetOrderCountsResponseDayWithCount {
    Day : string; // DateTime
    Count : number; // Int32
  }
  
  export class GetPopularProducts extends EVA.Core.RequestMessageGeneric<EVA.BI.Reporting.GetPopularProductsResponse> {
    StartDate : string; // DateTime, nullable
    EndDate : string; // DateTime, nullable
    Amount : number; // Int32, nullable
    __response : EVA.BI.Reporting.GetPopularProductsResponse;
  }
  
  export class GetPopularProductsResponse extends EVA.Core.ResponseMessage {
    Products : EVA.BI.Reporting.GetPopularProductsResponseProductWithCount[]; 
  }
  
  export class GetPopularProductsResponseProductWithCount {
    ID : number; // Int32
    Name : string; 
    Count : number; // Int32
  }
  
}
/* tslint:disable */
declare module EVA.BI {
  
  export class GetSalesBudgets extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    __response : EVA.Core.ResourceResponseMessage;
  }
  
  export class UpdateSalesBudgets extends EVA.Core.RequestMessageWithEmptyResponse {
    Data : number[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
}
/* tslint:disable */
declare module EVA.Babylon {
  
  export enum StreamApiLocation {
    USEast = 0,
    USWest = 1,
    EUWest = 2,
    AsiaJapan = 3,
  }
  
  export class AddFashionUserMediaBase extends EVA.Core.RequestMessageWithEmptyResponse {
    BlobID : string; 
    Name : string; 
    Description : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class AddFashionUserMediaToProduct extends EVA.Babylon.AddFashionUserMediaBase {
    ProductID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class AddFashionUserMediaToFashionCollection extends EVA.Babylon.AddFashionUserMediaBase {
    CollectionID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteFashionUserMedia extends EVA.Core.RequestMessageWithEmptyResponse {
    UserMediaID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetFashionUserMediaByID extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetFashionUserMediaByIDResponse> {
    UserMediaID : number; // Int32
    __response : EVA.Babylon.GetFashionUserMediaByIDResponse;
  }
  
  export class GetFashionUserMediaByIDResponse extends EVA.Core.ResponseMessage {
    UserMedia : EVA.Babylon.FashionUserMediaByID; 
  }
  
  export class FashionUserMediaByID {
    UserID : number; // Int32
    ProductID : number; // Int32, nullable
    CollectionID : number; // Int32, nullable
    BlobID : string; 
    Sequence : number; // Int32
    Name : string; 
    Description : string; 
  }
  
  export class ListFashionUserMediaForProduct extends EVA.Core.PagedResultRequest<EVA.Babylon.ListFashionUserMediaResponse> {
    ProductID : number; // Int32
    UserID : number; // Int32, nullable
    __response : EVA.Babylon.ListFashionUserMediaResponse;
  }
  
  export class ListFashionUserMediaResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.FashionUserMedia> {
  }
  
  export class FashionUserMedia {
    ID : number; // Int32
    BlobID : string; 
    CreationTime : string; // DateTime
    UserID : number; // Int32
    User : EVA.Babylon.FashionUserMediaUser; 
    Name : string; 
    Description : string; 
    SocialStats : EVA.Babylon.SocialStats; 
    Width : number; // Int32
    Height : number; // Int32
  }
  
  export class FashionUserMediaUser {
    FirstName : string; 
    ID : number; // Int32
    Name : string; 
    Nickname : string; 
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
  }
  
  export class SocialStats {
    ID : string; 
    Likes : number; // Int32
    Comments : number; // Int32
    Views : number; // Int32
    AlreadyLiked : boolean; 
    AlreadyClipped : boolean; 
    AlreadyFollowing : boolean; 
  }
  
  export class ListFashionUserMediaForCollection extends EVA.Core.PagedResultRequest<EVA.Babylon.ListFashionUserMediaResponse> {
    CollectionID : number; // Int32
    UserID : number; // Int32, nullable
    __response : EVA.Babylon.ListFashionUserMediaResponse;
  }
  
  export enum SupplierStatuses {
    Pending = 0,
    Approved = 1,
  }
  
  export enum ProductManagementMethods {
    None = 0,
    Manual = 1,
    EffectConnect = 2,
    TradeByte = 3,
    Channable = 4,
  }
  
  export enum FullfillmentMethods {
    None = 0,
    Manual = 1,
    EffectConnect = 2,
    TradeByte = 3,
    Channable = 4,
  }
  
  export enum Modules {
    None = 0,
    ShipmentAndReturns = 1,
    ProductMedia = 2,
  }
  
  export class GenerateSupplierContract extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GenerateSupplierContractResponse> {
    Company : EVA.Core.CompanyDto; 
    ProductManagementMethodID : number; // Int32
    FullfillmentMethodID : number; // Int32
    ModulesID : number; // Int32
    StatusID : number; // Int32
    ContractUser : EVA.Core.UserDto; 
    ContractUserFunction : string; 
    __response : EVA.Babylon.GenerateSupplierContractResponse;
  }
  
  export class GenerateSupplierContractResponse extends EVA.Core.ResponseMessage {
    Url : string; 
  }
  
  export class GetFashionSupplierData extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetFashionSupplierDataResponse> {
    SupplierID : number; // Int32
    __response : EVA.Babylon.GetFashionSupplierDataResponse;
  }
  
  export class GetFashionSupplierDataResponse extends EVA.Core.ResponseMessage {
    SupplierData : EVA.Babylon.FashionSupplierDataDto; 
  }
  
  export class FashionSupplierDataDto {
    SupplierID : number; // Int32
    ProductManagementMethod : EVA.Babylon.ProductManagementMethods; 
    FullfillmentMethod : EVA.Babylon.FullfillmentMethods; 
    Modules : EVA.Babylon.Modules; 
    Status : EVA.Babylon.SupplierStatuses; 
    UserCompanyFunction : string; 
    UserID : number; // Int32
    ReturnsPolicy : string; 
    ReturnDays : number; // Int32, nullable
    ReturnCostsAmount : number; // Decimal, nullable
    ReturnsCarrierName : string; 
    ShippingCostsCutoffAmount : number; // Decimal, nullable
    ShippingCostsPolicy : string; 
    ShippingCostsAmount : number; // Decimal, nullable
    ShippingCarrierName : string; 
    ReturnsAddress : EVA.Core.AddressDto; 
    ContactEmailAddress : string; 
    ContactPhoneNumber : string; 
    SupplierName : string; 
  }
  
  export class ListSuppliers extends EVA.Core.PagedResultRequest<EVA.Babylon.ListSuppliersResponse> {
    __response : EVA.Babylon.ListSuppliersResponse;
  }
  
  export class ListSuppliersResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.ListSuppliersResponseModel> {
  }
  
  export class ListSuppliersResponseModel {
    SupplierID : number; // Int32
    User : EVA.Core.UserDto; 
  }
  
  export class UploadCompanyLogo extends EVA.Core.RequestMessageGeneric<EVA.Babylon.UploadCompanyLogoResponse> {
    OriginalName : string; 
    MimeType : string; 
    Data : number[]; 
    __response : EVA.Babylon.UploadCompanyLogoResponse;
  }
  
  export class UploadCompanyLogoResponse extends EVA.Core.ResponseMessage {
    BlobID : string; 
  }
  
  export class UpdateSupplier extends EVA.Core.RequestMessageWithEmptyResponse {
    SupplierID : number; // Int32
    ProductManagementMethodID : number; // Int32
    FullfillmentMethodID : number; // Int32
    ModulesID : number; // Int32
    StatusID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateSupplier extends EVA.Core.RequestMessageGeneric<EVA.Babylon.CreateSupplierResponse> {
    Company : EVA.Core.CompanyDto; 
    CompanyTradeName : string; 
    WebshopTypeName : string; 
    ProductManagementMethodID : number; // Int32
    FullfillmentMethodID : number; // Int32
    ModulesID : number; // Int32
    StatusID : number; // Int32
    ContractUser : EVA.Core.UserDto; 
    ContractUserFunction : string; 
    Password : string; 
    Nickname : string; 
    __response : EVA.Babylon.CreateSupplierResponse;
  }
  
  export class CreateSupplierResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export enum ReportedContentActions {
    Delete = 0,
    Ignore = 1,
  }
  
  export enum ContentTypes {
    User = 0,
    Product = 1,
    UserMedia = 2,
    CoverSheet = 3,
  }
  
  export enum SocialMediaPlatform {
    Facebook = 0,
    Twitter = 1,
  }
  
  export class SocialGetFollowSuggestions extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialGetFollowSuggestionsResponse> {
    SuggestionCount : number; // Int32
    __response : EVA.Babylon.SocialGetFollowSuggestionsResponse;
  }
  
  export class SocialGetFollowSuggestionsResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Babylon.SocialFollowSuggestion[]; 
  }
  
  export class SocialFollowSuggestion {
    UserID : number; // Int32
    FirstName : string; 
    Nickname : string; 
    RecommendationType : string; 
  }
  
  export enum CommentedOnObjectTypes {
    Product = 0,
    FashionCollection = 1,
    UserMedia = 2,
  }
  
  export enum SocialReportContentTypes {
    None = 0,
    FashionCollection = 1,
    UserMedia = 2,
    User = 3,
    Comment = 4,
    Product = 5,
    CoverSheet = 6,
  }
  
  export enum SocialReportReasons {
    None = 0,
    Spam = 1,
    Offensive = 2,
    Inappropriate = 3,
    NonFashion = 4,
    CopyrightInfringement = 5,
    Automatic = 6,
  }
  
  export enum SocialReportContentStatuses {
    New = 0,
    ContentRemoved = 1,
    Ignored = 2,
  }
  
  export enum ProductCreationResultTypes {
    Product = 0,
    UserMedia = 1,
  }
  
  export class DeleteReportedContent extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class IgnoreReportedContent extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class BlockUser extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class UnblockUser extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialListBlockedFollowers extends EVA.Core.PagedResultRequest<EVA.Babylon.SocialListBlockedFollowersResponse> {
    UserID : number; // Int32
    __response : EVA.Babylon.SocialListBlockedFollowersResponse;
  }
  
  export class SocialListBlockedFollowersResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.BlockedUser> {
  }
  
  export class BlockedUser {
    UserID : number; // Int32
    Nickname : string; 
    FirstName : string; 
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
  }
  
  export class GetReportedContentByID extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetReportedContentByIDResponse> {
    ID : number; // Int32
    __response : EVA.Babylon.GetReportedContentByIDResponse;
  }
  
  export class GetReportedContentByIDResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Babylon.GetReportedContentByIDResponseReportedContentDto; 
  }
  
  export class GetReportedContentByIDResponseReportedContentDto {
    ContentID : string; 
    ContentType : EVA.Babylon.SocialReportContentTypes; 
    ReportedByUserID : number; // Int32
    ReportedByUser : EVA.Core.UserDto; 
    ReportDescription : string; 
    ReportReason : EVA.Babylon.SocialReportReasons; 
    Status : EVA.Babylon.SocialReportContentStatuses; 
  }
  
  export class ListReportedContent extends EVA.Core.PagedResultRequest<EVA.Babylon.ListReportedContentResponse> {
    __response : EVA.Babylon.ListReportedContentResponse;
  }
  
  export class ListReportedContentResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.ListReportedContentResponseReportedContentDto> {
  }
  
  export class ListReportedContentResponseReportedContentDto {
    ID : number; // Int32
    ContentID : string; 
    ContentType : EVA.Babylon.SocialReportContentTypes; 
    ReportedByUserID : number; // Int32
    ReportedByUser : EVA.Core.UserDto; 
    ReportDescription : string; 
    ReportReason : EVA.Babylon.SocialReportReasons; 
    Status : EVA.Babylon.SocialReportContentStatuses; 
  }
  
  export class SocialReportContent extends EVA.Core.RequestMessageWithEmptyResponse {
    Type : EVA.Babylon.SocialReportContentTypes; 
    Reason : EVA.Babylon.SocialReportReasons; 
    ID : string; 
    Description : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ShareProductWithUsers extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    Message : string; 
    UserIDs : number[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ShareFashionCollectionWithUsers extends EVA.Core.RequestMessageWithEmptyResponse {
    CollectionID : number; // Int32
    Message : string; 
    UserIDs : number[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialProductSharedExternally extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    Platform : EVA.Babylon.SocialMediaPlatform; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialFashionCollectionSharedExternally extends EVA.Core.RequestMessageWithEmptyResponse {
    CollectionID : number; // Int32
    Platform : EVA.Babylon.SocialMediaPlatform; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialGetProgressionRanking extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialGetProgressionRankingResponse> {
    UserID : number; // Int32
    __response : EVA.Babylon.SocialGetProgressionRankingResponse;
  }
  
  export class SocialGetProgressionRankingResponse extends EVA.Core.ResponseMessage {
    GlobalRank : number; // Int32
    FriendsRank : number; // Int32
    UserCount : number; // Int32
    FriendsCount : number; // Int32
  }
  
  export class SocialInviteFriends extends EVA.Core.RequestMessageWithEmptyResponse {
    Invites : EVA.Babylon.InviteFriendsDto[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class InviteFriendsDto {
    EmailAddress : string; 
    FirstName : string; 
    LastName : string; 
    Message : string; 
  }
  
  export class SocialListFacebookFriends extends EVA.Core.PagedResultRequest<EVA.Babylon.SocialListFacebookFriendsResponse> {
    __response : EVA.Babylon.SocialListFacebookFriendsResponse;
  }
  
  export class SocialListFacebookFriendsResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.FacebookFriend> {
  }
  
  export class FacebookFriend {
    UserID : number; // Int32
    Nickname : string; 
    FirstName : string; 
    AlreadyFollowing : boolean; 
    AlreadyBlocked : boolean; 
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
  }
  
  export class SocialListProductsCreationsByUser extends EVA.Core.PagedResultRequest<EVA.Babylon.SocialListProductsCreationsByUserResponse> {
    UserID : number; // Int32
    __response : EVA.Babylon.SocialListProductsCreationsByUserResponse;
  }
  
  export class SocialListProductsCreationsByUserResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.ProductCreationByUserResult> {
  }
  
  export class ProductCreationByUserResult {
    ID : number; // Int32
    Name : string; 
    Type : EVA.Babylon.ProductCreationResultTypes; 
    Price : number; // Decimal, nullable
    SocialStats : EVA.Babylon.SocialStats; 
    CreationTime : string; // DateTime
    BlobID : string; 
    FullName : string; 
    ImageSize : string; 
    ProductID : number; // Int32, nullable
    CollectionID : number; // Int32, nullable
    ProductType : string; 
    OrganizationUnitID : number; // Int32, nullable
    FashionCoinsPrice : number; // Decimal, nullable
    BabylonProductType : string; 
    BrandName : string; 
    FashionCoinsReward : number; // Int32, nullable
    OriginalPrice : number; // Decimal, nullable
  }
  
  export class SocialUpdateGuidedTourProgress extends EVA.Core.RequestMessageWithEmptyResponse {
    TourID : string; 
    CurrentStep : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialGetGuidedTourProgress extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialGetGuidedTourProgressResponse> {
    TourID : string; 
    __response : EVA.Babylon.SocialGetGuidedTourProgressResponse;
  }
  
  export class SocialGetGuidedTourProgressResponse extends EVA.Core.ResponseMessage {
    CurrentStep : number; // Int32
  }
  
  export class SocialAddCommentToProduct extends EVA.Core.RequestMessageGeneric<EVA.Babylon.AddCommentResponse> {
    CommentText : string; 
    ProductID : number; // Int32
    __response : EVA.Babylon.AddCommentResponse;
  }
  
  export class AddCommentResponse extends EVA.Core.ResponseMessage {
    ID : string; 
  }
  
  export class SocialListCommentsBase extends EVA.Core.PagedResultRequest<EVA.Babylon.SocialListCommentsResponse> {
  }
  
  export class SocialListCommentsResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.Comment> {
  }
  
  export class Comment {
    Text : string; 
    UserID : number; // Int32
    UserName : string; 
    CreationTime : string; // DateTime
    ID : string; 
    Nickname : string; 
    FirstName : string; 
    CanDelete : boolean; 
    SocialStats : EVA.Babylon.SocialStats; 
    Mentions : EVA.Babylon.CommentMention[]; 
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
    CommentOnType : string; 
    CommentOnID : number; // Int32, nullable
  }
  
  export class CommentMention {
    UserID : number; // Int32
    FirstName : string; 
    Nickname : string; 
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
  }
  
  export class SocialListCommentsForProduct extends EVA.Babylon.SocialListCommentsBase {
    ProductID : number; // Int32
    __response : EVA.Babylon.SocialListCommentsResponse;
  }
  
  export class SocialAddCommentToFashionCollection extends EVA.Core.RequestMessageGeneric<EVA.Babylon.AddCommentResponse> {
    CommentText : string; 
    CollectionID : number; // Int32
    __response : EVA.Babylon.AddCommentResponse;
  }
  
  export class SocialAddCommentToFashionUserMedia extends EVA.Core.RequestMessageGeneric<EVA.Babylon.AddCommentResponse> {
    CommentText : string; 
    UserMediaID : number; // Int32
    __response : EVA.Babylon.AddCommentResponse;
  }
  
  export class SocialListCommentsForFashionCollection extends EVA.Babylon.SocialListCommentsBase {
    CollectionID : number; // Int32
    __response : EVA.Babylon.SocialListCommentsResponse;
  }
  
  export class SocialListCommentsForFashionUserMedia extends EVA.Babylon.SocialListCommentsBase {
    UserMediaID : number; // Int32
    __response : EVA.Babylon.SocialListCommentsResponse;
  }
  
  export class SocialDeleteComment extends EVA.Core.RequestMessageWithEmptyResponse {
    CommentID : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialGetComment extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialGetCommentResponse> {
    CommentID : string; 
    __response : EVA.Babylon.SocialGetCommentResponse;
  }
  
  export class SocialGetCommentResponse extends EVA.Core.ResponseMessage {
    Comment : EVA.Babylon.Comment; 
  }
  
  export enum SocialInteracionTypes {
    None = 0,
    Likes = 1,
    Commented = 2,
    Clipped = 3,
  }
  
  export class SocialListInteractionsSummaryBase extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialListInteractionsSummaryResponse> {
    InteractionType : EVA.Babylon.SocialInteracionTypes; 
    __response : EVA.Babylon.SocialListInteractionsSummaryResponse;
  }
  
  export class SocialListInteractionsSummaryResponse extends EVA.Core.ResponseMessage {
    UserIDs : number[]; 
  }
  
  export class SocialListInteractionDetailsBase extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialInteractionDetailsResponse> {
    PageConfig : EVA.Babylon.PageConfigDateTimeOffset; 
    InteractionType : EVA.Babylon.SocialInteracionTypes; 
    __response : EVA.Babylon.SocialInteractionDetailsResponse;
  }
  
  export class SocialInteractionDetailsResponse extends EVA.Core.ResponseMessage {
    Interactions : EVA.Babylon.PagedDateTimeOffsetResult<EVA.Babylon.SocialInteraction>; 
  }
  
  export class PagedDateTimeOffsetResult<TResult> {
    Page : TResult[]; 
    NextOffset : string; // DateTime, nullable
    Limit : number; // Int32
  }
  
  export class SocialInteraction {
    UserID : number; // Int32
    Name : string; 
    Type : EVA.Babylon.SocialInteracionTypes; 
    Following : boolean; 
    CreationTime : string; // DateTime
    FirstName : string; 
    Nickname : string; 
    CoverPhotoID : string; 
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
  }
  
  export class PageConfigDateTimeOffset {
    Offset : string; // DateTime, nullable
    Limit : number; // Int32
  }
  
  export class SocialListInteractionsSummaryForProduct extends EVA.Babylon.SocialListInteractionsSummaryBase {
    ProductID : number; // Int32
    __response : EVA.Babylon.SocialListInteractionsSummaryResponse;
  }
  
  export class SocialListInteractionDetailsForProduct extends EVA.Babylon.SocialListInteractionDetailsBase {
    ProductID : number; // Int32
    __response : EVA.Babylon.SocialInteractionDetailsResponse;
  }
  
  export class SocialListInteractionsSummaryForFashionCollection extends EVA.Babylon.SocialListInteractionsSummaryBase {
    CollectionID : number; // Int32
    __response : EVA.Babylon.SocialListInteractionsSummaryResponse;
  }
  
  export class SocialListInteractionDetailsForFashionCollection extends EVA.Babylon.SocialListInteractionDetailsBase {
    CollectionID : number; // Int32
    __response : EVA.Babylon.SocialInteractionDetailsResponse;
  }
  
  export class SocialListInteractionsSummaryForUser extends EVA.Babylon.SocialListInteractionsSummaryBase {
    UserID : number; // Int32
    __response : EVA.Babylon.SocialListInteractionsSummaryResponse;
  }
  
  export class SocialListInteractionDetailsForUser extends EVA.Babylon.SocialListInteractionDetailsBase {
    UserID : number; // Int32
    __response : EVA.Babylon.SocialInteractionDetailsResponse;
  }
  
  export class SocialListLikedObjects extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialListLikedObjectsResponse> {
    PageConfig : EVA.Babylon.PageConfigDateTimeOffset; 
    __response : EVA.Babylon.SocialListLikedObjectsResponse;
  }
  
  export class SocialListLikedObjectsResponse extends EVA.Core.ResponseMessage {
    LikedObjects : EVA.Babylon.PagedDateTimeOffsetResult<EVA.Babylon.LikedObject>; 
  }
  
  export class LikedObject {
    ObjectID : string; 
    ObjectType : string; 
    Name : string; 
    CreationTime : string; // DateTime
    CollectionTopProductIDs : number[]; 
    SocialStats : EVA.Babylon.SocialObjectStats; 
    Actor : EVA.Babylon.FeedItemActor; 
    CoverSheetBlobID : string; 
    FullName : string; 
    ImageSize : string; 
    UserMediaBlobID : string; 
    FirstName : string; 
    Nickname : string; 
    CommentText : string; 
    OrganizationUnitID : number; // Int32, nullable
    FashionCoinsPrice : number; // Decimal, nullable
    BabylonProductType : string; 
    FashionCoinsReward : number; // Int32, nullable
  }
  
  export class SocialObjectStats {
    ObjectID : string; 
    ObjectType : string; 
    Likes : number; // Int32
    Comments : number; // Int32
    Views : number; // Int32
    AlreadyLiked : boolean; 
    AlreadyClipped : boolean; 
  }
  
  export class FeedItemActor {
    FirstName : string; 
    ID : number; // Int32
    Name : string; 
    Nickname : string; 
    Type : string; 
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
  }
  
  export class SocialGetProductsStats extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialStatsResponse> {
    ProductIDs : number[]; 
    __response : EVA.Babylon.SocialStatsResponse;
  }
  
  export class SocialStatsResponse extends EVA.Core.ResponseMessage {
    Stats : EVA.Babylon.SocialStats[]; 
  }
  
  export class SocialGetFashionCollectionsStats extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialStatsResponse> {
    CollectionIDs : number[]; 
    __response : EVA.Babylon.SocialStatsResponse;
  }
  
  export class SocialGetUserMediaStats extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialStatsResponse> {
    UserMediaIDs : number[]; 
    __response : EVA.Babylon.SocialStatsResponse;
  }
  
  export class SocialGetStatsForFeedObjects extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialObjectStatsResponse> {
    ObjectIDs : EVA.Babylon.FeedObjectDto[]; 
    __response : EVA.Babylon.SocialObjectStatsResponse;
  }
  
  export class SocialObjectStatsResponse extends EVA.Core.ResponseMessage {
    Stats : EVA.Babylon.SocialObjectStats[]; 
  }
  
  export class FeedObjectDto {
    ObjectType : string; 
    ObjectID : string; 
  }
  
  export class SocialListFollowing extends EVA.Core.PagedResultRequest<EVA.Babylon.SocialListFollowingResponse> {
    UserID : number; // Int32
    __response : EVA.Babylon.SocialListFollowingResponse;
  }
  
  export class SocialListFollowingResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.Following> {
  }
  
  export class Following {
    UserID : number; // Int32
    Nickname : string; 
    FirstName : string; 
    AlreadyFollowing : boolean; 
    AlreadyBlocked : boolean; 
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
  }
  
  export class SocialListFollowers extends EVA.Core.PagedResultRequest<EVA.Babylon.SocialListFollowersResponse> {
    UserID : number; // Int32
    __response : EVA.Babylon.SocialListFollowersResponse;
  }
  
  export class SocialListFollowersResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.Follower> {
  }
  
  export class Follower {
    UserID : number; // Int32
    Nickname : string; 
    FirstName : string; 
    AlreadyFollowing : boolean; 
    AlreadyBlocked : boolean; 
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
  }
  
  export class SocialGetUserProfile extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialGetUserProfileResponse> {
    UserID : number; // Int32
    __response : EVA.Babylon.SocialGetUserProfileResponse;
  }
  
  export class SocialGetUserProfileResponse extends EVA.Core.ResponseMessage {
    Profile : EVA.Babylon.SocialUserProfile; 
  }
  
  export class SocialUserProfile {
    UserID : number; // Int32
    Name : string; 
    FirstName : string; 
    LastName : string; 
    Gender : string; 
    Nickname : string; 
    DateOfBirth : string; // DateTime, nullable
    Collections : number; // Int32
    Followers : number; // Int32
    Following : number; // Int32
    Biography : string; 
    AvatarID : string; 
    CoverPhotoID : string; 
    ThingsLiked : number; // Int32
    Views : number; // Int32
    ProductCreationsCount : number; // Int32
    AlreadyFollowing : boolean; 
    AlreadyBlocked : boolean; 
    CanEditProfile : boolean; 
    Likes : number; // Int32
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
  }
  
  export class SocialGetUserProfileByNickname extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialGetUserProfileResponse> {
    Nickname : string; 
    __response : EVA.Babylon.SocialGetUserProfileResponse;
  }
  
  export class SocialUpdateUserProfile extends EVA.Core.RequestMessageWithEmptyResponse {
    Profile : EVA.Babylon.SocialUpdateUserProfileModel; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialUpdateUserProfileModel {
    Biography : string; 
    Avatar : string; 
    CoverPhoto : string; 
    DateOfBirth : string; // DateTime, nullable
    FirstName : string; 
    LastName : string; 
    Gender : string; 
    Nickname : string; 
  }
  
  export class SocialUnlikeProduct extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialUnlikeFashionCollection extends EVA.Core.RequestMessageWithEmptyResponse {
    CollectionID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialUnlikeUser extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialUnlikeFashionUserMedia extends EVA.Core.RequestMessageWithEmptyResponse {
    UserMediaID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialUnlikeComment extends EVA.Core.RequestMessageWithEmptyResponse {
    CommentID : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialUnfollowUser extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialFollowUser extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialIsFollowing extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialIsFollowingResponse> {
    UserID : number; // Int32
    __response : EVA.Babylon.SocialIsFollowingResponse;
  }
  
  export class SocialIsFollowingResponse extends EVA.Core.ResponseMessage {
    IsFollowing : boolean; 
  }
  
  export class SocialIsFollowingUsers extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialIsFollowingUsersResponse> {
    UserIDs : number[]; 
    __response : EVA.Babylon.SocialIsFollowingUsersResponse;
  }
  
  export class SocialIsFollowingUsersResponse extends EVA.Core.ResponseMessage {
    Results : EVA.Babylon.IsFollowingUserResult[]; 
  }
  
  export class IsFollowingUserResult {
    UserID : number; // Int32
    IsFollowing : boolean; 
    IsBlocked : boolean; 
  }
  
  export class SocialLikeProduct extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialLikeFashionCollection extends EVA.Core.RequestMessageWithEmptyResponse {
    CollectionID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialLikeUser extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialLikeFashionUserMedia extends EVA.Core.RequestMessageWithEmptyResponse {
    UserMediaID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class SocialLikeComment extends EVA.Core.RequestMessageWithEmptyResponse {
    CommentID : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CoverSheetProductsSearch extends EVA.Core.RequestMessageGeneric<EVA.Babylon.CoverSheetProductsSearchResponse> {
    Query : string; 
    PageSize : number; // Int32, nullable
    LikedProductsPage : number; // Int32, nullable
    CreatedProductsPage : number; // Int32, nullable
    __response : EVA.Babylon.CoverSheetProductsSearchResponse;
  }
  
  export class CoverSheetProductsSearchResponse extends EVA.Core.ResponseMessage {
    CreatedProducts : EVA.Babylon.CreatedProductsForCoverSheet; 
    LikedProducts : EVA.Babylon.LikedProductsForCoverSheet; 
    PageSize : number; // Int32
  }
  
  export class CreatedProductsForCoverSheet {
    Products : any[]; 
    Total : number; // Int64
    CreatedProductsPage : number; // Int32, nullable
  }
  
  export class LikedProductsForCoverSheet {
    Products : any[]; 
    Total : number; // Int64
    LikedProductsPage : number; // Int32, nullable
  }
  
  export class QuickSearchFashionItems extends EVA.Core.RequestMessageGeneric<EVA.Babylon.QuickSearchFashionItemsResponse> {
    FashionCollectionSize : number; // Int32, nullable
    ProductSize : number; // Int32, nullable
    ActorSize : number; // Int32, nullable
    Query : string; 
    OnlyAutocompleteProducts : boolean; 
    __response : EVA.Babylon.QuickSearchFashionItemsResponse;
  }
  
  export class QuickSearchFashionItemsResponse extends EVA.Core.ResponseMessage {
    FashionCollectionResults : EVA.Babylon.FashionCollectionSearchResultset; 
    ProductResults : EVA.Babylon.FashionProductSearchResultset; 
    ActorResults : EVA.Babylon.ActorSearchResultset; 
    ProductAutocompleteSuggestions : EVA.Core.SuggestionModel[]; 
  }
  
  export class FashionCollectionSearchResultset {
    Collections : EVA.Babylon.FashionCollectionSearchResult[]; 
    Page : number; // Int32
    PageSize : number; // Int32
    Total : number; // Int64
  }
  
  export class FashionCollectionSearchResult {
    ID : number; // Int32
    Name : string; 
    Description : string; 
    User : EVA.Babylon.FashionCollectionSearchResultCreator; 
    Supplier : EVA.Babylon.FashionCollectionSearchResultCreator; 
    TopProducts : EVA.Babylon.FashionCollectionSearchResultTopProduct[]; 
    CoverSheetBlobID : string; 
    SocialStats : EVA.Babylon.SocialStats; 
  }
  
  export class FashionCollectionSearchResultCreator {
    ID : number; // Int32
    Name : string; 
  }
  
  export class FashionCollectionSearchResultTopProduct {
    ProductID : number; // Int32
    DisplayValue : string; 
  }
  
  export class FashionProductSearchResultset {
    Products : any[]; 
  }
  
  export class ActorSearchResultset {
    Actors : EVA.Babylon.ActorSearchResult[]; 
    Page : number; // Int32
    PageSize : number; // Int32
    Total : number; // Int64
  }
  
  export class ActorSearchResult {
    ID : number; // Int32
    FirstName : string; 
    Nickname : string; 
    SupplierName : string; 
    Type : EVA.Babylon.ActorTypes; 
    AlreadyFollowing : boolean; 
    AlreadyBlocked : boolean; 
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
  }
  
  export enum ActorTypes {
    User = 0,
    Supplier = 1,
  }
  
  export class SearchFashionProducts extends EVA.Core.Services.SearchProducts {
    __response : EVA.Core.Services.SearchProductsResponse;
  }
  
  export class SocialUserSearch extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialUserSearchResponse> {
    Page : number; // Int32, nullable
    PageSize : number; // Int32, nullable
    Query : string; 
    __response : EVA.Babylon.SocialUserSearchResponse;
  }
  
  export class SocialUserSearchResponse extends EVA.Core.ResponseMessage {
    Results : EVA.Babylon.ActorSearchResultset; 
  }
  
  export class SocialSearchFriends extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SocialSearchFriendsResponse> {
    Page : number; // Int32, nullable
    PageSize : number; // Int32, nullable
    Query : string; 
    __response : EVA.Babylon.SocialSearchFriendsResponse;
  }
  
  export class SocialSearchFriendsResponse extends EVA.Core.ResponseMessage {
    Results : EVA.Babylon.ActorSearchResultset; 
  }
  
  export class BabylonPushNotificationTest extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    Title : string; 
    Body : string; 
    Data : any; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class BabylonSendPushNotificationBatch extends EVA.Core.RequestMessageWithEmptyResponse {
    Title : string; 
    Message : string; 
    UserIDs : number[]; 
    Payload : any; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetProductImagesForCoverSheet extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetProductImagesForCoverSheetResponse> {
    ProductID : number; // Int32
    __response : EVA.Babylon.GetProductImagesForCoverSheetResponse;
  }
  
  export class GetProductImagesForCoverSheetResponse extends EVA.Core.ResponseMessage {
    Images : EVA.Babylon.ProductCoverSheetImage[]; 
  }
  
  export class ProductCoverSheetImage {
    BlobID : string; 
    IsTransparent : boolean; 
    Name : string; 
    Sequence : number; // Int32
    Type : string; 
  }
  
  export class GetBabylonCsvImportTemplate extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetBabylonCsvImportTemplateResponse> {
    __response : EVA.Babylon.GetBabylonCsvImportTemplateResponse;
  }
  
  export class GetBabylonCsvImportTemplateResponse extends EVA.Core.ResponseMessage {
    Url : string; 
  }
  
  export class GetCsvImportStatus extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetCsvImportStatusResponse> {
    StatusID : string; 
    __response : EVA.Babylon.GetCsvImportStatusResponse;
  }
  
  export class GetCsvImportStatusResponse extends EVA.Core.ResponseMessage {
    StatusLabel : string; 
    RevisionID : number; // Int32
  }
  
  export class GetFashionProductCreator extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetFashionProductCreatorResponse> {
    ProductID : number; // Int32
    __response : EVA.Babylon.GetFashionProductCreatorResponse;
  }
  
  export class GetFashionProductCreatorResponse extends EVA.Core.ResponseMessage {
    UserID : number; // Int32, nullable
    UserName : string; 
    FirstName : string; 
    Nickname : string; 
    CreationTime : string; // DateTime
    AlreadyFollowing : boolean; 
    AlreadyBlocked : boolean; 
    Type : EVA.Babylon.ProductCreatorTypes; 
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
  }
  
  export enum ProductCreatorTypes {
    User = 1,
    Supplier = 2,
  }
  
  export class ImportProductsFromCsv extends EVA.Core.RequestMessageGeneric<EVA.Babylon.ImportProductsFromCsvResponse> {
    Data : number[]; 
    SupplierID : number; // Int32, nullable
    __response : EVA.Babylon.ImportProductsFromCsvResponse;
  }
  
  export class ImportProductsFromCsvResponse extends EVA.Core.ResponseMessage {
    Errors : EVA.Babylon.ImportProductsFromCsvError[]; 
    StatusID : string; 
  }
  
  export class ImportProductsFromCsvError {
    Row : number; // Int32
    Message : string; 
  }
  
  export class GetFashionProductCategories extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetFashionProductCategoriesResponse> {
    __response : EVA.Babylon.GetFashionProductCategoriesResponse;
  }
  
  export class GetFashionProductCategoriesResponse extends EVA.Core.ResponseMessage {
    Categories : EVA.Babylon.FashionProductCategoryDto[]; 
  }
  
  export class FashionProductCategoryDto {
    ID : number; // Int32
    ParentID : number; // Int32, nullable
    CategoryProductID : number; // Int32, nullable
    Key : string; 
    Level : number; // Int32
    Sequence : number; // Int32
    Name : string; 
    ProductCount : number; // Int64
    SubCategories : EVA.Babylon.FashionProductCategoryDto[]; 
  }
  
  export class ListBabylonStock extends EVA.Core.RequestMessageGeneric<EVA.Babylon.ListBabylonStockResponse> {
    ProductID : number; // Int32, nullable
    BackendID : string; 
    CustomID : string; 
    Query : string; 
    PageSize : number; // Int32, nullable
    Page : number; // Int32, nullable
    __response : EVA.Babylon.ListBabylonStockResponse;
  }
  
  export class ListBabylonStockResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Babylon.ListBabylonStockResponseModel[]; 
    Page : number; // Int32
    PageSize : number; // Int32
    Total : number; // Int64
  }
  
  export class ListBabylonStockResponseModel {
    ProductID : number; // Int32
    BackendID : string; 
    CustomID : string; 
    DisplayName : string; 
    Size : string; 
    PrimaryColor : string; 
    UnitCost : number; // Decimal
    UnitPriceInTax : number; // Decimal
    QuantityOnHand : number; // Int32
  }
  
  export class ListInvalidProducts extends EVA.Core.RequestMessageGeneric<EVA.Babylon.ListInvalidProductsResponse> {
    Page : number; // Int32
    PageSize : number; // Int32, nullable
    __response : EVA.Babylon.ListInvalidProductsResponse;
  }
  
  export class ListInvalidProductsResponse extends EVA.Core.ResponseMessage {
    ProductIDs : number[]; 
    Page : number; // Int32
    PageSize : number; // Int32
    Total : number; // Int64
  }
  
  export class ListRecentlyViewedProducts extends EVA.Core.PagedResultRequest<EVA.Babylon.ListRecentlyViewedProductsResponse> {
    __response : EVA.Babylon.ListRecentlyViewedProductsResponse;
  }
  
  export class ListRecentlyViewedProductsResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.RecentlyViewedProduct> {
  }
  
  export class RecentlyViewedProduct {
    Product : any; 
    ProductID : number; // Int32
    SocialStats : EVA.Babylon.SocialStats; 
  }
  
  export class UpdateBabylonStock extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    ProductID : number; // Int32
    QuantityAvailable : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateFashionBrand extends EVA.Core.RequestMessageGeneric<EVA.Babylon.CreateFashionBrandResponse> {
    Name : string; 
    __response : EVA.Babylon.CreateFashionBrandResponse;
  }
  
  export class CreateFashionBrandResponse extends EVA.Core.ResponseMessage {
    BrandID : number; // Int32
  }
  
  export class CreateFashionProduct extends EVA.Core.RequestMessageGeneric<EVA.Babylon.CreateFashionProductResponse> {
    Name : string; 
    ShortDescription : string; 
    LongDescription : string; 
    UnitPriceInTax : number; // Decimal, nullable
    Brand : string; 
    Images : string[]; 
    ExternalLink : string; 
    Tags : string[]; 
    DominantColors : string[]; 
    __response : EVA.Babylon.CreateFashionProductResponse;
  }
  
  export class CreateFashionProductResponse extends EVA.Core.ResponseMessage {
    ProductID : number; // Int32
  }
  
  export class UpdateFashionProduct extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    Name : string; 
    ShortDescription : string; 
    LongDescription : string; 
    UnitPriceInTax : number; // Decimal, nullable
    Brand : string; 
    Images : string[]; 
    ExternalLink : string; 
    Tags : string[]; 
    DominantColors : string[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteFashionProduct extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetFashionSupplierDataForOrder extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetFashionSupplierDataForOrderResponse> {
    OrderID : number; // Int32
    __response : EVA.Babylon.GetFashionSupplierDataForOrderResponse;
  }
  
  export class GetFashionSupplierDataForOrderResponse extends EVA.Core.ResponseMessage {
    SupplierData : EVA.Babylon.FashionSupplierDataDto[]; 
  }
  
  export class SetFashionCollectionOriginForOrderLine extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderLineID : number; // Int32
    CollectionID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class FashionPredictClothingColor extends EVA.Core.RequestMessageGeneric<EVA.Babylon.FashionPredictClothingColorResponse> {
    BlobID : string; 
    __response : EVA.Babylon.FashionPredictClothingColorResponse;
  }
  
  export class FashionPredictClothingColorResponse extends EVA.Core.ResponseMessage {
    Predictions : EVA.Babylon.ColorPrediction[]; 
  }
  
  export class ColorPrediction {
    Name : string; 
    Score : number; // Double
  }
  
  export enum TrendingFeedTypes {
    All = 0,
    Products = 1,
    Collections = 2,
  }
  
  export enum FeedTypes {
    Timeline = 0,
    Collections = 1,
    Discovery = 2,
    TrendingCollections = 3,
    Social = 4,
  }
  
  export class GetNotificationFeed extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetNotificationFeedResponse> {
    OffsetID : string; 
    Limit : number; // Int32, nullable
    __response : EVA.Babylon.GetNotificationFeedResponse;
  }
  
  export class GetNotificationFeedResponse extends EVA.Core.ResponseMessage {
    FeedItems : EVA.Babylon.FeedItem[]; 
    OffsetID : string; 
    UnseenCount : number; // Int32
  }
  
  export class FeedItem {
    ID : string; 
    Verb : string; 
    Object : EVA.Babylon.FeedItemObject; 
    Actor : EVA.Babylon.FeedItemActor; 
    Time : string; // DateTime, nullable
    Target : EVA.Babylon.FeedItemObject; 
    SocialStats : EVA.Babylon.FeedItemSocialStats; 
    Activity : EVA.Babylon.Activity; 
    Data : any; 
    Aggregation : EVA.Babylon.FeedItemAggregation; 
    Score : number; // Double, nullable
  }
  
  export class FeedItemObject {
    ID : string; 
    Type : string; 
    Data : any; 
    Object : EVA.Babylon.FeedObject; 
  }
  
  export class FeedObject {
    ObjectID : string; 
    ObjectType : string; 
    Value : string; 
  }
  
  export class FeedItemSocialStats {
    Likes : number; // Int32
    Comments : number; // Int32
    AlreadyLiked : boolean; 
    AlreadyClipped : boolean; 
    Views : number; // Int32
  }
  
  export class Activity {
    Data : any; 
    Id : string; 
    Actor : string; 
    Verb : string; 
    Object : string; 
    Target : string; 
    Time : string; // DateTime, nullable
    ForeignId : string; 
    To : string[]; 
    Score : number; // Double, nullable
  }
  
  export class FeedItemAggregation {
    ActorCount : number; // Int32
    CreatedAt : string; // DateTime, nullable
    FeedItems : EVA.Babylon.FeedItem[]; 
    Group : string; 
    UpdatedAt : string; // DateTime, nullable
    Actors : EVA.Babylon.ActorActivityGroup[]; 
  }
  
  export class ActorActivityGroup {
    Actor : EVA.Babylon.FeedItemActor; 
    Verb : string; 
    Time : string; // DateTime, nullable
  }
  
  export class GetUnseenNotificationCount extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetUnseenNotificationCountResponse> {
    __response : EVA.Babylon.GetUnseenNotificationCountResponse;
  }
  
  export class GetUnseenNotificationCountResponse extends EVA.Core.ResponseMessage {
    UnseenCount : number; // Int32
  }
  
  export class GetSocialFeed extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetSocialFeedResponse> {
    OffsetID : string; 
    Limit : number; // Int32, nullable
    __response : EVA.Babylon.GetSocialFeedResponse;
  }
  
  export class GetSocialFeedResponse extends EVA.Core.ResponseMessage {
    FeedItems : EVA.Babylon.FeedItem[]; 
    OffsetID : string; 
  }
  
  export class GetTrendingFeed extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetTrendingFeedResponse> {
    ScoreOffset : number; // Double, nullable
    Limit : number; // Int32, nullable
    Type : EVA.Babylon.TrendingFeedTypes; 
    __response : EVA.Babylon.GetTrendingFeedResponse;
  }
  
  export class GetTrendingFeedResponse extends EVA.Core.ResponseMessage {
    FeedItems : EVA.Babylon.FeedItem[]; 
    ScoreOffset : number; // Double
  }
  
  export class GetUserFeed extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetUserFeedResponse> {
    OffsetID : string; 
    Limit : number; // Int32, nullable
    FeedType : EVA.Babylon.FeedTypes; 
    __response : EVA.Babylon.GetUserFeedResponse;
  }
  
  export class GetUserFeedResponse extends EVA.Core.ResponseMessage {
    FeedItems : EVA.Babylon.FeedItem[]; 
    OffsetID : string; 
  }
  
  export enum FashionCoinsTypes {
    Silver = 0,
    Gold = 1,
  }
  
  export class ConvertFashionCoins extends EVA.Core.RequestMessageGeneric<EVA.Babylon.ConvertFashionCoinsResponse> {
    Amount : number; // Decimal
    Direction : EVA.Babylon.FashionCoinConversionDirection; 
    __response : EVA.Babylon.ConvertFashionCoinsResponse;
  }
  
  export class ConvertFashionCoinsResponse extends EVA.Core.ResponseMessage {
    ConvertedAmount : number; // Decimal
  }
  
  export enum FashionCoinConversionDirection {
    CurrencyToFashionCoins = 0,
    FashionCoinsToCurrency = 1,
  }
  
  export class GetFashionCoinTotalsForUser extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetFashionCoinTotalsForUserResponse> {
    __response : EVA.Babylon.GetFashionCoinTotalsForUserResponse;
  }
  
  export class GetFashionCoinTotalsForUserResponse extends EVA.Core.ResponseMessage {
    SilverFashionCoinsTotal : number; // Int32
    GoldFashionCoinsTotal : number; // Int32
  }
  
  export class ListFashionCoinTransactions extends EVA.Core.PagedResultRequest<EVA.Babylon.ListFashionCoinTransactionsResponse> {
    __response : EVA.Babylon.ListFashionCoinTransactionsResponse;
  }
  
  export class ListFashionCoinTransactionsResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.FashionCoinTransaction> {
  }
  
  export class FashionCoinTransaction {
    CreationTime : string; // DateTime
    Amount : number; // Decimal
    Description : string; 
    Status : EVA.Core.UserCardMutationStatuses; 
    StartDate : string; // DateTime, nullable
    FashionCoinType : EVA.Babylon.FashionCoinsTypes; 
  }
  
  export class UploadFashionCoinRewards extends EVA.Core.RequestMessageWithEmptyResponse {
    Data : number[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetActiveFashionEvent extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetActiveFashionEventResponse> {
    __response : EVA.Babylon.GetActiveFashionEventResponse;
  }
  
  export class GetActiveFashionEventResponse extends EVA.Core.ResponseMessage {
    ActiveEvent : EVA.Babylon.FashionEventDto; 
  }
  
  export class FashionEventDto {
    ID : number; // Int32
    Name : string; 
    Description : string; 
  }
  
  export class GetBarcodeDataForFashionEvent extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetBarcodeDataForFashionEventResponse> {
    __response : EVA.Babylon.GetBarcodeDataForFashionEventResponse;
  }
  
  export class GetBarcodeDataForFashionEventResponse extends EVA.Core.ResponseMessage {
    Data : string; 
  }
  
  export class ScanBarcodeForFashionEvent extends EVA.Core.RequestMessageGeneric<EVA.Babylon.ScanBarcodeForFashionEventResponse> {
    Data : string; 
    __response : EVA.Babylon.ScanBarcodeForFashionEventResponse;
  }
  
  export class ScanBarcodeForFashionEventResponse extends EVA.Core.ResponseMessage {
    Success : boolean; 
  }
  
  export class ExtractUrlInformation extends EVA.Core.RequestMessageGeneric<EVA.Babylon.ExtractUrlInformationResponse> {
    Url : string; 
    __response : EVA.Babylon.ExtractUrlInformationResponse;
  }
  
  export class ExtractUrlInformationResponse extends EVA.Core.ResponseMessage {
    Success : boolean; 
    Data : EVA.Babylon.ExtractedUrlInformation; 
  }
  
  export class ExtractedUrlInformation {
    Description : string; 
    Title : string; 
    Safe : boolean; 
    Images : EVA.Babylon.ExtractedUrlInformationImage[]; 
    Keywords : EVA.Babylon.ExtractedUrlInformationKeyword[]; 
  }
  
  export class ExtractedUrlInformationImage {
    Caption : string; 
    Url : string; 
    Height : number; // Int32
    Width : number; // Int32
  }
  
  export class ExtractedUrlInformationKeyword {
    Name : string; 
  }
  
  export class GetCoverSheetEditorCapabilities extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetCoverSheetEditorCapabilitiesResponse> {
    __response : EVA.Babylon.GetCoverSheetEditorCapabilitiesResponse;
  }
  
  export class GetCoverSheetEditorCapabilitiesResponse extends EVA.Core.ResponseMessage {
    Capabilities : EVA.Babylon.CoverSheetCapability[]; 
  }
  
  export class CoverSheetCapability {
    Name : string; 
    Description : string; 
    Capability : string; 
    BlobID : string; 
    IsAvailable : boolean; 
    RequiredLevel : number; // Int32, nullable
  }
  
  export class GetFashionCollectionCoverSheet extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetFashionCollectionCoverSheetResponse> {
    CollectionID : number; // Int32
    __response : EVA.Babylon.GetFashionCollectionCoverSheetResponse;
  }
  
  export class GetFashionCollectionCoverSheetResponse extends EVA.Core.ResponseMessage {
    CoverSheet : EVA.Babylon.CoverSheetDocument; 
  }
  
  export class CoverSheetDocument {
    Items : EVA.Babylon.CoverSheetItem[]; 
    BackgroundBlobID : string; 
  }
  
  export class CoverSheetItem {
    IsActive : boolean; 
    Left : number; // Double, nullable
    Top : number; // Double, nullable
    ScaleX : number; // Double, nullable
    ScaleY : number; // Double, nullable
    Width : number; // Double, nullable
    Height : number; // Double, nullable
    RotationAngle : number; // Double, nullable
    BlobID : string; 
    ProductID : number; // Int32, nullable
    Type : string; 
    Text : string; 
  }
  
  export class GetImageCutoutSuggestions extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetImageCutoutSuggestionsResponse> {
    BlobID : string; 
    __response : EVA.Babylon.GetImageCutoutSuggestionsResponse;
  }
  
  export class GetImageCutoutSuggestionsResponse extends EVA.Core.ResponseMessage {
    Suggestions : EVA.Babylon.ImageCutoutSuggestion[]; 
  }
  
  export class ImageCutoutSuggestion {
    BlobID : string; 
    ExpiresOn : string; // DateTime
  }
  
  export class SaveFashionCollectionCoverSheet extends EVA.Core.RequestMessageWithEmptyResponse {
    CollectionID : number; // Int32
    CoverSheet : EVA.Babylon.CoverSheetDocument; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export enum FashionCollectionSearchModelSortOptions {
    Newest = 0,
    Popular = 1,
  }
  
  export class GetActiveFashionCollectionContests extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetActiveFashionCollectionContestsResponse> {
    __response : EVA.Babylon.GetActiveFashionCollectionContestsResponse;
  }
  
  export class GetActiveFashionCollectionContestsResponse extends EVA.Core.ResponseMessage {
    Contests : EVA.Babylon.FashionCollectionContestDto[]; 
  }
  
  export class FashionCollectionContestDto {
    Name : string; 
    Description : string; 
    StartDate : string; // DateTime
    EndDate : string; // DateTime
    WinningUserID : number; // Int32, nullable
    ImageBlobID : string; 
    ID : number; // Int32
  }
  
  export class GetFashionCoinEarningsForCollections extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetFashionCoinEarningsForCollectionsResponse> {
    __response : EVA.Babylon.GetFashionCoinEarningsForCollectionsResponse;
  }
  
  export class GetFashionCoinEarningsForCollectionsResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Babylon.FashionCollectionSummaryWithEarnings[]; 
  }
  
  export class FashionCollectionSummaryWithEarnings {
    ID : number; // Int32
    ContestID : number; // Int32, nullable
    Name : string; 
    Description : string; 
    TopProductIDs : number[]; 
    CoverSheetBlobID : string; 
    PreviewCoverSheetBlobID : string; 
    CreationTime : string; // DateTime
    ProductCount : number; // Int32
    FashionCoinsEarned : number; // Int32
    SocialStats : EVA.Babylon.SocialStats; 
  }
  
  export class GetFashionCollectionStatsOverTime extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetFashionCollectionStatsOverTimeResponse> {
    CollectionID : number; // Int32
    Granularity : EVA.Babylon.CollectionStatsGranularity; 
    __response : EVA.Babylon.GetFashionCollectionStatsOverTimeResponse;
  }
  
  export class GetFashionCollectionStatsOverTimeResponse extends EVA.Core.ResponseMessage {
    Stats : EVA.Babylon.CollectionStatsItem[]; 
  }
  
  export class CollectionStatsItem {
    DateTime : string; // DateTime
    Likes : number; // Int32
  }
  
  export enum CollectionStatsGranularity {
    Hour = 0,
    Day = 1,
    Week = 2,
  }
  
  export class GetTopFashionCollections extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetTopFashionCollectionsResponse> {
    TopCount : number; // Int32
    UserID : number; // Int32, nullable
    CreationTime : string; // DateTime, nullable
    __response : EVA.Babylon.GetTopFashionCollectionsResponse;
  }
  
  export class GetTopFashionCollectionsResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Babylon.FashionCollectionSummary[]; 
  }
  
  export class FashionCollectionSummary {
    ID : number; // Int32
    ContestID : number; // Int32, nullable
    Name : string; 
    Description : string; 
    TopProductIDs : number[]; 
    CoverSheetBlobID : string; 
    PreviewCoverSheetBlobID : string; 
    User : EVA.Babylon.FashionCollectionSummaryCreator; 
    SocialStats : EVA.Babylon.SocialStats; 
    CreationTime : string; // DateTime
    ProductCount : number; // Int32
    Tags : string[]; 
  }
  
  export class FashionCollectionSummaryCreator {
    ID : number; // Int32
    Name : string; 
    FirstName : string; 
    Nickname : string; 
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
  }
  
  export class ListFashionCollectionContests extends EVA.Core.PagedResultRequest<EVA.Babylon.ListFashionCollectionContestsResponse> {
    __response : EVA.Babylon.ListFashionCollectionContestsResponse;
  }
  
  export class ListFashionCollectionContestsResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.FashionCollectionContestDto> {
  }
  
  export class ListFashionCollectionsForContest extends EVA.Core.PagedResultRequest<EVA.Babylon.ListFashionCollectionsForContestResponse> {
    ContestID : number; // Int32
    __response : EVA.Babylon.ListFashionCollectionsForContestResponse;
  }
  
  export class ListFashionCollectionsForContestResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.FashionCollectionSummary> {
  }
  
  export class ListTrendingFashionCollections extends EVA.Core.RequestMessageGeneric<EVA.Babylon.ListTrendingFashionCollectionsResponse> {
    PageConfig : EVA.Core.PageConfig; 
    __response : EVA.Babylon.ListTrendingFashionCollectionsResponse;
  }
  
  export class ListTrendingFashionCollectionsResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.FashionCollectionSummary> {
  }
  
  export class ListProductsForCollection extends EVA.Core.PagedResultRequest<EVA.Babylon.ListProductsForCollectionResponse> {
    CollectionID : number; // Int32
    __response : EVA.Babylon.ListProductsForCollectionResponse;
  }
  
  export class ListProductsForCollectionResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.FashionCollectionProductDetails> {
  }
  
  export class FashionCollectionProductDetails {
    Product : any; 
    ProductID : number; // Int32
    SocialStats : EVA.Babylon.SocialStats; 
  }
  
  export class SearchFashionCollections extends EVA.Core.RequestMessageGeneric<EVA.Babylon.SearchFashionCollectionsResponse> {
    Query : string; 
    PageSize : number; // Int32, nullable
    Page : number; // Int32, nullable
    SupplierName : string; 
    SortOptions : EVA.Babylon.FashionCollectionSearchModelSortOptions; 
    __response : EVA.Babylon.SearchFashionCollectionsResponse;
  }
  
  export class SearchFashionCollectionsResponse extends EVA.Core.ResponseMessage {
    Page : number; // Int32
    PageSize : number; // Int32
    Total : number; // Int64
    Collections : EVA.Babylon.FashionCollectionSearchResult[]; 
  }
  
  export class CreateFashionCollection extends EVA.Core.RequestMessageGeneric<EVA.Babylon.CreateFashionCollectionResponse> {
    Collection : EVA.Babylon.CreateFashionCollectionRequestModel; 
    __response : EVA.Babylon.CreateFashionCollectionResponse;
  }
  
  export class CreateFashionCollectionResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class CreateFashionCollectionRequestModel {
    Description : string; 
    Name : string; 
    ProductIDs : number[]; 
    Tags : string[]; 
    ContestID : number; // Int32, nullable
    TargetAudience : string; 
  }
  
  export class GetFashionCollectionDetailsByID extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetFashionCollectionDetailsByIdResponse> {
    CollectionID : number; // Int32
    __response : EVA.Babylon.GetFashionCollectionDetailsByIdResponse;
  }
  
  export class GetFashionCollectionDetailsByIdResponse extends EVA.Core.ResponseMessage {
    Collection : EVA.Babylon.FashionCollectionDetail; 
  }
  
  export class FashionCollectionDetail {
    ID : number; // Int32
    ContestID : number; // Int32, nullable
    Name : string; 
    Description : string; 
    TopProductIDs : number[]; 
    CoverSheetBlobID : string; 
    PreviewCoverSheetBlobID : string; 
    User : EVA.Babylon.FashionCollectionDetailCreator; 
    Supplier : EVA.Babylon.FashionCollectionDetailCreator; 
    SocialStats : EVA.Babylon.SocialStats; 
    CreationTime : string; // DateTime
    ProductCount : number; // Int32
    Tags : string[]; 
  }
  
  export class FashionCollectionDetailCreator {
    ID : number; // Int32
    Name : string; 
    FirstName : string; 
    Nickname : string; 
    AlreadyFollowing : boolean; 
    CombinedCurrentLevel : number; // Int32, nullable
    CurrentLevel : number; // Int32, nullable
    CurrentPrestigeLevel : number; // Int32, nullable
  }
  
  export class AddProductsToFashionCollection extends EVA.Core.RequestMessageWithEmptyResponse {
    CollectionID : number; // Int32
    ProductIDs : number[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteProductFromFashionCollection extends EVA.Core.RequestMessageWithEmptyResponse {
    CollectionID : number; // Int32
    ProductID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteFashionCollection extends EVA.Core.RequestMessageWithEmptyResponse {
    CollectionID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListFashionCollectionsForUser extends EVA.Core.RequestMessageGeneric<EVA.Babylon.ListFashionCollectionsForUserResponse> {
    PageConfig : EVA.Core.PageConfig; 
    UserID : number; // Int32
    FilterCoverSheetExists : boolean; 
    __response : EVA.Babylon.ListFashionCollectionsForUserResponse;
  }
  
  export class ListFashionCollectionsForUserResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.FashionCollectionSummary> {
  }
  
  export class ListFashionCollectionsForProduct extends EVA.Core.RequestMessageGeneric<EVA.Babylon.ListFashionCollectionsForProductResponse> {
    PageConfig : EVA.Core.PageConfig; 
    ProductID : number; // Int32
    UserID : number; // Int32, nullable
    __response : EVA.Babylon.ListFashionCollectionsForProductResponse;
  }
  
  export class ListFashionCollectionsForProductResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.FashionCollectionSummary> {
  }
  
  export class UpdateFashionCollection extends EVA.Core.RequestMessageWithEmptyResponse {
    CollectionID : number; // Int32
    Name : string; 
    Description : string; 
    CoverSheetBlobID : string; 
    Tags : string[]; 
    PropertiesToDelete : string[]; 
    ContestID : number; // Int32, nullable
    TargetAudience : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetFashionCollectionProductDetails extends EVA.Core.RequestMessageGeneric<EVA.Babylon.GetFashionCollectionProductDetailsResponse> {
    CollectionID : number; // Int32
    ProductID : number; // Int32
    __response : EVA.Babylon.GetFashionCollectionProductDetailsResponse;
  }
  
  export class GetFashionCollectionProductDetailsResponse extends EVA.Core.ResponseMessage {
    CollectionProduct : EVA.Babylon.FashionCollectionProductDetail; 
  }
  
  export class FashionCollectionProductDetail {
    CollectionID : number; // Int32
    ProductID : number; // Int32
    Sequence : number; // Int32
    CreationTime : string; // DateTime
  }
  
  export class UpdateFashionCollectionProductSequence extends EVA.Core.RequestMessageWithEmptyResponse {
    CollectionID : number; // Int32
    ProductID : number; // Int32
    Sequence : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CountFashionCollectionsForProduct extends EVA.Core.RequestMessageGeneric<EVA.Babylon.CountFashionCollectionsForProductResponse> {
    ProductID : number; // Int32
    __response : EVA.Babylon.CountFashionCollectionsForProductResponse;
  }
  
  export class CountFashionCollectionsForProductResponse extends EVA.Core.ResponseMessage {
    CollectionCount : number; // Int32
  }
  
  export enum ChannableOrderLineTypes {
    Product = 0,
    ShippingCosts = 1,
  }
  
  export class ListOpenChannableOrdersForSupplier extends EVA.Core.PagedResultRequest<EVA.Babylon.ListOpenChannableOrdersForSupplierResponse> {
    SupplierID : number; // Int32
    __response : EVA.Babylon.ListOpenChannableOrdersForSupplierResponse;
  }
  
  export class ListOpenChannableOrdersForSupplierResponse extends EVA.Core.PagedResultResponse<EVA.Babylon.ChannableOrder> {
  }
  
  export class ChannableOrder {
    OrderID : number; // Int32
    ShippingAddress : EVA.Babylon.ChannableOrderAddress; 
    BillingAddress : EVA.Babylon.ChannableOrderAddress; 
    Customer : EVA.Babylon.ChannableOrderCustomer; 
    Lines : EVA.Babylon.ChannableOrderLine[]; 
    Payments : EVA.Babylon.ChannableOrderPayment[]; 
    Amounts : EVA.Babylon.ChannableOrderAmounts; 
  }
  
  export class ChannableOrderAddress {
    Street : string; 
    HouseNumber : string; 
    HouseNumberExtension : string; 
    CountryCode : string; 
    ZipCode : string; 
    City : string; 
    Region : string; 
  }
  
  export class ChannableOrderCustomer {
    EmailAddress : string; 
    Gender : string; 
    PhoneNumber : string; 
    FirstName : string; 
    LastName : string; 
  }
  
  export class ChannableOrderLine {
    Description : string; 
    OrderLineID : number; // Int32
    UnitPrice : number; // Decimal
    TaxRate : number; // Decimal
    UnitPriceInTax : number; // Decimal
    QuantityOrdered : number; // Int32
    EAN : string; 
    ProductID : string; 
    Type : string; 
  }
  
  export class ChannableOrderPayment {
    Currency : string; 
    PaymentMethod : string; 
    PaidAmount : number; // Decimal
  }
  
  export class ChannableOrderAmounts {
    TotalAmount : number; // Decimal
    TotalAmountInTax : number; // Decimal
    PaidAmount : number; // Decimal
    Taxes : EVA.Core.TaxAmount[]; 
  }
  
  export enum BIActivityLedgerTypes {
    None = 0,
    Like = 1,
    Follow = 2,
    View = 3,
    Comment = 4,
  }
  
}
/* tslint:disable */
declare module EVA.Blobs {
  
  export class CreateBlob extends EVA.Core.RequestMessageGeneric<EVA.Blobs.CreateBlobResponse> {
    Category : string; 
    OriginalName : string; 
    MimeType : string; 
    LifeTime : any; // TimeSpan, nullable
    __response : EVA.Blobs.CreateBlobResponse;
  }
  
  export class CreateBlobResponse extends EVA.Core.ResponseMessage {
    Guid : string; 
    Url : string; 
  }
  
  export class DeleteBlob extends EVA.Core.RequestMessageWithEmptyResponse {
    BlobID : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetBlobInfo extends EVA.Core.RequestMessageGeneric<EVA.Blobs.GetBlobInfoResponse> {
    Guid : string; 
    Category : string; 
    OriginalName : string; 
    __response : EVA.Blobs.GetBlobInfoResponse;
  }
  
  export class GetBlobInfoResponse extends EVA.Core.ResponseMessage {
    Guid : string; 
    MimeType : string; 
    OriginalName : string; 
    Category : string; 
    ExpireDate : string; // DateTime, nullable
    LastModificationTimeUtc : string; // DateTime
    Size : number; // Int64
    Url : string; 
  }
  
  export class GetProductImagePlaceholder extends EVA.Core.RequestMessageGeneric<EVA.Blobs.GetPlaceholderResponse> {
    __response : EVA.Blobs.GetPlaceholderResponse;
  }
  
  export class GetPlaceholderResponse extends EVA.Core.ResponseMessage {
    Guid : string; 
    Url : string; 
  }
  
  export class GetBrandImagePlaceholder extends EVA.Core.RequestMessageGeneric<EVA.Blobs.GetPlaceholderResponse> {
    __response : EVA.Blobs.GetPlaceholderResponse;
  }
  
  export class GetApplicationImagePlaceholder extends EVA.Core.RequestMessageGeneric<EVA.Blobs.GetPlaceholderResponse> {
    __response : EVA.Blobs.GetPlaceholderResponse;
  }
  
  export class ListBlobs extends EVA.Core.PagedResultRequest<EVA.Blobs.ListBlobsResponse> {
    __response : EVA.Blobs.ListBlobsResponse;
  }
  
  export class ListBlobsResponse extends EVA.Core.PagedResultResponse<EVA.Blobs.BlobDto> {
  }
  
  export class BlobDto {
    ID : string; 
    OriginalName : string; 
    MimeType : string; 
    Category : string; 
    ExpireDate : string; // DateTime, nullable
    LocationType : string; 
    Url : string; 
  }
  
  export class ProcessDocument extends EVA.Core.RequestMessageGeneric<EVA.Blobs.ProcessDocumentResponse> {
    Data : number[]; 
    Type : string; 
    __response : EVA.Blobs.ProcessDocumentResponse;
  }
  
  export class ProcessDocumentResponse extends EVA.Core.ResponseMessage {
    ProcessedData : number[]; 
    ExtractedText : { [ key : string ] : any }; 
    Success : boolean; 
  }
  
  export class SetProductImagePlaceholder extends EVA.Core.RequestMessageGeneric<EVA.Blobs.SetPlaceholderResponse> {
    MimeType : string; 
    Data : number[]; 
    __response : EVA.Blobs.SetPlaceholderResponse;
  }
  
  export class SetPlaceholderResponse extends EVA.Core.ResponseMessage {
    Guid : string; 
    Url : string; 
  }
  
  export class SetBrandImagePlaceholder extends EVA.Core.RequestMessageGeneric<EVA.Blobs.SetPlaceholderResponse> {
    MimeType : string; 
    Data : number[]; 
    __response : EVA.Blobs.SetPlaceholderResponse;
  }
  
  export class SetApplicationImagePlaceholder extends EVA.Core.RequestMessageGeneric<EVA.Blobs.SetPlaceholderResponse> {
    MimeType : string; 
    Data : number[]; 
    __response : EVA.Blobs.SetPlaceholderResponse;
  }
  
  export class StoreBlob extends EVA.Core.RequestMessageGeneric<EVA.Blobs.StoreBlobResponse> {
    Category : string; 
    OriginalName : string; 
    MimeType : string; 
    Data : number[]; 
    LifeTime : any; // TimeSpan, nullable
    __response : EVA.Blobs.StoreBlobResponse;
  }
  
  export class StoreBlobResponse extends EVA.Core.ResponseMessage {
    Guid : string; 
    Url : string; 
  }
  
}
/* tslint:disable */
declare module EVA.Bluetrace {
  
  export enum BluetraceType {
    None = 0,
    Inside = 1,
    Outside = 2,
  }
  
}
/* tslint:disable */
declare module EVA.BuildersAndPerformers {
  
  export class BPSendInvoice extends EVA.Core.RequestMessageWithEmptyResponse {
    Sender : string; 
    Invoicee : string; 
    InvoiceNumber : string; 
    InvoiceDate : string; // DateTime
    CurrencyCode : string; 
    Discounts : EVA.BuildersAndPerformers.BPSendInvoiceAdditionalCost[]; 
    Charges : EVA.BuildersAndPerformers.BPSendInvoiceAdditionalCost[]; 
    Lines : EVA.BuildersAndPerformers.BPSendInvoiceInvoiceLine[]; 
    Totals : EVA.Core.InvoiceTotalsModel; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class BPSendInvoiceAdditionalCost {
    Amount : number; // Decimal
    IsDutyFree : boolean; 
  }
  
  export class BPSendInvoiceInvoiceLine {
    Reference : string; 
    BackendID : string; 
    DeliveredQuantity : number; // Int32
    InvoicedQuantity : number; // Int32
    UnitPrice : number; // Decimal
    TaxRate : number; // Decimal
    UnitPriceInTax : number; // Decimal
    Discounts : EVA.BuildersAndPerformers.BPSendInvoiceAdditionalCost[]; 
    Charges : EVA.BuildersAndPerformers.BPSendInvoiceAdditionalCost[]; 
  }
  
  export class BPSendOrderConfirmation extends EVA.Core.RequestMessageWithEmptyResponse {
    Sender : string; 
    Reference : string; 
    OrderDate : string; // DateTime
    CurrencyCode : string; 
    Lines : EVA.BuildersAndPerformers.BPSendOrderConfirmationOrderConfirmationLine[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class BPSendOrderConfirmationOrderConfirmationLine {
    BackendID : string; 
    DeliveryDate : string; // DateTime
    UnitPrice : number; // Decimal
    UnitPriceInTax : number; // Decimal
    TotalAmount : number; // Decimal
    OrderedQuantity : number; // Int32
    BackOrderQuantity : number; // Int32
    CancelledQuantity : number; // Int32
    DeliveredQuantity : number; // Int32
  }
  
  export class BPSendProducts extends EVA.Core.RequestMessageWithEmptyResponse {
    Sender : string; 
    CatalogDate : string; // DateTime
    Products : EVA.BuildersAndPerformers.BPSendProductsCatalogProduct[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class BPSendProductsCatalogProduct {
    BackendID : string; 
    Barcode : string; 
    Brand : string; 
    Description : string; 
    PurchasePrice : number; // Decimal
    CurrencyCode : string; 
  }
  
  export class BPSendShipmentConfirmation extends EVA.Core.RequestMessageWithEmptyResponse {
    Sender : string; 
    Reference : string; 
    OrderDate : string; // DateTime
    ShipmentDate : string; // DateTime
    CurrencyCode : string; 
    Carrier : EVA.BuildersAndPerformers.BPSendShipmentConfirmationOrderShipmentCarrier; 
    Shipments : EVA.BuildersAndPerformers.BPSendShipmentConfirmationOrderShipment[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class BPSendShipmentConfirmationOrderShipmentCarrier {
    ID : string; 
    Name : string; 
  }
  
  export class BPSendShipmentConfirmationOrderShipment {
    Tracking : EVA.BuildersAndPerformers.BPSendShipmentConfirmationOrderShipmentTracking; 
    Lines : EVA.BuildersAndPerformers.BPSendShipmentConfirmationOrderShipmentLine[]; 
  }
  
  export class BPSendShipmentConfirmationOrderShipmentTracking {
    ID : string; 
    Link : string; 
  }
  
  export class BPSendShipmentConfirmationOrderShipmentLine {
    BackendID : string; 
    Barcode : string; 
    OrderedQuantity : number; // Int32
    DeliveredQuantity : number; // Int32
  }
  
  export class BPSendStockUpdate extends EVA.Core.RequestMessageWithEmptyResponse {
    Sender : string; 
    InventoryDate : string; // DateTime
    Products : EVA.BuildersAndPerformers.BPSendStockUpdateStockUpdateEntry[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class BPSendStockUpdateStockUpdateEntry {
    BackendID : string; 
    QuantityOnHand : number; // Int32
  }
  
}
/* tslint:disable */
declare module EVA.CMS {
  
  export class GetSiteMap extends EVA.Core.RequestMessageGeneric<EVA.CMS.GetSiteMapResponse> {
    __response : EVA.CMS.GetSiteMapResponse;
  }
  
  export class GetSiteMapResponse extends EVA.Core.GetResponse<EVA.CMS.CmsSiteMapNode[]> {
    CmsEntityTypes : EVA.CMS.CmsEntityTypeDto[]; 
    CmsWidgetTypes : EVA.CMS.CmsWidgetTypeDto[]; 
  }
  
  export class CmsSiteMapNode {
    CmsPageID : number; // Int32, nullable
    Title : string; 
    IsActive : boolean; 
    Children : EVA.CMS.CmsSiteMapNode[]; 
    PageTypeID : number; // Int32
    RequestPath : string; 
  }
  
  export class CmsEntityTypeDto extends EVA.Core.EnumDtoBase {
  }
  
  export class CmsWidgetTypeDto extends EVA.Core.EnumDtoBase {
  }
  
  export class CreateCmsWidget extends EVA.Core.CreateRequest<EVA.CMS.CmsWidgetDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }
  
  export class CmsWidgetDto {
    ID : number; // Int32
    ParentID : number; // Int32, nullable
    Parent : EVA.CMS.CmsWidgetDto; 
    CmsEntityID : number; // Int32
    CmsEntity : EVA.CMS.CmsEntityDto; 
    TypeID : number; // Int32
    Type : EVA.CMS.CmsWidgetTypeDto; 
    Identifier : string; 
    StartDate : string; // DateTime, nullable
    EndDate : string; // DateTime, nullable
    Data : string; 
    IsActive : boolean; 
    Children : EVA.CMS.CmsWidgetDto[]; 
  }
  
  export class CmsEntityDto {
    ID : number; // Int32
    Title : string; 
    BrowserTitle : string; 
    TitleOverride : boolean; 
    MetaDescription : string; 
    RequestPath : string; 
    Background : string; 
    TypeID : number; // Int32
    Type : EVA.CMS.CmsEntityTypeDto; 
    ParentID : number; // Int32, nullable
    Parent : EVA.CMS.CmsEntityDto; 
    Children : EVA.CMS.CmsEntityDto[]; 
    Views : EVA.CMS.CmsWidgetDto[]; 
    Position : number; // Int32
    IsActive : boolean; 
  }
  
  export class UpdateCmsWidget extends EVA.Core.UpdateRequest<EVA.CMS.CmsWidgetDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteCmsWidget extends EVA.Core.DeleteRequest implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetCmsWidgetByID extends EVA.Core.GetRequestGeneric<EVA.CMS.GetCmsWidgetByIDResponse> {
    __response : EVA.CMS.GetCmsWidgetByIDResponse;
  }
  
  export class GetCmsWidgetByIDResponse extends EVA.Core.GetResponse<EVA.CMS.CmsWidgetDto> {
  }
  
  export class CreateUrlRewrite extends EVA.Core.CreateRequest<EVA.CMS.CmsUrlRewriteDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }
  
  export class CmsUrlRewriteDto {
    ID : number; // Int32
    RequestPath : string; 
    TargetPath : string; 
    UrlRewriteType : EVA.CMS.CmsUrlRewriteTypes; 
    Description : string; 
    IsActive : boolean; 
    IsRegex : boolean; 
  }
  
  export enum CmsUrlRewriteTypes {
    MovedPermanently = 301,
    MovedTemporarily = 302,
    TemporaryRedirect = 307,
    PermanentRedirect = 308,
    Gone = 410,
    Silent = 999,
  }
  
  export class DeleteUrlRewrite extends EVA.Core.DeleteRequest implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetUrlRewriteByID extends EVA.Core.RequestMessageGeneric<EVA.CMS.GetUrlRewriteByIDResponse> {
    ID : number; // Int32
    __response : EVA.CMS.GetUrlRewriteByIDResponse;
  }
  
  export class GetUrlRewriteByIDResponse extends EVA.Core.ResponseMessage {
    Rewrite : EVA.CMS.CmsUrlRewriteDto; 
  }
  
  export class GetUrlRewrites extends EVA.Core.RequestMessageGeneric<EVA.CMS.GetUrlRewritesResponse> {
    __response : EVA.CMS.GetUrlRewritesResponse;
  }
  
  export class GetUrlRewritesResponse extends EVA.Core.ResponseMessage {
    Rewrites : EVA.CMS.CmsUrlRewriteDto[]; 
  }
  
  export class ListUrlRewrites extends EVA.Core.PagedResultRequest<EVA.CMS.ListUrlRewritesResponse> {
    __response : EVA.CMS.ListUrlRewritesResponse;
  }
  
  export class ListUrlRewritesResponse extends EVA.Core.PagedResultResponse<EVA.CMS.CmsUrlRewriteDto> {
  }
  
  export class RewriteUrl extends EVA.Core.RequestMessageGeneric<EVA.CMS.RewriteUrlResponse> {
    Url : string; 
    __response : EVA.CMS.RewriteUrlResponse;
  }
  
  export class RewriteUrlResponse extends EVA.Core.ResponseMessage {
    Url : string; 
  }
  
  export class UpdateUrlRewrite extends EVA.Core.UpdateRequest<EVA.CMS.CmsUrlRewriteDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetCmsPageByRequestPath extends EVA.Core.RequestMessageGeneric<EVA.CMS.GetCmsPageByRequestPathResponse> {
    Path : string; 
    __response : EVA.CMS.GetCmsPageByRequestPathResponse;
  }
  
  export class GetCmsPageByRequestPathResponse extends EVA.Core.GetResponse<EVA.CMS.CmsPageDto> {
  }
  
  export class CmsPageDto {
    ID : number; // Int32
    Title : string; 
    BrowserTitle : string; 
    TitleOverride : boolean; 
    MetaDescription : string; 
    RequestPath : string; 
    Background : string; 
    TypeID : number; // Int32
    Type : EVA.CMS.CmsEntityTypeDto; 
    DisplayTypeID : number; // Int32
    DisplayType : EVA.CMS.CmsWidgetTypeDto; 
    ParentID : number; // Int32, nullable
    Parent : EVA.CMS.CmsPageDto; 
    Children : EVA.CMS.CmsPageDto[]; 
    Data : string; 
    DisplayData : any; 
    Widgets : EVA.CMS.CmsPageWidgetDto[]; 
    Position : number; // Int32
  }
  
  export class CmsPageWidgetDto {
    ID : number; // Int32
    ParentID : number; // Int32, nullable
    Parent : EVA.CMS.CmsPageWidgetDto; 
    Children : EVA.CMS.CmsPageWidgetDto[]; 
    TypeID : number; // Int32
    Type : EVA.CMS.CmsWidgetTypeDto; 
    Identifier : string; 
    Data : string; 
    DisplayData : any; 
  }
  
  export class GetCmsPagesByRequestPath extends EVA.Core.RequestMessageGeneric<EVA.CMS.GetCmsPagesByRequestPathResponse> {
    Path : string; 
    __response : EVA.CMS.GetCmsPagesByRequestPathResponse;
  }
  
  export class GetCmsPagesByRequestPathResponse extends EVA.Core.ResponseMessage {
    Pages : { [ key : string ] : string }; 
  }
  
  export class GetCmsPage extends EVA.Core.GetRequestGeneric<EVA.CMS.GetCmsPageResponse> {
    __response : EVA.CMS.GetCmsPageResponse;
  }
  
  export class GetCmsPageResponse extends EVA.Core.GetResponse<EVA.CMS.CmsPageDto> {
  }
  
  export class GetCmsPages extends EVA.Core.RequestMessageGeneric<EVA.CMS.GetCmsPagesResponse> {
    __response : EVA.CMS.GetCmsPagesResponse;
  }
  
  export class GetCmsPagesResponse extends EVA.Core.GetResponse<EVA.CMS.CmsPageDto[]> {
  }
  
  export class ListCmsPages extends EVA.Core.PagedResultRequest<EVA.CMS.ListCmsPagesResponse> {
    __response : EVA.CMS.ListCmsPagesResponse;
  }
  
  export class ListCmsPagesResponse extends EVA.Core.PagedResultResponse<EVA.CMS.CmsPageDto> {
  }
  
  export class CreateCmsMenuItem extends EVA.Core.CreateRequest<EVA.CMS.CmsMenuItemDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }
  
  export class CmsMenuItemDto {
    ID : number; // Int32
    MenuID : number; // Int32
    Title : string; 
    ParentID : number; // Int32, nullable
    Parent : EVA.CMS.CmsMenuDto; 
    Depth : number; // Int32
    Lineage : string; 
    Position : number; // Int32
    EntityID : number; // Int32, nullable
    Entity : EVA.CMS.CmsEntityDto; 
    Url : string; 
    Children : EVA.CMS.CmsMenuItemDto[]; 
  }
  
  export class CmsMenuDto {
    ID : number; // Int32
    Identifier : string; 
    Children : EVA.CMS.CmsMenuItemDto[]; 
  }
  
  export class CreateCmsMenu extends EVA.Core.CreateRequest<EVA.CMS.CmsMenuDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }
  
  export class DeleteCmsMenuItem extends EVA.Core.DeleteRequest implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteCmsMenu extends EVA.Core.DeleteRequest implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetCmsMenuByIdentifier extends EVA.Core.RequestMessageGeneric<EVA.CMS.GetCmsMenuByIdentifierResponse> {
    Identifier : string; 
    __response : EVA.CMS.GetCmsMenuByIdentifierResponse;
  }
  
  export class GetCmsMenuByIdentifierResponse extends EVA.Core.GetResponse<EVA.CMS.CmsMenuDto> {
  }
  
  export class GetCmsMenuByID extends EVA.Core.GetRequestGeneric<EVA.CMS.GetCmsMenuByIDResponse> {
    __response : EVA.CMS.GetCmsMenuByIDResponse;
  }
  
  export class GetCmsMenuByIDResponse extends EVA.Core.GetResponse<EVA.CMS.CmsMenuDto> {
  }
  
  export class GetFlatHierarchyByMenuID extends EVA.Core.GetRequestGeneric<EVA.CMS.GetFlatHierarchyByMenuIDResponse> {
    __response : EVA.CMS.GetFlatHierarchyByMenuIDResponse;
  }
  
  export class GetFlatHierarchyByMenuIDResponse extends EVA.Core.GetResponse<EVA.CMS.CmsMenuItemDto[]> {
  }
  
  export class ListCmsMenu extends EVA.Core.PagedResultRequest<EVA.CMS.ListCmsMenuResponse> {
    __response : EVA.CMS.ListCmsMenuResponse;
  }
  
  export class ListCmsMenuResponse extends EVA.Core.PagedResultResponse<EVA.CMS.CmsMenuDto> {
  }
  
  export class ListCmsMenus extends EVA.Core.RequestMessageGeneric<EVA.CMS.ListCmsMenusResponse> {
    __response : EVA.CMS.ListCmsMenusResponse;
  }
  
  export class ListCmsMenusResponse extends EVA.Core.GetResponse<EVA.CMS.CmsMenuDto[]> {
  }
  
  export class UpdateCmsMenuItem extends EVA.Core.UpdateRequest<EVA.CMS.CmsMenuItemDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class UpdateCmsMenu extends EVA.Core.UpdateRequest<EVA.CMS.CmsMenuDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateCmsEntity extends EVA.Core.CreateRequest<EVA.CMS.CmsEntityDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }
  
  export class UpdateCmsEntity extends EVA.Core.UpdateRequest<EVA.CMS.CmsEntityDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteCmsEntity extends EVA.Core.DeleteRequest implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetCmsEntityByID extends EVA.Core.GetRequestGeneric<EVA.CMS.GetCmsEntityByIDResponse> {
    __response : EVA.CMS.GetCmsEntityByIDResponse;
  }
  
  export class GetCmsEntityByIDResponse extends EVA.Core.GetResponse<EVA.CMS.CmsEntityDto> {
  }
  
  export class ListCmsEntities extends EVA.Core.RequestMessageGeneric<EVA.CMS.ListCmsEntitiesResponse> {
    __response : EVA.CMS.ListCmsEntitiesResponse;
  }
  
  export class ListCmsEntitiesResponse extends EVA.Core.GetResponse<EVA.CMS.CmsEntityDto[]> {
  }
  
  export class MoveCmsEntity extends EVA.Core.RequestMessageGeneric<EVA.CMS.MoveCmsEntityResponse> {
    ID : number; // Int32
    ParentID : number; // Int32
    Position : number; // Int32
    __response : EVA.CMS.MoveCmsEntityResponse;
  }
  
  export class MoveCmsEntityResponse extends EVA.Core.ResponseMessage {
  }
  
  export class GetCmsBlocks extends EVA.Core.PagedResultRequest<EVA.CMS.GetCmsBlocksResponse> {
    __response : EVA.CMS.GetCmsBlocksResponse;
  }
  
  export class GetCmsBlocksResponse extends EVA.Core.GetResponse<EVA.CMS.CmsBlockDto[]> {
  }
  
  export class CmsBlockDto {
    ID : number; // Int32
    Identifier : string; 
    DisplayTypeID : number; // Int32
    DisplayType : EVA.CMS.CmsWidgetTypeDto; 
    Data : string; 
    DisplayData : any; 
    Widgets : EVA.CMS.CmsPageWidgetDto[]; 
  }
  
  export class ListCmsBlocks extends EVA.Core.PagedResultRequest<EVA.CMS.ListCmsBlocksResponse> {
    __response : EVA.CMS.ListCmsBlocksResponse;
  }
  
  export class ListCmsBlocksResponse extends EVA.Core.PagedResultResponse<EVA.CMS.CmsPageDto> {
  }
  
  export class CreateCmsBanner extends EVA.Core.CreateRequest<EVA.CMS.CmsBannerDto> implements EVA.Core.IRequestRespondsAs<EVA.CMS.CreateCmsBannerResponse> {
    __response : EVA.CMS.CreateCmsBannerResponse;
  }
  
  export class CmsBannerDto {
    ID : string; 
    Url : string; 
    ImageGuid : string; 
    Name : string; 
    Title : string; 
    Alt : string; 
    StartDate : string; // DateTime, nullable
    EndDate : string; // DateTime, nullable
    Enabled : boolean; 
    Target : EVA.CMS.CmsBannerTargets; 
    Pages : EVA.CMS.CmsEntityDto[]; 
  }
  
  export enum CmsBannerTargets {
    Self = 0,
    NewWindow = 1,
  }
  
  export class CreateCmsBannerResponse extends EVA.Core.CreateResponse {
    UniqueIdentifier : string; 
  }
  
  export class GetCmsBanner extends EVA.Core.RequestMessageGeneric<EVA.CMS.GetCmsBannerResponse> {
    ID : string; 
    __response : EVA.CMS.GetCmsBannerResponse;
  }
  
  export class GetCmsBannerResponse extends EVA.Core.GetResponse<EVA.CMS.CmsBannerDto> {
  }
  
  export class UpdateCmsBanner extends EVA.Core.UpdateRequest<EVA.CMS.CmsBannerDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteCmsBanner extends EVA.Core.DeleteRequest implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    UniqueIdentifier : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListCmsBanners extends EVA.Core.PagedResultRequest<EVA.CMS.ListCmsBannersResponse> {
    __response : EVA.CMS.ListCmsBannersResponse;
  }
  
  export class ListCmsBannersResponse extends EVA.Core.PagedResultResponse<EVA.CMS.CmsBannerDto> {
  }
  
}
/* tslint:disable */
declare module EVA.CNET {
  
  export class CnetGetMappingAsExcel extends EVA.Core.RequestMessageGeneric<EVA.CNET.CnetGetMappingAsExcelResponse> {
    __response : EVA.CNET.CnetGetMappingAsExcelResponse;
  }
  
  export class CnetGetMappingAsExcelResponse extends EVA.Core.ResponseMessage {
    DownloadUrl : string; 
  }
  
  export class CnetUpdateMappingFromExcel extends EVA.Core.RequestMessageWithEmptyResponse {
    Data : number[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
}
/* tslint:disable */
declare module EVA.CRM.Core {
  
  export enum RefundMethod {
    UserCard = 1,
    Automatic = 2,
  }
  
  export class CreateCustomerReturn extends EVA.Core.RequestMessageGeneric<EVA.Core.ShoppingCartResponse> {
    OrderID : number; // Int32
    SessionID : string; 
    Lines : EVA.CRM.Core.CustomerReturnLine[]; 
    ReturnWithoutProducts : boolean; 
    __response : EVA.Core.ShoppingCartResponse;
  }
  
  export class CustomerReturnLine {
    OrderLineID : number; // Int32
    Quantity : number; // Int32
    Reason : string; 
  }
  
  export class GetRefundOptionsForOrder extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.GetRefundOptionsForOrderResponse> {
    OrderID : number; // Int32
    __response : EVA.CRM.Core.GetRefundOptionsForOrderResponse;
  }
  
  export class GetRefundOptionsForOrderResponse extends EVA.Core.ResponseMessage {
    IsRefundAvailable : boolean; 
    AmountAvailableToRefund : number; // Decimal
    Reason : string; 
  }
  
  export class GetReturnOrdersForOrder extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.GetReturnOrdersForOrderResponse> {
    OrderID : number; // Int32
    __response : EVA.CRM.Core.GetReturnOrdersForOrderResponse;
  }
  
  export class GetReturnOrdersForOrderResponse extends EVA.Core.ResponseMessage {
    Orders : EVA.CRM.Core.ReturnOrder[]; 
  }
  
  export class ReturnOrder {
    ID : number; // Int32
    IsReturnWithoutProducts : boolean; 
    CreationTime : string; // DateTime
    TotalAmountInTax : number; // Decimal
    ForeignTotalAmountInTax : number; // Decimal
    CurrencyID : string; 
    IsPaid : boolean; 
    IsCompleted : boolean; 
    IsShipped : boolean; 
    PaidAmount : number; // Decimal
    ForeignPaidAmount : number; // Decimal
  }
  
  export class ReceiveReturnOrder extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.ReceiveReturnOrderResponse> {
    OrderID : number; // Int32
    Lines : EVA.CRM.Core.ReceiveReturnOrderReturnedLine[]; 
    __response : EVA.CRM.Core.ReceiveReturnOrderResponse;
  }
  
  export class ReceiveReturnOrderResponse extends EVA.Core.ResponseMessage {
    Messages : EVA.Core.ConfirmShipmentResultMessage[]; 
  }
  
  export class ReceiveReturnOrderReturnedLine {
    OrderLineID : number; // Int32
    Remark : string; 
    Quantity : number; // Int32
  }
  
  export class RefundAmountFromUserCard extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.RefundAmountFromUserCardResponse> {
    UserCardID : number; // Int32
    Amount : number; // Decimal
    RefundPaymentTypeCode : string; 
    PaymentTransactionID : number; // Int32, nullable
    RefundOptions : any; 
    __response : EVA.CRM.Core.RefundAmountFromUserCardResponse;
  }
  
  export class RefundAmountFromUserCardResponse extends EVA.Core.ResponseMessage {
    ActualRefundedAmount : number; // Decimal
    RefundStatus : EVA.Core.PaymentStatuses; 
    Message : EVA.Core.RefundAttemptMessage; 
  }
  
  export class RefundOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderID : number; // Int32
    Reason : string; 
    AmountToRefund : number; // Decimal, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ReturnOrderLines extends EVA.Core.RequestMessageGeneric<EVA.Core.ShoppingCartResponse> {
    OrderID : number; // Int32, nullable
    Lines : EVA.CRM.Core.ReturnLineDto[]; 
    SessionID : string; 
    ForceCreate : boolean; 
    LineActionType : EVA.Core.LineActionTypes; 
    ReturnToSameStockOrganizationUnit : boolean; 
    __response : EVA.Core.ShoppingCartResponse;
  }
  
  export class ReturnLineDto {
    OrderLineID : number; // Int32, nullable
    ProductID : number; // Int32, nullable
    Quantity : number; // Int32
    ResourceID : number; // Int32, nullable
    Remark : string; 
    ReturnStockLabel : number; // Int32
  }
  
  export class SetReturnOrderRefundCorrection extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderID : number; // Int32
    NewOpenAmount : number; // Decimal
    Reason : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetUserInteractionByID extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.GetUserInteractionByIDResponse> {
    ID : number; // Int32
    __response : EVA.CRM.Core.GetUserInteractionByIDResponse;
  }
  
  export class GetUserInteractionByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    UserID : number; // Int32
    User : EVA.CRM.Core.GetUserInteractionByIDResponseUserDto; 
    Text : string; 
    OrderID : number; // Int32, nullable
    UserTaskID : number; // Int32, nullable
    CreationTime : string; // DateTime
  }
  
  export class GetUserInteractionByIDResponseUserDto {
    FirstName : string; 
    LastName : string; 
    EmailAddress : string; 
  }
  
  export class CreateUserInteraction extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.CreateUserInteractionResponse> {
    UserID : number; // Int32
    Text : string; 
    OrderID : number; // Int32, nullable
    UserTaskID : number; // Int32, nullable
    __response : EVA.CRM.Core.CreateUserInteractionResponse;
  }
  
  export class CreateUserInteractionResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class UpdateUserInteraction extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    UserID : number; // Int32
    Text : string; 
    OrderID : number; // Int32, nullable
    UserTaskID : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteUserInteraction extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListUserInteractions extends EVA.Core.PagedResultRequest<EVA.CRM.Core.ListUserInteractionsResponse> {
    __response : EVA.CRM.Core.ListUserInteractionsResponse;
  }
  
  export class ListUserInteractionsResponse extends EVA.Core.PagedResultResponse<EVA.CRM.Core.ListUserInteractionsResponseUserInteractionDto> {
  }
  
  export class ListUserInteractionsResponseUserInteractionDto {
    ID : number; // Int32
    UserID : number; // Int32
    User : EVA.CRM.Core.ListUserInteractionsResponseUserInteractionDtoUserDto; 
    CreatedByID : number; // Int32
    CreatedBy : EVA.CRM.Core.ListUserInteractionsResponseUserInteractionDtoUserDto; 
    Text : string; 
    OrderID : number; // Int32, nullable
    UserTaskID : number; // Int32, nullable
    CreationTime : string; // DateTime
  }
  
  export class ListUserInteractionsResponseUserInteractionDtoUserDto {
    FirstName : string; 
    LastName : string; 
    EmailAddress : string; 
  }
  
  export class CompleteOrderInterventionTask extends EVA.Core.RequestMessageWithEmptyResponse {
    WorkSet : EVA.CRM.Core.OrderInterventionWorkSet; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class OrderInterventionWorkSet {
    UserTaskID : number; // Int32
    OrderInterventionTaskID : number; // Int32
    OrderID : number; // Int32
    Reason : string; 
    Comment : string; 
  }
  
  export class ListOrderInterventionTasks extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.ListOrderInterventionTasksResponse> {
    PageConfig : EVA.Core.PageConfig; 
    __response : EVA.CRM.Core.ListOrderInterventionTasksResponse;
  }
  
  export class ListOrderInterventionTasksResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.PagedResultGeneric<EVA.CRM.Core.OrderInterventionTaskDto>; 
  }
  
  export class OrderInterventionTaskDto {
    ID : number; // Int32
    UserTaskID : number; // Int32
    Reason : string; 
    Comment : string; 
    OrderID : number; // Int32
    CreationTime : string; // DateTime
    AssignedToUser : string; 
  }
  
  export class StartOrderInterventionTask extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.StartOrderInterventionTaskResponse> {
    UserTaskID : number; // Int32
    __response : EVA.CRM.Core.StartOrderInterventionTaskResponse;
  }
  
  export class StartOrderInterventionTaskResponse extends EVA.Core.ResponseMessage {
    WorkSet : EVA.CRM.Core.OrderInterventionWorkSet; 
  }
  
  export class CompleteCustomerInteractionTask extends EVA.Core.RequestMessageWithEmptyResponse {
    WorkSet : EVA.CRM.Core.CustomerInteractionWorkSet; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CustomerInteractionWorkSet {
    UserTaskID : number; // Int32
    UserTask : EVA.Core.UserTaskDto; 
    TypeID : number; // Int32
    TypeName : string; 
    CustomerID : number; // Int32
    Customer : EVA.CRM.Core.CustomerInteractionWorkSetCustomerDto; 
    Priority : EVA.CRM.Core.CustomerInteractionTaskPriorities; 
  }
  
  export class CustomerInteractionWorkSetCustomerDto {
    FirstName : string; 
    LastName : string; 
    EmailAddress : string; 
    PhoneNumber : string; 
  }
  
  export enum CustomerInteractionTaskPriorities {
    None = 0,
    Low = 1,
    Normal = 2,
    High = 3,
    Immediate = 4,
  }
  
  export class GetCustomerInteractionTaskByID extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.GetCustomerInteractionTaskByIDResponse> {
    ID : number; // Int32
    __response : EVA.CRM.Core.GetCustomerInteractionTaskByIDResponse;
  }
  
  export class GetCustomerInteractionTaskByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    Priority : EVA.CRM.Core.CustomerInteractionTaskPriorities; 
    Type : EVA.CRM.Core.CustomerInteractionTaskTypeDto; 
    Customer : EVA.CRM.Core.CustomerInteractionUserDto; 
    CustomerID : number; // Int32
    UserTask : EVA.CRM.Core.CustomerInteractionUserTaskDto; 
    UserTaskID : number; // Int32
  }
  
  export class CustomerInteractionTaskTypeDto {
    ID : number; // Int32
    Name : string; 
    Description : string; 
    FollowUpTypeID : number; // Int32, nullable
    FollowUpTypeName : string; 
  }
  
  export class CustomerInteractionUserDto {
    FullName : string; 
    PhoneNumber : string; 
    EmailAddress : string; 
  }
  
  export class CustomerInteractionUserTaskDto {
    StartTime : string; // DateTime, nullable
    DeadLine : string; // DateTime, nullable
    Description : string; 
    UserID : number; // Int32, nullable
    User : EVA.CRM.Core.CustomerInteractionUserDto; 
    OrganizationUnitID : number; // Int32
    OrganizationUnitName : string; 
    IsActive : boolean; 
    IsCompleted : boolean; 
  }
  
  export class CreateCustomerInteractionTask extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.CreateCustomerInteractionTaskResponse> {
    Priority : EVA.CRM.Core.CustomerInteractionTaskPriorities; 
    TypeID : number; // Int32
    CustomerID : number; // Int32
    UserTask : EVA.CRM.Core.CustomerInteractionUserTaskDto; 
    __response : EVA.CRM.Core.CreateCustomerInteractionTaskResponse;
  }
  
  export class CreateCustomerInteractionTaskResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class DeleteCustomerInteractionTask extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListCustomerInteractionTasks extends EVA.Core.PagedResultRequest<EVA.CRM.Core.ListCustomerInteractionTasksResponse> {
    __response : EVA.CRM.Core.ListCustomerInteractionTasksResponse;
  }
  
  export class ListCustomerInteractionTasksResponse extends EVA.Core.PagedResultResponse<EVA.CRM.Core.ListCustomerInteractionTasksResponseCustomerInteractionTaskDto> {
  }
  
  export class ListCustomerInteractionTasksResponseCustomerInteractionTaskDto {
    ID : number; // Int32
    Priority : EVA.CRM.Core.CustomerInteractionTaskPriorities; 
    Type : EVA.CRM.Core.CustomerInteractionTaskTypeDto; 
    Customer : EVA.CRM.Core.CustomerInteractionUserDto; 
    CustomerID : number; // Int32
    UserTask : EVA.CRM.Core.CustomerInteractionUserTaskDto; 
    UserTaskID : number; // Int32
  }
  
  export class GetCustomerInteractionTaskTypeByID extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.GetCustomerInteractionTaskTypeByIDResponse> {
    ID : number; // Int32
    __response : EVA.CRM.Core.GetCustomerInteractionTaskTypeByIDResponse;
  }
  
  export class GetCustomerInteractionTaskTypeByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    Name : string; 
    Description : string; 
    FollowUpTypeID : number; // Int32, nullable
    FollowUpTypeName : string; 
  }
  
  export class CreateCustomerInteractionTaskType extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.CreateCustomerInteractionTaskTypeResponse> {
    Name : string; 
    Description : string; 
    FollowUpTypeID : number; // Int32, nullable
    __response : EVA.CRM.Core.CreateCustomerInteractionTaskTypeResponse;
  }
  
  export class CreateCustomerInteractionTaskTypeResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class UpdateCustomerInteractionTaskType extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Description : string; 
    FollowUpTypeID : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteCustomerInteractionTaskType extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetCustomerInteractionTaskTypes extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.GetCustomerInteractionTaskTypesResponse> {
    __response : EVA.CRM.Core.GetCustomerInteractionTaskTypesResponse;
  }
  
  export class GetCustomerInteractionTaskTypesResponse extends EVA.Core.ResponseMessage {
    CustomerInteractionTaskTypes : EVA.CRM.Core.CustomerInteractionTaskTypeDto[]; 
  }
  
  export class DetachFromCustomerInteractionTask extends EVA.Core.RequestMessageWithEmptyResponse {
    UserTaskID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class StartCustomerInteractionTask extends EVA.Core.RequestMessageGeneric<EVA.CRM.Core.StartCustomerInteractionTaskResponse> {
    UserTaskID : number; // Int32
    __response : EVA.CRM.Core.StartCustomerInteractionTaskResponse;
  }
  
  export class StartCustomerInteractionTaskResponse extends EVA.Core.ResponseMessage {
    WorkSet : EVA.CRM.Core.CustomerInteractionWorkSet; 
  }
  
}
/* tslint:disable */
declare module EVA.Carrier.PostNL {
  
  export enum LocationOptions {
    Daytime = 1,
    Evening = 2,
    Morning = 4,
    Noon = 8,
    Sunday = 16,
    Sameday = 32,
    Afternoon = 64,
  }
  
  export enum TimeframeOptions {
    Daytime = 1,
    Evening = 2,
    Morning = 4,
    Noon = 8,
    Sunday = 16,
    Sameday = 32,
    Afternoon = 64,
    All = 127,
  }
  
  export class PostNLGetAvailablePickUpLocationsForArea extends EVA.Core.RequestMessageGeneric<EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaResponse> {
    OrderID : number; // Int32
    NorthWest : EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaCoordinate; 
    SouthEast : EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaCoordinate; 
    __response : EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForAreaResponse;
  }
  
  export class PostNLGetAvailablePickUpLocationsForAreaResponse extends EVA.Core.ResponseMessage {
    Locations : EVA.Carrier.PostNL.AvailableLocation[]; 
  }
  
  export class AvailableLocation {
    ID : string; 
    Name : string; 
    Longitude : number; // Decimal
    Latitude : number; // Decimal
    Distance : number; // Int32
    Street : string; 
    HouseNumber : string; 
    ZipCode : string; 
    City : string; 
    CountryID : string; 
    PhoneNumber : string; 
    Remark : string; 
    OpeningHours : EVA.Carrier.PostNL.LocationOpeningHours; 
    Area : string; 
    BuildingName : string; 
    Department : string; 
    Floor : string; 
    Doorcode : string; 
    HouseNumberExt : string; 
  }
  
  export class LocationOpeningHours {
    Sunday : string[]; 
    Monday : string[]; 
    Tuesday : string[]; 
    Wednesday : string[]; 
    Thursday : string[]; 
    Friday : string[]; 
    Saturday : string[]; 
  }
  
  export class PostNLGetAvailablePickUpLocationsForAreaCoordinate {
    Latitude : number; // Decimal
    Longitude : number; // Decimal
  }
  
  export class PostNLGetAvailablePickUpLocationsForOrder extends EVA.Core.RequestMessageGeneric<EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForOrderResponse> {
    OrderID : number; // Int32
    __response : EVA.Carrier.PostNL.PostNLGetAvailablePickUpLocationsForOrderResponse;
  }
  
  export class PostNLGetAvailablePickUpLocationsForOrderResponse extends EVA.Core.ResponseMessage {
    Locations : EVA.Carrier.PostNL.AvailableLocation[]; 
  }
  
  export class PostNLGetAvailableTimeframesForOrder extends EVA.Core.RequestMessageGeneric<EVA.Carrier.PostNL.PostNLGetAvailableTimeframesForOrderResponse> {
    OrderID : number; // Int32
    StartDate : string; // DateTime
    EndDate : string; // DateTime
    __response : EVA.Carrier.PostNL.PostNLGetAvailableTimeframesForOrderResponse;
  }
  
  export class PostNLGetAvailableTimeframesForOrderResponse extends EVA.Core.ResponseMessage {
    Frames : EVA.Carrier.PostNL.AvailableTimeframeDate[]; 
  }
  
  export class AvailableTimeframeDate {
    Date : string; // DateTime
    Timeframes : EVA.Carrier.PostNL.AvailableTimeframe[]; 
  }
  
  export class AvailableTimeframe {
    Option : EVA.Carrier.PostNL.TimeframeOptions; 
    StartDateTime : string; // DateTime
    EndDateTime : string; // DateTime
    Costs : number; // Decimal
  }
  
  export class PostNLGetShippingOptionsForOrder extends EVA.Core.RequestMessageGeneric<EVA.Carrier.PostNL.PostNLGetShippingOptionsForOrderResponse> {
    OrderID : number; // Int32
    __response : EVA.Carrier.PostNL.PostNLGetShippingOptionsForOrderResponse;
  }
  
  export class PostNLGetShippingOptionsForOrderResponse extends EVA.Core.ResponseMessage {
    Date : string; // DateTime, nullable
    TimeframeOptions : EVA.Carrier.PostNL.TimeframeOptions; 
    PickUpLocationID : string; 
  }
  
  export class PostNLUpdateShippingOptionsForOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderID : number; // Int32
    Date : string; // DateTime, nullable
    TimeframeOptions : EVA.Carrier.PostNL.TimeframeOptions; 
    PickUpLocationID : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
}
/* tslint:disable */
declare module EVA.ClippingMagic {
  
  export class CreateBlobFromClippingMagic extends EVA.Core.RequestMessageGeneric<EVA.ClippingMagic.CreateBlobFromClippingMagicResponse> {
    ImageID : number; // Int32
    __response : EVA.ClippingMagic.CreateBlobFromClippingMagicResponse;
  }
  
  export class CreateBlobFromClippingMagicResponse extends EVA.Core.ResponseMessage {
    BlobID : string; 
  }
  
  export class UploadBlobToClippingMagic extends EVA.Core.RequestMessageGeneric<EVA.ClippingMagic.UploadBlobToClippingMagicResponse> {
    BlobID : string; 
    ImageID : string; 
    __response : EVA.ClippingMagic.UploadBlobToClippingMagicResponse;
  }
  
  export class UploadBlobToClippingMagicResponse extends EVA.Core.ResponseMessage {
    Image : EVA.ClippingMagic.UploadBlobToClippingMagicResult; 
  }
  
  export class UploadBlobToClippingMagicResult {
    ID : number; // Int32
    Secret : string; 
    ResultRevision : number; // Int32
    OriginalFileName : string; 
    IsTest : boolean; 
  }
  
}
/* tslint:disable */
declare module EVA.Cookbook {
  
  export class CreateAccountingRecipe extends EVA.Core.RequestMessageGeneric<EVA.Cookbook.CreateAccountingRecipeResponse> {
    Recipe : string; 
    IsActive : boolean; 
    Name : string; 
    __response : EVA.Cookbook.CreateAccountingRecipeResponse;
  }
  
  export class CreateOrUpdateRecipeResponse extends EVA.Core.ResponseMessage {
    HasErrors : boolean; 
    Errors : EVA.Cookbook.ParseRecipeError[]; 
  }
  
  export class CreateAccountingRecipeResponse extends EVA.Cookbook.CreateOrUpdateRecipeResponse {
    ID : number; // Int32
  }
  
  export class ParseRecipeError {
    Type : EVA.Cookbook.ParsingErrorType; 
    Message : string; 
    SourceLine : string; 
    SourceLineNumber : number; // Int32
  }
  
  export enum ParsingErrorType {
    InvalidSyntax = 0,
    UnknownVariable = 1,
    InvalidComparison = 2,
    InvalidOperator = 3,
    MissingCredit = 4,
    MissingDebit = 5,
    AmountMustBeNumerical = 6,
    InvalidBookOnOrganizationUnit = 7,
  }
  
  export class GetAccountingRecipe extends EVA.Core.RequestMessageGeneric<EVA.Cookbook.GetAccountingRecipeResponse> {
    ID : number; // Int32
    __response : EVA.Cookbook.GetAccountingRecipeResponse;
  }
  
  export class GetAccountingRecipeResponse extends EVA.Core.ResponseMessage {
    Recipe : EVA.Cookbook.AccountingRecipeDto; 
  }
  
  export class AccountingRecipeDto {
    Recipe : string; 
    Name : string; 
    EventType : EVA.Core.FinancialEventTypes; 
    IsActive : boolean; 
  }
  
  export class ListAccountingRecipes extends EVA.Core.PagedResultRequest<EVA.Cookbook.ListAccountingRecipesResponse> {
    IsActive : boolean; 
    Type : EVA.Core.FinancialEventTypes; 
    __response : EVA.Cookbook.ListAccountingRecipesResponse;
  }
  
  export class ListAccountingRecipesResponse extends EVA.Core.PagedResultResponse<EVA.Cookbook.AccountingRecipeDto> {
  }
  
  export class PreviewAccountingRecipe extends EVA.Core.RequestMessageGeneric<EVA.Cookbook.PreviewAccountingRecipeResponse> {
    Recipes : EVA.Cookbook.AccountingRecipeToPreview[]; 
    FinancialEventIDs : number[]; 
    OrderID : number; // Int32, nullable
    __response : EVA.Cookbook.PreviewAccountingRecipeResponse;
  }
  
  export class PreviewAccountingRecipeResponse extends EVA.Cookbook.CreateOrUpdateRecipeResponse {
    BookingPreviewSummaries : EVA.Cookbook.AccountBookingPreview[]; 
    Warnings : string[]; 
    BookingPreviewDetails : EVA.Cookbook.AccountBookingDetails[]; 
  }
  
  export class AccountBookingPreview {
    Date : string; // DateTime
    BookedOnOrganizationUnitID : number; // Int32
    BookedOnOrganizationUnitName : string; 
    BookedOnAccountID : number; // Int32
    BookedOnAccountNumber : string; 
    BookedOnAccountName : string; 
    Amount : number; // Decimal
  }
  
  export class AccountBookingDetails {
    Amount : number; // Decimal
    BookedOnOrganizationUnitID : number; // Int32
    BookedOnOrganizationUnitName : string; 
    BookedOnAccountID : number; // Int32
    BookedOnAccountNumber : string; 
    BookedOnAccountName : string; 
    AccountingRecipeID : number; // Int32
    Date : string; // DateTime
    Description : string; 
  }
  
  export class AccountingRecipeToPreview {
    ID : number; // Int32, nullable
    Recipe : string; 
  }
  
  export class UpdateAccountingRecipe extends EVA.Core.RequestMessageGeneric<EVA.Cookbook.UpdateAccountingRecipeResponse> {
    ID : number; // Int32
    Recipe : string; 
    IsActive : boolean; 
    Name : string; 
    __response : EVA.Cookbook.UpdateAccountingRecipeResponse;
  }
  
  export class UpdateAccountingRecipeResponse extends EVA.Cookbook.CreateOrUpdateRecipeResponse {
  }
  
  export enum ActionBlockModifier {
    None = 0,
    Else = 1,
    Also = 2,
  }
  
  export enum OperatorTypes {
    Equals = 0,
    NotEquals = 1,
    GreaterThan = 2,
    LessThan = 3,
    GreaterThanOrEquals = 4,
    LessThanOrEquals = 5,
    HasValue = 6,
    HasNoValue = 7,
  }
  
}
/* tslint:disable */
declare module EVA.Copernica {
  
  export enum CopernicaDatabaseFieldTypes {
    Text = 0,
    Integer = 1,
    Float = 2,
    Date = 3,
    DateTime = 4,
    Email = 5,
    Phone = 6,
    Select = 7,
  }
  
  export class CopernicaProfileCallback extends EVA.Core.RequestMessageWithEmptyResponse {
    Profile : EVA.Copernica.CopernicaProfile; 
    Action : string; 
    Parameters : { [ key : string ] : any }; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CopernicaProfile {
    ID : number; // Int32, nullable
    Fields : EVA.Copernica.CopernicaUser; 
    Interests : any[]; 
    DatabaseID : number; // Int32
    Secret : string; 
    Created : string; 
  }
  
  export class CopernicaUser {
    EVA_ID : number; // Int32
    FirstName : string; 
    LastName : string; 
    Gender : string; 
    Email : string; 
    DateOfBirth : string; // DateTime, nullable
    PhoneNumber : string; 
    CompanyName : string; 
    Initials : string; 
    ReceiveNewsLetters : string; 
    ShouldReceiveNewsLetters : boolean; 
  }
  
}
/* tslint:disable */
declare module EVA.Core.Services {

  export class StockResourceTypeDto {
    Name : string;
    IsUnique : boolean;
  }

  export class SearchProducts extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.SearchProductsResponse> {
    Query : string;
    Filters : { [ key : string ] : EVA.Core.FilterModel };
    IncludeAggregations : boolean;
    AggregationState : string;
    AggregationOptions : { [ key : string ] : EVA.Core.AggregationFilterModel };
    PageSize : number; // Int32, nullable
    Page : number; // Int32, nullable
    Sort : EVA.Core.SortFieldDescriptor[];
    ExcludedFields : string[];
    ExcludedFieldsOption : EVA.Core.ExcludedFieldOptions;
    IncludedFields : string[];
    __response : EVA.Core.Services.SearchProductsResponse;
  }

  export class SearchProductsResponse extends EVA.Core.ResponseMessage {
    Products : any[];
    AggregationState : string;
    Aggregations : any;
    AggregationOptions : { [ key : string ] : EVA.Core.AggregationFilterModel };
    Page : number; // Int32
    PageSize : number; // Int32
    Total : number; // Int64
    Sort : EVA.Core.SortFieldDescriptor[];
  }

  export class AddWishListToOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.ShoppingCartResponse> {
    SessionID : string;
    WishListID : number; // Int32, nullable
    WishListToken : string;
    LineActionType : EVA.Core.LineActionTypes;
    __response : EVA.Core.ShoppingCartResponse;
  }

  export class GetWishListByID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetWishListResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetWishListResponse;
  }

  export class GetWishListResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    Name : string;
    UserID : number; // Int32
    UserFullName : string;
    PublicAccessToken : string;
    Lines : EVA.Core.Services.WishListLineDto[];
    CreationTime : string; // DateTime
  }

  export class WishListLineDto {
    ProductID : number; // Int32
    ProductCustomID : string;
    Description : string;
    Quantity : number; // Int32
    CreationTime : string; // DateTime
  }

  export class GetWishListByToken extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetWishListResponse> {
    Token : string;
    __response : EVA.Core.Services.GetWishListResponse;
  }

  export class CreateWishList extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreateWishListResponse> {
    Name : string;
    __response : EVA.Core.Services.CreateWishListResponse;
  }

  export class CreateWishListResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }

  export class UpdateWishList extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Name : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteWishList extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetWishListLineByID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetWishListLineByIDResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetWishListLineByIDResponse;
  }

  export class GetWishListLineByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    WishListID : number; // Int32
    ProductID : number; // Int32
    ProductCustomID : string;
    Description : string;
    Quantity : number; // Int32
    CreationTime : string; // DateTime
  }

  export class CreateWishListLine extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreateWishListLineResponse> {
    WishListID : number; // Int32
    ProductID : number; // Int32
    Quantity : number; // Int32, nullable
    __response : EVA.Core.Services.CreateWishListLineResponse;
  }

  export class CreateWishListLineResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }

  export class UpdateWishListLine extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Quantity : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteWishListLine extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListWishLists extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListWishListsResponse> {
    __response : EVA.Core.Services.ListWishListsResponse;
  }

  export class ListWishListsResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.ListWishListsResponseWishListDto> {
  }

  export class ListWishListsResponseWishListDto {
    ID : number; // Int32
    Name : string;
    UserID : number; // Int32
    UserFullName : string;
    PublicAccessToken : string;
    Lines : EVA.Core.Services.WishListLineDto[];
    CreationTime : string; // DateTime
  }

  export class GetRobotsTxt extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetRobotsTxtResponse> {
    __response : EVA.Core.Services.GetRobotsTxtResponse;
  }

  export class GetRobotsTxtResponse extends EVA.Core.ResponseMessage {
    Robots : string;
  }

  export class UpdateRobotsTxt extends EVA.Core.RequestMessageWithEmptyResponse {
    Robots : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class SendContactForm extends EVA.Core.RequestMessageWithEmptyResponse {
    Type : string;
    Properties : { [ key : string ] : string };
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ChangeUserPassword extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ChangeUserPasswordResponse> {
    UserID : number; // Int32
    NewPassword : string;
    OldPassword : string;
    __response : EVA.Core.Services.ChangeUserPasswordResponse;
  }

  export class ChangeUserPasswordResponse extends EVA.Core.ResponseMessage {
    Success : boolean;
    Result : EVA.Core.PasswordValidationResults;
  }

  export class CheckEmailAddressAvailability extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CheckEmailAddressAvailabilityResponse> {
    EmailAddress : string;
    __response : EVA.Core.Services.CheckEmailAddressAvailabilityResponse;
  }

  export class CheckEmailAddressAvailabilityResponse extends EVA.Core.ResponseMessage {
    IsAvailable : boolean;
    IsValid : boolean;
    IsMigrated : boolean;
    IsIncomplete : boolean;
  }

  export class CheckNicknameAvailability extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CheckNicknameAvailabilityResponse> {
    Nickname : string;
    __response : EVA.Core.Services.CheckNicknameAvailabilityResponse;
  }

  export class CheckNicknameAvailabilityResponse extends EVA.Core.ResponseMessage {
    IsAvailable : boolean;
    IsValid : boolean;
  }

  export enum CreateApiKeysFunctionalities {
    ManageApiKeys = 0,
    CreatePermanentApiKeys = 1,
  }

  export class CreateApiKey extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreateApiKeyResponse> {
    UserID : number; // Int32
    ApplicationID : number; // Int32, nullable
    OrganizationUnitID : number; // Int32, nullable
    RequestPermanentApiKey : boolean;
    __response : EVA.Core.Services.CreateApiKeyResponse;
  }

  export class CreateApiKeyResponse extends EVA.Core.ResponseMessage {
    ApiKey : string;
    ExpirationDate : string; // DateTime, nullable
  }

  export class CreateCustomer extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreateCustomerResponse> {
    User : EVA.Core.Services.CustomerDto;
    SessionID : string;
    NoAccount : boolean;
    AutoLogin : boolean;
    __response : EVA.Core.Services.CreateCustomerResponse;
  }

  export class CreateCustomerResponse extends EVA.Core.ResponseMessage {
    User : EVA.Core.LoggedInUserDto;
    Result : EVA.Core.Services.CreateCustomerResults;
  }

  export enum CreateCustomerResults {
    CreatedCustomer = 0,
    InvalidEmail = 1,
    UsedIncompleteAccount = 2,
    EmailAlreadyInUse = 3,
    NicknameAlreadyInUse = 4,
  }

  export class CustomerDto {
    ID : number; // Int32
    EmailAddress : string;
    Gender : string;
    Initials : string;
    FirstName : string;
    LastName : string;
    PhoneNumber : string;
    SubscriptionType : EVA.Core.SubscriptionTypes;
    DateOfBirth : string; // DateTime, nullable
    PlaceOfBirth : string;
    BankAccount : string;
    Nickname : string;
    Password : string;
    LanguageID : string;
    ShippingAddress : EVA.Core.AddressDto;
    BillingAddress : EVA.Core.AddressDto;
  }

  export class CreateCustomerWithCompany extends EVA.Core.RequestMessageWithEmptyResponse {
    Nickname : string;
    EmailAddress : string;
    Gender : string;
    Initials : string;
    FirstName : string;
    LastName : string;
    PhoneNumber : string;
    LanguageID : string;
    Company : EVA.Core.Services.CustomerCompany;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CustomerCompany {
    Name : string;
    RegistrationNumber : string;
    RegistrationCity : string;
    RegistrationCountryID : string;
    VatNumber : string;
    LegalForm : EVA.Core.LegalForms;
    EstablishedDate : string; // DateTime, nullable
    VisitorsAddress : EVA.Core.AddressDto;
    DeliveryAddress : EVA.Core.AddressDto;
    ReturnsAddress : EVA.Core.AddressDto;
    InvoiceAddress : EVA.Core.AddressDto;
    InvoiceEmailAddress : string;
    ContactEmailAddress : string;
    ContactPhoneNumber : string;
    AccountHolderName : string;
    IBAN : string;
    BIC : string;
    LogoID : string;
  }

  export class CreateEmployeeUser extends EVA.Core.CreateRequest<EVA.Core.UserDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.Services.CreateEmployeeUserResponse> {
    Password : string;
    __response : EVA.Core.Services.CreateEmployeeUserResponse;
  }

  export class CreateEmployeeUserResponse extends EVA.Core.CreateResponse {
    UserID : number; // Int32
    IdentificationCode : string;
  }

  export class DeleteUser extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GenerateIdentificationCodeForEmployee extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GenerateIdentificationCodeForEmployeeResponse> {
    __response : EVA.Core.Services.GenerateIdentificationCodeForEmployeeResponse;
  }

  export class GenerateIdentificationCodeForEmployeeResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.UserIdWithIdentificationCodeDto;
  }

  export class UserIdWithIdentificationCodeDto {
    UserId : number; // Int32
    IdentificationCode : string;
  }

  export class GenerateTemporaryPasswordForUser extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GenerateTemporaryPasswordForUserResponse> {
    UserID : number; // Int32
    __response : EVA.Core.Services.GenerateTemporaryPasswordForUserResponse;
  }

  export class GenerateTemporaryPasswordForUserResponse extends EVA.Core.ResponseMessage {
    Password : string;
  }

  export class GetCurrentUser extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetCurrentUserResponse> {
    __response : EVA.Core.Services.GetCurrentUserResponse;
  }

  export class GetCurrentUserResponse extends EVA.Core.ResponseMessage {
    User : EVA.Core.LoggedInUserDto;
  }

  export class GetOrganizationUnitsForUser extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetOrganizationUnitsForUserResponse> {
    IncludeNonLoginOrganizationUnits : boolean;
    __response : EVA.Core.Services.GetOrganizationUnitsForUserResponse;
  }

  export class GetOrganizationUnitsForUserResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.OrganizationUnitDto[];
  }

  export class GetUserIdentificationByID extends EVA.Core.GetRequestGeneric<EVA.Core.Services.GetUserIdentificationByIDResponse> {
    __response : EVA.Core.Services.GetUserIdentificationByIDResponse;
  }

  export class GetUserIdentificationByIDResponse extends EVA.Core.GetResponse<EVA.Core.Services.IdentificationDto> {
  }

  export class IdentificationDto {
    ID : number; // Int32
    Type : EVA.Core.IdentificationTypes;
    Number : string;
    ValidTo : string; // DateTime
    IssuingDate : string; // DateTime, nullable
    IssuingCity : string;
    IssuingCountryID : string;
    OriginatingCountryID : string;
    DocumentID : string;
  }

  export class GetUser extends EVA.Core.GetRequestGeneric<EVA.Core.Services.GetUserResponse> {
    IncludeFunctionalities : boolean;
    __response : EVA.Core.Services.GetUserResponse;
  }

  export class GetUserResponse extends EVA.Core.GetResponse<EVA.Core.UserDto> {
  }

  export class ListAvailableTimeZones extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListAvailableTimeZonesResponse> {
    __response : EVA.Core.Services.ListAvailableTimeZonesResponse;
  }

  export class ListAvailableTimeZonesResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.ListAvailableTimeZonesResponseModel[];
  }

  export class ListAvailableTimeZonesResponseModel {
    ID : string;
    CountryID : string;
    CountryName : string;
  }

  export class ListUserIdentifications extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListUserIdentificationsResponse> {
    UserID : number; // Int32
    __response : EVA.Core.Services.ListUserIdentificationsResponse;
  }

  export class ListUserIdentificationsResponse extends EVA.Core.ResponseMessage {
    Identifications : EVA.Core.Services.IdentificationDto[];
  }

  export class ListUsersWithBadgesByIDs extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListUsersWithBadgesByIDsResponse> {
    UserIDs : number[];
    __response : EVA.Core.Services.ListUsersWithBadgesByIDsResponse;
  }

  export class ListUsersWithBadgesByIDsResponse extends EVA.Core.ResponseMessage {
    Users : EVA.Core.UserDto[];
  }

  export class RequestPasswordResetToken extends EVA.Core.RequestMessageWithEmptyResponse {
    EmailAddress : string;
    Context : string;
    ApplicationID : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ResetUserPassword extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ResetUserPasswordResponse> {
    Token : string;
    NewPassword : string;
    __response : EVA.Core.Services.ResetUserPasswordResponse;
  }

  export class ResetUserPasswordResponse extends EVA.Core.ResponseMessage {
    EmailAddress : string;
  }

  export class SearchUsers extends EVA.Core.PagedResultRequest<EVA.Core.Services.SearchUsersResponse> {
    EmailAddress : string;
    Name : string;
    SearchQuery : string;
    Types : EVA.Core.UserTypes;
    ZipCode : string;
    PhoneNumber : string;
    __response : EVA.Core.Services.SearchUsersResponse;
  }

  export class SearchUsersResponse extends EVA.Core.PagedResultResponse<EVA.Core.UserDto> {
  }

  export class UpdateUserEmailAddress extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    NewEmailAddress : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class UpdateUser extends EVA.Core.UpdateRequest<EVA.Core.UserDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.Services.UpdateUserResponse> {
    __response : EVA.Core.Services.UpdateUserResponse;
  }

  export class UpdateUserResponse extends EVA.Core.ResponseMessage {
    User : EVA.Core.UserDto;
  }

  export class GetUserDebtorData extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetUserDebtorDataResponse> {
    UserID : number; // Int32
    __response : EVA.Core.Services.GetUserDebtorDataResponse;
  }

  export class GetUserDebtorDataResponse extends EVA.Core.ResponseMessage {
    PaymentTerms : string;
    CreditLimit : number; // Decimal, nullable
  }

  export class UpdateUserDebtorData extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    PaymentTerms : string;
    CreditLimit : number; // Decimal, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetUserGroupByID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetUserGroupByIDResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetUserGroupByIDResponse;
  }

  export class GetUserGroupByIDResponse extends EVA.Core.ResponseMessage {
    Name : string;
  }

  export class CreateUserGroup extends EVA.Core.RequestMessageGeneric<EVA.Core.CreateResponse> {
    Name : string;
    __response : EVA.Core.CreateResponse;
  }

  export class UpdateUserGroup extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Name : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteUserGroup extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListUserGroups extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListUserGroupsResponse> {
    __response : EVA.Core.Services.ListUserGroupsResponse;
  }

  export class ListUserGroupsResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.UserGroupDto> {
  }

  export class UserGroupDto {
    ID : number; // Int32
    Name : string;
  }

  export class AddUserToGroup extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    GroupID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class RemoveUserFromGroup extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    GroupID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListUserGroupsForUser extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListUserGroupsForUserResponse> {
    UserID : number; // Int32
    __response : EVA.Core.Services.ListUserGroupsForUserResponse;
  }

  export class ListUserGroupsForUserResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.UserGroupDto> {
  }

  export class ListUsersForUserGroup extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListUsersForUserGroupResponse> {
    UserGroupID : number; // Int32
    __response : EVA.Core.Services.ListUsersForUserGroupResponse;
  }

  export class ListUsersForUserGroupResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.SimpleUserDto> {
  }

  export class SimpleUserDto {
    ID : number; // Int32
    FirstName : string;
    LastName : string;
  }

  export class CreateCompanyForUser extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    Name : string;
    RegistrationNumber : string;
    RegistrationCity : string;
    RegistrationCountryID : string;
    VatNumber : string;
    LegalFormID : number; // Int32
    EstablishedDate : string; // DateTime, nullable
    ContactEmailAddress : string;
    ContactPhoneNumber : string;
    AccountHolderName : string;
    IBAN : string;
    BIC : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DetachCompanyFromUser extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetCompanyForUser extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetCompanyForUserResponse> {
    UserID : number; // Int32
    __response : EVA.Core.Services.GetCompanyForUserResponse;
  }

  export class GetCompanyForUserResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.CompanyDto;
  }

  export class UpdateCompanyForUser extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    Name : string;
    RegistrationNumber : string;
    RegistrationCity : string;
    RegistrationCountryID : string;
    VatNumber : string;
    LegalFormID : number; // Int32
    EstablishedDate : string; // DateTime, nullable
    ContactEmailAddress : string;
    ContactPhoneNumber : string;
    AccountHolderName : string;
    IBAN : string;
    BIC : string;
    DeliveryAddress : EVA.Core.AddressDto;
    InvoiceAddress : EVA.Core.AddressDto;
    ReturnsAddress : EVA.Core.AddressDto;
    VisitorsAddress : EVA.Core.AddressDto;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ConfirmSubscribe extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ConfirmSubscribeResponse> {
    Token : string;
    Type : EVA.Core.SubscriptionTypes;
    __response : EVA.Core.Services.ConfirmSubscribeResponse;
  }

  export class ConfirmSubscribeResponse extends EVA.Core.ResponseMessage {
    Success : boolean;
  }

  export class HasSubscription extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.HasSubscriptionResponse> {
    EmailAddress : string;
    Type : EVA.Core.SubscriptionTypes;
    __response : EVA.Core.Services.HasSubscriptionResponse;
  }

  export class HasSubscriptionResponse extends EVA.Core.ResponseMessage {
    IsSubscribed : boolean;
  }

  export class Subscribe extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.SubscribeResponse> {
    EmailAddress : string;
    MobileNumber : string;
    Type : EVA.Core.SubscriptionTypes;
    UserID : number; // Int32, nullable
    __response : EVA.Core.Services.SubscribeResponse;
  }

  export class SubscribeResponse extends EVA.Core.ResponseMessage {
    Success : boolean;
  }

  export class Unsubscribe extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.UnsubscribeResponse> {
    EmailAddress : string;
    MobileNumber : string;
    Type : EVA.Core.SubscriptionTypes;
    UserID : number; // Int32, nullable
    __response : EVA.Core.Services.UnsubscribeResponse;
  }

  export class UnsubscribeResponse extends EVA.Core.ResponseMessage {
    Success : boolean;
  }

  export class AttachStockResourceToStock extends EVA.Core.RequestMessageWithEmptyResponse {
    ResourceID : number; // Int32
    StockLabel : number; // Int32
    OrganizationUnitID : number; // Int32
    ProductID : number; // Int32
    QuantityOnHand : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CreateStockResource extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreateStockResourceResponse> {
    Resources : { [ key : string ] : string };
    __response : EVA.Core.Services.CreateStockResourceResponse;
  }

  export class CreateStockResourceResponse extends EVA.Core.ResponseMessage {
    ResourceID : number; // Int32
  }

  export class FindStockResource extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.FindStockResourceResponse> {
    Type : string;
    Value : string;
    __response : EVA.Core.Services.FindStockResourceResponse;
  }

  export class FindStockResourceResponse extends EVA.Core.ResponseMessage {
    Resource : EVA.Core.Services.StockResourceDto;
  }

  export class StockResourceDto {
    ID : number; // Int32
    Lines : EVA.Core.Services.StockResourceLineDto[];
  }

  export class StockResourceLineDto {
    Type : string;
    Value : string;
  }

  export class GetStockResource extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetStockResourceResponse> {
    ResourceID : number; // Int32
    __response : EVA.Core.Services.GetStockResourceResponse;
  }

  export class GetStockResourceResponse extends EVA.Core.ResponseMessage {
    Resource : EVA.Core.Services.StockResourceDto;
  }

  export class ListRequiredStockResourceTypes extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListRequiredStockResourceTypesResponse> {
    ProductID : number; // Int32
    __response : EVA.Core.Services.ListRequiredStockResourceTypesResponse;
  }

  export class ListRequiredStockResourceTypesResponse extends EVA.Core.ResponseMessage {
    RequiredStockResourceTypes : EVA.Core.Services.StockResourceTypeDto[];
  }

  export class ListStockResourcesByProduct extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListStockResourcesByProductResponse> {
    ProductID : number; // Int32
    OrganizationUnitIDs : number[];
    __response : EVA.Core.Services.ListStockResourcesByProductResponse;
  }

  export class ListStockResourcesByProductResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.ProductWithResourceDto> {
  }

  export class ProductWithResourceDto {
    Product : any;
    StockLabelID : number; // Int32
    StockLabel : number; // Int32
    QuantityOnHand : number; // Int32
    ResourceID : number; // Int32
    Type : string;
    Value : string;
    CreationTime : string; // DateTime
    OrganizationUnit : EVA.Core.OrganizationUnitDto;
  }

  export class ListStockResourceStockMutations extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListStockResourceStockMutationsResponse> {
    __response : EVA.Core.Services.ListStockResourceStockMutationsResponse;
  }

  export class ListStockResourceStockMutationsResponse extends EVA.Core.PagedResultResponse<EVA.Core.StockMutationDto> {
  }

  export class ListStockResourceTypes extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListStockResourceTypesResponse> {
    __response : EVA.Core.Services.ListStockResourceTypesResponse;
  }

  export class ListStockResourceTypesResponse extends EVA.Core.ResponseMessage {
    StockResourceTypes : EVA.Core.IStockResourceType[];
  }

  export class AdjustStock extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    OrganizationUnitID : number; // Int32
    SourceLabel : number; // Int32
    Quantity : number; // Int32
    ResourceID : number; // Int32, nullable
    Reason : EVA.Core.StockMutationReasons;
    Remark : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetAvailabilityIndication extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetAvailabilityIndicationResponse> {
    OrganizationUnitIDs : number[];
    Products : EVA.Core.ProductQuantityDto[];
    FastestPickupShopOnly : boolean;
    DetailedShopInformation : boolean;
    IncludeAvailabilityTexts : boolean;
    __response : EVA.Core.Services.GetAvailabilityIndicationResponse;
  }

  export class GetAvailabilityIndicationResponse extends EVA.Core.ResponseMessage {
    Products : EVA.Core.ProductAvailabilityIndication[];
  }

  export class GetStockDetailsForProduct extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetStockDetailsForProductResponse> {
    ProductID : number; // Int32
    __response : EVA.Core.Services.GetStockDetailsForProductResponse;
  }

  export class GetStockDetailsForProductResponse extends EVA.Core.ResponseMessage {
    Product : EVA.Core.Services.GetStockDetailsForProductResponseProductWithDeliveryPromisedDelivery;
    QuantityOnHand : number; // Int32
    SellableQuantityAvailable : number; // Int32
    StockPerLabel : { [ key : number ] : number };
    StockInTransit : EVA.Core.Services.GetStockDetailsForProductResponseInTransit[];
    SellableStockInStoresWithinApplication : number; // Int32
    SellableStockInWarehouses : EVA.Core.Services.GetStockDetailsForProductResponseOrganizationUnitWithStock[];
  }

  export class GetStockDetailsForProductResponseProductWithDeliveryPromisedDelivery extends EVA.Core.ProductDto {
    PromisedDeliveryDate : string; // DateTime
    PromisedDeliveryStatus : EVA.Core.ProductPromisedDeliveryStatuses;
    PromisedDeliveryQuantity : number; // Int32
    PromisedDeliveryStatusID : number; // Int32
  }

  export class GetStockDetailsForProductResponseInTransit {
    DeliveryNoteNumber : string;
    CarrierReferenceID : string;
    QuantityOrdered : number; // Int32
  }

  export class GetStockDetailsForProductResponseOrganizationUnitWithStock {
    ID : number; // Int32
    Name : string;
    SellableStock : number; // Int32
  }

  export class GetStockLabels extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetStockLabelsResponse> {
    __response : EVA.Core.Services.GetStockLabelsResponse;
  }

  export class GetStockLabelsResponse extends EVA.Core.ResponseMessage {
    StockLabels : EVA.Core.Services.GetStockLabelsResponseStockLabelDto[];
  }

  export class GetStockLabelsResponseStockLabelDto {
    ID : number; // Int32
    Name : string;
    AllowedTypes : string[];
    AllowedDirections : string[];
    Description : string;
  }

  export class ListStockForOrganizationUnits extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListStockForOrganizationUnitsResponse> {
    DateTime : string; // DateTime, nullable
    OrganizationUnitIDs : number[];
    DownloadOverview : boolean;
    Query : string;
    __response : EVA.Core.Services.ListStockForOrganizationUnitsResponse;
  }

  export class ListStockForOrganizationUnitsResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.ListStockForOrganizationUnitsResponseStockDto> {
    Products : { [ key : number ] : EVA.Core.Services.ListStockForOrganizationUnitsResponseProductDto };
    Url : string;
  }

  export class ListStockForOrganizationUnitsResponseStockDto {
    ProductID : number; // Int32
    QuantityOnHand : number; // Int32
    QuantityCommitted : number; // Int32
    QuantityAvailable : number; // Int32
    StockLabel : number; // Int32
    OrganizationUnitID : number; // Int32
    OrganizationUnitName : string;
  }

  export class ListStockForOrganizationUnitsResponseProductDto {
    Product : any;
    TaxRate : number; // Decimal
    TaxCodeID : number; // Int32
    UnitCost : number; // Decimal
    UnitPrice : number; // Decimal
  }

  export class ListStockMutations extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListStockMutationsResponse> {
    __response : EVA.Core.Services.ListStockMutationsResponse;
  }

  export class ListStockMutationsResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.StockMutationWithFinancialPeriodDto> {
  }

  export class StockMutationWithFinancialPeriodDto extends EVA.Core.StockMutationDto {
    FinancialPeriod : EVA.Core.FinancialPeriodDto;
  }

  export class MoveStock extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    OrganizationUnitID : number; // Int32
    SourceLabel : number; // Int32
    DestinationLabel : number; // Int32
    Quantity : number; // Int32
    SourceResourceID : number; // Int32, nullable
    DestinationResourceID : number; // Int32, nullable
    Remark : string;
    Reason : EVA.Core.StockMutationReasons;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class SearchStockByFields extends EVA.Core.PagedResultRequest<EVA.Core.Services.SearchStockResponse> {
    Query : string;
    ProductID : number; // Int32, nullable
    BackendID : string;
    CustomID : string;
    __response : EVA.Core.Services.SearchStockResponse;
  }

  export class SearchStockResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.ProductWithStockDto> {
  }

  export class ProductWithStockDto extends EVA.Core.ProductDto {
    Stocks : EVA.Core.Services.StockDto[];
    TotalQuantityOnHand : number; // Int32
  }

  export class StockDto {
    ProductID : number; // Int32
    Product : EVA.Core.ProductDto;
    OrganizationUnitID : number; // Int32
    StockLabel : number; // Int32
    StockLabelID : number; // Int32
    ResourceID : number; // Int32, nullable
    QuantityOnHand : number; // Int32
    QuantityCommitted : number; // Int32
    QuantityAvailable : number; // Int32
    Remark : string;
  }

  export class UpdateStock extends EVA.Core.RequestMessageWithEmptyResponse {
    OrganizationUnitID : number; // Int32, nullable
    Stock : { [ key : number ] : number };
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetPurchaseOrderShipment extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetPurchaseOrderShipmentResponse> {
    ShipmentID : number; // Int32
    __response : EVA.Core.Services.GetPurchaseOrderShipmentResponse;
  }

  export class GetPurchaseOrderShipmentResponse extends EVA.Core.ResponseMessage {
    Shipment : EVA.Core.PurchaseOrderShipmentDto;
  }

  export class GetShipmentLines extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetShipmentLinesResponse> {
    ShipmentID : number; // Int32
    __response : EVA.Core.Services.GetShipmentLinesResponse;
  }

  export class GetShipmentLinesResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.GetShipmentLinesResponseModel[];
  }

  export class GetShipmentLinesResponseModel {
    ID : number; // Int32
    ProductID : number; // Int32
    Description : string;
    QuantityShipped : number; // Int32
    CurrencyID : string;
    UnitPrice : number; // Decimal
    ExchangeRate : number; // Decimal
    ForeignUnitPrice : number; // Decimal
    ForeignTotalAmount : number; // Decimal
  }

  export class ListPurchaseOrderShipmentLines extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListPurchaseOrderShipmentLinesResponse> {
    ShipmentID : number; // Int32
    __response : EVA.Core.Services.ListPurchaseOrderShipmentLinesResponse;
  }

  export class ListPurchaseOrderShipmentLinesResponse extends EVA.Core.PagedResultResponse<EVA.Core.PurchaseOrderShipmentLineDto> {
  }

  export class ListPurchaseOrderShipments extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListPurchaseOrderShipmentsResponse> {
    OrganizationUnitID : number; // Int32, nullable
    BackendID : string;
    TrackingCode : string;
    IsCompleted : boolean;
    __response : EVA.Core.Services.ListPurchaseOrderShipmentsResponse;
  }

  export class ListPurchaseOrderShipmentsResponse extends EVA.Core.PagedResultResponse<EVA.Core.PurchaseOrderShipmentDto> {
  }

  export class ProducePackingSlip extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    StationID : number; // Int32, nullable
    Download : boolean;
    Print : boolean;
    ShipmentID : number; // Int32
    __response : EVA.Core.ResourceResponseMessage;
  }

  export class ProducePickSlip extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    StationID : number; // Int32, nullable
    Download : boolean;
    Print : boolean;
    OrderID : number; // Int32
    __response : EVA.Core.ResourceResponseMessage;
  }

  export class GetSetting extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetSettingResponse> {
    OrganizationUnitID : number; // Int32, nullable
    Key : string;
    __response : EVA.Core.Services.GetSettingResponse;
  }

  export class GetSettingResponse extends EVA.Core.ResponseMessage {
    Value : string;
  }

  export class ListSettings extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListSettingsResponse> {
    OrganizationUnitID : number; // Int32
    KeyPrefix : string;
    __response : EVA.Core.Services.ListSettingsResponse;
  }

  export class ListSettingsResponse extends EVA.Core.ResponseMessage {
    Settings : { [ key : string ] : string };
  }

  export class SetSetting extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.SetSettingResponse> {
    OrganizationUnitID : number; // Int32, nullable
    Key : string;
    Value : string;
    __response : EVA.Core.Services.SetSettingResponse;
  }

  export class SetSettingResponse extends EVA.Core.ResponseMessage {
  }

  export class UnsetSetting extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.UnsetSettingResponse> {
    OrganizationUnitID : number; // Int32, nullable
    Key : string;
    __response : EVA.Core.Services.UnsetSettingResponse;
  }

  export class UnsetSettingResponse extends EVA.Core.ResponseMessage {
  }

  export class ApprovePendingUser extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetRole extends EVA.Core.GetRequestGeneric<EVA.Core.Services.GetRoleResponse> {
    __response : EVA.Core.Services.GetRoleResponse;
  }

  export class GetRoleResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.GetRoleResponseRoleWithFunctionalitiesDto;
  }

  export class RoleDto {
    ID : number; // Int32
    Name : string;
    UserTypeID : number; // Int32
    ApplicationID : number; // Int32
    Code : string;
  }

  export class GetRoleResponseRoleWithFunctionalitiesDto extends EVA.Core.Services.RoleDto {
    Functionalities : string[];
  }

  export class ListRoles extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListRolesResponse> {
    __response : EVA.Core.Services.ListRolesResponse;
  }

  export class ListRolesResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.RoleDto> {
  }

  export class CreateRole extends EVA.Core.CreateRequest<EVA.Core.Services.RoleDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }

  export class UpdateRole extends EVA.Core.UpdateRequest<EVA.Core.Services.RoleDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteRole extends EVA.Core.DeleteRequest implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class AttachFunctionalitiesToRole extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    RoleID : number; // Int32
    Functionalities : string[];
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DetachFunctionalitiesFromRole extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    RoleID : number; // Int32
    Functionalities : string[];
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetAvailableRoles extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetAvailableRolesResponse> {
    UserID : number; // Int32
    __response : EVA.Core.Services.GetAvailableRolesResponse;
  }

  export class GetAvailableRolesResponse extends EVA.Core.ResponseMessage {
    AvailableRoles : EVA.Core.Services.RoleDto[];
  }

  export class GetFlattenedFunctionalityByUserID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetFlattenedFunctionalityByUserIDResponse> {
    UserID : number; // Int32
    OrganizationUnitID : number; // Int32
    __response : EVA.Core.Services.GetFlattenedFunctionalityByUserIDResponse;
  }

  export class GetFlattenedFunctionalityByUserIDResponse extends EVA.Core.ResponseMessage {
    Functionalities : string[];
  }

  export class GetFunctionalitiesByUserID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetFunctionalitiesByUserIDResponse> {
    UserID : number; // Int32
    OrganizationUnitID : number; // Int32
    __response : EVA.Core.Services.GetFunctionalitiesByUserIDResponse;
  }

  export class GetFunctionalitiesByUserIDResponse extends EVA.Core.ResponseMessage {
    AvailableFunctionalities : string[];
    CurrentFunctionalities : string[];
    CurrentFunctionalitiesExtended : EVA.Core.Services.FunctionalityDto[];
  }

  export class FunctionalityDto {
    Functionality : string;
    EndDate : string; // DateTime, nullable
    DisableHierarchy : boolean;
    OrganizationUnitID : number; // Int32
    OrganizationUnitName : string;
    RoleID : number; // Int32, nullable
    RoleName : string;
  }

  export class GetSupportedFunctionalities extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetSupportedFunctionalitiesResponse> {
    __response : EVA.Core.Services.GetSupportedFunctionalitiesResponse;
  }

  export class GetSupportedFunctionalitiesResponse extends EVA.Core.ResponseMessage {
    Functionalities : string[];
  }

  export class GetUserRolesByUserID extends EVA.Core.PagedResultRequest<EVA.Core.Services.GetUserRolesByUserIDResponse> {
    UserID : number; // Int32
    OrganizationUnitID : number; // Int32
    __response : EVA.Core.Services.GetUserRolesByUserIDResponse;
  }

  export class GetUserRolesByUserIDResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.GetUserRolesByUserIDResponseUserRoleDto[];
  }

  export class GetUserRolesByUserIDResponseUserRoleDto {
    ID : number; // Int32
    UserID : number; // Int32
    OrganizationUnitID : number; // Int32
    RoleID : number; // Int32
    EndDate : string; // DateTime, nullable
    DisableHierarchy : boolean;
    Pending : boolean;
    Role : EVA.Core.Services.RoleDto;
  }

  export class ListPendingUsers extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListPendingUsersResponse> {
    __response : EVA.Core.Services.ListPendingUsersResponse;
  }

  export class ListPendingUsersResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.PendingUser> {
  }

  export class PendingUser {
    ID : number; // Int32
    FullName : string;
    EmailAddress : string;
    GravatarHash : string;
  }

  export class UpdateUserFunctionalities extends EVA.Core.RequestMessageWithEmptyResponse {
    Data : EVA.Core.Services.UpdatedUserFunctionalitiesDto[];
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class UpdatedUserFunctionalitiesDto {
    UserID : number; // Int32
    OrganizationUnitID : number; // Int32
    Functionalities : EVA.Core.Services.UpdatedFunctionalityDto[];
  }

  export class UpdatedFunctionalityDto {
    Functionality : string;
    IsRemoved : boolean;
    EndDate : string; // DateTime, nullable
    DisableHierarchy : boolean;
  }

  export class UpdateUserRoles extends EVA.Core.RequestMessageWithEmptyResponse {
    RoleID : number; // Int32
    OrganizationUnitID : number; // Int32
    IsRemoved : boolean;
    UserID : number; // Int32
    EndDate : string; // DateTime, nullable
    UserType : EVA.Core.UserTypes;
    DisableHierarchy : boolean;
    Pending : boolean;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CompleteReturnRequest extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CreateCMA extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    ReturnRequest : EVA.Core.Services.CMARequest;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CMARequest {
    ID : number; // Int32
    Reference : string;
    Lines : EVA.Core.Services.CMARequestLine[];
  }

  export class CMARequestLine {
    ID : number; // Int32
    ProductID : number; // Int32
    Quantity : number; // Int32
    ResourceID : number; // Int32, nullable
    Reason : string;
  }

  export class CreateRMA extends EVA.Core.RequestMessageWithEmptyResponse {
    Lines : EVA.Core.Services.RMARequestLine[];
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class RMARequestLine {
    Reference : string;
    ReturnRequestLineID : number; // Int32
  }

  export class DeleteRMALines extends EVA.Core.RequestMessageWithEmptyResponse {
    ReturnRequestLineIDs : number[];
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteRMA extends EVA.Core.RequestMessageWithEmptyResponse {
    ReturnRequestID : number; // Int32
    ReturnRequestLineIDs : number[];
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetReturnRequest extends EVA.Core.GetRequestGeneric<EVA.Core.Services.GetReturnRequestResponse> {
    __response : EVA.Core.Services.GetReturnRequestResponse;
  }

  export class GetReturnRequestResponse extends EVA.Core.GetResponse<EVA.Core.Services.ReturnRequestDto> {
  }

  export class ReturnRequestDto {
    ID : number; // Int32
    Lines : EVA.Core.Services.ReturnRequestLineDto[];
    Reference : string;
    Number : string;
    Status : EVA.Core.ReturnRequestStatus;
    Type : EVA.Core.ReturnRequestTypes;
    CreationTime : string; // DateTime
    OrganizationUnitID : number; // Int32
  }

  export class ReturnRequestLineDto {
    ID : number; // Int32
    Product : EVA.Core.ProductDto;
    ProductID : number; // Int32
    Quantity : number; // Int32
    ResourceID : number; // Int32, nullable
    Reason : string;
    StockMutationID : number; // Int32, nullable
  }

  export class ListAvailableRMA extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListAvailableRMAResponse> {
    __response : EVA.Core.Services.ListAvailableRMAResponse;
  }

  export class ListAvailableRMAResponse extends EVA.Core.ResponseMessage {
    Lines : EVA.Core.Services.ReturnRequestLineDto[];
  }

  export class ListReturnRequest extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListReturnRequestResponse> {
    __response : EVA.Core.Services.ListReturnRequestResponse;
  }

  export class ListReturnRequestResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.ReturnRequestDto> {
  }

  export class ProduceReturnRequestDocument extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    ReturnRequestID : number; // Int32
    StationID : number; // Int32, nullable
    DownloadDocument : boolean;
    __response : EVA.Core.ResourceResponseMessage;
  }

  export class UpdateCMA extends EVA.Core.RequestMessageWithEmptyResponse {
    ReturnRequest : EVA.Core.Services.CMARequest;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CreateRecurringTask extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string;
    FullName : string;
    Cron : string;
    Arguments : { [ key : string ] : string };
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteRecurringTask extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class EnqueueTask extends EVA.Core.RequestMessageWithEmptyResponse {
    FullName : string;
    Arguments : { [ key : string ] : string };
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListAvailableRecurringTasks extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListAvailableRecurringTasksResponse> {
    __response : EVA.Core.Services.ListAvailableRecurringTasksResponse;
  }

  export class ListAvailableRecurringTasksResponse extends EVA.Core.ResponseMessage {
    Tasks : EVA.Core.Services.ListAvailableRecurringTasksResponseTaskPluginDto[];
  }

  export class ListAvailableRecurringTasksResponseTaskPluginDto {
    Name : string;
    FullName : string;
    Description : string;
    AvailableSettings : EVA.Core.Services.TaskPluginSettings[];
    DefaultName : string;
    DefaultCron : string;
  }

  export class TaskPluginSettings {
    Key : string;
    Description : string;
    Required : boolean;
    Default : any;
  }

  export class ListRecurringTasks extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListRecurringTasksResponse> {
    __response : EVA.Core.Services.ListRecurringTasksResponse;
  }

  export class ListRecurringTasksResponse extends EVA.Core.ResponseMessage {
    Tasks : EVA.Core.RecurringTask[];
  }

  export class ListRecurringTasks2 extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListRecurringTasks2Response> {
    __response : EVA.Core.Services.ListRecurringTasks2Response;
  }

  export class ListRecurringTasks2Response extends EVA.Core.PagedResultResponse<EVA.Core.RecurringTask> {
  }

  export class ManualTriggerRecurringTask extends EVA.Core.RequestMessageWithEmptyResponse {
    Token : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class TriggerRecurringTask extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class UpdateRecurringTask extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string;
    FullName : string;
    Cron : string;
    Arguments : { [ key : string ] : string };
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class AddPushNotificationDevice extends EVA.Core.RequestMessageWithEmptyResponse {
    DeviceToken : string;
    DeviceOS : string;
    MobileAppID : string;
    BackendSystemID : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class RemovePushNotificationDevice extends EVA.Core.RequestMessageWithEmptyResponse {
    DeviceToken : string;
    BackendSystemID : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class SendPushNotificationBatch extends EVA.Core.RequestMessageWithEmptyResponse {
    Title : string;
    Message : string;
    UserIDs : number[];
    Priority : EVA.Core.PushNotificationPriority;
    TimeToLive : number; // Int32, nullable
    Sound : string;
    SilentNotification : boolean;
    Payload : any;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class AddLineToPurchaseOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.AddLineToPurchaseOrderResponse> {
    OrderID : number; // Int32
    ProductID : number; // Int32
    Quantity : number; // Int32
    UnitPrice : number; // Decimal
    RequestedDate : string; // DateTime, nullable
    Reference : string;
    __response : EVA.Core.Services.AddLineToPurchaseOrderResponse;
  }

  export class AddLineToPurchaseOrderResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.AddLineToPurchaseOrderResponseModel;
  }

  export class AddLineToPurchaseOrderResponseModel {
    ID : number; // Int32
    ProductID : number; // Int32
    Quantity : number; // Int32
    UnitPrice : number; // Decimal
    RequestedDate : string; // DateTime, nullable
    Reference : string;
  }

  export class CreatePurchaseOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreatePurchaseOrderResponse> {
    OrganizationUnitID : number; // Int32
    SupplierID : number; // Int32, nullable
    SupplierReference : string;
    __response : EVA.Core.Services.CreatePurchaseOrderResponse;
  }

  export class CreatePurchaseOrderResponse extends EVA.Core.ResponseMessage {
    Success : boolean;
    ID : number; // Int32
  }

  export class DeletePurchaseOrderLine extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ExportUnshippedPurchaseOrdersToExcel extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ExportUnshippedPurchaseOrdersToExcelResponse> {
    ShipFromOrganizationUnitID : number; // Int32
    __response : EVA.Core.Services.ExportUnshippedPurchaseOrdersToExcelResponse;
  }

  export class ExportUnshippedPurchaseOrdersToExcelResponse extends EVA.Core.ResponseMessage {
    DownloadUrl : string;
  }

  export class FullyReceiveDeliveryNoteNumber extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.FullyReceiveDeliveryNoteNumberResponse> {
    DeliveryNoteNumber : string;
    __response : EVA.Core.Services.FullyReceiveDeliveryNoteNumberResponse;
  }

  export class FullyReceiveDeliveryNoteNumberResponse extends EVA.Core.ResponseMessage {
    ReservedOrdersCount : number; // Int32
  }

  export class FullyShipPurchaseOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    PurchaseOrderID : number; // Int32
    ShipmentBackendID : string;
    BackendSystemID : string;
    TrackingCode : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetOrganizationUnitCreditBalance extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetOrganizationUnitCreditBalanceResponse> {
    OrganizationUnitID : number; // Int32
    __response : EVA.Core.Services.GetOrganizationUnitCreditBalanceResponse;
  }

  export class GetOrganizationUnitCreditBalanceResponse extends EVA.Core.ResponseMessage {
    CreditBalance : number; // Decimal
  }

  export class GetShipmentDetails2 extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetShipmentDetails2Response> {
    DeliveryNoteNumber : string;
    __response : EVA.Core.Services.GetShipmentDetails2Response;
  }

  export class GetShipmentDetails2Response extends EVA.Core.ResponseMessage {
    ReceiveMethod : EVA.Core.Services.PurchaseOrderReceiveMethods;
    WorkSet : EVA.Core.Services.ReceiveShipmentWorkSet;
  }

  export enum PurchaseOrderReceiveMethods {
    Manual = 0,
    Automatic = 1,
  }

  export class ReceiveShipmentWorkSet {
    DeliveryNoteNumber : string;
    Lines : EVA.Core.Services.ReceiveShipmentWorkSetLine[];
  }

  export class ReceiveShipmentWorkSetLine {
    ProductID : number; // Int32
    ProductPrimitiveName : string;
    QuantityOrdered : number; // Int32
    Receipts : EVA.Core.Services.ReceiveShipmentWorkSetLineReceipt[];
    RequiredResourceTypes : EVA.Core.Services.StockResourceTypeDto[];
    QuantityAlreadyReceived : number; // Int32
    QuantityShipped : number; // Int32
  }

  export class ReceiveShipmentWorkSetLineReceipt {
    QuantityReceived : number; // Int32
    Resource : EVA.Core.Services.ReceiveShipmentWorkSetLineResource;
  }

  export class ReceiveShipmentWorkSetLineResource {
    ResourceID : number; // Int32, nullable
    Resources : { [ key : string ] : string };
  }

  export class GetSupplierStockForProduct extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetSupplierStockForProductResponse> {
    OrganizationUnitID : number; // Int32
    SupplierID : number; // Int32
    ProductID : number; // Int32
    __response : EVA.Core.Services.GetSupplierStockForProductResponse;
  }

  export class GetSupplierStockForProductResponse extends EVA.Core.ResponseMessage {
    AvailableStock : number; // Int32
  }

  export class ModifyPurchaseOrderLine extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    UnitPrice : number; // Decimal, nullable
    RequestedDate : string; // DateTime, nullable
    Reference : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class PlacePurchaseOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ProcessUnshippedPurchaseOrdersFromExcel extends EVA.Core.RequestMessageWithEmptyResponse {
    Data : number[];
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GeneratePurchaseOrderExcelSample extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    __response : EVA.Core.ResourceResponseMessage;
  }

  export class UploadPurchaseOrderExcel extends EVA.Core.RequestMessageWithEmptyResponse {
    Data : number[];
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ReceivePurchaseOrderShipment extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ReceivePurchaseOrderShipmentResponse> {
    ShipmentID : number; // Int32
    QuantityReceived : { [ key : number ] : number };
    __response : EVA.Core.Services.ReceivePurchaseOrderShipmentResponse;
  }

  export class ReceivePurchaseOrderShipmentResponse extends EVA.Core.ResponseMessage {
    Success : boolean;
    Result : EVA.Core.ReceiveShipmentResult;
  }

  export class ReceiveShipment extends EVA.Core.RequestMessageWithEmptyResponse {
    WorkSet : EVA.Core.Services.ReceiveShipmentWorkSet;
    CompleteShipment : boolean;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ShipPurchaseOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ShipPurchaseOrderResponse> {
    OrderID : number; // Int32
    BackendID : string;
    TrackingCode : string;
    ShipmentDate : string; // DateTime
    Lines : EVA.Core.Services.ShipPurchaseOrderLine[];
    __response : EVA.Core.Services.ShipPurchaseOrderResponse;
  }

  export class ShipPurchaseOrderResponse extends EVA.Core.ResponseMessage {
    ShipmentID : number; // Int32
  }

  export class ShipPurchaseOrderLine {
    OrderLineID : number; // Int32
    QuantityToShip : number; // Int32
  }

  export class GetConfigurableProductDetail extends EVA.Core.GetRequestGeneric<EVA.Core.Services.GetConfigurableProductDetailResponse> {
    Includes : string[];
    __response : EVA.Core.Services.GetConfigurableProductDetailResponse;
  }

  export class GetConfigurableProductDetailResponse extends EVA.Core.ResponseMessage {
    Configurable : EVA.PIM.Core.ConfigurableProductDto;
  }

  export class GetConfigurableProductsDetail extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetConfigurableProductsDetailResponse> {
    ProductIDs : number[];
    Includes : string[];
    __response : EVA.Core.Services.GetConfigurableProductsDetailResponse;
  }

  export class GetConfigurableProductsDetailResponse extends EVA.Core.ResponseMessage {
    Configurables : { [ key : number ] : EVA.PIM.Core.ConfigurableProductDto };
  }

  export class GetProductByBarcode extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetProductByBarcodeResponse> {
    Barcode : string;
    __response : EVA.Core.Services.GetProductByBarcodeResponse;
  }

  export class GetProductByBarcodeResponse extends EVA.Core.ResponseMessage {
    Result : any;
  }

  export class GetProductDetail extends EVA.Core.GetRequestGeneric<EVA.Core.Services.GetProductDetailResponse> {
    __response : EVA.Core.Services.GetProductDetailResponse;
  }

  export class GetProductDetailResponse extends EVA.Core.GetResponse<any> {
  }

  export class GetProductImage extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetProductImageResponse> {
    ProductID : number; // Int32
    SequenceID : number; // Int32
    Width : number; // Int32
    Height : number; // Int32
    Format : string;
    __response : EVA.Core.Services.GetProductImageResponse;
  }

  export class GetProductImageResponse extends EVA.Core.ResponseMessage {
    Format : string;
    Path : string;
    Description : string;
    Stream : number[];
  }

  export class GetProductPrices extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetProductPricesResponse> {
    ProductIDs : number[];
    __response : EVA.Core.Services.GetProductPricesResponse;
  }

  export class GetProductPricesResponse extends EVA.Core.ResponseMessage {
    Prices : EVA.Core.Services.PriceInfo[];
  }

  export class PriceInfo {
    ProductID : number; // Int32
    PriceListID : number; // Int32
    PriceListUsageTypeID : number; // Int32
    PriceListUsageTypeName : string;
    CurrencyID : string;
    TaxRate : number; // Decimal
    Price : number; // Decimal
    PriceInTax : number; // Decimal
    OriginalPrice : number; // Decimal, nullable
    OriginalPriceInTax : number; // Decimal, nullable
  }

  export class GetProductPricing extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetProductPricingResponse> {
    ProductID : number; // Int32
    __response : EVA.Core.Services.GetProductPricingResponse;
  }

  export class GetProductPricingResponse extends EVA.Core.ResponseMessage {
    UnitPrice : number; // Decimal
    OriginalUnitPrice : number; // Decimal, nullable
    TaxRate : number; // Decimal
    UnitPriceInTax : number; // Decimal
    OriginalUnitPriceInTax : number; // Decimal, nullable
    UnitCost : number; // Decimal, nullable
  }

  export class GetProductSearchSuggestions extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetProductSearchSuggestionsResponse> {
    Text : string;
    MaxSuggestions : number; // Int32, nullable
    __response : EVA.Core.Services.GetProductSearchSuggestionsResponse;
  }

  export class GetProductSearchSuggestionsResponse extends EVA.Core.ResponseMessage {
    Suggestions : EVA.Core.SuggestionModel[];
  }

  export class ListBrandsPaged extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListBrandsPagedResponse> {
    __response : EVA.Core.Services.ListBrandsPagedResponse;
  }

  export class ListBrandsPagedResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.BrandDto> {
  }

  export class BrandDto {
    ID : number; // Int32
    Name : string;
    BackendID : string;
  }

  export class ListBrands extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListBrandsResponse> {
    __response : EVA.Core.Services.ListBrandsResponse;
  }

  export class ListBrandsResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.BrandDto[];
  }

  export class CreateProductAvailabilityData extends EVA.Core.CreateRequest<EVA.Core.ProductAvailabilityDataDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteProductAvailabilityData extends EVA.Core.DeleteRequest implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetProductAvailabilityData extends EVA.Core.GetRequestGeneric<EVA.Core.Services.GetProductAvailabilityDataResponse> {
    __response : EVA.Core.Services.GetProductAvailabilityDataResponse;
  }

  export class GetProductAvailabilityDataResponse extends EVA.Core.GetResponse<EVA.Core.ProductAvailabilityDataDto> {
  }

  export class ListProductAvailabilityData extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListProductAvailabilityDataResponse> {
    __response : EVA.Core.Services.ListProductAvailabilityDataResponse;
  }

  export class ListProductAvailabilityDataResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.ProductAvailabilityDataDto[];
  }

  export class UpdateProductAvailabilityData extends EVA.Core.UpdateRequest<EVA.Core.ProductAvailabilityDataDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class SearchBrands extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.SearchBrandsResponse> {
    PageSize : number; // Int32, nullable
    Query : string;
    __response : EVA.Core.Services.SearchBrandsResponse;
  }

  export class SearchBrandsResponse extends EVA.Core.ResponseMessage {
    Brands : EVA.Core.BrandNameInfo[];
  }

  export class UploadSupplierProductsBase extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.UploadSupplierProductsResponse> {
    OrganizationUnitID : number; // Int32, nullable
    Data : number[];
  }

  export class UploadSupplierProductsResponse extends EVA.Core.ResponseMessage {
    TotalProductCount : number; // Int32
    FailedCount : number; // Int32
    Messages : { [ key : string ] : string };
    DeletedCount : number; // Int32
  }

  export class UploadSupplierProducts extends EVA.Core.Services.UploadSupplierProductsBase {
    __response : EVA.Core.Services.UploadSupplierProductsResponse;
  }

  export class UploadSupplierProductsStock extends EVA.Core.Services.UploadSupplierProductsBase {
    __response : EVA.Core.Services.UploadSupplierProductsResponse;
  }

  export class UploadSupplierProductsPricing extends EVA.Core.Services.UploadSupplierProductsBase {
    __response : EVA.Core.Services.UploadSupplierProductsResponse;
  }

  export class DownloadSupplierProductsSample extends EVA.Core.RequestMessageWithResourceResponse {
    __response : EVA.Core.ResourceResponseMessage;
  }

  export class DownloadSupplierProductsStockSample extends EVA.Core.RequestMessageWithResourceResponse {
    __response : EVA.Core.ResourceResponseMessage;
  }

  export class DownloadSupplierProductsPricingSample extends EVA.Core.RequestMessageWithResourceResponse {
    __response : EVA.Core.ResourceResponseMessage;
  }

  export class UpdateProductPricing extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    UnitPrice : number; // Decimal, nullable
    UnitCost : number; // Decimal, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetPriceListAdjustmentByID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetPriceListAdjustmentByIDResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetPriceListAdjustmentByIDResponse;
  }

  export class GetPriceListAdjustmentByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    PriceListID : number; // Int32
    PriceList : EVA.Core.Services.GetPriceListAdjustmentByIDResponsePriceListDto;
    Sequence : number; // Int32
    Name : string;
    Target : EVA.Core.PriceListAdjustmentTargets;
    EffectiveDate : string; // DateTime
    ExpireDate : string; // DateTime, nullable
    OverridePrice : boolean;
    Type : string;
    Data : any;
  }

  export class GetPriceListAdjustmentByIDResponsePriceListDto {
    Name : string;
    CurrencyID : string;
  }

  export class CreatePriceListAdjustment extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreatePriceListAdjustmentResponse> {
    PriceListID : number; // Int32
    Sequence : number; // Int32
    Name : string;
    Target : EVA.Core.PriceListAdjustmentTargets;
    EffectiveDate : string; // DateTime
    ExpireDate : string; // DateTime, nullable
    OverridePrice : boolean;
    Type : string;
    Data : any;
    __response : EVA.Core.Services.CreatePriceListAdjustmentResponse;
  }

  export class CreatePriceListAdjustmentResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }

  export class UpdatePriceListAdjustment extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    PriceListID : number; // Int32
    Sequence : number; // Int32
    Name : string;
    Target : EVA.Core.PriceListAdjustmentTargets;
    EffectiveDate : string; // DateTime
    ExpireDate : string; // DateTime, nullable
    OverridePrice : boolean;
    Type : string;
    Data : any;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeletePriceListAdjustment extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListPriceListAdjustments extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListPriceListAdjustmentsResponse> {
    __response : EVA.Core.Services.ListPriceListAdjustmentsResponse;
  }

  export class ListPriceListAdjustmentsResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.ListPriceListAdjustmentsResponsePriceListAdjustmentDto> {
  }

  export class ListPriceListAdjustmentsResponsePriceListAdjustmentDto {
    ID : number; // Int32
    PriceListID : number; // Int32
    PriceList : EVA.Core.Services.ListPriceListAdjustmentsResponsePriceListAdjustmentDtoPriceListDto;
    Sequence : number; // Int32
    Name : string;
    Target : EVA.Core.PriceListAdjustmentTargets;
    EffectiveDate : string; // DateTime
    ExpireDate : string; // DateTime, nullable
    OverridePrice : boolean;
    Type : string;
    Data : any;
  }

  export class ListPriceListAdjustmentsResponsePriceListAdjustmentDtoPriceListDto {
    Name : string;
    CurrencyID : string;
  }

  export class GetPriceListByID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetPriceListByIDResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetPriceListByIDResponse;
  }

  export class GetPriceListByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    Name : string;
    CurrencyID : string;
    IsActive : boolean;
  }

  export class CreatePriceList extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreatePriceListResponse> {
    Name : string;
    CurrencyID : string;
    IsActive : boolean;
    __response : EVA.Core.Services.CreatePriceListResponse;
  }

  export class CreatePriceListResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }

  export class UpdatePriceList extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Name : string;
    CurrencyID : string;
    IsActive : boolean;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeletePriceList extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListPriceLists extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListPriceListsResponse> {
    __response : EVA.Core.Services.ListPriceListsResponse;
  }

  export class ListPriceListsResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.ListPriceListsResponsePriceListDto> {
  }

  export class ListPriceListsResponsePriceListDto {
    ID : number; // Int32
    Name : string;
    CurrencyID : string;
    IsActive : boolean;
  }

  export class GetPriceListOrganizationUnitByID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetPriceListOrganizationUnitByIDResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetPriceListOrganizationUnitByIDResponse;
  }

  export class GetPriceListOrganizationUnitByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    OrganizationUnitID : number; // Int32
    OrganizationUnitName : string;
    PriceListID : number; // Int32
    PriceList : EVA.Core.Services.GetPriceListOrganizationUnitByIDResponsePriceListDto;
    PriceListUsageTypeID : number; // Int32
    PriceListUsageTypeName : string;
  }

  export class GetPriceListOrganizationUnitByIDResponsePriceListDto {
    Name : string;
    CurrencyID : string;
  }

  export class CreatePriceListOrganizationUnit extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreatePriceListOrganizationUnitResponse> {
    OrganizationUnitID : number; // Int32
    PriceListID : number; // Int32
    PriceListUsageTypeID : number; // Int32
    __response : EVA.Core.Services.CreatePriceListOrganizationUnitResponse;
  }

  export class CreatePriceListOrganizationUnitResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }

  export class UpdatePriceListOrganizationUnit extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    OrganizationUnitID : number; // Int32
    PriceListID : number; // Int32
    PriceListUsageTypeID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeletePriceListOrganizationUnit extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListPriceListOrganizationUnits extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListPriceListOrganizationUnitsResponse> {
    __response : EVA.Core.Services.ListPriceListOrganizationUnitsResponse;
  }

  export class ListPriceListOrganizationUnitsResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.ListPriceListOrganizationUnitsResponsePriceListOrganizationUnitDto> {
  }

  export class ListPriceListOrganizationUnitsResponsePriceListOrganizationUnitDto {
    ID : number; // Int32
    OrganizationUnitID : number; // Int32
    OrganizationUnitName : string;
    PriceListID : number; // Int32
    PriceList : EVA.Core.Services.ListPriceListOrganizationUnitsResponsePriceListOrganizationUnitDtoPriceListDto;
    PriceListUsageTypeID : number; // Int32
    PriceListUsageTypeName : string;
  }

  export class ListPriceListOrganizationUnitsResponsePriceListOrganizationUnitDtoPriceListDto {
    Name : string;
    CurrencyID : string;
  }

  export class GetPriceListUsageTypeByID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetPriceListUsageTypeByIDResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetPriceListUsageTypeByIDResponse;
  }

  export class GetPriceListUsageTypeByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    Name : string;
    Description : string;
  }

  export class CreatePriceListUsageType extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreatePriceListUsageTypeResponse> {
    Name : string;
    Description : string;
    __response : EVA.Core.Services.CreatePriceListUsageTypeResponse;
  }

  export class CreatePriceListUsageTypeResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }

  export class UpdatePriceListUsageType extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Description : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeletePriceListUsageType extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetPriceListUsageTypes extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetPriceListUsageTypesResponse> {
    __response : EVA.Core.Services.GetPriceListUsageTypesResponse;
  }

  export class GetPriceListUsageTypesResponse extends EVA.Core.ResponseMessage {
    PriceListUsageTypes : EVA.Core.Services.GetPriceListUsageTypesResponsePriceListUsageTypeDto[];
  }

  export class GetPriceListUsageTypesResponsePriceListUsageTypeDto {
    ID : number; // Int32
    Name : string;
    Description : string;
  }

  export class CreatePayment extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreatePaymentResponse> {
    OrderID : number; // Int32
    Code : string;
    Amount : number; // Decimal, nullable
    Properties : any;
    __response : EVA.Core.Services.CreatePaymentResponse;
  }

  export class CreatePaymentResponse extends EVA.Core.ResponseMessage {
    PaymentTransaction : EVA.Core.PaymentTransactionDto;
    OpenAmount : number; // Decimal
    Properties : any;
  }

  export class FinalizePayment extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.FinalizePaymentResponse> {
    PaymentTransactionID : number; // Int32
    Amount : number; // Decimal, nullable
    __response : EVA.Core.Services.FinalizePaymentResponse;
  }

  export class FinalizePaymentResponse extends EVA.Core.ResponseMessage {
    PaymentTransaction : EVA.Core.PaymentTransactionDto;
    OpenAmount : number; // Decimal
  }

  export class GetActivePaymentTypes extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetActivePaymentTypesResponse> {
    __response : EVA.Core.Services.GetActivePaymentTypesResponse;
  }

  export class GetActivePaymentTypesResponse extends EVA.Core.ResponseMessage {
    Result : string[];
  }

  export class ListPaymentTypes extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListPaymentTypesResponse> {
    __response : EVA.Core.Services.ListPaymentTypesResponse;
  }

  export class ListPaymentTypesResponse extends EVA.Core.ResponseMessage {
    Result : string[];
  }

  export class GetAvailablePaymentMethods extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetAvailablePaymentMethodsResponse> {
    OrderID : number; // Int32
    __response : EVA.Core.Services.GetAvailablePaymentMethodsResponse;
  }

  export class GetAvailablePaymentMethodsResponse extends EVA.Core.ResponseMessage {
    PaymentMethods : string[];
  }

  export class GetAvailableRefundPaymentMethods extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetAvailableRefundPaymentMethodsResponse> {
    UserID : number; // Int32
    CurrencyID : string;
    __response : EVA.Core.Services.GetAvailableRefundPaymentMethodsResponse;
  }

  export class GetAvailableRefundPaymentMethodsResponse extends EVA.Core.ResponseMessage {
    Methods : EVA.Core.Services.GetAvailableRefundPaymentMethodsResponsePaymentMethod[];
  }

  export class GetAvailableRefundPaymentMethodsResponsePaymentMethod {
    Code : string;
    Transactions : EVA.Core.Services.GetAvailableRefundPaymentMethodsResponseRefundablePaymentTransaction[];
  }

  export class GetAvailableRefundPaymentMethodsResponseRefundablePaymentTransaction {
    ID : number; // Int32
    BackendID : string;
    PaidAmount : number; // Decimal
    RefundableAmount : number; // Decimal
    Type : string;
  }

  export class GetPaymentTransaction extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetPaymentTransactionResponse> {
    PaymentTransactionID : number; // Int32
    __response : EVA.Core.Services.GetPaymentTransactionResponse;
  }

  export class GetPaymentTransactionResponse extends EVA.Core.ResponseMessage {
    PaymentTransaction : EVA.Core.PaymentTransactionDto;
  }

  export class GetPaymentTypeByID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetPaymentTypeByIDResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetPaymentTypeByIDResponse;
  }

  export class GetPaymentTypeByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    Name : string;
    Code : string;
    IsActive : boolean;
    HasChange : boolean;
    IsRoundingType : boolean;
    IncludeInCashJournal : boolean;
    IsExternal : boolean;
    ReturnAction : EVA.Core.PaymentReturnActions;
    LedgerClassID : string;
    PrintOnDocuments : boolean;
    ExtraCostProductID : number; // Int32, nullable
    BackendRelationID : string;
    BookPaymentMethodInvoice : boolean;
    KickbackRuleID : number; // Int32, nullable
    DelayFinancialBooking : boolean;
    CanBeUsedForAuthorization : boolean;
    Category : EVA.Core.PaymentTypeCategory;
  }

  export class CreatePaymentType extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreatePaymentTypeResponse> {
    Name : string;
    Code : string;
    IsActive : boolean;
    HasChange : boolean;
    IsRoundingType : boolean;
    IncludeInCashJournal : boolean;
    IsExternal : boolean;
    ReturnAction : EVA.Core.PaymentReturnActions;
    LedgerClassID : string;
    PrintOnDocuments : boolean;
    ExtraCostProductID : number; // Int32, nullable
    BackendRelationID : string;
    BookPaymentMethodInvoice : boolean;
    KickbackRuleID : number; // Int32, nullable
    DelayFinancialBooking : boolean;
    CanBeUsedForAuthorization : boolean;
    Category : EVA.Core.PaymentTypeCategory;
    __response : EVA.Core.Services.CreatePaymentTypeResponse;
  }

  export class CreatePaymentTypeResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }

  export class UpdatePaymentType extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Name : string;
    Code : string;
    IsActive : boolean;
    HasChange : boolean;
    IsRoundingType : boolean;
    IncludeInCashJournal : boolean;
    IsExternal : boolean;
    ReturnAction : EVA.Core.PaymentReturnActions;
    LedgerClassID : string;
    PrintOnDocuments : boolean;
    ExtraCostProductID : number; // Int32, nullable
    BackendRelationID : string;
    BookPaymentMethodInvoice : boolean;
    KickbackRuleID : number; // Int32, nullable
    DelayFinancialBooking : boolean;
    CanBeUsedForAuthorization : boolean;
    Category : EVA.Core.PaymentTypeCategory;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeletePaymentType extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListPaymentTypes2 extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListPaymentTypes2Response> {
    __response : EVA.Core.Services.ListPaymentTypes2Response;
  }

  export class ListPaymentTypes2Response extends EVA.Core.PagedResultResponse<EVA.Core.Services.ListPaymentTypes2ResponsePaymentTypeDto> {
  }

  export class ListPaymentTypes2ResponsePaymentTypeDto {
    ID : number; // Int32
    Name : string;
    Code : string;
    IsActive : boolean;
    HasChange : boolean;
    IsRoundingType : boolean;
    IncludeInCashJournal : boolean;
    IsExternal : boolean;
    ReturnAction : EVA.Core.PaymentReturnActions;
    LedgerClassID : string;
    PrintOnDocuments : boolean;
    ExtraCostProductID : number; // Int32, nullable
    BackendRelationID : string;
    BookPaymentMethodInvoice : boolean;
    KickbackRuleID : number; // Int32, nullable
    DelayFinancialBooking : boolean;
    CanBeUsedForAuthorization : boolean;
    Category : EVA.Core.PaymentTypeCategory;
  }

  export class RequestPaymentUpdate extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.RequestPaymentUpdateResponse> {
    PaymentTransactionID : number; // Int32
    __response : EVA.Core.Services.RequestPaymentUpdateResponse;
  }

  export class RequestPaymentUpdateResponse extends EVA.Core.ResponseMessage {
    PaymentTransaction : EVA.Core.PaymentTransactionDto;
  }

  export class CreateOrganizationOpeningHours extends EVA.Core.CreateRequest<EVA.Core.OpeningHoursDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    OpeningHoursDto : EVA.Core.OpeningHoursDto[];
    __response : EVA.Core.CreateResponse;
  }

  export class CreateOrganizationUnit extends EVA.Core.CreateRequest<EVA.Core.OrganizationUnitDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }

  export class DeleteOrganizationOpeningHours extends EVA.Core.DeleteRequest implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteOrganizationUnit extends EVA.Core.RequestMessageWithEmptyResponse {
    OrganizationUnitID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetOrganizationUnitDetailed extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetOrganizationUnitDetailedResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetOrganizationUnitDetailedResponse;
  }

  export class GetOrganizationUnitDetailedResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    ParentID : number; // Int32, nullable
    Name : string;
    Description : string;
    AddressID : number; // Int32, nullable
    Address : EVA.Core.AddressDto;
    EmailAddress : string;
    PhoneNumber : string;
    Type : EVA.Core.OrganizationUnitTypes;
    Status : EVA.Core.OrganizationUnitStatus;
    OpeningHours : EVA.Core.OpeningHoursDto[];
    Subnet : string;
    RegisterCashLimit : number; // Decimal
    SafeCashLimit : number; // Decimal
    VisibleByApplicationID : number; // Int32
    Latitude : number; // Double, nullable
    Longitude : number; // Double, nullable
    CocNumber : string;
    VatNumber : string;
    BankAccount : string;
    CurrencyID : string;
    TimeZone : string;
  }

  export class GetOrganizationUnitOpeningHoursForPeriod extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetOrganizationUnitOpeningHoursForPeriodResponse> {
    OrganizationUnitID : number; // Int32
    From : string; // DateTime
    To : string; // DateTime
    __response : EVA.Core.Services.GetOrganizationUnitOpeningHoursForPeriodResponse;
  }

  export class GetOrganizationUnitOpeningHoursForPeriodResponse extends EVA.Core.ResponseMessage {
    OpeningHours : { [ key : string ] : EVA.Core.OpeningClosingHourPair };
  }

  export class GetOrganizationUnit extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetOrganizationUnitResponse> {
    OrganizationUnitID : number; // Int32
    __response : EVA.Core.Services.GetOrganizationUnitResponse;
  }

  export class GetOrganizationUnitResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.OrganizationUnitDto;
  }

  export class GetOrganizationUnitSettings extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetOrganizationUnitSettingsResponse> {
    OrganizationUnitID : number; // Int32
    __response : EVA.Core.Services.GetOrganizationUnitSettingsResponse;
  }

  export class GetOrganizationUnitSettingsResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    ParentID : number; // Int32, nullable
    BackendID : string;
    BackendRelationID : string;
    BackendCompanyID : string;
    BranchNumber : string;
    GlobalLocationNumber : string;
    RegisterCashLimit : number; // Decimal
    SafeCashLimit : number; // Decimal
    TypeID : number; // Int32
    Subnet : string;
    UseForAccounting : boolean;
    AttachedToUserID : number; // Int32, nullable
    IpAddress : string;
    CountryID : string;
    CurrencyID : string;
    TimeZone : string;
  }

  export class ListOrganizationUnitByProximity extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListOrganizationUnitByProximityResponse> {
    Latitude : number; // Double
    Longitude : number; // Double
    __response : EVA.Core.Services.ListOrganizationUnitByProximityResponse;
  }

  export class ListOrganizationUnitByProximityResponse extends EVA.Core.PagedResultResponse<EVA.Core.OrganizationUnitDto> {
  }

  export class ListOrganizationUnitsByType extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListOrganizationUnitsByTypeResponse> {
    OrganizationUnitTypes : EVA.Core.OrganizationUnitTypes;
    IncludeParentApplications : boolean;
    __response : EVA.Core.Services.ListOrganizationUnitsByTypeResponse;
  }

  export class ListOrganizationUnitsByTypeResponse extends EVA.Core.PagedResultResponse<EVA.Core.OrganizationUnitDto> {
  }

  export class ListOrganizationUnits extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListOrganizationUnitsResponse> {
    __response : EVA.Core.Services.ListOrganizationUnitsResponse;
  }

  export class ListOrganizationUnitsResponse extends EVA.Core.PagedResultResponse<EVA.Core.OrganizationUnitDto> {
  }

  export class UpdateOrganizationOpeningHours extends EVA.Core.UpdateRequest<EVA.Core.OpeningHoursDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.Services.UpdateOrganizationOpeningHoursResponse> {
    openingHoursDto : EVA.Core.OpeningHoursDto[];
    __response : EVA.Core.Services.UpdateOrganizationOpeningHoursResponse;
  }

  export class UpdateOrganizationOpeningHoursResponse extends EVA.Core.ResponseMessage {
    Success : boolean;
  }

  export class UpdateOrganizationUnit2 extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Name : string;
    Description : string;
    OpeningHours : EVA.Core.OpeningHoursDto[];
    AddressID : number; // Int32, nullable
    Address : EVA.Core.AddressDto;
    StatusID : number; // Int32
    Latitude : number; // Double
    Longitude : number; // Double
    BankAccount : string;
    CocNumber : string;
    VatNumber : string;
    EmailAddress : string;
    PhoneNumber : string;
    CompanyID : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class UpdateOrganizationUnit extends EVA.Core.UpdateRequest<EVA.Core.OrganizationUnitDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    OrganizationUnits : EVA.Core.OrganizationUnitDto[];
    AllowTypeUpdate : boolean;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class UpdateOrganizationUnitSettings extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    ParentID : number; // Int32, nullable
    BackendID : string;
    BackendRelationID : string;
    BackendCompanyID : string;
    BranchNumber : string;
    GlobalLocationNumber : string;
    RegisterCashLimit : number; // Decimal
    SafeCashLimit : number; // Decimal
    TypeID : number; // Int32
    Subnet : string;
    UseForAccounting : boolean;
    AttachedToUserID : number; // Int32, nullable
    IpAddress : string;
    CountryID : string;
    CurrencyID : string;
    TimeZone : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class AddDiscountToOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.ShoppingCartResponse> {
    SessionID : string;
    CouponCode : string;
    DiscountID : number; // Int32
    DiscountAmount : number; // Decimal
    CurrencyID : string;
    Reason : string;
    OrderLines : EVA.Core.OrderLineWithQuantity[];
    Password : string;
    ForceCreate : boolean;
    __response : EVA.Core.ShoppingCartResponse;
  }

  export class AddInsuranceItemToOrderLine extends EVA.Core.RequestMessageGeneric<EVA.Core.ShoppingCartResponse> {
    OrderLineID : number; // Int32
    InsuranceItemID : number; // Int32
    __response : EVA.Core.ShoppingCartResponse;
  }

  export class AddProductToOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.AddProductToOrderResponse> {
    SessionID : string;
    ForceCreate : boolean;
    Barcode : string;
    ProductID : number; // Int32, nullable
    QuantityOrdered : number; // Int32, nullable
    LineActionType : EVA.Core.LineActionTypes;
    StockLabel : number; // Int32
    CustomOrderLineType : string;
    ParentID : number; // Int32, nullable
    ResourceID : number; // Int32, nullable
    GroupID : string;
    __response : EVA.Core.Services.AddProductToOrderResponse;
  }

  export class AddProductToOrderResponse extends EVA.Core.ShoppingCartResponse {
    OrderLineID : number; // Int32
  }

  export class AddServiceProductToOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.AddServiceProductToOrderResponse> {
    SessionID : string;
    ForceCreate : boolean;
    ProductID : number; // Int32
    Description : string;
    UnitPrice : number; // Decimal, nullable
    UnitCost : number; // Decimal, nullable
    __response : EVA.Core.Services.AddServiceProductToOrderResponse;
  }

  export class AddServiceProductToOrderResponse extends EVA.Core.ShoppingCartResponse {
    OrderLineID : number; // Int32
  }

  export class ApprovePayment extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ApprovePaymentResponse> {
    PaymentID : number; // Int32
    __response : EVA.Core.Services.ApprovePaymentResponse;
  }

  export class ApprovePaymentResponse extends EVA.Core.ResponseMessage {
    HasBeenApproved : boolean;
    Reason : EVA.Core.Services.ApprovementFailureReasons;
  }

  export enum ApprovementFailureReasons {
    Unknown = 0,
    AlreadyApproved = 1,
    OrderAlreadyPaid = 2,
  }

  export class AttachCustomerToOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32, nullable
    OrderID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class AttachIdentificationToOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.AttachIdentificationToOrderResponse> {
    OrderID : number; // Int32
    Type : EVA.Core.IdentificationTypes;
    Number : string;
    ValidTo : string; // DateTime
    IssuingDate : string; // DateTime, nullable
    IssuingCity : string;
    IssuingCountryID : string;
    OriginatingCountryID : string;
    DocumentMimeType : string;
    Document : number[];
    __response : EVA.Core.Services.AttachIdentificationToOrderResponse;
  }

  export class AttachIdentificationToOrderResponse extends EVA.Core.ResponseMessage {
    IdentificationID : number; // Int32
  }

  export class AttachOrderToSession extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    OrderID : number; // Int32
    SessionID : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CancelOrderLine extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CancelOrderLineResponse> {
    OrderLineID : number; // Int32
    __response : EVA.Core.Services.CancelOrderLineResponse;
  }

  export class CancelOrderLineResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.OrderCancellationOptions;
  }

  export class CreateOrderFromShoppingCart extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreateOrderFromShoppingCartResponse> {
    SessionID : string;
    CartID : number; // Int32, nullable
    __response : EVA.Core.Services.CreateOrderFromShoppingCartResponse;
  }

  export class CreateOrderFromShoppingCartResponse extends EVA.Core.ResponseMessage {
    Order : EVA.Core.OrderDto;
    TotalAmountInTax : number; // Decimal
    OpenAmount : number; // Decimal
  }

  export class DetachOrderFromSession extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    SessionID : string;
    OrderID : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetConfigurableOrderView extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetConfigurableOrderViewResponse> {
    OrderID : number; // Int32
    LogicalLevel : string;
    GroupByPropertyType : string;
    IncludeAllChildren : boolean;
    ProductProperties : string[];
    __response : EVA.Core.Services.GetConfigurableOrderViewResponse;
  }

  export class GetConfigurableOrderViewResponse extends EVA.Core.ResponseMessage {
    PropertyGroups : EVA.Core.Services.PropertyGroup[];
    OtherLines : { [ key : string ] : EVA.Core.Services.SimpleOrderLine[] };
    TotalAmount : number; // Decimal
    TotalAmountInTax : number; // Decimal
  }

  export class PropertyGroup {
    PropertyValue : any;
    TotalAmount : number; // Decimal
    TotalAmountInTax : number; // Decimal
    Quantity : number; // Int32
    ChildGroups : EVA.Core.Services.ConfigurableGroup[];
  }

  export class ConfigurableGroup {
    ProductID : number; // Int32
    Properties : any;
    LogicalLevel : string;
    ConfigurableProperty : string;
    Value : any;
    Values : any[];
    TotalAmount : number; // Decimal
    TotalAmountInTax : number; // Decimal
    Quantity : number; // Int32
    Children : EVA.Core.Services.ConfigurableGroup[];
    OrderLines : EVA.Core.Services.ConfigurableOrderLine[];
  }

  export class ConfigurableOrderLine {
    OrderLineID : number; // Int32
    Quantity : number; // Int32
    TotalAmount : number; // Decimal
    TotalAmountInTax : number; // Decimal
  }

  export class SimpleOrderLine {
    OrderLineID : number; // Int32
    Description : string;
    Quantity : number; // Int32
    TotalAmount : number; // Decimal
    TotalAmountInTax : number; // Decimal
  }

  export class GetCustomOrderData extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetCustomOrderDataResponse> {
    OrderID : number; // Int32, nullable
    SessionID : string;
    Key : string;
    __response : EVA.Core.Services.GetCustomOrderDataResponse;
  }

  export class GetCustomOrderDataResponse extends EVA.Core.ResponseMessage {
    Values : any[];
  }

  export class GetCustomOrderLineData extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetCustomOrderLineDataResponse> {
    OrderLineID : number; // Int32
    Key : string;
    __response : EVA.Core.Services.GetCustomOrderLineDataResponse;
  }

  export class GetCustomOrderLineDataResponse extends EVA.Core.ResponseMessage {
    Values : string[];
  }

  export class GetOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetOrderResponse> {
    OrderID : number; // Int32
    IncludeFailedPayments : boolean;
    __response : EVA.Core.Services.GetOrderResponse;
  }

  export class GetOrderResponse extends EVA.Core.GetResponse<EVA.Core.OrderDto> {
    TotalAmountInTax : number; // Decimal
    OpenAmount : number; // Decimal
    HasMoreLines : boolean;
  }

  export class GetOrderStatistics extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetOrderStatisticsResponse> {
    OrderID : number; // Int32
    __response : EVA.Core.Services.GetOrderStatisticsResponse;
  }

  export class GetOrderStatisticsResponse extends EVA.Core.ResponseMessage {
    Statistics : EVA.Core.OrderStatistics;
  }

  export class GetRequiredDataForOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetRequiredDataForOrderResponse> {
    OrderID : number; // Int32
    RequiredFor : EVA.Core.RequiredFor;
    __response : EVA.Core.Services.GetRequiredDataForOrderResponse;
  }

  export class GetRequiredDataForOrderResponse extends EVA.Core.ResponseMessage {
    RequiredData : EVA.Core.RequiredData;
  }

  export class GetReturnableStatusForOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetReturnableStatusForOrderResponse> {
    OrderID : number; // Int32
    __response : EVA.Core.Services.GetReturnableStatusForOrderResponse;
  }

  export class GetReturnableStatusForOrderResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.ReturnableStatusForOrderLine[];
  }

  export class ReturnableStatusForOrderLine {
    OrderLineID : number; // Int32
    ReturnableQuantity : number; // Int32
    IsReturnable : boolean;
    IsReturnableWithParent : boolean;
  }

  export class GetShippingMethodsForOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetShippingMethodsForOrderResponse> {
    SessionID : string;
    OrderID : number; // Int32, nullable
    __response : EVA.Core.Services.GetShippingMethodsForOrderResponse;
  }

  export class GetShippingMethodsForOrderResponse extends EVA.Core.ResponseMessage {
    ShippingMethods : EVA.Core.ShippingMethodByOrderLineDto[];
  }

  export class ListAvailableInsurancesForOrderLine extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListAvailableInsurancesForOrderLineResponse> {
    OrderLineID : number; // Int32
    __response : EVA.Core.Services.ListAvailableInsurancesForOrderLineResponse;
  }

  export class ListAvailableInsurancesForOrderLineResponse extends EVA.Core.ResponseMessage {
    Insurances : EVA.Core.InsuranceItemDto[];
  }

  export class ListAvailableShippingDates extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListAvailableShippingDatesResponse> {
    SessionID : string;
    OrderID : number; // Int32, nullable
    ShippingMethodID : number; // Int32
    __response : EVA.Core.Services.ListAvailableShippingDatesResponse;
  }

  export class ListAvailableShippingDatesResponse extends EVA.Core.ResponseMessage {
    AvailableDeliveryDates : string[];
  }

  export class ListAvailableShippingMethods extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListAvailableShippingMethodsResponse> {
    SessionID : string;
    OrderID : number; // Int32, nullable
    OrderLineIDs : number[];
    __response : EVA.Core.Services.ListAvailableShippingMethodsResponse;
  }

  export class ListAvailableShippingMethodsResponse extends EVA.Core.ResponseMessage {
    AvailableShippingMethods : EVA.Core.ShippingMethodByOrderLineDto[];
  }

  export class ListExternalOrderStatusForOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListExternalOrderStatusForOrderResponse> {
    OrderID : number; // Int32
    __response : EVA.Core.Services.ListExternalOrderStatusForOrderResponse;
  }

  export class ListExternalOrderStatusForOrderResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.ListExternalOrderStatusForOrderResponseExternalOrderStatus[];
  }

  export class ListExternalOrderStatusForOrderResponseExternalOrderStatus {
    Name : string;
    Status : string;
    CanPollStatus : boolean;
  }

  export class ListInvoicesForOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListInvoicesForOrderResponse> {
    OrderID : number; // Int32
    __response : EVA.Core.Services.ListInvoicesForOrderResponse;
  }

  export class ListInvoicesForOrderResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.InvoiceDto[];
  }

  export class InvoiceDto {
    ID : number; // Int32
    InvoiceNumber : string;
    InvoiceDate : string; // DateTime, nullable
    CreatedByID : number; // Int32
    CreationTime : string; // DateTime
  }

  export class ListOrderLedgerForOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListOrderLedgerForOrderResponse> {
    OrderID : number; // Int32
    __response : EVA.Core.Services.ListOrderLedgerForOrderResponse;
  }

  export class ListOrderLedgerForOrderResponse extends EVA.Core.ResponseMessage {
    Ledgers : EVA.Core.Services.OrderLedgerDto[];
  }

  export class OrderLedgerDto {
    ID : number; // Int32
    OrderID : number; // Int32
    OrderLineID : number; // Int32, nullable
    Type : EVA.Core.Services.OrderLedgerTypeDto;
    TypeID : number; // Int32
    OldValue : string;
    NewValue : string;
    Description : string;
    CreatedByID : number; // Int32
    CreationTime : string; // DateTime
    CreatedBy : EVA.Core.UserDto;
    Client : EVA.Core.Clients;
  }

  export class OrderLedgerTypeDto extends EVA.Core.EnumDtoBase {
  }

  export class ListOrderLines extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListOrderLinesResponse> {
    OrderID : number; // Int32
    __response : EVA.Core.Services.ListOrderLinesResponse;
  }

  export class ListOrderLinesResponse extends EVA.Core.PagedResultResponse<EVA.Core.OrderLineDto> {
  }

  export class ListOrdersForCustomer extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListOrdersForCustomerResponse> {
    ID : number; // Int32
    OpenOrdersOnly : boolean;
    __response : EVA.Core.Services.ListOrdersForCustomerResponse;
  }

  export class ListOrdersForCustomerResponse extends EVA.Core.PagedResultResponse<EVA.Core.OrderDto> {
  }

  export class ListOrderShipments extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListOrderShipmentsResponse> {
    OrderID : number; // Int32
    __response : EVA.Core.Services.ListOrderShipmentsResponse;
  }

  export class ListOrderShipmentsResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.ListOrderShipmentsResponseModel[];
  }

  export class ListOrderShipmentsResponseModel {
    ID : number; // Int32
    BackendID : string;
    ShipmentDate : string; // DateTime
    TrackingCode : string;
    TrackingLink : string;
    OrganizationUnit : EVA.Core.OrganizationUnitDto;
    ShippedFromOrganizationUnit : EVA.Core.OrganizationUnitDto;
    TotalQuantityShipped : number; // Int32, nullable
  }

  export class ListOrdersWithReference extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListOrdersWithReferenceResponse> {
    __response : EVA.Core.Services.ListOrdersWithReferenceResponse;
  }

  export class ListOrdersWithReferenceResponse extends EVA.Core.PagedResultResponse<EVA.Core.OrderWithReference> {
  }

  export class ModifyLineActionType extends EVA.Core.RequestMessageGeneric<EVA.Core.ShoppingCartResponse> {
    OrderLineID : number; // Int32
    LineActionType : EVA.Core.LineActionTypes;
    __response : EVA.Core.ShoppingCartResponse;
  }

  export class ModifyOrderLinePrice extends EVA.Core.RequestMessageGeneric<EVA.Core.ShoppingCartResponse> {
    OrderLineID : number; // Int32
    UnitPriceInTax : number; // Decimal
    UnitCost : number; // Decimal, nullable
    __response : EVA.Core.ShoppingCartResponse;
  }

  export class ModifyQuantityOrdered extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ModifyQuantityOrderedResponse> {
    OrderLineID : number; // Int32
    NewQuantityOrdered : number; // Int32
    __response : EVA.Core.Services.ModifyQuantityOrderedResponse;
  }

  export class ModifyQuantityOrderedResponse extends EVA.Core.ShoppingCartResponse {
    Messages : EVA.Core.Services.ModifyQuantityOrderedResponseQuantityMutationResultMessage[];
  }

  export class ModifyQuantityOrderedResponseQuantityMutationResultMessage {
    Code : string;
    Message : string;
  }

  export class ModifyStockOrganizationUnit extends EVA.Core.RequestMessageGeneric<EVA.Core.ShoppingCartResponse> {
    OrderLineID : number; // Int32
    StockOrganizationUnitID : number; // Int32
    LineActionType : EVA.Core.LineActionTypes;
    __response : EVA.Core.ShoppingCartResponse;
  }

  export class PlaceOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.PlaceOrderResponse> {
    OrderID : number; // Int32
    __response : EVA.Core.Services.PlaceOrderResponse;
  }

  export class PlaceOrderResponse extends EVA.Core.ResponseMessage {
    ValidationResult : EVA.Core.OrderExportValidationResult;
  }

  export class PollExternalOrderStatus extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    OrderID : number; // Int32
    Name : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ProduceDocuments extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ProduceDocumentsResponse> {
    PrintInvoice : boolean;
    EmailInvoice : boolean;
    PrintReceipt : boolean;
    DownloadInvoice : boolean;
    StationID : number; // Int32, nullable
    OrderID : number; // Int32
    EmailAddress : string;
    InvoiceID : number; // Int32, nullable
    __response : EVA.Core.Services.ProduceDocumentsResponse;
  }

  export class ProduceDocumentsResponse extends EVA.Core.ResponseMessage {
    InvoiceUrl : string;
  }

  export class ProduceInvoice extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    OrderID : number; // Int32
    EmailAddress : string;
    StationID : number; // Int32, nullable
    EmailInvoice : boolean;
    DownloadInvoice : boolean;
    PrintInvoice : boolean;
    InvoiceID : number; // Int32, nullable
    __response : EVA.Core.ResourceResponseMessage;
  }

  export class ProduceReceipt extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ProduceReceiptResponse> {
    OrderID : number; // Int32
    StationID : number; // Int32, nullable
    InvoiceID : number; // Int32, nullable
    __response : EVA.Core.Services.ProduceReceiptResponse;
  }

  export class ProduceReceiptResponse extends EVA.Core.ResponseMessage {
    PrintSuccessful : boolean;
  }

  export class ProduceShipmentDocuments extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ProduceShipmentDocumentsResponse> {
    OrderID : number; // Int32
    LinesToShip : EVA.Core.Services.ProduceShipmentDocumentsOrderLine[];
    StationID : number; // Int32, nullable
    __response : EVA.Core.Services.ProduceShipmentDocumentsResponse;
  }

  export class ProduceShipmentDocumentsResponse extends EVA.Core.ResponseMessage {
    ShipmentDocuments : EVA.Core.Services.ProduceShipmentDocumentsResponseModel[];
  }

  export class ProduceShipmentDocumentsResponseModel {
    Type : string;
    Url : string;
  }

  export class ProduceShipmentDocumentsOrderLine {
    ID : number; // Int32
    ProductID : number; // Int32
    QuantityToShip : number; // Int32
    TrackAndTraceCode : string;
    TrackAndTraceLink : string;
  }

  export class ProduceTrackingInformation extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ProduceTrackingInformationResponse> {
    OrderID : number; // Int32
    __response : EVA.Core.Services.ProduceTrackingInformationResponse;
  }

  export class ProduceTrackingInformationResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.ProduceTrackingInformationResponseTrackingInformation;
  }

  export class ProduceTrackingInformationResponseTrackingInformation {
    Link : string;
    Code : string;
  }

  export class SearchOrders extends EVA.Core.PagedResultRequest<EVA.Core.Services.SearchOrdersResponse> {
    Query : string;
    IsPaid : boolean;
    IsShipped : boolean;
    IsCompleted : boolean;
    StartTime : string; // DateTime, nullable
    EndTime : string; // DateTime, nullable
    OrderIDs : number[];
    OrderLineID : number; // Int32, nullable
    InvoiceNumber : string;
    CompanyName : string;
    ProductID : number; // Int32, nullable
    IsReserved : boolean;
    IsOrder : boolean;
    IsInvoiced : boolean;
    PaymentTypeID : number; // Int32, nullable
    PaymentTypeName : string;
    OrganizationUnitID : number; // Int32, nullable
    MinTotalAmountInTax : number; // Decimal, nullable
    MaxTotalAmountInTax : number; // Decimal, nullable
    ProductVariation : { [ key : string ] : string[] };
    HasReturns : boolean;
    HasCustomer : boolean;
    OrderType : EVA.Core.OrderTypes;
    ShipFromOrganizationUnitID : number; // Int32, nullable
    CustomerID : number; // Int32, nullable
    CustomerReference : string;
    ShipToOrganizationUnitID : number; // Int32, nullable
    SoldFromOrganizationUnitID : number; // Int32, nullable
    SoldToOrganizationUnitID : number; // Int32, nullable
    OriginatingOrganizationUnitID : number; // Int32, nullable
    PickupOrganizationUnitID : number; // Int32, nullable
    Properties : number[];
    CustomStatus : number[];
    __response : EVA.Core.Services.SearchOrdersResponse;
  }

  export class SearchOrdersResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.PagedResultGeneric<EVA.Core.OrderSearchResultItem>;
    ProductVariations : { [ key : string ] : { [ key : string ] : number } };
  }

  export class SetCustomerReferenceOnOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderID : number; // Int32
    Reference : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class SetCustomOrderData extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    OrderID : number; // Int32
    SessionID : string;
    Key : string;
    Value : any;
    IfKeyAlreadyExistsOption : EVA.Core.Services.ExistingKeyOptions;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export enum ExistingKeyOptions {
    Replace = 0,
    Add = 1,
    Error = 2,
  }

  export class SetCustomOrderLineData extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    OrderLineID : number; // Int32
    Key : string;
    Value : any;
    IfKeyAlreadyExistsOption : EVA.Core.Services.ExistingKeyOptions;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class SetPickupOrganizationUnit extends EVA.Core.RequestMessageGeneric<EVA.Core.ShoppingCartResponse> {
    OrderID : number; // Int32, nullable
    SessionID : string;
    OrganizationUnitID : number; // Int32
    __response : EVA.Core.ShoppingCartResponse;
  }

  export class SetRemarkOnOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderID : number; // Int32
    Remark : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class SetShippingMethod extends EVA.Core.RequestMessageGeneric<EVA.Core.ShoppingCartResponse> {
    SessionID : string;
    OrderID : number; // Int32, nullable
    OrderLineID : number; // Int32, nullable
    ShippingMethodID : number; // Int32
    RequestedDeliveryDate : string; // DateTime, nullable
    __response : EVA.Core.ShoppingCartResponse;
  }

  export class ShipOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ShipOrderResponse> {
    SessionID : string;
    OrderID : number; // Int32, nullable
    Lines : EVA.Core.Services.ShipOrderShipmentOrderLine[];
    Force : boolean;
    __response : EVA.Core.Services.ShipOrderResponse;
  }

  export class ShipOrderResponse extends EVA.Core.ResponseMessage {
    ShipmentIDs : number[];
    ShippedOrderLineIDs : number[];
    Messages : EVA.Core.ConfirmShipmentResultMessage[];
  }

  export class ShipOrderShipmentOrderLine {
    OrderLineID : number; // Int32
    QuantityShipped : number; // Int32, nullable
    DeliveryNoteNumber : string;
    TrackingCode : string;
    TrackingLink : string;
  }

  export class TransferOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    SessionID : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class UpdateContractNumber extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderLineID : number; // Int32
    ContractNumber : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetContractNumber extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetContractNumberResponse> {
    OrderLineID : number; // Int32
    __response : EVA.Core.Services.GetContractNumberResponse;
  }

  export class GetContractNumberResponse extends EVA.Core.ResponseMessage {
    ContractNumber : string;
  }

  export class UpdateOrderAddresses extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.UpdateOrderAddressesResponse> {
    SessionID : string;
    OrderID : number; // Int32, nullable
    CopyShippingAddressFromCustomer : boolean;
    CopyBillingAddressFromCustomer : boolean;
    ShipToAddress : EVA.Core.AddressDto;
    BillToAddress : EVA.Core.AddressDto;
    __response : EVA.Core.Services.UpdateOrderAddressesResponse;
  }

  export class UpdateOrderAddressesResponse extends EVA.Core.ResponseMessage {
    CreditcardAllowed : boolean;
    ShipToAddress : EVA.Core.AddressDto;
    BillToAddress : EVA.Core.AddressDto;
  }

  export class UpdateOrderShippingAddress extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.UpdateOrderAddressResponse> {
    SessionID : string;
    OrderID : number; // Int32, nullable
    Address : EVA.Core.AddressDto;
    AddressBookID : number; // Int32, nullable
    __response : EVA.Core.Services.UpdateOrderAddressResponse;
  }

  export class UpdateOrderAddressResponse extends EVA.Core.ResponseMessage {
    ShippingAddress : EVA.Core.AddressDto;
    BillingAddress : EVA.Core.AddressDto;
  }

  export class UpdateOrderBillingAddress extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.UpdateOrderAddressResponse> {
    SessionID : string;
    OrderID : number; // Int32, nullable
    Address : EVA.Core.AddressDto;
    AddressBookID : number; // Int32, nullable
    __response : EVA.Core.Services.UpdateOrderAddressResponse;
  }

  export class UpdateOrderCurrency extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderID : number; // Int32, nullable
    SessionID : string;
    CurrencyID : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class UpdateSerialNumber extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderLineID : number; // Int32
    SerialNumber : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetSerialNumber extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetSerialNumberResponse> {
    OrderLineID : number; // Int32
    __response : EVA.Core.Services.GetSerialNumberResponse;
  }

  export class GetSerialNumberResponse extends EVA.Core.ResponseMessage {
    SerialNumber : string;
  }

  export class ValidateRequiredDataForOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ValidateRequiredDataForOrderResponse> {
    OrderID : number; // Int32
    RequiredFor : EVA.Core.RequiredFor;
    __response : EVA.Core.Services.ValidateRequiredDataForOrderResponse;
  }

  export class ValidateRequiredDataForOrderResponse extends EVA.Core.ResponseMessage {
    ValidatedData : EVA.Core.RequiredDataValidationResult;
  }

  export enum VerifyCustomerFunctionalities {
    ReleasePaidPickupOrders = 0,
  }

  export class VerifyCustomer extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderID : number; // Int32
    VerificationCode : string;
    ManualRelease : boolean;
    IdentificationCode : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetDataModelForTemplateHandler extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetDataModelForTemplateHandlerResponse> {
    Handler : string;
    __response : EVA.Core.Services.GetDataModelForTemplateHandlerResponse;
  }

  export class GetDataModelForTemplateHandlerResponse extends EVA.Core.ResponseMessage {
    DataModel : any;
  }

  export class ListMessageTemplateLayouts extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListMessageTemplateLayoutsResponse> {
    OrganizationUnitID : number; // Int32, nullable
    LanguageID : string;
    CountryID : string;
    Destination : EVA.Core.MessageTemplateDestinations;
    __response : EVA.Core.Services.ListMessageTemplateLayoutsResponse;
  }

  export class ListMessageTemplateLayoutsResponse extends EVA.Core.ResponseMessage {
    Layouts : string[];
  }

  export class ListTemplateHandlers extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListTemplateHandlersResponse> {
    __response : EVA.Core.Services.ListTemplateHandlersResponse;
  }

  export class ListTemplateHandlersResponse extends EVA.Core.ResponseMessage {
    Handlers : string[];
  }

  export class GetMessageTemplateByID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetMessageTemplateByIDResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetMessageTemplateByIDResponse;
  }

  export class GetMessageTemplateByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    Name : string;
    OrganizationUnitID : number; // Int32, nullable
    LanguageID : string;
    CountryID : string;
    Template : string;
    Helpers : string;
    Type : EVA.Core.MessageTemplateTypes;
    Layout : string;
    Destination : EVA.Core.MessageTemplateDestinations;
    PaperProperties : EVA.Core.PaperProperties;
  }

  export class CreateMessageTemplate extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreateMessageTemplateResponse> {
    Name : string;
    OrganizationUnitID : number; // Int32, nullable
    LanguageID : string;
    CountryID : string;
    Template : string;
    Helpers : string;
    Type : EVA.Core.MessageTemplateTypes;
    Layout : string;
    Destination : EVA.Core.MessageTemplateDestinations;
    PaperProperties : EVA.Core.PaperProperties;
    __response : EVA.Core.Services.CreateMessageTemplateResponse;
  }

  export class CreateMessageTemplateResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }

  export class UpdateMessageTemplate extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Name : string;
    OrganizationUnitID : number; // Int32, nullable
    LanguageID : string;
    CountryID : string;
    Template : string;
    Helpers : string;
    Layout : string;
    Destination : EVA.Core.MessageTemplateDestinations;
    PaperProperties : EVA.Core.PaperProperties;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteMessageTemplate extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListMessageTemplates extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListMessageTemplatesResponse> {
    __response : EVA.Core.Services.ListMessageTemplatesResponse;
  }

  export class ListMessageTemplatesResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.ListMessageTemplatesResponseMessageTemplateDto> {
  }

  export class ListMessageTemplatesResponseMessageTemplateDto {
    ID : number; // Int32
    Name : string;
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnitName : string;
    LanguageID : string;
    CountryID : string;
    Type : EVA.Core.MessageTemplateTypes;
    Layout : string;
    Destination : EVA.Core.MessageTemplateDestinations;
    PaperProperties : EVA.Core.PaperProperties;
  }

  export class PreviewMessageTemplate extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    Name : string;
    OrganizationUnitID : number; // Int32, nullable
    LanguageID : string;
    CountryID : string;
    Template : string;
    Helpers : string;
    Type : EVA.Core.MessageTemplateTypes;
    Layout : string;
    Destination : EVA.Core.MessageTemplateDestinations;
    PaperProperties : EVA.Core.PaperProperties;
    TargetContentType : EVA.Core.MessageTargetContentTypes;
    __response : EVA.Core.ResourceResponseMessage;
  }

  export class SendSampleMailMessageTemplate extends EVA.Core.RequestMessageWithEmptyResponse {
    Name : string;
    OrganizationUnitID : number; // Int32, nullable
    LanguageID : string;
    CountryID : string;
    Template : string;
    Helpers : string;
    Type : EVA.Core.MessageTemplateTypes;
    Layout : string;
    Destination : EVA.Core.MessageTemplateDestinations;
    EmailAddress : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListMessageQueueErrors extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListMessageQueueErrorsResponse> {
    __response : EVA.Core.Services.ListMessageQueueErrorsResponse;
  }

  export class ListMessageQueueErrorsResponse extends EVA.Core.PagedResultResponse<EVA.Core.MessageQueueErrorDto> {
  }

  export class RequeueErrorMessage extends EVA.Core.RequestMessageWithEmptyResponse {
    MessageQueueErrorID : number; // Int32
    MessageQueueErrorIDs : number[];
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListLedgerClass extends EVA.Core.GetRequestGeneric<EVA.Core.Services.ListLedgerClassResponse> {
    __response : EVA.Core.Services.ListLedgerClassResponse;
  }

  export class ListLedgerClassResponse extends EVA.Core.GetResponse<EVA.Core.Services.LedgerClassDto[]> {
  }

  export class LedgerClassDto {
    ID : string;
  }

  export class ListProductLedger extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListProductLedgerResponse> {
    ProductID : number; // Int32
    StockLabel : number; // Int32, nullable
    OrganizationUnitID : number; // Int32, nullable
    ResourceID : number; // Int32, nullable
    Type : EVA.Core.ProductLedgerTypes;
    PageConfig : EVA.Core.PageConfig;
    __response : EVA.Core.Services.ListProductLedgerResponse;
  }

  export class ListProductLedgerResponse extends EVA.Core.ResponseMessage {
    Results : EVA.Core.PagedResultGeneric<EVA.Core.ProductLedgerDto>;
  }

  export class BookInvoice extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CreateInvoice extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreateInvoiceResponse> {
    OrganizationUnitID : number; // Int32
    SupplierOrganizationUnitID : number; // Int32
    InvoiceDate : string; // DateTime
    InvoiceNumber : string;
    Description : string;
    TaxAmounts : EVA.Core.Services.InvoiceTaxAmountDto[];
    AdditionalAmounts : EVA.Core.Services.InvoiceAdditionalAmountDto[];
    Blobs : EVA.Core.Services.InvoiceBlobDto[];
    TotalAmount : number; // Decimal
    Type : EVA.Core.InvoiceTypes;
    __response : EVA.Core.Services.CreateInvoiceResponse;
  }

  export class CreateInvoiceResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }

  export class InvoiceTaxAmountDto {
    TaxCodeID : number; // Int32
    Amount : number; // Decimal
  }

  export class InvoiceAdditionalAmountDto {
    Type : EVA.Core.InvoiceAdditionalAmountTypes;
    Amount : number; // Decimal
    Description : string;
  }

  export class InvoiceBlobDto {
    BlobID : string;
  }

  export class GetInvoice extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetInvoiceResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetInvoiceResponse;
  }

  export class GetInvoiceResponse extends EVA.Core.ResponseMessage {
    Invoice : EVA.Core.Services.InvoiceDetailsDto;
  }

  export class InvoiceDetailsDto {
    OrganizationUnitID : number; // Int32
    ID : number; // Int32
    InvoiceDate : string; // DateTime, nullable
    InvoiceNumber : string;
    Description : string;
    TaxAmounts : EVA.Core.Services.InvoiceTaxAmountDto[];
    AdditionalAmounts : EVA.Core.Services.InvoiceAdditionalAmountDto[];
    Lines : EVA.Core.Services.InvoiceDetailLineDto[];
    Blobs : EVA.Core.Services.InvoiceBlobDto[];
    Status : EVA.Core.InvoiceStatuses;
    SupplierOrganizationUnitID : number; // Int32, nullable
    TotalAmount : number; // Decimal, nullable
  }

  export class InvoiceDetailLineDto {
    ID : number; // Int32
    QuantityInvoiced : number; // Int32
    OrderLine : EVA.Core.Services.InvoiceDetailsOrderLineDto;
    ShipmentLineID : number; // Int32, nullable
    InvoiceDate : string; // DateTime, nullable
    UnitCost : number; // Decimal, nullable
    QuantityToInvoice : number; // Int32
  }

  export class InvoiceDetailsOrderLineDto {
    Description : string;
    UnitCost : number; // Decimal
    UnitPrice : number; // Decimal
    ID : number; // Int32
    OrderID : number; // Int32
    ProductID : number; // Int32, nullable
  }

  export class ListInvoices extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListInvoicesResponse> {
    InvoiceNumber : string;
    Type : EVA.Core.InvoiceTypes;
    StartDate : string; // DateTime, nullable
    EndDate : string; // DateTime, nullable
    __response : EVA.Core.Services.ListInvoicesResponse;
  }

  export class ListInvoicesResponse extends EVA.Core.PagedResultResponse<EVA.Core.ListInvoicesDto> {
  }

  export class UpdateInvoiceLines extends EVA.Core.RequestMessageWithEmptyResponse {
    InvoiceID : number; // Int32
    Lines : EVA.Core.Services.UpdateInvoiceLine[];
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class UpdateInvoiceLine {
    ShipmentLineID : number; // Int32
    QuantityToInvoice : number; // Int32
    InvoicePrice : number; // Decimal
  }

  export class UpdateInvoice extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    InvoiceDate : string; // DateTime
    InvoiceNumber : string;
    Description : string;
    TotalAmount : number; // Decimal, nullable
    OrganizationUnitID : number; // Int32
    SupplierOrganizationUnitID : number; // Int32
    TaxAmounts : EVA.Core.Services.InvoiceTaxAmountDto[];
    AdditionalAmounts : EVA.Core.Services.InvoiceAdditionalAmountDto[];
    Blobs : EVA.Core.Services.InvoiceBlobDto[];
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListInterbranchOrganizationUnitForOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListInterbranchOrganizationUnitForOrderResponse> {
    OrderID : number; // Int32, nullable
    SessionID : string;
    __response : EVA.Core.Services.ListInterbranchOrganizationUnitForOrderResponse;
  }

  export class ListInterbranchOrganizationUnitForOrderResponse extends EVA.Core.ResponseMessage {
    OrganizationUnits : EVA.Core.Services.InterbranchOrganizationUnit[];
  }

  export class InterbranchOrganizationUnit {
    ID : number; // Int32
    Name : string;
  }

  export class SetInterbranchOrganizationUnitOnOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderID : number; // Int32, nullable
    SessionID : string;
    OrganizationUnitID : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListInsurancesForProduct extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListInsurancesForProductResponse> {
    ProductID : number; // Int32
    __response : EVA.Core.Services.ListInsurancesForProductResponse;
  }

  export class ListInsurancesForProductResponse extends EVA.Core.ResponseMessage {
    Insurances : EVA.Core.InsuranceItemDto[];
  }

  export class ProduceInsuranceDocuments extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ProduceInsuranceDocumentsResponse> {
    EmailDocuments : boolean;
    DownloadDocuments : boolean;
    PrintDocuments : boolean;
    IncludeTerms : boolean;
    OrderID : number; // Int32, nullable
    OrderLineID : number; // Int32, nullable
    Copies : number; // Int32, nullable
    StationID : number; // Int32, nullable
    EmailAddress : string;
    __response : EVA.Core.Services.ProduceInsuranceDocumentsResponse;
  }

  export class ProduceInsuranceDocumentsResponse extends EVA.Core.ResponseMessage {
    ContractUrl : string;
    TermsUrl : string;
  }

  export class RequestInsurancesForOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CreateDevice extends EVA.Core.CreateRequest<EVA.Core.DeviceDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }

  export class CreateStation extends EVA.Core.CreateRequest<EVA.Core.StationDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }

  export class DeleteDevice extends EVA.Core.DeleteRequest implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteStation extends EVA.Core.DeleteRequest implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetDevice extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetDeviceResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetDeviceResponse;
  }

  export class GetDeviceResponse extends EVA.Core.GetResponse<EVA.Core.DeviceDto> {
  }

  export class GetStation extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetStationResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetStationResponse;
  }

  export class GetStationResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.StationDto;
  }

  export class ListDevices extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListDevicesResponse> {
    __response : EVA.Core.Services.ListDevicesResponse;
  }

  export class ListDevicesResponse extends EVA.Core.PagedResultResponse<EVA.Core.DeviceDto> {
  }

  export class ListDeviceTypes extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListDeviceTypesResponse> {
    __response : EVA.Core.Services.ListDeviceTypesResponse;
  }

  export class ListDeviceTypesResponse extends EVA.Core.ResponseMessage {
    DeviceTypes : EVA.Core.EnumDtoBase[];
  }

  export class ListStationsForOrganizationUnit extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListStationsForOrganizationUnitResponse> {
    OrganizationUnitID : number; // Int32
    __response : EVA.Core.Services.ListStationsForOrganizationUnitResponse;
  }

  export class ListStationsForOrganizationUnitResponse extends EVA.Core.PagedResultResponse<EVA.Core.StationDto> {
  }

  export class ScanStation extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.SelectStationResponse> {
    Barcode : string;
    __response : EVA.Core.Services.SelectStationResponse;
  }

  export class SelectStationResponse extends EVA.Core.ResponseMessage {
    Station : EVA.Core.StationDto;
    HasPrinterDevice : boolean;
    HasPinDevice : boolean;
    HasReceiptPrinterDevice : boolean;
  }

  export class SelectStation extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.SelectStationResponse> {
    StationID : number; // Int32
    __response : EVA.Core.Services.SelectStationResponse;
  }

  export class SendConfigurationPage extends EVA.Core.RequestMessageWithEmptyResponse {
    OrganizationUnitID : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class UpdateDevice extends EVA.Core.UpdateRequest<EVA.Core.DeviceDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.Services.UpdateDeviceResponse> {
    __response : EVA.Core.Services.UpdateDeviceResponse;
  }

  export class UpdateDeviceResponse extends EVA.Core.ResponseMessage {
    Success : boolean;
  }

  export class UpdateStation extends EVA.Core.UpdateRequest<EVA.Core.StationDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CardBalanceCheck extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CardBalanceCheckResponse> {
    Barcode : string;
    CardType : string;
    CardNumber : string;
    CardPin : string;
    __response : EVA.Core.Services.CardBalanceCheckResponse;
  }

  export class CardBalanceCheckResponse extends EVA.Core.ResponseMessage {
    CardID : string;
    Status : string;
    Balance : number; // Decimal
    ResultCode : number; // Int32
  }

  export class GetFraudItem extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetFraudItemResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetFraudItemResponse;
  }

  export class GetFraudItemResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    TypeID : number; // Int32
    Data : string;
    Object : any;
  }

  export class UpdateFraudItem extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Data : string;
    Object : any;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CreateFraudItem extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreateFraudItemResponse> {
    TypeID : number; // Int32
    Data : string;
    Object : any;
    __response : EVA.Core.Services.CreateFraudItemResponse;
  }

  export class CreateFraudItemResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }

  export class DeleteFraudItem extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListFraudItems extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListFraudItemsResponse> {
    __response : EVA.Core.Services.ListFraudItemsResponse;
  }

  export class ListFraudItemsResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.FraudItemDto> {
  }

  export class FraudItemDto {
    ID : number; // Int32
    TypeID : number; // Int32
    Data : string;
    Object : any;
  }

  export class DownloadFraudItems extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    __response : EVA.Core.ResourceResponseMessage;
  }

  export class UploadFraudItems extends EVA.Core.RequestMessageWithEmptyResponse {
    Data : number[];
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DownloadFinancialPeriodDeposit extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    FinancialPeriodID : number; // Int32
    __response : EVA.Core.ResourceResponseMessage;
  }

  export class GetCurrentFinancialPeriodSummary extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetCurrentFinancialPeriodSummaryResponse> {
    __response : EVA.Core.Services.GetCurrentFinancialPeriodSummaryResponse;
  }

  export class GetCurrentFinancialPeriodSummaryResponse extends EVA.Core.ResponseMessage {
    FinancialPeriodID : number; // Int32
    FinancialPeriodStatus : EVA.Core.FinancialPeriodStatus;
  }

  export class GetFinancialPeriodAccountsSummary extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetFinancialPeriodAccountsSummaryResponse> {
    FinancialPeriodID : number; // Int32
    __response : EVA.Core.Services.GetFinancialPeriodAccountsSummaryResponse;
  }

  export class GetFinancialPeriodAccountsSummaryResponse extends EVA.Core.ResponseMessage {
    Accounts : EVA.Core.AccountSummary[];
  }

  export class GetFinancialPeriodDetails extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetFinancialPeriodDetailsResponse> {
    FinancialPeriodID : number; // Int32
    __response : EVA.Core.Services.GetFinancialPeriodDetailsResponse;
  }

  export class GetFinancialPeriodDetailsResponse extends EVA.Core.ResponseMessage {
    Details : EVA.Core.FinancialPeriodDetailsDto;
  }

  export class ListBookings extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListBookingsResponse> {
    __response : EVA.Core.Services.ListBookingsResponse;
  }

  export class ListBookingsResponse extends EVA.Core.PagedResultResponse<EVA.Core.GeneralLedgerDto> {
  }

  export class ListFinancialPeriods extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListFinancialPeriodsResponse> {
    __response : EVA.Core.Services.ListFinancialPeriodsResponse;
  }

  export class ListFinancialPeriodsResponse extends EVA.Core.PagedResultResponse<EVA.Core.FinancialPeriodDto> {
  }

  export class ListGeneralLedgers extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListGeneralLedgersResponse> {
    __response : EVA.Core.Services.ListGeneralLedgersResponse;
  }

  export class ListGeneralLedgersResponse extends EVA.Core.PagedResultResponse<EVA.Core.GeneralLedgerDto> {
  }

  export class ListHistoricFinancialPeriods extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListHistoricFinancialPeriodsResponse> {
    From : string; // DateTime, nullable
    Till : string; // DateTime, nullable
    __response : EVA.Core.Services.ListHistoricFinancialPeriodsResponse;
  }

  export class ListHistoricFinancialPeriodsResponse extends EVA.Core.PagedResultResponse<EVA.Core.FinancialPeriodDto> {
  }

  export class ProcessPeriodClosing extends EVA.Core.RequestMessageWithEmptyResponse {
    WorkSet : EVA.Core.PeriodClosingWorkSet;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ProcessPeriodOpening extends EVA.Core.RequestMessageWithEmptyResponse {
    WorkSet : EVA.Core.PeriodOpeningWorkSet;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class RepostFinancialPeriod extends EVA.Core.RequestMessageWithEmptyResponse {
    FinancialPeriodID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class StartPeriodClosing extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.StartPeriodClosingResponse> {
    __response : EVA.Core.Services.StartPeriodClosingResponse;
  }

  export class StartPeriodClosingResponse extends EVA.Core.ResponseMessage {
    WorkSet : EVA.Core.PeriodClosingWorkSet;
  }

  export class StartPeriodOpening extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.StartPeriodOpeningResponse> {
    __response : EVA.Core.Services.StartPeriodOpeningResponse;
  }

  export class StartPeriodOpeningResponse extends EVA.Core.ResponseMessage {
    WorkSet : EVA.Core.PeriodOpeningWorkSet;
  }

  export class ValidatePeriodClosing extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ValidatePeriodClosingResponse> {
    WorkSet : EVA.Core.PeriodClosingWorkSet;
    __response : EVA.Core.Services.ValidatePeriodClosingResponse;
  }

  export class ValidatePeriodClosingResponse extends EVA.Core.ResponseMessage {
    ValidationErrors : { [ key : string ] : string[] };
  }

  export class ListEnumValues extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListEnumValuesResponse> {
    Name : string;
    __response : EVA.Core.Services.ListEnumValuesResponse;
  }

  export class ListEnumValuesResponse extends EVA.Core.ResponseMessage {
    Values : EVA.Core.Services.ListEnumValuesResponseEnumValue[];
    IsFlags : boolean;
  }

  export class ListEnumValuesResponseEnumValue {
    Name : string;
    Value : number; // Int32
    Description : string;
  }

  export class CreateDiscountBatch extends EVA.Core.RequestMessageWithEmptyResponse {
    Amount : number; // Int32
    DiscountID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CreateUpdateDiscountCoupon extends EVA.Core.CreateRequest<EVA.Core.DiscountCouponDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }

  export class CreateUpdateDiscount extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreateUpdateDiscountResponse> {
    Discount : EVA.Core.DiscountDto;
    CouponCodeLength : number; // Int32, nullable
    __response : EVA.Core.Services.CreateUpdateDiscountResponse;
  }

  export class CreateUpdateDiscountResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }

  export class GetDiscountByID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetDiscountByIDResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetDiscountByIDResponse;
  }

  export class GetDiscountByIDResponse extends EVA.Core.ResponseMessage {
    Discount : EVA.Core.DiscountDto;
  }

  export class GetDiscountCoupons extends EVA.Core.PagedResultRequest<EVA.Core.Services.GetDiscountCouponsResponse> {
    DiscountID : number; // Int32
    __response : EVA.Core.Services.GetDiscountCouponsResponse;
  }

  export class GetDiscountCouponsResponse extends EVA.Core.PagedResultResponse<EVA.Core.DiscountCouponDto> {
  }

  export class ListAvailableDiscountActionsAndConditions extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListAvailableDiscountActionsAndConditionsResponse> {
    __response : EVA.Core.Services.ListAvailableDiscountActionsAndConditionsResponse;
  }

  export class ListAvailableDiscountActionsAndConditionsResponse extends EVA.Core.ResponseMessage {
    Conditions : string[];
    Actions : string[];
  }

  export class ListManualDiscounts extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListManualDiscountsResponse> {
    __response : EVA.Core.Services.ListManualDiscountsResponse;
  }

  export class ListManualDiscountsResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.ListManualDiscountsResponseManualDiscountDto[];
  }

  export class ListManualDiscountsResponseManualDiscountDto {
    ID : number; // Int32
    Description : string;
    Type : string;
    NeedsReason : boolean;
    FixedAmount : number; // Decimal, nullable
    MaxAmount : number; // Decimal, nullable
  }

  export class GetPickProductDiscountOptionsForOrderLine extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetPickProductDiscountOptionsForOrderLineResponse> {
    OrderLineID : number; // Int32
    __response : EVA.Core.Services.GetPickProductDiscountOptionsForOrderLineResponse;
  }

  export class GetPickProductDiscountOptionsForOrderLineResponse extends EVA.Core.ResponseMessage {
    Options : number[];
    CurrentSelection : number; // Int32, nullable
  }

  export class SetPickProductDiscountOptionsForOrderLine extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderLineID : number; // Int32
    Selection : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class SearchDiscountsByQuery extends EVA.Core.PagedResultRequest<EVA.Core.Services.SearchDiscountsByQueryResponse> {
    IsActive : boolean;
    DiscountTriggerID : number; // Int32
    Description : string;
    CouponCode : string;
    CreatedBy : string;
    __response : EVA.Core.Services.SearchDiscountsByQueryResponse;
  }

  export class SearchDiscountsByQueryResponse extends EVA.Core.PagedResultResponse<EVA.Core.DiscountDto> {
  }

  export class VerifyDiscount extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    DiscountID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetCurrency extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetCurrencyResponse> {
    ID : string;
    __response : EVA.Core.Services.GetCurrencyResponse;
  }

  export class GetCurrencyResponse extends EVA.Core.ResponseMessage {
    ID : string;
    Name : string;
  }

  export class UpdateCurrency extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string;
    Name : string;
    ExchangeRate : number; // Decimal, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CreateCurrency extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string;
    Name : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteCurrency extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class AttachApplicationToCurrency extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string;
    ExchangeRate : number; // Decimal
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DettachApplicationFromCurrency extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DetachApplicationFromCurrency extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class GetAvailableCurrencies extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetAvailableCurrenciesResponse> {
    __response : EVA.Core.Services.GetAvailableCurrenciesResponse;
  }

  export class GetAvailableCurrenciesResponse extends EVA.Core.ResponseMessage {
    Currencies : EVA.Core.Services.CurrencyDto[];
  }

  export class CurrencyDto {
    ID : string;
    Name : string;
    ExchangeRate : number; // Decimal
    IsBaseCurrency : boolean;
  }

  export class ListCurrencies extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListCurrenciesResponse> {
    __response : EVA.Core.Services.ListCurrenciesResponse;
  }

  export class ListCurrenciesResponse extends EVA.Core.PagedResultResponse<EVA.Core.CurrencyWithExchangeRate> {
  }

  export class GetCommunicationMessage extends EVA.Core.GetRequestGeneric<EVA.Core.Services.GetCommunicationMessageResponse> {
    MarkAsRead : boolean;
    __response : EVA.Core.Services.GetCommunicationMessageResponse;
  }

  export class GetCommunicationMessageResponse extends EVA.Core.GetResponse<EVA.Core.Services.CommunicationMessageDto> {
  }

  export class CommunicationMessageDto {
    ID : number; // Int32
    Document : string;
    Subject : string;
    UserID : number; // Int32, nullable
    EmailFrom : string;
    EmailFromName : string;
    EmailTo : string;
    EmailToName : string;
    SmsTo : string;
    SmsToName : string;
    Type : EVA.Core.CommunicationMessageTypes;
    Processed : boolean;
    Note : string;
    Read : boolean;
    CreationTime : string; // DateTime
    UniqueCode : string;
    ProcessedDocument : string;
  }

  export class ListCommunicationMessage extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListCommunicationMessageResponse> {
    UserID : number; // Int32
    UnreadOnly : boolean;
    __response : EVA.Core.Services.ListCommunicationMessageResponse;
  }

  export class ListCommunicationMessageResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.CommunicationMessageDto> {
  }

  export class GetShoppingCartInfo extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetShoppingCartInfoResponse> {
    SessionID : string;
    __response : EVA.Core.Services.GetShoppingCartInfoResponse;
  }

  export class GetShoppingCartInfoResponse extends EVA.Core.ResponseMessage {
    QuantityOrdered : number; // Int32
    TotalAmount : number; // Decimal
    ForeignTotalAmount : number; // Decimal
    CurrencyID : string;
  }

  export class GetShoppingCart extends EVA.Core.RequestMessageGeneric<EVA.Core.ShoppingCartResponse> {
    SessionID : string;
    CartID : number; // Int32, nullable
    ProductProperties : string[];
    __response : EVA.Core.ShoppingCartResponse;
  }

  export class RecoverShoppingCart extends EVA.Core.RequestMessageGeneric<EVA.Core.ShoppingCartResponse> {
    ReminderToken : string;
    SessionID : string;
    __response : EVA.Core.ShoppingCartResponse;
  }

  export class FlushCache extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.FlushCacheResponse> {
    Pattern : string;
    __response : EVA.Core.Services.FlushCacheResponse;
  }

  export class FlushCacheResponse extends EVA.Core.ResponseMessage {
  }

  export class AttachBlobToOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    BlobID : string;
    Name : string;
    OrderID : number; // Int32, nullable
    OrderLineID : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListBlobsForFinancialPeriod extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListBlobsForFinancialPeriodResponse> {
    FinancialPeriodID : number; // Int32
    __response : EVA.Core.Services.ListBlobsForFinancialPeriodResponse;
  }

  export class ListBlobsForFinancialPeriodResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.FinancialPeriodBlobDto[];
  }

  export class FinancialPeriodBlobDto {
    FinancialPeriodID : number; // Int32
    Name : string;
    MimeType : string;
    BlobID : string;
  }

  export class ListBlobsForOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListBlobsForOrderResponse> {
    OrderID : number; // Int32
    __response : EVA.Core.Services.ListBlobsForOrderResponse;
  }

  export class ListBlobsForOrderResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.OrderBlobDto[];
  }

  export class OrderBlobDto {
    OrderID : number; // Int32
    OrderLineID : number; // Int32, nullable
    Name : string;
    MimeType : string;
    BlobID : string;
    CreationTime : string; // DateTime
  }

  export class StoreAndAttachBlobToOrder extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.StoreAndAttachBlobToOrderResponse> {
    Name : string;
    OrderID : number; // Int32, nullable
    OrderLineID : number; // Int32, nullable
    Category : string;
    OriginalName : string;
    MimeType : string;
    Data : number[];
    __response : EVA.Core.Services.StoreAndAttachBlobToOrderResponse;
  }

  export class StoreAndAttachBlobToOrderResponse extends EVA.Core.ResponseMessage {
    Guid : string;
    Url : string;
  }

  export class ParseBarcode extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ParseBarcodeResponse> {
    Barcode : string;
    __response : EVA.Core.Services.ParseBarcodeResponse;
  }

  export class ParseBarcodeResponse extends EVA.Core.ResponseMessage {
    Value : string;
    Type : string;
    Data : { [ key : string ] : any };
  }

  export class ListBadges extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListBadgesResponse> {
    __response : EVA.Core.Services.ListBadgesResponse;
  }

  export class ListBadgesResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.BadgeDto> {
  }

  export class BadgeDto {
    ID : number; // Int32
    Name : string;
    Description : string;
    TypeID : number; // Int32
    Type : EVA.Core.BadgeTypes;
  }

  export class SaveBadge extends EVA.Core.RequestMessageWithEmptyResponse {
    Badge : EVA.Core.Services.BadgeDto;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class AuthenticateWithThirdPartyLogin extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.AuthenticateWithThirdPartyLoginResponse> {
    Code : string;
    Data : { [ key : string ] : string };
    __response : EVA.Core.Services.AuthenticateWithThirdPartyLoginResponse;
  }

  export class AuthenticateWithThirdPartyLoginResponse extends EVA.Core.ResponseMessage {
    Authentication : EVA.Core.AuthenticationResults;
    AuthenticationToken : string;
  }

  export class GetAvailableThirdPartiesForLogin extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetAvailableThirdPartiesForLoginResponse> {
    __response : EVA.Core.Services.GetAvailableThirdPartiesForLoginResponse;
  }

  export class GetAvailableThirdPartiesForLoginResponse extends EVA.Core.ResponseMessage {
    AuthenticationMethods : string[];
  }

  export class Login extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.LoginResponse> implements EVA.Core.ILoginRequest {
    Username : string;
    Password : string;
    OrganizationUnitID : number; // Int32, nullable
    ApplicationID : number; // Int32
    ConfirmationToken : string;
    AuthenticationToken : string;
    IdentificationCode : string;
    Client : EVA.Core.Clients;
    RegisterApiKey : boolean;
    SelectOrganizationByApplicationID : boolean;
    LanguageID : string;
    CountryID : string;
    CustomAuthenticatorType : string;
    CustomAuthenticateData : any;
    ClientVersion : string;
    Context : string;
    PublicLogin : boolean;
    UserType : EVA.Core.UserTypes;
    __response : EVA.Core.Services.LoginResponse;
  }

  export class LoginResponse extends EVA.Core.ResponseMessage {
    Authentication : EVA.Core.AuthenticationResults;
    OrganizationUnits : EVA.Core.OrganizationUnitDto[];
    User : EVA.Core.LoggedInUserDto;
    LoggedInOrganizationID : number; // Int32, nullable
    IsCustomAuthenticateResult : boolean;
    AuthenticationToken : string;
    OrganizationUnitCurrencyID : string;
  }

  export class Logout extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.LogoutResponse> {
    AuthenticationToken : string;
    ClockOut : boolean;
    Client : EVA.Core.Clients;
    __response : EVA.Core.Services.LogoutResponse;
  }

  export class LogoutResponse extends EVA.Core.ResponseMessage {
    LogoutSuccesful : boolean;
  }

  export class Ping extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class RequestThirdPartyLogin extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.RequestThirdPartyLoginResponse> {
    Code : string;
    ReturnUrlSuccess : string;
    ReturnUrlError : string;
    __response : EVA.Core.Services.RequestThirdPartyLoginResponse;
  }

  export class RequestThirdPartyLoginResponse extends EVA.Core.ResponseMessage {
    RedirectUrl : string;
  }

  export class GetAssortmentByID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetAssortmentByIDResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetAssortmentByIDResponse;
  }

  export class GetAssortmentByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    Name : string;
    StartDateTime : string; // DateTime
    EndDateTime : string; // DateTime, nullable
  }

  export class CreateAssortment extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreateAssortmentResponse> {
    Name : string;
    StartDateTime : string; // DateTime
    EndDateTime : string; // DateTime, nullable
    __response : EVA.Core.Services.CreateAssortmentResponse;
  }

  export class CreateAssortmentResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }

  export class UpdateAssortment extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Name : string;
    StartDateTime : string; // DateTime
    EndDateTime : string; // DateTime, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteAssortment extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListAssortments extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListAssortmentsResponse> {
    __response : EVA.Core.Services.ListAssortmentsResponse;
  }

  export class ListAssortmentsResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.ListAssortmentsResponseAssortmentDto> {
  }

  export class ListAssortmentsResponseAssortmentDto {
    ID : number; // Int32
    Name : string;
    StartDateTime : string; // DateTime
    EndDateTime : string; // DateTime, nullable
  }

  export class GetOrganizationUnitAssortmentProductByID extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetOrganizationUnitAssortmentProductByIDResponse> {
    ID : number; // Int32
    __response : EVA.Core.Services.GetOrganizationUnitAssortmentProductByIDResponse;
  }

  export class GetOrganizationUnitAssortmentProductByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    ProductID : number; // Int32
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnitTypeID : number; // Int32, nullable
    AssortmentID : number; // Int32
  }

  export class CreateOrganizationUnitAssortmentProduct extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.CreateOrganizationUnitAssortmentProductResponse> {
    ProductID : number; // Int32
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnitTypeID : number; // Int32, nullable
    AssortmentID : number; // Int32
    __response : EVA.Core.Services.CreateOrganizationUnitAssortmentProductResponse;
  }

  export class CreateOrganizationUnitAssortmentProductResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }

  export class UpdateOrganizationUnitAssortmentProduct extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    ProductID : number; // Int32
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnitTypeID : number; // Int32, nullable
    AssortmentID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteOrganizationUnitAssortmentProduct extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListOrganizationUnitAssortmentProducts extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListOrganizationUnitAssortmentProductsResponse> {
    __response : EVA.Core.Services.ListOrganizationUnitAssortmentProductsResponse;
  }

  export class ListOrganizationUnitAssortmentProductsResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.ListOrganizationUnitAssortmentProductsResponseOrganizationUnitAssortmentProductDto> {
  }

  export class ListOrganizationUnitAssortmentProductsResponseOrganizationUnitAssortmentProductDto {
    ID : number; // Int32
    ProductID : number; // Int32
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnitTypeID : number; // Int32, nullable
    AssortmentID : number; // Int32
  }

  export class GetApplicationConfiguration extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetApplicationConfigurationResponse> {
    __response : EVA.Core.Services.GetApplicationConfigurationResponse;
  }

  export class GetApplicationConfigurationResponse extends EVA.Core.ResponseMessage {
    Configuration : { [ key : string ] : any };
  }

  export class GetCurrentApplication extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetCurrentApplicationResponse> {
    __response : EVA.Core.Services.GetCurrentApplicationResponse;
  }

  export class GetCurrentApplicationResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    Name : string;
    OrganizationUnitID : number; // Int32
    AssetsBaseUrl : string;
    PluginConfigurations : EVA.Core.Services.ApplicationPluginConfigurationDto[];
    RequiredUserTypeID : number; // Int32, nullable
    BaseUrl : string;
  }

  export class ApplicationPluginConfigurationDto {
    PluginCategory : string;
    IsEnabled : boolean;
  }

  export class ListApplicationsForCatalog extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListApplicationsForCatalogResponse> {
    __response : EVA.Core.Services.ListApplicationsForCatalogResponse;
  }

  export class ListApplicationsForCatalogResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.ApplicationDto[];
  }

  export class ApplicationDto {
    ID : number; // Int32
    Name : string;
    OrganizationUnitID : number; // Int32
    AuthenticationToken : string;
    AssetsBaseUrl : string;
    PluginConfigurations : EVA.Core.Services.ApplicationPluginConfigurationDto[];
    RequiredUserTypeID : number; // Int32, nullable
    BaseUrl : string;
  }

  export class ListApplications extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListApplicationsResponse> {
    __response : EVA.Core.Services.ListApplicationsResponse;
  }

  export class ListApplicationsResponse extends EVA.Core.GetResponse<EVA.Core.Services.ApplicationDto[]> {
  }

  export class ListAddressBook extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListAddressBookResponse> {
    UserID : number; // Int32, nullable
    __response : EVA.Core.Services.ListAddressBookResponse;
  }

  export class ListAddressBookResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.AddressBookDto> {
  }

  export class AddressBookDto {
    ID : number; // Int32
    Address : EVA.Core.AddressDto;
    Description : string;
    DefaultShippingAddress : boolean;
    DefaultBillingAddress : boolean;
  }

  export class CreateAddressBookItem extends EVA.Core.RequestMessageGeneric<EVA.Core.CreateResponse> {
    UserID : number; // Int32, nullable
    Description : string;
    Address : EVA.Core.AddressDto;
    __response : EVA.Core.CreateResponse;
  }

  export class UpdateAddressBookItem extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Description : string;
    Address : EVA.Core.AddressDto;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteAddressBookItem extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class SetDefaultShippingAddress extends EVA.Core.RequestMessageWithEmptyResponse {
    AddressBookID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class SetDefaultBillingAddress extends EVA.Core.RequestMessageWithEmptyResponse {
    AddressBookID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class AutocompleteAddress extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.AutocompleteAddressResponse> {
    Query : string;
    __response : EVA.Core.Services.AutocompleteAddressResponse;
  }

  export class AutocompleteAddressResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.AddressSuggestion[];
  }

  export class GetAddressForZipCode extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetAddressForZipCodeResponse> {
    ZipCode : string;
    HouseNumber : string;
    __response : EVA.Core.Services.GetAddressForZipCodeResponse;
  }

  export class GetAddressForZipCodeResponse extends EVA.Core.GetResponse<EVA.Core.AddressDto> {
  }

  export class GetAutocompleteAddressByReference extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetAutocompleteAddressByReferenceResponse> {
    Suggestion : EVA.Core.AddressSuggestion;
    __response : EVA.Core.Services.GetAutocompleteAddressByReferenceResponse;
  }

  export class GetAutocompleteAddressByReferenceResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.AddressSuggestionDetails;
  }

  export class ListCountries extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListCountriesResponse> {
    __response : EVA.Core.Services.ListCountriesResponse;
  }

  export class ListCountriesResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.CountryDto[];
  }

  export class CountryDto {
    ID : string;
    Name : string;
  }

  export class UpdateAddress extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    BillToShipping : boolean;
    ShipToAddress : EVA.Core.AddressDto;
    BillToAddress : EVA.Core.AddressDto;
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteAccountingRule extends EVA.Core.DeleteRequest implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class DeleteAccount extends EVA.Core.DeleteRequest implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class CreateAccount extends EVA.Core.CreateRequest<EVA.Core.Services.AccountDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }

  export class AccountDto {
    ID : number; // Int32
    Name : string;
    ObjectAccount : string;
    Subsidiary : string;
    AccountStyleID : number; // Int32
    AccountStyle : EVA.Core.AccountStyle;
    VisibleByApplicationID : number; // Int32
    BookOnOrganizationUnitID : number; // Int32, nullable
    BookOnOrganizationUnit : EVA.Core.OrganizationUnitDto;
    BookingFlagsID : number; // Int32
    BookingFlags : EVA.Core.BookingFlags;
  }

  export class GetAccount extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.GetAccountResponse> {
    Id : number; // Int32
    __response : EVA.Core.Services.GetAccountResponse;
  }

  export class GetAccountResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.Services.AccountDto;
  }

  export class ListAccounts extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListAccountsResponse> {
    StyleFilter : EVA.Core.AccountStyle;
    PageConfig : EVA.Core.PageConfig;
    __response : EVA.Core.Services.ListAccountsResponse;
  }

  export class ListAccountsResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.PagedResultGeneric<EVA.Core.Services.AccountDto>;
  }

  export class UpdateAccount extends EVA.Core.UpdateRequest<EVA.Core.Services.AccountDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class ListAccountingBookings extends EVA.Core.RequestMessageGeneric<EVA.Core.Services.ListAccountingBookingsResponse> {
    PageConfig : EVA.Core.PageConfig;
    BookingFilter : EVA.Core.Bookings;
    OrganizationUnitIDFilter : number; // Int32, nullable
    LedgerClassFilter : string;
    FilterFallbacks : boolean;
    __response : EVA.Core.Services.ListAccountingBookingsResponse;
  }

  export class ListAccountingBookingsResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.PagedResultGeneric<EVA.Core.Services.AccountingBookingDto>;
  }

  export class AccountingBookingDto {
    ID : number; // Int32
    ParentID : number; // Int32, nullable
    Booking : EVA.Core.Bookings;
    OrganizationUnitTypes : EVA.Core.OrganizationUnitTypes;
    OrganizationUnitID : number; // Int32, nullable
    LedgerClassID : string;
    BookOnOrganizationUnitID : number; // Int32, nullable
    BookWithLedgerClassID : string;
    AccountingInstructionID : number; // Int32
    BalanceAccountingInstructionID : number; // Int32, nullable
    BookingFunction : string;
    Children : EVA.Core.Services.AccountingBookingDto[];
  }

  export class ListAccountingRules extends EVA.Core.PagedResultRequest<EVA.Core.Services.ListAccountingRulesResponse> {
    __response : EVA.Core.Services.ListAccountingRulesResponse;
  }

  export class ListAccountingRulesResponse extends EVA.Core.PagedResultResponse<EVA.Core.Services.AccountingRuleDto> {
  }

  export class AccountingRuleDto {
    ID : number; // Int32
    AccountingInstructionID : number; // Int32
    AccountID : number; // Int32
    Account : EVA.Core.Services.AccountDtoWithAccountingRules;
    VisibleByApplicationID : number; // Int32
    LedgerClassID : string;
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnit : EVA.Core.OrganizationUnitDto;
  }

  export class AccountDtoWithAccountingRules {
    ID : number; // Int32
    Name : string;
    ObjectAccount : string;
    Subsidiary : string;
    AccountStyleID : number; // Int32
    AccountStyle : EVA.Core.AccountStyle;
    VisibleByApplicationID : number; // Int32
    BookOnOrganizationUnitID : number; // Int32, nullable
    BookOnOrganizationUnit : EVA.Core.OrganizationUnitDto;
    BookingFlagsID : number; // Int32
    BookingFlags : EVA.Core.BookingFlags;
    AccountingRules : EVA.Core.Services.AccountingRuleDto[];
  }

  export class CreateAccountingBooking extends EVA.Core.CreateRequest<EVA.Core.Services.AccountingBookingDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }

  export class CreateAccountingRule extends EVA.Core.CreateRequest<EVA.Core.Services.AccountingRuleDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }

  export class UpdateAccountingBooking extends EVA.Core.UpdateRequest<EVA.Core.Services.AccountingBookingDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

  export class UpdateAccountingRule extends EVA.Core.UpdateRequest<EVA.Core.Services.AccountingRuleDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }

}

/* tslint:disable */
declare module EVA.Core {
  
  export enum MessageQueueProfile {
    SendOnly = 0,
    SendAndReceive = 1,
  }
  
  export enum RedisIntents {
    Default = 0,
    Cache = 1,
  }
  
  export enum RequiredFor {
    PlaceOrder = 1,
    Payment = 2,
    Ship = 4,
    Invoice = 8,
    All = 15,
  }
  
  export enum UsernameFields {
    EmailAddress = 1,
    Nickname = 2,
    PhoneNumber = 3,
  }
  
  export enum InvalidStockMutationReasons {
    DestinationLabelEqualsSourceLabel = 0,
    InvalidSourceLabel = 1,
    InvalidDestinationLabel = 2,
    InvalidQuantity = 3,
    InvalidLabelForAdjustment = 4,
    RemarkRequired = 5,
    ReasonRequired = 6,
    NonStockProduct = 7,
    InvalidProduct = 8,
    InvalidResourceID = 9,
    InvalidOrganizationUnitID = 10,
    TypeRequired = 11,
  }
  
  export enum Functionalities {
    Login = 0,
    PerformCycleCount = 1,
    ApprovePayment = 2,
    ViewCustomers = 3,
    ViewReports = 4,
    PerformInitialCycleCount = 5,
    PerformPreCount = 6,
    ManageStoreTypes = 7,
    ExternalLogin = 8,
    MailReports = 9,
    ProductsBaseFeed = 10,
    OrganizationUnitsBaseFeed = 11,
  }
  
  export enum PasswordValidationResults {
    Valid = 0,
    TooShort = 1,
    NoMatchWithOldPassword = 2,
    TooLong = 3,
  }
  
  export enum UrlSafetyResult {
    Safe = 0,
    Unsafe = 1,
    InvalidUrl = 2,
  }
  
  export enum GeocodeResultStatus {
    OK = 0,
    NoResults = 1,
    InvalidRequest = 2,
    UnknownError = 3,
  }
  
  export enum ExcludedFieldOptions {
    UseDefaultExcludes = 0,
    AdditionalExcludes = 1,
    ReplaceDefaultExcludes = 2,
    NoExcludes = 3,
  }
  
  export enum BrandNameSearchSortOption {
    NameAscending = 0,
    NameDescending = 1,
    Hits = 2,
  }
  
  export enum ProductStatus {
    None = 0,
    PreRelease = 1,
    DeliveryOnly = 4,
    DisableDelivery = 8,
    DisablePickup = 16,
    DisableBackorder = 32,
    UseUp = 34,
  }
  
  export enum ProductPropertyNames {
    ProductID = 0,
    Barcodes = 1,
    VendorIDs = 2,
  }
  
  export enum PriceListAdjustmentTargets {
    Price = 0,
    SalesRules = 1,
    PurchaseRules = 2,
  }
  
  export enum FactorType {
    Amount = 0,
    Percentage = 1,
  }
  
  export enum BankAccountAuthorizationResultTypes {
    NoPaymentFound = 1,
    NoPaymentDetails = 2,
    NoBankAccountInDetails = 3,
    NoMatchWithCustomerBankAccount = 4,
    Success = 5,
    NoMatchWithCustomerName = 6,
  }
  
  export enum CancellationInitiator {
    System = 1,
    User = 2,
    External = 5,
  }
  
  export enum ReservedOrderLineAction {
    RemoveStockAndQuantity = 0,
    OnlyRemoveQuantity = 1,
    ForcedRemoveStock = 2,
  }
  
  export enum DefaultOrderShipperFunctionalities {
    ForcedManualShipment = 0,
  }
  
  export enum LineActionTypeChangeInitiator {
    System = 1,
    User = 2,
  }
  
  export enum MomentOfCommitment {
    None = 0,
    Creation = 1,
    Payment = 2,
  }
  
  export enum OrderLineCloneIntent {
    Split = 0,
    Derived = 1,
  }
  
  export enum OrderShipmentValidationResults {
    Unknown = 0,
    Valid = 1,
    Invalid = 2,
  }
  
  export enum OrderLineCommitmentResultTypes {
    Committed = 0,
    NoCommitmentNecessary = 1,
    InsuffientStock = 2,
  }
  
  export enum OrderCancellationOptions {
    CanBeCancelled = 0,
    AlreadyCancelled = 1,
    ShouldBeRequested = 2,
    MustBeRequested = 3,
    CannotBeCancelled = 4,
  }
  
  export enum OrderLineWithStockProcessAction {
    None = 0,
    CreateStockReservationTask = 1,
    Export = 2,
  }
  
  export enum ReturnableStatuses {
    Returnable = 1,
    NotReturnable = 2,
    SelfAndChildrenNotReturnable = 4,
    SelfAndParentsNotReturnable = 8,
    HierarchyNotReturnable = 12,
    ReturnableWithParent = 16,
  }
  
  export enum OrderLineCancellationResultReasons {
    Cancelled = 0,
    CouldNoLongerCancel = 1,
    CancellationNotSupported = 2,
    OrderLineNotFoundInExternalSystem = 3,
    InProgress = 4,
  }
  
  export enum OrderExportValidationResults {
    Unknown = 0,
    Valid = 1,
    Invalid = 2,
    NothingToBeExported = 3,
  }
  
  export enum NotificationPriority {
    Normal = 0,
    Low = 1,
  }
  
  export enum ClientNotificationType {
    Info = 1,
    Success = 2,
    Error = 3,
    Warning = 4,
  }
  
  export enum PushNotificationPriority {
    Low = 1,
    High = 2,
  }
  
  export enum MessageTargetContentTypes {
    Html = 0,
    Pdf = 1,
    Plain = 2,
  }
  
  export enum SystemQueues {
    Default = 0,
    Mails = 1,
  }
  
  export enum MappingProfiles {
    Get = 0,
    Update = 1,
    Create = 2,
  }
  
  export enum SortDirection {
    Ascending = 0,
    Descending = 1,
    NotSorted = 2,
  }
  
  export enum GravatarRating {
    G = 0,
    PG = 1,
    R = 2,
    X = 3,
  }
  
  export enum GiftCardFunctionalities {
    ForceProcessCards = 0,
  }
  
  export enum Bookings {
    Sales = 100,
    Purchase = 101,
    SalesDiscounts = 110,
    SalesTax = 130,
    COGS = 140,
    Payment = 200,
    PaymentRoundings = 201,
    CashDifferences = 218,
    CashDifferenceCorrections = 219,
    CashExpenses = 220,
    CashDeposits = 221,
    GeneralAccounting = 300,
    Kickbacks = 400,
    Shipment = 500,
    StockAdjustment = 501,
    StockCorrection = 503,
    StockCorrectionAutomatic = 504,
    StockRevaluation = 505,
    StockReceipt = 506,
    StockReceiptDeviations = 507,
    StockInTransit = 508,
    StockCycleCount = 509,
    StockInterbranch = 510,
  }
  
  export enum AccountingInstructions {
    Sales = 1000,
    SalesDiscounts = 1100,
    SalesTaxes = 1300,
    CostOfGoodsSold = 1600,
    AR = 2000,
    CurrentAccount = 2001,
    GenericBooking = 2002,
    Payment = 2100,
    CashDeposits = 2110,
    CashExpenses = 2111,
    AP = 2300,
    Stock = 3000,
    StockDifferences = 3001,
    StockRevaluations = 3002,
    StockInterbranch = 3003,
    GoodsToBeInvoiced = 4770,
    PurchasedGoodsToBeInvoiced = 4771,
    PurchaseInvoice = 4772,
    CashDifferenceCorrection = 5000,
  }
  
  export enum FinancialEventProcessStatuses {
    Success = 0,
    SuccessWithWarnings = 1,
    Failure = 2,
  }
  
  export enum ServiceExceptionTypes {
    General = 0,
    Unknown = 1,
    Unauthorized = 2,
    PasswordPolicyViolation = 3,
    UserPhoneNumberRequired = 4,
    ProductNotOnPurchaseOrder = 5,
    ProductOnPurchaseOrderAlreadyReceived = 6,
    ReceivedMoreThanIsOpenOnOrder = 7,
    CannotReceivePurchaseOrdersFromMultipleVendors = 8,
    SpecifiedFunctionalityNotPresentOnUser = 9,
    PasswordResetTokenInvalid = 10,
    SubscribeTokenInvalid = 11,
    PasswordResetOldPasswordInvalid = 12,
    CannotReceiveNegativeQuantityOnPurchaseOrder = 13,
    EmailAddressInUse = 14,
    MustBeAnEmployeeToScanStation = 15,
    UnknownStation = 16,
    UnknownDevice = 17,
    AddingToShoppingCartNotAllowed = 18,
    NoShoppingCart = 19,
    ProductNotInShoppingCart = 20,
    LineNotInShoppingCart = 21,
    ProductNotFound = 22,
    ProductNotFoundWithBarcode = 23,
    CannotChangeStationWhilePaymentInProgress = 24,
    CustomerMissing = 25,
    UnknownOrganization = 26,
    NoOrganization = 27,
    PaymentValidationError = 28,
    NoGiftWrapProduct = 29,
    UserNotAttachedToTask = 30,
    ObjectNotCheckedForVisibility = 31,
    LoyaltyCardNotFound = 32,
    UserContainerNotFound = 33,
    IncompleteLogin = 34,
    IncompleteConfirmation = 35,
    InvalidEmailAddress = 36,
    AppSettingNotDefined = 37,
    SecurityException = 38,
    StationRequired = 39,
    OrderContainsPayments = 40,
    OrderAlreadyFullyPaid = 41,
    BarcodeNotFound = 42,
    ScanStationBeforeInitiatingPayment = 43,
    AdjustStockRemarkRequired = 44,
    InvalidEan13Barcode = 45,
    NoReasonSupplied = 46,
    ShippingAddressRequired = 47,
    DeliveryRequiresAddress = 48,
    AttachCustomerNotAllowed = 49,
    FinanceException = 50,
    NoOpenFinancePeriod = 51,
    FinancePeriodUnavailable = 52,
    FinancePeriodAlreadyOpened = 53,
    AmountExceedsStationCashLimit = 54,
    AmountExceedsSafeCashLimit = 55,
    CannotChangeChildLines = 56,
    ReceiptClosed = 57,
    OrderCompleted = 58,
    PrintFailed = 59,
    NotFound = 60,
    DeletingOrderLineNotAllowed = 61,
    UpdateLineActionTypeNotAllowed = 62,
    OrderLineAlreadyCompleted = 63,
    AddLineNotAllowed = 64,
    RemoveLineNotAllowed = 65,
    CannotDeleteOrder = 66,
    CannotModifyQuantity = 67,
    InvalidAddress = 68,
    InvalidPickupOrder = 69,
    UnknownProduct = 70,
    OrderLineAlreadyExported = 71,
    InvalidOpeningHours = 72,
    NoLinesForConfirmShipment = 73,
    InvalidRequest = 74,
    UserNotFound = 75,
    PeriodClosingCashDifference = 76,
    UnknownPaymentType = 77,
    ShoppingCartNotFound = 78,
    InvalidStockLabel = 79,
    InsufficientStock = 80,
    ModifyLineNotAllowed = 81,
    IncreaseCmaNotAllowed = 82,
    LineNotInBackorder = 83,
    InvalidBarcode = 84,
    OpenCycleCountsRemanining = 85,
    OrderHasHoldStatus = 86,
    OrderAlreadyExported = 87,
    CycleCountAlreadyCompleted = 88,
    NonStockReservation = 89,
    PendingPayment = 90,
    CreditcardDisabled = 91,
    InvalidOrder = 92,
    InvalidSerial = 93,
    InvalidBankAccount = 94,
    CustomerRequired = 95,
    ObsoleteProductCannotBeOrdered = 96,
    CardActivationFailure = 97,
    CardCancellationFailure = 98,
    UnknownItemNumber = 99,
    UnknownShopNumber = 100,
    InvalidCustomer = 101,
    InvalidWebOrderNumber = 102,
    InvalidZipCode = 103,
    ReservationFailed = 104,
    DetachCustomerNotAllowed = 105,
    CannotAddLineToPaidOrderWithDiscount = 106,
    CannotAddDiscountToPaidOrder = 107,
    NotImplemented = 108,
    NoCountedQuantitiesSpecified = 109,
    UnknownStockReservationTask = 110,
    CannotIncreaseQuantityOnReservedLine = 111,
    TaskAlreadyCompleted = 112,
    InvalidQuantityToCancel = 113,
    InvalidTaxRate = 114,
    BillingAddressRequired = 115,
    InvalidCountry = 116,
    ParseFailure = 117,
    InvalidPurchaseDate = 118,
    EmptyDeliveryNoteNumber = 119,
    RmaReferenceAlreadyUsed = 120,
    CannotMoveBackMoreToSellableThanWasRequested = 121,
    RmaLineCannotBeDeleted = 122,
    InvalidClientVersion = 123,
    RmaReferenceIsRequired = 124,
    ScanInitialCycleCountLabel = 125,
    InitialCycleCountAlreadyExists = 126,
    CannotCreateInitialCycleCount = 127,
    CannotCreateInitialCycleCountWithOpenRmaRemaining = 128,
    CannotCreateInitialCycleCountWithOpenCmaRemaining = 129,
    CannotCountNonStockProduct = 130,
    CannotRecoverOtherCart = 131,
    CannotRecoverOrderFromOtherOrganization = 132,
    PaymentReturnActionBlocked = 133,
    CannotCreateInitialCycleCountWithoutOpenPeriod = 134,
    CouponCodeAlreadyInUse = 135,
    TransactionAlreadyConfirmed = 136,
    CannotChangeShippingMethod = 137,
    ReservationCleanupNoProductsMoved = 138,
    CannotRemovePrePaymentStatus = 139,
    ReservationCleanupWrongNumberOfProductsMoved = 140,
    OrganizationUnitUnavailableForPickup = 141,
    PasswordResetTokenAlreadyUsed = 142,
    ValidationFailed = 143,
    CannotCancelOrderLine = 144,
    InvalidStockMutation = 145,
    InvalidVerificationCode = 146,
    OrderCannotBeShipped = 147,
    PolicyOrReferenceNumberNotValid = 148,
    PolicyAndReferenceNumberRequired = 149,
    OpeningCashDrawerDisabled = 150,
    UsersStillClockedIn = 151,
    UserTaskNotActive = 152,
    UserTaskAlreadyCompleted = 153,
    UserTaskNotAttached = 154,
    UserNotAttachedToUserTask = 155,
    CannotCancelOrder = 156,
    StockResourceInvalid = 157,
    OrderFlaggedForFraud = 158,
  }
  
  export enum StartupPriority {
    Normal = 0,
    Later = 1,
    AsLateAsPossible = 2,
    Deferred = 3,
    AsSoonAsPossible = -2,
    Sooner = -1,
  }
  
  export enum StartupType {
    Normal = 0,
    Always = 1,
  }
  
  export enum AuthenticationResults {
    NotAuthenticated = 0,
    NotAuthorized = 1,
    Authenticated = 2,
    NeedsTwoStepAuthentication = 3,
    NeedsOrganizationUnitID = 4,
  }
  
  export enum Clients {
    Unknown = 0,
    Website = 1,
    Ipod = 2,
    Backend = 3,
    ManagementApplication = 4,
    ThirdParty = 5,
  }
  
  export enum CustomActionTypes {
    Pre = 0,
    Post = 1,
  }
  
  export enum EventLogStatus {
    New = 0,
    InProgress = 1,
    Solved = 2,
    Incidental = 3,
    WontFix = 4,
  }
  
  export enum LineActionTypes {
    None = 0,
    ReserveLine = 1,
    OrderLine = 2,
    ShipLine = 3,
    Delivery = 4,
  }
  
  export enum PaymentLogType {
    EJournal = 0,
    Receipt = 1,
    CustomerReceipt = 2,
    MerchantReceipt = 3,
  }
  
  export enum StockMutationDirection {
    None = 0,
    Positive = 1,
    Negative = 2,
    Both = 3,
  }
  
  export enum DiscountInvalidReasons {
    None = 0,
    NotExist = 1,
    NotValidYet = 2,
    Expired = 3,
    HasAlreadyBeenUsed = 4,
    CouponCodeAlreadyAdded = 5,
    ManualValueIsInvalid = 6,
    UserCardNotFound = 7,
    UserCardIsInvalid = 8,
    UserCardInsufficientBalance = 9,
    UserCardInvalidPassword = 10,
  }
  
  export enum POSPrinterFont {
    FontA = 0,
    FontB = 1,
    FontC = 2,
  }
  
  export enum POSPrinterOrientation {
    Landscape = 0,
    Portrait = 1,
  }
  
  export enum POSImageSize {
    Normal = 0,
    DoubleWidth = 1,
    DoubleHeight = 2,
  }
  
  export enum Drawer {
    DrawerA = 0,
    DrawerB = 1,
  }
  
  export enum POSPrinterAlignment {
    Left = 0,
    Center = 1,
    Right = 2,
  }
  
  export enum POSBarcodeHRI {
    NotPrinted = 0,
    AboveBarcode = 1,
    BelowBarcode = 2,
  }
  
  export enum POSBarcodeType {
    UpcA = 0,
    UpcE = 1,
    Jan13 = 2,
    Jan8 = 3,
    Code39 = 4,
    Itf = 5,
    Codabar = 6,
    TriopticCode39 = -12,
    BooklandEAN = -11,
    EAN128 = -10,
    MSI = -9,
    Code11 = -8,
    Discrete = -7,
    Interleaved = -6,
    Code93 = -5,
    Code128 = -4,
    Ean13 = -3,
    Ean8 = -2,
    Unknown = -1,
  }
  
  export enum LineSize {
    Regular = 0,
    Double = 1,
    Half = 2,
  }
  
  export enum OpenCashDrawerResults {
    Failure = 0,
    Opened = 1,
    AlreadyOpen = 2,
  }
  
  export enum OverallPinResultStatus {
    None = 0,
    TimeoutFromPinDevice = 1,
    TransactionStillInProgressForPayment = 2,
    Success = 3,
    Aborted = 4,
    Failure = 5,
    DeviceUnavailable = 6,
    PrintLastTicket = 7,
    TimedOut = 8,
    TransactionAlreadyInProgressForUser = 9,
    UserMustScanStationToAbort = 10,
    PaymentValidationError = 11,
    InProgress = 12,
    ClientFailure = 13,
    SelectPaymentMethod = 14,
    MustRevalidate = 16,
    ConnectToTerminal = 17,
  }
  
  export enum BookingFlags {
    None = 0,
    WithTaxInformation = 1,
    WithoutOffsets = 2,
    BookWithOrderNumber = 4,
    BookWithReference = 8,
    BookWithInvoiceNumber = 16,
  }
  
  export enum AccountStyle {
    Balance = 0,
    ProfitLoss = 1,
  }
  
  export enum BadgeTypes {
    Role = 1,
    Capability = 2,
    Achievement = 3,
  }
  
  export enum CardActionTypes {
    Activate = 0,
    Cancel = 1,
    PreventActivation = 2,
    Purchase = 3,
  }
  
  export enum CashJournalTypes {
    Register = 0,
    Safe = 1,
  }
  
  export enum CommunicationMessageTypes {
    Email = 0,
    SMS = 1,
  }
  
  export enum LegalForms {
    BV = 1,
    NV = 2,
    VoF = 3,
    Eenmanszaak = 4,
    Stichting = 5,
    VrijBeroep = 6,
    Vereniging = 7,
    CV = 8,
    Maatschap = 9,
    Anders = 10,
  }
  
  export enum DiscountTriggers {
    Automatic = 0,
    Manual = 1,
    Coupon = 2,
    UserCard = 3,
    PriceBuilding = 4,
    SystemManaged = -1,
  }
  
  export enum DiscountConditionTypes {
    OneOf = 0,
    All = 1,
  }
  
  export enum DiscountObjectTypes {
    Discount = 0,
    Condition = 1,
    Action = 2,
    Coupon = 3,
  }
  
  export enum FinancialEventStatuses {
    Unprocessed = 0,
    Processed = 1,
    Ignored = 2,
    NoProcessingRequired = 3,
    NoMatchingRecipe = 4,
  }
  
  export enum FinancialEventTypes {
    Sales = 10,
    SalesTax = 11,
    SalesDiscounts = 12,
    Purchase = 20,
    CostOfGoods = 30,
    Payment = 40,
    PaymentRoundings = 41,
    CashAdjustment = 50,
    StockMutation = 60,
    StockMutationAutomaticCorrection = 61,
  }
  
  export enum FinancialPeriodStatus {
    Open = 0,
    Closing = 1,
    Closed = 2,
    Processed = 3,
    Pending = -1,
  }
  
  export enum FraudDataType {
    Address = 1,
    IBAN = 2,
    IdentificationDocument = 3,
  }
  
  export enum IdentificationTypes {
    DiplomaticPassport = 1,
    DriverLicense = 2,
    EuropeanIdentification = 3,
    ForeignPassport = 4,
    INDSticker = 5,
    NatoPassport = 6,
    Passport = 7,
    PermanentResidencyDocument = 8,
    PrivilegedDocument = 9,
    ResidencePermitTypeEuEea = 10,
    ResidencePermitTypeI = 11,
    ResidencePermitTypeII = 12,
    ResidencePermitTypeIII = 13,
    ResidencePermitTypeIV = 14,
    ResidencePermitTypeW = 15,
    VNGCard = 16,
    ResidencePermitTypeV = 17,
  }
  
  export enum InvoiceTypes {
    Sales = 0,
    Purchase = 1,
  }
  
  export enum InvoiceStatuses {
    Open = 0,
    Closed = 1,
  }
  
  export enum InvoiceAdditionalAmountTypes {
    ShippingCosts = 0,
    AdministrativeCosts = 1,
    OtherCosts = 2,
  }
  
  export enum MessageQueueErrorStatuses {
    New = 0,
    Republished = 1,
    SuccessAfterRetry = 2,
    FailureAfterRetry = 3,
    Ignored = 4,
  }
  
  export enum MessageTemplateTypes {
    Template = 1,
    Partial = 2,
    Layout = 3,
  }
  
  export enum MessageTemplateDestinations {
    Mail = 1,
    Sms = 2,
    Pdf = 4,
    Thermal = 8,
    Notification = 16,
  }
  
  export enum PaperFormats {
    A3 = 1,
    A4 = 2,
    A5 = 3,
    Legal = 4,
    Letter = 5,
    Tabloid = 6,
  }
  
  export enum PaperOrientations {
    Portrait = 1,
    Landscape = 2,
  }
  
  export enum OrderTypes {
    Sales = 0,
    Purchase = 1,
  }
  
  export enum OrderCharacteristics {
    None = 0,
    IsPickup = 1,
    CreatedByEmployee = 2,
    IsInterbranch = 4,
    IsB2b = 8,
  }
  
  export enum OrderStatus {
    Cart = 0,
    Order = 1,
  }
  
  export enum OrderProperties {
    None = 0,
    IgnoreDiscounts = 1,
    IgnoreShippingCosts = 2,
    UseAlternateTaxCalculationMethod = 4,
    DisableAutomaticLineCreation = 11,
    IgnoreOrderLineValidation = 16,
    SystemGenerated = 59,
    DoNotCommitStock = 64,
    DisableAutoReceiveShipment = 128,
  }
  
  export enum CardTransactionStatus {
    NotActivated = 0,
    Activating = 1,
    Activated = 2,
    Cancelled = 99,
  }
  
  export enum ExternalModificationStatuses {
    None = 0,
    CancellationRequested = 1,
    QuantityChangeRequested = 2,
    CancellationRequestDenied = 4,
    CancellationRequestApproved = 8,
    QuantityChangeRequestDenied = 16,
    QuantityChangeRequestApproved = 32,
  }
  
  export enum OrderExportStatuses {
    NotExported = 0,
    ShouldBeExported = 1,
    Exporting = 2,
    Exported = 3,
    WillNotBeExported = 4,
  }
  
  export enum OrderLineTypes {
    NormalProduct = 0,
    Discount = 1,
    ExtraCosts = 2,
    Contract = 3,
    SubscriptionContract = 4,
    ShippingCosts = 5,
    ReturnCosts = 6,
  }
  
  export enum OrganizationUnitTypes {
    None = 0,
    Shop = 1,
    WebShop = 2,
    Container = 4,
    Pickup = 8,
    Warehouse = 16,
    Franchise = 64,
    EVA = 128,
    TestOrganizationUnit = 256,
    DisableLogin = 512,
    Supplier = 1024,
    Consignment = 3072,
    B2b = 4096,
  }
  
  export enum OrganizationUnitStatus {
    Default = 0,
    Open = 1,
    Closed = 2,
    OpeningSoon = 4,
    TemporarilyClosed = 8,
    Sale = 16,
    Hidden = 32,
  }
  
  export enum PaymentStatuses {
    New = 0,
    Pending = 1,
    Confirmed = 10,
    Failed = -1,
  }
  
  export enum PaymentTypeCategory {
    EFT = 1,
    Ideal = 2,
  }
  
  export enum PaymentReturnActions {
    Default = 0,
    Blocked = 1,
    Forced = 2,
  }
  
  export enum ProductTypes {
    None = 0,
    Stock = 1,
    Marketing = 4,
    GiftCard = 8,
    Service = 16,
    CustomPricing = 64,
    External = 128,
    OrderCosts = 256,
    SystemGenerated = 512,
    ProductSet = 1024,
    Configurable = 16384,
    SupplierProduct = 32768,
  }
  
  export enum ProductPromisedDeliveryStatuses {
    Unknown = 0,
    KnownUnSure = 1,
    KnownQuiteSure = 2,
    KnownSure = 3,
    OnDay = 4,
    Stock = 5,
  }
  
  export enum ProductChangeMutationTypes {
    Created = 1,
    Updated = 2,
    Deleted = 3,
  }
  
  export enum ProductLedgerTypes {
    Adjustment = 0,
    AutomaticCorrection = 3,
    MoveFrom = 4,
    MoveTo = 5,
    Summary = 6,
    Commit = 7,
    Uncommit = 8,
    ExternalModification = 9,
  }
  
  export enum PurchaseOrderExportStatuses {
    NotExported = 0,
    Exported = 1,
  }
  
  export enum ReturnRequestStatus {
    New = 0,
    Exported = 1,
    Completed = 2,
  }
  
  export enum ReturnRequestTypes {
    CMA = 0,
    RMA = 1,
  }
  
  export enum SettingSensitivityTypes {
    Normal = 0,
    Sensitive = 1,
  }
  
  export enum SettingExposureTypes {
    Normal = 0,
    ApplicationConfiguration = 1,
  }
  
  export enum StockMutationTypes {
    Unknown = 0,
    Move = 1,
    Adjust = 2,
  }
  
  export enum StockMutationReasons {
    Unknown = 0,
    ChangeOrganizationUnit = 2,
    Correction = 3,
    Damage = 4,
    Theft = 5,
    Movement = 6,
    CycleCountDeviation = 7,
    Sold = 8,
    Received = 10,
    Returned = 11,
    DOA = 12,
    Scrap = 13,
    InternalUse = 14,
    Demo = 15,
    SentToVendor = 16,
    InitialInventory = 17,
    UndoOrderReservation = 18,
    CreateOrderReservation = 20,
    CreateReturnRequestStock = 21,
    InTransit = 22,
    ReceiptSurplus = 23,
    ReceiptDeficiency = 24,
    Revaluation = 26,
    InventoryReset = 27,
    CancelReturnRequestLine = 28,
    ReservationSurplus = 29,
    ShopClosingReturns = 31,
    NonReturnedProducts = 32,
    SentBySupplier = 33,
  }
  
  export enum SubscriptionTypes {
    None = 0,
    Newsletter = 1,
    Sms = 2,
    EmailDisabled = 8,
  }
  
  export enum UserTypes {
    None = 0,
    Employee = 1,
    Customer = 2,
    Anonymous = 4,
    Business = 8,
    System = 17,
    Migrated = 32,
    Debtor = 64,
    Incomplete = 128,
    LimitedTrust = 256,
    Tester = 512,
  }
  
  export enum UserCardAmountTypes {
    Currency = 0,
    Points = 1,
  }
  
  export enum UserCardMutationStatuses {
    Pending = 0,
    Completed = 1,
    Cancelled = 2,
  }
  
  export enum UserCardMutationTypes {
    Deposit = 0,
    Withdraw = 1,
  }
  
  export enum UserLedgerTypes {
    None = 0,
    Deleted = 1,
    EmailAddressChanged = 2,
    NameChanged = 3,
    DOBChanged = 4,
    CocNumberChanged = 5,
    CompanyNameChanged = 6,
    VatNumberChanged = 7,
    BankAccountChanged = 8,
    TypeChanged = 9,
    PasswordChanged = 10,
    PasswordResetRequested = 11,
    FunctionalitiesUpdated = 12,
    ShippingAddressChanged = 13,
    BillingAddressChanged = 14,
    PasswordResetFailed = 15,
    SubscriptionChanged = 16,
  }
  
  export enum ZipCodeHouseNumber {
    Uneven = 0,
    Even = 1,
    Sequential = 2,
  }
  
  export enum AfterCommitType {
    Insert = 1,
    Update = 2,
    Delete = 3,
  }
  
  export enum ConcurrencyControl {
    None = 0,
    Optimistic = 1,
    OptimisticModifiedColumnsOnly = 2,
  }
  
  export enum RunStartupComponentSideEffectsSettings {
    DoNotRun = 0,
    Prompt = 1,
    AlwaysRun = 2,
  }
  
  export enum AppScanTargets {
    Details = 0,
    Cart = 1,
  }
  
  export enum AppSearchMethods {
    Query = 0,
    CustomID = 1,
  }
  
  export enum AppStockReservationActions {
    ForceComplete = 1,
    Order = 2,
    SetAside = 4,
    Cancel = 8,
    All = 15,
  }
  
  export enum CommunicationMessageResults {
    Found = 0,
    Fallback = 1,
    Missing = 2,
  }
  
  export enum SendMode {
    Immediate = 0,
    Deferred = 1,
  }
  
  export enum PhoneNumberType {
    FixedLine = 0,
    Mobile = 1,
    FixedLineOrMobile = 2,
    TollFree = 3,
    PremiumRate = 4,
    SharedCost = 5,
    Voip = 6,
    PersonalNumber = 7,
    Pager = 8,
    UniversalAccessNumber = 9,
    VoiceMail = 10,
    Unknown = 11,
  }
  
  export enum SmsPriority {
    Normal = 0,
    High = 1,
  }
  
  export enum InvalidationPatternType {
    WildcardPostfix = 0,
    WildcardPrefix = 1,
    WildcardPreAndPostfix = 2,
    NoWildcard = 3,
  }
  
  export enum DocumentType {
    BankAccountCard = 0,
    ID = 1,
  }
  
  export enum EVAExecutionContextType {
    Unknown = 0,
    WebService = 1,
    MessageConsumer = 2,
    Task = 3,
  }
  
  export class RequestMessage {
  }
  
  export class CreateRequest<TModel> extends EVA.Core.RequestMessage {
    ToCreate : TModel; 
  }
  
  export class DeleteRequest extends EVA.Core.RequestMessage {
    ID : number; // Int32
  }
  
  export class RequestMessageGeneric<T extends ResponseMessage> extends EVA.Core.RequestMessage implements EVA.Core.IRequestRespondsAs<T> {
__response : T;
    }
  
  export class GetRequestGeneric<T extends EVA.Core.ResponseMessage> extends EVA.Core.RequestMessageGeneric<T> {
    ID : number; // Int32
  }
  
  export class ResponseMessage {
    Exception : EVA.Core.ServiceExceptionResult; 
  }
  
  export class ServiceExceptionResult {
    ExceptionMessage : string; 
    Type : string; 
    ErrorCode : string; 
  }
  
  export interface IRequestRespondsAs<TResponse extends EVA.Core.ResponseMessage> {
    __response : TResponse;
  }
  
  export class GetRequest extends EVA.Core.RequestMessage {
    ID : number; // Int32
  }
  
  export class PagedResultRequest<TResponse extends EVA.Core.ResponseMessage> extends EVA.Core.RequestMessageGeneric<TResponse> {
    PageConfig : EVA.Core.PageConfig; 
  }
  
  export class PageConfig {
    Start : number; // Int32
    Limit : number; // Int32
    SortProperty : string; 
    SortDirection : EVA.Core.SortDirection; 
    Filter : { [ key : string ] : string }; 
  }
  
  export class RequestMessageWithEmptyResponse extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
  }
  
  export class EmptyResponseMessage extends EVA.Core.ResponseMessage {
  }
  
  export class RequestMessageWithResourceResponse extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
  }
  
  export class ResourceResponseMessage extends EVA.Core.ResponseMessage {
    Url : string; 
  }
  
  export class UpdateRequest<TModel> extends EVA.Core.RequestMessage {
    ToUpdate : TModel; 
  }
  
  export enum MessageTypeKinds {
    Request = 0,
    Response = 1,
  }
  
  export class GetResponse<TResult> extends EVA.Core.ResponseMessage {
    Result : TResult; 
  }
  
  export class EnumDtoBase {
    ID : number; // Int32
    Name : string; 
    Description : string; 
    ApplicationID : number; // Int32, nullable
  }
  
  export class CreateResponse extends EVA.Core.ResponseMessage {
    Success : boolean; 
    ID : number; // Int32
  }
  
  export class PagedResultResponse<TModel> extends EVA.Core.ResponseMessage {
    Result : EVA.Core.PagedResultGeneric<TModel>; 
  }
  
  export class PagedResult {
  }
  
  export class PagedResultGeneric<TModel> extends EVA.Core.PagedResult {
    PageConfig : EVA.Core.PageConfig; 
    Page : TModel[]; 
    Offset : number; // Int32
    Limit : number; // Int32
    Total : number; // Int32
    SortProperty : string; 
    SortDirection : EVA.Core.SortDirection; 
    Filters : { [ key : string ] : string }; 
    NumberOfPages : number; // Int32
    CurrentPage : number; // Int32
  }
  
  export class OrganizationUnitDto {
    ID : number; // Int32
    ParentID : number; // Int32, nullable
    Name : string; 
    Description : string; 
    AddressID : number; // Int32, nullable
    Address : EVA.Core.AddressDto; 
    EmailAddress : string; 
    PhoneNumber : string; 
    Type : EVA.Core.OrganizationUnitTypes; 
    Status : EVA.Core.OrganizationUnitStatus; 
    OpeningHours : EVA.Core.OpeningHoursDto[]; 
    VisibleByApplicationID : number; // Int32
    Latitude : number; // Double, nullable
    Longitude : number; // Double, nullable
  }
  
  export class AddressDto {
    ID : number; // Int32
    ZipCode : string; 
    HouseNumber : string; 
    Street : string; 
    City : string; 
    AddressedTo : string; 
    CountryID : string; 
    CountryName : string; 
    Latitude : number; // Double, nullable
    Longitude : number; // Double, nullable
    Region : string; 
  }
  
  export class OpeningHoursDto {
    ID : number; // Int32
    OrganizationUnitID : number; // Int32
    DayOfWeek : System.Private.CoreLib.DayOfWeek; 
    ClosedForReceipts : boolean; 
    StartTime : any; // TimeSpan, nullable
    EndTime : any; // TimeSpan, nullable
    Date : string; // DateTime, nullable
    Description : string; 
    IsSpecial : boolean; 
    IsClosed : boolean; 
  }
  
  export class ShoppingCartResponse extends EVA.Core.ResponseMessage {
    ShoppingCart : EVA.Core.OrderDto; 
    OpenAmount : number; // Decimal
    ForeignOpenAmount : number; // Decimal
    TotalAmountInTax : number; // Decimal
    ForeignTotalAmountInTax : number; // Decimal
    TotalAmount : number; // Decimal
    ForeignTotalAmount : number; // Decimal
  }
  
  export class OrderDto {
    ID : number; // Int32
    BackendID : string; 
    CustomerID : number; // Int32, nullable
    Customer : EVA.Core.UserDto; 
    CreatedByID : number; // Int32
    CreatedBy : EVA.Core.UserDto; 
    CreationTime : string; // DateTime
    Payments : EVA.Core.PaymentTransactionDto[]; 
    ShippingAddressID : number; // Int32, nullable
    BillingAddressID : number; // Int32, nullable
    ShippingAddress : EVA.Core.AddressDto; 
    BillingAddress : EVA.Core.AddressDto; 
    Lines : EVA.Core.OrderLineDto[]; 
    IsActive : boolean; 
    OfferExpirationDate : string; // DateTime, nullable
    TotalAmountInTax : number; // Decimal
    ForeignTotalAmountInTax : number; // Decimal
    TaxTable : EVA.Core.TaxAmount[]; 
    StateDescription : string; 
    IsCompleted : boolean; 
    IsShipped : boolean; 
    IsPaid : boolean; 
    IsInvoiced : boolean; 
    IsCancelled : boolean; 
    Status : EVA.Core.OrderStatus; 
    HoldStatusID : number; // Int32, nullable
    Remark : string; 
    CustomerReference : string; 
    TotalItems : number; // Int32
    Messages : EVA.Core.DiscountInvalidReasons[]; 
    NeedsExtendedCustomerInformation : boolean; 
    InvoiceDate : string; // DateTime, nullable
    HasDelivery : boolean; 
    IdentificationID : number; // Int32, nullable
    SessionID : string; 
    Characteristics : EVA.Core.OrderCharacteristics; 
    OriginatingOrganizationUnitID : number; // Int32
    DestinationOrganizationUnitID : number; // Int32, nullable
    OrganizationUnitID : number; // Int32
    PickupOrganizationUnitID : number; // Int32
    SoldFromOrganizationUnitID : number; // Int32
    ShipFromOrganizationUnitID : number; // Int32, nullable
    SoldToOrganizationUnitID : number; // Int32, nullable
    CurrencyID : string; 
    OrderStatus : string; 
  }
  
  export class UserDto {
    ID : number; // Int32
    BackendRelationID : string; 
    EmailAddress : string; 
    Initials : string; 
    FirstName : string; 
    LastName : string; 
    FullName : string; 
    DateOfBirth : string; // DateTime, nullable
    PlaceOfBirth : string; 
    Gender : string; 
    ShippingAddressID : number; // Int32, nullable
    ShippingAddress : EVA.Core.AddressDto; 
    BillingAddressID : number; // Int32, nullable
    BillingAddress : EVA.Core.AddressDto; 
    Type : EVA.Core.UserTypes; 
    LanguageID : string; 
    IsDeleted : boolean; 
    Nickname : string; 
    Company : EVA.Core.CompanyDto; 
    BankAccount : string; 
    IsDebtor : boolean; 
    SubscriptionType : EVA.Core.SubscriptionTypes; 
    PhoneNumber : string; 
    GravatarHash : string; 
    Data : { [ key : string ] : string }; 
    TimeZone : string; 
  }
  
  export class CompanyDto {
    Name : string; 
    RegistrationNumber : string; 
    RegistrationCity : string; 
    RegistrationCountryID : string; 
    VatNumber : string; 
    LegalFormID : number; // Int32
    VisitorsAddress : EVA.Core.AddressDto; 
    DeliveryAddress : EVA.Core.AddressDto; 
    ReturnsAddress : EVA.Core.AddressDto; 
    InvoiceAddress : EVA.Core.AddressDto; 
    InvoiceEmailAddress : string; 
    EstablishedDate : string; // DateTime, nullable
    ContactEmailAddress : string; 
    ContactPhoneNumber : string; 
    AccountHolderName : string; 
    IBAN : string; 
    BIC : string; 
    LogoID : string; 
  }
  
  export class PaymentTransactionDto {
    ID : number; // Int32
    OrderID : number; // Int32
    PaymentDetails : string; 
    ErrorDetails : string; 
    PaymentDate : string; // DateTime, nullable
    Amount : number; // Decimal
    Status : EVA.Core.PaymentStatuses; 
    IsConfirmed : boolean; 
    IsSuccess : boolean; 
    PendingOrConfirmed : boolean; 
    StatusID : number; // Int32
    PaidAmount : number; // Decimal
    PaymentName : string; 
    Change : number; // Decimal
    TypeID : number; // Int32
    Type : EVA.Core.PaymentTypeDto; 
    CurrencyID : string; 
    ExchangeRate : number; // Decimal
    ForeignAmount : number; // Decimal
    ForeignPaidAmount : number; // Decimal
    Description : string; 
  }
  
  export class PaymentTypeDto {
    Code : string; 
    Name : string; 
    IsRoundingType : boolean; 
    PrintOnDocuments : boolean; 
  }
  
  export class OrderLineDto {
    ID : number; // Int32
    OrderID : number; // Int32, nullable
    Parent : EVA.Core.OrderLineDto; 
    ParentID : number; // Int32, nullable
    Type : EVA.Core.OrderLineTypes; 
    StockLabel : number; // Int32
    ResourceID : number; // Int32, nullable
    Description : string; 
    AdditionalDescription : string; 
    QuantityOrdered : number; // Int32
    QuantityCommitted : number; // Int32
    QuantityShipped : number; // Int32
    QuantityReserved : number; // Int32
    QuantityBackordered : number; // Int32
    QuantityReturned : number; // Int32
    QuantityCancelled : number; // Int32
    OrderStatus : string; 
    ProductID : number; // Int32, nullable
    Product : EVA.Core.ProductDto; 
    UnitPrice : number; // Decimal
    TaxRate : number; // Decimal
    ShowTaxInfo : boolean; 
    SerialNumber : string; 
    InsuranceItemID : number; // Int32, nullable
    InsuranceItem : EVA.Core.InsuranceItemDto; 
    IsCancelled : boolean; 
    TotalQuantityToShip : number; // Int32
    TotalAmountInTax : number; // Decimal
    TotalAmount : number; // Decimal
    CanModifyPrice : boolean; 
    ModificationAllowed : boolean; 
    Remark : string; 
    ReturnStockLabel : number; // Int32
    LineActionType : EVA.Core.LineActionTypes; 
    ReturnedOrderLineID : number; // Int32, nullable
    ExportStatusID : number; // Int32
    ContractNumber : string; 
    IsCompleted : boolean; 
    IsShipped : boolean; 
    ExpectedAvailabilityDate : string; // DateTime, nullable
    RequestedDate : string; // DateTime, nullable
    CreationTime : string; // DateTime
    LastModificationTime : string; // DateTime, nullable
    DiscountID : number; // Int32, nullable
    DiscountCouponID : number; // Int32, nullable
    DiscountAmount : number; // Decimal
    ShippingMethodID : number; // Int32, nullable
    ExternalModificationStatus : EVA.Core.ExternalModificationStatuses; 
    CustomOrderLineType : string; 
    CurrencyID : string; 
    ExchangeRate : number; // Decimal
    ForeignUnitPrice : number; // Decimal
    ForeignUnitPriceInTax : number; // Decimal
    ForeignTotalAmountInTax : number; // Decimal
    ProductVariation : { [ key : string ] : string }; 
  }
  
  export class ProductDto {
    ID : number; // Int32
    BackendID : string; 
    CustomID : string; 
    BrandID : number; // Int32, nullable
    BrandName : string; 
    PrimitiveName : string; 
    Type : EVA.Core.ProductTypes; 
    CatalogID : number; // Int32
    LedgerClassID : string; 
    OrganizationUnitID : number; // Int32, nullable
    Properties : any; 
  }
  
  export class InsuranceItemDto {
    ID : number; // Int32
    ProductID : number; // Int32
    Code : string; 
    Description : string; 
    DefaultServicePeriod : string; 
    InvoicePeriod : string; 
    PolicyCost : number; // Decimal, nullable
    InvoicePeriodAmount : number; // Decimal, nullable
    OwnRiskDamage : number; // Decimal, nullable
    Accessoires : boolean; 
    AbuseTelephoneConversation : boolean; 
    LoanCellPhone : boolean; 
    Stealing : boolean; 
    Damage : boolean; 
    Electrical : boolean; 
    ManufacturingErrors : boolean; 
    DataRecovery : boolean; 
    InvoicePeriodText : string; 
    DisplayText : string; 
    SinglePremium : boolean; 
  }
  
  export class TaxAmount {
    Rate : number; // Decimal
    Amount : number; // Decimal
    ForeignAmount : number; // Decimal
  }
  
  export class UserCardBalance {
    CardBalance : number; // Decimal
    CurrencyBalance : number; // Decimal
    CurrencyID : string; 
  }
  
  export class UserCardDto {
    ID : number; // Int32
    UserID : number; // Int32
    User : EVA.Core.UserDto; 
    Barcode : string; 
    IsActive : boolean; 
    CurrentBalance : EVA.Core.UserCardBalance; 
    TypeID : number; // Int32
    Type : EVA.Core.UserCardTypeDto; 
    AvailableDiscounts : EVA.Core.UserCardDiscountDto[]; 
    CurrencyID : string; 
  }
  
  export class UserCardTypeDto extends EVA.Core.EnumDtoBase {
    AmountType : EVA.Core.UserCardAmountTypes; 
  }
  
  export class DiscountDto {
    ID : number; // Int32
    IsActive : boolean; 
    Description : string; 
    NeedsReason : boolean; 
    CreatedByID : number; // Int32
    CreatedBy : EVA.Core.UserDto; 
    VerifiedByID : number; // Int32, nullable
    VerifiedBy : EVA.Core.UserDto; 
    VerificationTime : string; // DateTime, nullable
    TotalDiscountGiven : number; // Decimal
    LedgerClassID : string; 
    MaximumUsage : number; // Int32
    UsageCount : number; // Int32
    IsExclusive : boolean; 
    MaximumUsagePerOrder : number; // Int32, nullable
    Actions : EVA.Core.DiscountActionDto[]; 
    Conditions : EVA.Core.DiscountConditionDto[]; 
    Coupons : EVA.Core.DiscountCouponDto[]; 
    ConditionType : EVA.Core.DiscountConditionTypes; 
    Trigger : EVA.Core.DiscountTriggers; 
  }
  
  export class UserCardDiscountDto extends EVA.Core.DiscountDto {
    Balance : EVA.Core.UserCardBalance; 
  }
  
  export class DiscountActionDto {
    ID : number; // Int32
    DiscountID : number; // Int32
    DiscountConditionID : number; // Int32, nullable
    Type : string; 
    Data : any; 
  }
  
  export class DiscountConditionDto {
    ID : number; // Int32
    DiscountID : number; // Int32
    Type : string; 
    Data : any; 
  }
  
  export class DiscountCouponDto {
    ID : number; // Int32
    CouponCode : string; 
    DiscountID : number; // Int32
    IsActive : boolean; 
    UsageCount : number; // Int32
  }
  
  export interface IUserTaskResult {
    Name : string; 
    Description : string; 
    Type : string; 
    Value : string; 
    Data : number[]; 
  }
  
  export class UserTaskTypeDto extends EVA.Core.EnumDtoBase {
    Configuration : string; 
    ExpectedTimeToComplete : any; // TimeSpan, nullable
  }
  
  export class FinancialPeriodDto {
    ID : number; // Int32
    OpeningTime : string; // DateTime, nullable
    ClosingTime : string; // DateTime, nullable
    Status : EVA.Core.FinancialPeriodStatus; 
    OrganizationUnitID : number; // Int32
    UserID : number; // Int32, nullable
    CurrencyID : string; 
  }
  
  export class UserTaskDto {
    ID : number; // Int32
    UserID : number; // Int32, nullable
    User : EVA.Core.UserDto; 
    OrganizationUnitID : number; // Int32
    OrganizationUnit : EVA.Core.OrganizationUnitDto; 
    FinancialPeriodID : number; // Int32, nullable
    FinancialPeriod : EVA.Core.FinancialPeriodDto; 
    Type : EVA.Core.UserTaskTypeDto; 
    Priority : number; // Int32
    IsCompleted : boolean; 
    IsActive : boolean; 
    CreationTime : string; // DateTime
    Deadline : string; // DateTime, nullable
    ExpectedTimeToComplete : any; // TimeSpan, nullable
    CompletionTime : string; // DateTime, nullable
    Description : string; 
  }
  
  export class FilterModel {
    Values : any[]; 
    From : string; 
    To : string; 
    Negation : boolean; 
    ExactMatch : boolean; 
    IncludeMissing : boolean; 
  }
  
  export class AggregationFilterModel extends EVA.Core.FilterModel {
    MaxAggregationTerms : number; // Int32, nullable
    TermsAggregation : boolean; 
    StatsAggregation : boolean; 
    AggregationOptions : { [ key : string ] : EVA.Core.AggregationFilterModel }; 
  }
  
  export class SortFieldDescriptor {
    FieldName : string; 
    Direction : EVA.Core.SortDirection; 
  }
  
  export class ConfirmShipmentResultMessage {
    Code : string; 
    Message : string; 
  }
  
  export class RefundAttemptMessage {
    Code : string; 
    Message : string; 
  }
  
  export class InvoiceTotalsModel {
    Total : number; // Decimal
    SubTotal : number; // Decimal
    Taxes : EVA.Core.InvoiceTaxModel[]; 
    OpenAmount : number; // Decimal
  }
  
  export class InvoiceTaxModel {
    Rate : number; // Decimal
    Amount : number; // Decimal
  }
  
  export class LoggedInUserDto extends EVA.Core.UserDto {
    OrganizationUnitIDs : number[]; 
    CurrentOrganizationID : number; // Int32, nullable
    CurrentOrganizationName : string; 
    CurrentApplicationID : number; // Int32
    CurrentCurrencyID : string; 
    AuthenticationToken : string; 
    Functionalities : string[]; 
    SessionID : string; 
    CurrentOrganizationUnitType : EVA.Core.OrganizationUnitTypes; 
  }
  
  export class StockMutationDto {
    ID : number; // Int32
    CreationTime : string; // DateTime
    SourceOrganizationUnitID : number; // Int32
    SourceOrganizationUnit : EVA.Core.OrganizationUnitDto; 
    SourceStockLabelID : number; // Int32
    SourceStockLabel : number; // Int32
    DestinationOrganizationUnitID : number; // Int32
    DestinationOrganizationUnit : EVA.Core.OrganizationUnitDto; 
    DestinationStockLabelID : number; // Int32
    DestinationStockLabel : number; // Int32
    ReasonID : number; // Int32
    Reason : EVA.Core.StockMutationReasons; 
    ProductID : number; // Int32
    Product : EVA.Core.ProductDto; 
    OrderLine : EVA.Core.OrderLineDto; 
    ResourceID : number; // Int32, nullable
    MutationQuantity : number; // Int32
    Remark : string; 
    SourceUnitCost : number; // Decimal
    DestinationUnitCost : number; // Decimal
  }
  
  export interface IStockResourceType {
    Name : string; 
    IsUnique : boolean; 
  }
  
  export class ProductAvailabilityIndication {
    ProductID : number; // Int32
    PickupIndications : EVA.Core.PickupAvailabilityIndication[]; 
    DeliveryIndication : string; // DateTime, nullable
    StoreAvailabilityCount : number; // Int32
    StoreCount : number; // Int32
    DeliveryQuantityOnHand : number; // Int32
    AvailabilityDateIsExact : boolean; 
    ProductStatus : EVA.Core.ProductStatus; 
    ExpectedAvailabilityStatus : EVA.Core.ProductPromisedDeliveryStatuses; 
    DeliveryText : string; 
    PickupText : string; 
  }
  
  export class PickupAvailabilityIndication {
    PickupOrganizationUnit : EVA.Core.OrganizationUnitDto; 
    PickupIndicationDate : string; // DateTime
    QuantityOnHand : number; // Int32
    QuantityAvailable : number; // Int32
  }
  
  export class ProductQuantityDto {
    ProductID : number; // Int32
    QuantityRequested : number; // Int32
    ShippingMethodID : number; // Int32, nullable
  }
  
  export class PurchaseOrderShipmentDto {
    ID : number; // Int32
    OrganizationUnitID : number; // Int32
    OrganizationUnitName : string; 
    ShipmentDate : string; // DateTime
    ExpectedDeliveryDate : string; // DateTime, nullable
    BackendID : string; 
    BackendSystemID : string; 
    TrackingCode : string; 
    TrackingLink : string; 
    CreationTime : string; // DateTime
    TotalQuantityShipped : number; // Int32
    TotalQuantityDelivered : number; // Int32
  }
  
  export class PurchaseOrderShipmentLineDto {
    ID : number; // Int32
    ProductID : number; // Int32
    Description : string; 
    QuantityShipped : number; // Int32
    QuantityDelivered : number; // Int32
    IsCompleted : boolean; 
    CurrencyID : string; 
    UnitPrice : number; // Decimal
    ExchangeRate : number; // Decimal
    ForeignUnitPrice : number; // Decimal
    ForeignTotalAmount : number; // Decimal
    ShipmentDate : string; // DateTime
  }
  
  export class RecurringTask {
    Cron : string; 
    ID : string; 
    LastExecution : string; // DateTime, nullable
    NextExecution : string; // DateTime, nullable
    IsDeleted : boolean; 
    Type : any; 
    TypeName : string; 
    Args : any[]; 
  }
  
  export class ReceiveShipmentResult {
    ValidationResult : EVA.Core.ValidationResult; 
    ReservedOrdersCount : number; // Int32
  }
  
  export class ValidationResult {
    Success : boolean; 
    Code : string; 
    Message : string; 
  }
  
  export class SuggestionModel {
    Score : number; // Double
    Text : string; 
    Highlighted : string; 
    Payload : any; 
  }
  
  export class ProductAvailabilityDataDto {
    ID : number; // Int32
    PromisedDeliveryStatusID : number; // Int32, nullable
    PromisedDeliveryStatus : EVA.Core.ProductPromisedDeliveryStatuses; 
    MinDeviationDays : number; // Int32
    MaxDeviationDays : number; // Int32
    DeliveryText : string; 
    PickupNoStoresText : string; 
    PickupSomeStoresText : string; 
    PickupAllStoresText : string; 
    ProductID : number; // Int32, nullable
    Product : EVA.Core.ProductDto; 
    ValidThrough : string; // DateTime, nullable
  }
  
  export class BrandNameInfo {
    Name : string; 
    ProductCount : number; // Int32
  }
  
  export class OpeningClosingHourPair {
    StartTime : any; // TimeSpan, nullable
    EndTime : any; // TimeSpan, nullable
    SpecialReason : string; 
    DayOfWeek : System.Private.CoreLib.DayOfWeek; 
  }
  
  export class OrderLineWithQuantity {
    OrderLineID : number; // Int32
    Quantity : number; // Int32
  }
  
  export class OrderStatistics {
    GrossMargin : number; // Decimal
    OrderLines : { [ key : number ] : EVA.Core.OrderStatisticsOrderLineStatistics }; 
  }
  
  export class OrderStatisticsOrderLineStatistics {
    UnitPrice : number; // Decimal
    UnitCost : number; // Decimal
    DiscountAmount : number; // Decimal
    KickbackAmount : number; // Decimal
  }
  
  export class RequiredData {
    Order : EVA.Core.Requirement[]; 
    OrderLines : { [ key : number ] : EVA.Core.Requirement[] }; 
    Customer : EVA.Core.Requirement[]; 
  }
  
  export class Requirement {
    Name : string; 
    IsValid : boolean; 
    Message : string; 
    Type : string; 
    ValidationRule : string; 
    DataType : string; 
    RequiredFor : EVA.Core.RequiredFor; 
  }
  
  export class ShippingMethodDto {
    ID : number; // Int32
    CarrierID : number; // Int32
    Carrier : EVA.Core.CarrierDto; 
    Name : string; 
    Description : string; 
    Code : string; 
    ExtraCosts : number; // Decimal, nullable
  }
  
  export class ShippingMethodByOrderLineDto extends EVA.Core.ShippingMethodDto {
    AppliesToOrderLineIDs : number[]; 
    RequestedDeliveryDates : EVA.Core.RequestedDateByOrderLineID[]; 
  }
  
  export class CarrierDto {
    ID : number; // Int32
    Name : string; 
    Code : string; 
  }
  
  export class RequestedDateByOrderLineID {
    OrderLineID : number; // Int32
    RequestedDate : string; // DateTime, nullable
  }
  
  export class OrderWithReference {
    ID : number; // Int32
    CustomerReference : string; 
    CreationTime : string; // DateTime
  }
  
  export class OrderExportValidationResult {
    Result : EVA.Core.OrderExportValidationResults; 
    Messages : EVA.Core.OrderExportValidationResultMessage[]; 
  }
  
  export class OrderExportValidationResultMessage {
    Code : string; 
    Message : string; 
  }
  
  export class OrderSearchResultItem {
    Customer : EVA.Core.OrderSearchResultItemCustomer; 
    OrganizationUnits : EVA.Core.OrderSearchResultItemOrganizationUnit[]; 
    SoldFromOrganizationUnit : EVA.Core.OrderSearchResultItemOrganizationUnit; 
    SoldToOrganizationUnit : EVA.Core.OrderSearchResultItemOrganizationUnit; 
    ShipFromOrganizationUnit : EVA.Core.OrderSearchResultItemOrganizationUnit; 
    OriginatingOrganizationUnit : EVA.Core.OrderSearchResultItemOrganizationUnit; 
    PickupOrganizationUnitID : EVA.Core.OrderSearchResultItemOrganizationUnit; 
    IsCompleted : boolean; 
    IsPaid : boolean; 
    IsShipped : boolean; 
    IsReserved : boolean; 
    IsInvoiced : boolean; 
    OpenAmountInTax : number; // Decimal
    ForeignOpenAmountInTax : number; // Decimal
    ID : number; // Int32
    BackendID : string; 
    PaidAmount : number; // Decimal
    ForeignPaidAmount : number; // Decimal
    TotalAmountInTax : number; // Decimal
    ForeignTotalAmountInTax : number; // Decimal
    LastModificationTime : string; // DateTime
    CreationTime : string; // DateTime
    CurrencyID : string; 
    Type : EVA.Core.OrderTypes; 
    CustomerReference : string; 
    HasReturns : boolean; 
    TotalQuantityToShip : number; // Int32
    TotalQuantityShipped : number; // Int32
    Properties : EVA.Core.OrderCharacteristics; 
    PropertiesIDs : number[]; 
    CustomStatus : number; // Int32
    CustomStatusIDs : number[]; 
  }
  
  export class OrderSearchResultItemCustomer {
    ID : number; // Int32
    FullName : string; 
  }
  
  export class OrderSearchResultItemOrganizationUnit {
    ID : number; // Int32
    Name : string; 
  }
  
  export class RequiredDataValidationResult {
    Requirements : EVA.Core.RequiredData; 
    ValidationErrors : EVA.Core.ValidationError[]; 
  }
  
  export class ValidationError {
    Field : string; 
    Message : string; 
    Context : string; 
  }
  
  export class PaperProperties {
    Format : EVA.Core.PaperFormats; 
    Orientation : EVA.Core.PaperOrientations; 
  }
  
  export class MessageQueueErrorDto {
    ID : number; // Int32
    MessageID : string; 
    MessageBody : string; 
    MessageTypeName : string; 
    ExceptionMessage : string; 
    StackTrace : string; 
    ErrorCode : string; 
    HostInfo : string; 
    Headers : string; 
    Addresses : string; 
    StatusID : number; // Int32
    Status : EVA.Core.MessageQueueErrorStatuses; 
    CreationTime : string; // DateTime
  }
  
  export class ProductLedgerDto {
    ID : number; // Int32
    Type : EVA.Core.ProductLedgerTypes; 
    StockMutationReason : EVA.Core.StockMutationReasons; 
    ProductID : number; // Int32
    Product : EVA.Core.ProductDto; 
    OrganizationUnitID : number; // Int32
    OrganizationUnit : EVA.Core.OrganizationUnitDto; 
    Quantity : number; // Int32
    QuantityCommitted : number; // Int32
    Remark : string; 
    StockLabel : number; // Int32
    IsSummary : boolean; 
    StockMutationID : number; // Int32, nullable
    OrderLineID : number; // Int32, nullable
    OrderLine : EVA.Core.OrderLineDto; 
    ResourceID : number; // Int32, nullable
    CreatedByID : number; // Int32
    CreationTime : string; // DateTime
    CreatedBy : EVA.Core.UserDto; 
    UnitCost : number; // Decimal
  }
  
  export class ListInvoicesDto {
    ID : number; // Int32
    InvoiceDate : string; // DateTime, nullable
    InvoiceNumber : string; 
    OrganizationUnitID : string; 
    OrganizationUnitName : string; 
    SupplierOrganizationUnitID : number; // Int32, nullable
    SupplierOrganizationUnitName : string; 
    Description : string; 
    TotalAmount : number; // Decimal, nullable
    Status : EVA.Core.InvoiceStatuses; 
  }
  
  export class DeviceDto {
    ID : number; // Int32
    Name : string; 
    Type : EVA.Core.DeviceTypeDto; 
    TypeID : number; // Int32
    NetworkName : string; 
    IpAddress : string; 
    Station : EVA.Core.StationDto; 
    StationID : number; // Int32, nullable
    AssemblyName : string; 
    EcrID : string; 
    HardwareID : string; 
    UserID : number; // Int32, nullable
    User : EVA.Core.UserDto; 
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnit : EVA.Core.OrganizationUnitDto; 
    IsActive : boolean; 
  }
  
  export class DeviceTypeDto extends EVA.Core.EnumDtoBase {
  }
  
  export class StationDto {
    ID : number; // Int32
    Name : string; 
    OrganizationUnitID : number; // Int32
    OrganizationUnit : EVA.Core.OrganizationUnitDto; 
    OrganizationUnitDescription : string; 
    Devices : EVA.Core.DeviceDto[]; 
    HasPrinterDevice : boolean; 
    HasPinDevice : boolean; 
    HasThermalPrinterDevice : boolean; 
    HasCashDrawerDevice : boolean; 
  }
  
  export class AccountSummary {
    AccountID : number; // Int32
    Name : string; 
    Amount : number; // Decimal
    ObjectAccount : string; 
    Subsidiary : string; 
  }
  
  export class FinancialPeriodDetailsDto {
    PreviousPeriodID : number; // Int32, nullable
    OpeningTime : string; // DateTime
    ClosingTime : string; // DateTime, nullable
    Status : EVA.Core.FinancialPeriodStatus; 
    CurrencyID : string; 
    CashDeposit : EVA.Core.CashDepositDto; 
    CashJournals : EVA.Core.CashJournalDto[]; 
    LedgerBookings : EVA.Core.GeneralLedgerDto[]; 
    Expenses : EVA.Core.ExpenseDto[]; 
    Corrections : EVA.Core.GeneralLedgerDto[]; 
    LastModifiedByFullName : string; 
    CreatedByFullName : string; 
    ApprovedByFullName : string; 
    LastModifiedByID : number; // Int32
    CreatedByID : number; // Int32
    PaymentTotalPerTypes : EVA.Core.PaymentTotalPerPaymentTypeDto[]; 
    Stations : EVA.Core.StationClosing[]; 
    AmountOfRoundingDifference : number; // Decimal
    AmountOfOpeningDifference : number; // Decimal
    AmountOfCashDifference : number; // Decimal
    CashDepositTotal : number; // Decimal
    TotalAmountOfExpenses : number; // Decimal
    TotalAmountOfCorrections : number; // Decimal
    DiscountStatistics : EVA.Core.DiscountStatisticsDto[]; 
  }
  
  export class CashDepositDto {
    Number : string; 
    Description : string; 
    Total : number; // Decimal
    Lines : EVA.Core.CashDepositLineDto[]; 
  }
  
  export class CashDepositLineDto {
    Currency : number; // Decimal
    Quantity : number; // Int32
  }
  
  export class CashJournalDto {
    OpeningAmount : number; // Decimal
    ClosingAmount : number; // Decimal, nullable
    ApprovedByID : number; // Int32, nullable
    ApprovedByFullName : string; 
    CreatedByID : number; // Int32
    CreatedByFullName : string; 
    StationID : number; // Int32, nullable
    StationName : string; 
    TypeID : number; // Int32
    Type : EVA.Core.CashJournalTypes; 
  }
  
  export class GeneralLedgerDto {
    ID : number; // Int32
    OrganizationUnitID : number; // Int32
    OrganizationUnit : EVA.Core.OrganizationUnitDto; 
    Amount : number; // Decimal
    Remark : string; 
    PaymentTransactionID : number; // Int32, nullable
    PaymentTransaction : EVA.Core.PaymentTransactionDto; 
    CreationTime : string; // DateTime
    OrderID : number; // Int32, nullable
    AccountName : string; 
    AccountObjectAccount : string; 
    AccountingID : number; // Int32
    StockMutationID : number; // Int32, nullable
    StockMutation : EVA.Core.StockMutationDto; 
  }
  
  export class ExpenseDto {
    ID : number; // Int32
    TypeID : number; // Int32
    TypeDescription : string; 
    TaxRate : number; // Decimal
    Amount : number; // Decimal
    Description : string; 
    CreationTime : string; // DateTime
  }
  
  export class PaymentTotalPerPaymentTypeDto {
    Total : number; // Decimal
    TypeName : string; 
  }
  
  export class StationClosing {
    InitialAmount : number; // Decimal
    Name : string; 
    Type : EVA.Core.CashJournalTypes; 
    TypeName : string; 
    StationID : number; // Int32, nullable
    ClosingAmount : number; // Decimal
    Currencies : EVA.Core.StationCashResult[]; 
  }
  
  export class StationCashResult {
    Currency : number; // Decimal
    Quantity : number; // Int32
  }
  
  export class DiscountStatisticsDto {
    User : EVA.Core.UserDto; 
    Statistics : EVA.Core.DiscountStatisticDto[]; 
  }
  
  export class DiscountStatisticDto {
    Discount : EVA.Core.DiscountDto; 
    Amount : number; // Decimal
  }
  
  export class PeriodClosingWorkSet {
    FinancialPeriodID : number; // Int32
    OrganizationUnitID : number; // Int32
    AvailableExpenseTypes : EVA.Core.ExpenseTypeDto[]; 
    UserID : number; // Int32
    OrganizationUnit : EVA.Core.PeriodClosingOrganizationUnitDto; 
    CashJournalPaymentsTotal : number; // Decimal
    RoundingDifference : number; // Decimal
    OpeningsDifference : number; // Decimal
    DiscountStatistics : EVA.Core.DiscountStatisticsDto[]; 
    OpenOrders : EVA.Core.OrderDto[]; 
    CurrencyID : string; 
    Coins : number[]; 
    BankNotes : number[]; 
    CashDeposits : EVA.Core.CashDepositDto[]; 
    Expenses : EVA.Core.PeriodClosingExpense[]; 
    Corrections : EVA.Core.CashDifferenceCorrection[]; 
    Stations : EVA.Core.StationClosing[]; 
    Payments : EVA.Core.PaymentTypeResult[]; 
    NumberOfOpenTasks : number; // Int32
    OpenTasks : EVA.Core.UserTaskDto[]; 
  }
  
  export class ExpenseTypeDto {
    ID : number; // Int32
    Description : string; 
  }
  
  export class PeriodClosingOrganizationUnitDto {
    Name : string; 
    RegisterCashLimit : number; // Decimal
    SafeCashLimit : number; // Decimal
  }
  
  export class PeriodClosingExpense {
    TypeID : number; // Int32
    TaxCodeID : number; // Int32, nullable
    AmountInTax : number; // Decimal
    Description : string; 
  }
  
  export class CashDifferenceCorrection {
    Remark : string; 
    Amount : number; // Decimal
  }
  
  export class PaymentTypeResult {
    Name : string; 
    TotalAmount : number; // Decimal
  }
  
  export class PeriodOpeningWorkSet {
    OrganizationUnitID : number; // Int32
    PreviousAmount : number; // Decimal, nullable
    Stations : EVA.Core.StationToCount[]; 
    CurrencyID : string; 
    Coins : number[]; 
    BankNotes : number[]; 
  }
  
  export class StationToCount {
    StationID : number; // Int32, nullable
    StationName : string; 
    Type : EVA.Core.CashJournalTypes; 
    InitialAmount : number; // Decimal
  }
  
  export class CurrencyWithExchangeRate {
    ID : string; 
    Name : string; 
    ExchangeRate : number; // Decimal, nullable
  }
  
  export interface ILoginRequest {
    Username : string; 
    OrganizationUnitID : number; // Int32, nullable
    ApplicationID : number; // Int32
  }
  
  export class AddressSuggestion {
    ID : string; 
    Reference : string; 
    Description : string; 
  }
  
  export class AddressSuggestionDetails {
    Formatted : string; 
    Components : EVA.Core.AddressSuggestionDetailsComponent[]; 
    Geometry : EVA.Core.AddressSuggestionDetailsGeometryDetails; 
    UtcOffset : number; // Double
    HouseNumber : EVA.Core.AddressSuggestionDetailsComponent; 
    Street : EVA.Core.AddressSuggestionDetailsComponent; 
    City : EVA.Core.AddressSuggestionDetailsComponent; 
    Region : EVA.Core.AddressSuggestionDetailsComponent; 
    Country : EVA.Core.AddressSuggestionDetailsComponent; 
    PostalCode : EVA.Core.AddressSuggestionDetailsComponent; 
  }
  
  export class AddressSuggestionDetailsComponent {
    LongName : string; 
    ShortName : string; 
    Types : string[]; 
  }
  
  export class AddressSuggestionDetailsGeometryDetails {
    Location : EVA.Core.GeometryLocation; 
  }
  
  export class GeometryLocation {
    Latitude : number; // Double
    Longitude : number; // Double
  }
  
}
/* tslint:disable */
declare module EVA.DMS {
  
  export class DmsCreateWidgetType extends EVA.Core.CreateRequest<EVA.DMS.WidgetTypeDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }
  
  export class WidgetTypeDto {
    ID : number; // Int32
    Name : string; 
    Description : string; 
    Template : string; 
    StyleSheet : string; 
    Columns : number; // Int32
    MaxEntries : number; // Int32
    ContentTypeID : number; // Int32
    ContentType : EVA.DMS.ContentTypeDto; 
  }
  
  export class ContentTypeDto {
    ID : number; // Int32
    Name : string; 
    Description : string; 
    Fields : EVA.DMS.ContentTypeFieldDto[]; 
  }
  
  export class ContentTypeFieldDto {
    ID : number; // Int32
    Name : string; 
    DataType : EVA.DMS.ContentDataType; 
    ContentTypeID : number; // Int32
  }
  
  export enum ContentDataType {
    Text = 0,
    Number = 1,
    Boolean = 2,
    Datetime = 3,
    Image = 4,
    Product = 5,
    ProductGroup = 6,
  }
  
  export class DmsGetWidgetTypePreview extends EVA.Core.RequestMessageGeneric<EVA.DMS.DmsGetWidgetTypePreviewResponse> {
    Model : EVA.DMS.WidgetTypeDto; 
    __response : EVA.DMS.DmsGetWidgetTypePreviewResponse;
  }
  
  export class DmsGetWidgetTypePreviewResponse extends EVA.Core.GetResponse<string> {
    Success : boolean; 
    Message : string; 
  }
  
  export class DmsGetWidgetType extends EVA.Core.GetRequestGeneric<EVA.DMS.DmsGetWidgetTypeResponse> {
    __response : EVA.DMS.DmsGetWidgetTypeResponse;
  }
  
  export class DmsGetWidgetTypeResponse extends EVA.Core.GetResponse<EVA.DMS.WidgetTypeDto> {
  }
  
  export class DmsListWidgetTypes extends EVA.Core.PagedResultRequest<EVA.DMS.DmsListWidgetTypesResponse> {
    __response : EVA.DMS.DmsListWidgetTypesResponse;
  }
  
  export class DmsListWidgetTypesResponse extends EVA.Core.PagedResultResponse<EVA.DMS.WidgetTypeDto> {
  }
  
  export class DmsUpdateWidgetType extends EVA.Core.UpdateRequest<EVA.DMS.WidgetTypeDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsCreateWidget extends EVA.Core.CreateRequest<EVA.DMS.WidgetDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    ViewID : number; // Int32
    __response : EVA.Core.CreateResponse;
  }
  
  export class WidgetDto {
    ID : number; // Int32
    Name : string; 
    IsActive : boolean; 
    SizeX : number; // Int32
    SizeY : number; // Int32
    Row : number; // Int32
    Col : number; // Int32
    Selector : EVA.DMS.SelectorGroupDto; 
    Data : string; 
    WidgetTypeID : number; // Int32, nullable
    WidgetType : EVA.DMS.WidgetTypeDto; 
    ViewID : number; // Int32
    View : EVA.DMS.ViewDto; 
    TypeID : number; // Int32
    Type : EVA.DMS.DefaultWidgetTypes; 
  }
  
  export class SelectorGroupDto {
    operator : string; 
    rules : EVA.DMS.SelectorRuleDto[]; 
  }
  
  export class SelectorRuleDto {
    condition : string; 
    field : number; // Int32
    data : string; 
    group : EVA.DMS.SelectorGroupDto; 
  }
  
  export class ViewDto {
    ID : number; // Int32
    Name : string; 
    Background : string; 
    StartDate : string; // DateTime, nullable
    EndDate : string; // DateTime, nullable
    PageID : number; // Int32
    IsActive : boolean; 
    Widgets : EVA.DMS.WidgetDto[]; 
  }
  
  export enum DefaultWidgetTypes {
    Custom = 0,
    Html = 1,
    Image = 2,
    ProductList = 3,
  }
  
  export class DmsDeleteWidget extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsGetWidgetByID extends EVA.Core.GetRequestGeneric<EVA.DMS.DmsGetWidgetByIDResponse> {
    __response : EVA.DMS.DmsGetWidgetByIDResponse;
  }
  
  export class DmsGetWidgetByIDResponse extends EVA.Core.GetResponse<EVA.DMS.WidgetDto> {
  }
  
  export class DmsGetWidgetPreview extends EVA.Core.RequestMessageGeneric<EVA.DMS.DmsGetWidgetPreviewResponse> {
    Group : EVA.DMS.SelectorGroupDto; 
    WidgetTypeID : number; // Int32
    __response : EVA.DMS.DmsGetWidgetPreviewResponse;
  }
  
  export class DmsGetWidgetPreviewResponse extends EVA.Core.GetResponse<string> {
    Success : boolean; 
    Message : string; 
  }
  
  export class DmsUpdateWidget extends EVA.Core.UpdateRequest<EVA.DMS.WidgetDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsCreateView extends EVA.Core.CreateRequest<EVA.DMS.ViewDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    ObjectType : string; 
    ObjectID : number; // Int32
    __response : EVA.Core.CreateResponse;
  }
  
  export class DmsGetViewByID extends EVA.Core.GetRequestGeneric<EVA.DMS.DmsGetViewByIDResponse> {
    __response : EVA.DMS.DmsGetViewByIDResponse;
  }
  
  export class DmsGetViewByIDResponse extends EVA.Core.GetResponse<EVA.DMS.ViewDto> {
  }
  
  export class DmsGetViewLayout extends EVA.Core.RequestMessage implements EVA.Core.IRequestRespondsAs<EVA.DMS.DmsGetViewLayoutResponse> {
    ID : number; // Int32
    __response : EVA.DMS.DmsGetViewLayoutResponse;
  }
  
  export class DmsGetViewLayoutResponse extends EVA.Core.ResponseMessage {
    Blocks : EVA.DMS.WidgetLayoutBlockDto[]; 
  }
  
  export class WidgetLayoutBlockDto {
    widgetID : number; // Int32
    typeID : number; // Int32
    name : string; 
    sizeX : number; // Int32
    sizeY : number; // Int32
    row : number; // Int32
    col : number; // Int32
  }
  
  export class DmsUpdateViewLayout extends EVA.Core.RequestMessageWithEmptyResponse {
    Blocks : EVA.DMS.WidgetLayoutBlockDto[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsUpdateView extends EVA.Core.UpdateRequest<EVA.DMS.ViewDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsCreateProductPage extends EVA.Core.CreateRequest<EVA.DMS.ProductPageDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }
  
  export class ProductPageDto {
    ID : number; // Int32
    Title : string; 
    BrowserTitle : string; 
    TitleOverride : boolean; 
    MetaDescription : string; 
    ProductID : number; // Int32
    Product : EVA.Core.ProductDto; 
    IsActive : boolean; 
    Views : EVA.DMS.ViewDto[]; 
    ObjectType : string; 
  }
  
  export class DmsDeleteProductPage extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsGetProductPageByID extends EVA.Core.GetRequestGeneric<EVA.DMS.DmsGetProductPageByIDResponse> {
    __response : EVA.DMS.DmsGetProductPageByIDResponse;
  }
  
  export class DmsGetProductPageByIDResponse extends EVA.Core.GetResponse<EVA.DMS.ProductPageDto> {
  }
  
  export class DmsListProductPages extends EVA.Core.PagedResultRequest<EVA.DMS.DmsListProductPagesResponse> {
    __response : EVA.DMS.DmsListProductPagesResponse;
  }
  
  export class DmsListProductPagesResponse extends EVA.Core.PagedResultResponse<EVA.DMS.ProductPageDto> {
  }
  
  export class DmsUpdateProductPage extends EVA.Core.UpdateRequest<EVA.DMS.ProductPageDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsCreatePage extends EVA.Core.CreateRequest<EVA.DMS.PageDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }
  
  export class PageDto {
    ID : number; // Int32
    Title : string; 
    BrowserTitle : string; 
    TitleOverride : boolean; 
    MetaDescription : string; 
    Slug : string; 
    RequestPath : string; 
    ParentID : number; // Int32, nullable
    Parent : EVA.DMS.PageDto; 
    Depth : number; // Int32
    Lineage : string; 
    Position : number; // Int32
    ShowInMenu : boolean; 
    IsActive : boolean; 
    Views : EVA.DMS.ViewDto[]; 
    Children : EVA.DMS.PageDto[]; 
    ObjectType : string; 
  }
  
  export class DmsDeletePage extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsGetPageByID extends EVA.Core.GetRequestGeneric<EVA.DMS.DmsGetPageByIDResponse> {
    __response : EVA.DMS.DmsGetPageByIDResponse;
  }
  
  export class DmsGetPageByIDResponse extends EVA.Core.GetResponse<EVA.DMS.PageDto> {
  }
  
  export class DmsGetSiteMap extends EVA.Core.RequestMessageGeneric<EVA.DMS.DmsGetSiteMapResponse> {
    __response : EVA.DMS.DmsGetSiteMapResponse;
  }
  
  export class DmsGetSiteMapResponse extends EVA.Core.GetResponse<EVA.DMS.SiteMapNode[]> {
  }
  
  export class SiteMapNode {
    PageID : number; // Int32
    Title : string; 
    IsActive : boolean; 
    RequestPath : string; 
    Children : EVA.DMS.SiteMapNode[]; 
  }
  
  export class DmsMovePage extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    ParentID : number; // Int32
    Position : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsUpdatePage extends EVA.Core.UpdateRequest<EVA.DMS.PageDto> implements EVA.Core.IRequestRespondsAs<EVA.DMS.DmsUpdatePageResponse> {
    __response : EVA.DMS.DmsUpdatePageResponse;
  }
  
  export class DmsUpdatePageResponse extends EVA.Core.GetResponse<EVA.DMS.PageDto> {
  }
  
  export class DmsCreateBlock extends EVA.Core.CreateRequest<EVA.DMS.BlockDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }
  
  export class BlockDto {
    ID : number; // Int32
    Identifier : string; 
    IsActive : boolean; 
    Views : EVA.DMS.ViewDto[]; 
    ObjectType : string; 
  }
  
  export class DmsDeleteBlock extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsGetBlockByID extends EVA.Core.GetRequestGeneric<EVA.DMS.DmsGetBlockByIDResponse> {
    __response : EVA.DMS.DmsGetBlockByIDResponse;
  }
  
  export class DmsGetBlockByIDResponse extends EVA.Core.GetResponse<EVA.DMS.BlockDto> {
  }
  
  export class DmsListBlocks extends EVA.Core.PagedResultRequest<EVA.DMS.DmsListBlocksResponse> {
    __response : EVA.DMS.DmsListBlocksResponse;
  }
  
  export class DmsListBlocksResponse extends EVA.Core.PagedResultResponse<EVA.DMS.BlockDto> {
  }
  
  export class DmsUpdateBlock extends EVA.Core.UpdateRequest<EVA.DMS.BlockDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsCreateUrlRewrite extends EVA.Core.CreateRequest<EVA.DMS.UrlRewriteDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }
  
  export class UrlRewriteDto {
    ID : number; // Int32
    RequestPath : string; 
    TargetPath : string; 
    UrlRewriteType : EVA.DMS.UrlRewriteTypes; 
    Description : string; 
    IsActive : boolean; 
    IsRegex : boolean; 
  }
  
  export enum UrlRewriteTypes {
    MovedPermanently = 301,
    MovedTemporarily = 302,
    TemporaryRedirect = 307,
    PermanentRedirect = 308,
    Gone = 410,
    Silent = 999,
  }
  
  export class DmsDeleteUrlRewrite extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsGetUrlRewriteByID extends EVA.Core.GetRequestGeneric<EVA.DMS.DmsGetUrlRewriteByIDResponse> {
    __response : EVA.DMS.DmsGetUrlRewriteByIDResponse;
  }
  
  export class DmsGetUrlRewriteByIDResponse extends EVA.Core.GetResponse<EVA.DMS.UrlRewriteDto> {
  }
  
  export class DmsListUrlRewrites extends EVA.Core.PagedResultRequest<EVA.DMS.DmsListUrlRewritesResponse> {
    __response : EVA.DMS.DmsListUrlRewritesResponse;
  }
  
  export class DmsListUrlRewritesResponse extends EVA.Core.PagedResultResponse<EVA.DMS.UrlRewriteDto> {
  }
  
  export class DmsUpdateUrlRewrite extends EVA.Core.UpdateRequest<EVA.DMS.UrlRewriteDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsGetPageByViewID extends EVA.Core.RequestMessageGeneric<EVA.DMS.DmsGetPageByViewIDResponse> {
    ID : number; // Int32
    __response : EVA.DMS.DmsGetPageByViewIDResponse;
  }
  
  export class DmsGetPageByViewIDResponse extends EVA.Core.GetResponse<EVA.DMS.LivePageDto> {
  }
  
  export class LivePageDto {
    ID : number; // Int32
    Title : string; 
    BrowserTitle : string; 
    TitleOverride : boolean; 
    MetaDescription : string; 
    Slug : string; 
    RequestPath : string; 
    ActiveVersionID : number; // Int32
    Data : string; 
  }
  
  export class DmsListViewsForPage extends EVA.Core.RequestMessageGeneric<EVA.DMS.DmsListViewsForPageResponse> {
    ID : number; // Int32
    __response : EVA.DMS.DmsListViewsForPageResponse;
  }
  
  export class DmsListViewsForPageResponse extends EVA.Core.GetResponse<EVA.DMS.ViewDto[]> {
  }
  
  export class DmsGetCompiledWidgetByID extends EVA.Core.GetRequestGeneric<EVA.DMS.DmsGetCompiledWidgetByIDResponse> {
    __response : EVA.DMS.DmsGetCompiledWidgetByIDResponse;
  }
  
  export class DmsGetCompiledWidgetByIDResponse extends EVA.Core.GetResponse<EVA.DMS.LiveWidgetDto> {
  }
  
  export class LiveWidgetDto {
    ID : number; // Int32
    Html : string; 
    Css : string; 
    Js : string; 
    Data : string; 
  }
  
  export class DmsGetLiveBlock extends EVA.Core.RequestMessageGeneric<EVA.DMS.DmsGetLiveBlockResponse> {
    Identifier : string; 
    __response : EVA.DMS.DmsGetLiveBlockResponse;
  }
  
  export class DmsGetLiveBlockResponse extends EVA.Core.GetResponse<EVA.DMS.LiveBlockDto> {
  }
  
  export class LiveBlockDto {
    ID : number; // Int32
    ActiveVersionID : number; // Int32
    Data : string; 
  }
  
  export class DmsGetLivePage extends EVA.Core.RequestMessageGeneric<EVA.DMS.DmsGetLivePageResponse> {
    ID : number; // Int32, nullable
    Path : string; 
    __response : EVA.DMS.DmsGetLivePageResponse;
  }
  
  export class DmsGetLivePageResponse extends EVA.Core.GetResponse<EVA.DMS.LivePageDto> {
  }
  
  export class DmsGetLiveProductPage extends EVA.Core.RequestMessageGeneric<EVA.DMS.DmsGetLiveProductPageResponse> {
    ProductID : number; // Int32
    __response : EVA.DMS.DmsGetLiveProductPageResponse;
  }
  
  export class DmsGetLiveProductPageResponse extends EVA.Core.GetResponse<EVA.DMS.LivePageDto> {
  }
  
  export class DmsGetMenuByIdentifier extends EVA.Core.RequestMessageGeneric<EVA.DMS.DmsGetMenuByIdentifierResponse> {
    Path : string; 
    Depth : number; // Int32, nullable
    __response : EVA.DMS.DmsGetMenuByIdentifierResponse;
  }
  
  export class DmsGetMenuByIdentifierResponse extends EVA.Core.GetResponse<EVA.DMS.MenuDto> {
  }
  
  export class MenuDto {
    ID : number; // Int32
    Children : EVA.DMS.MenuItem[]; 
  }
  
  export class MenuItem {
    ID : number; // Int32
    Title : string; 
    Position : number; // Int32
    Url : string; 
    Children : EVA.DMS.MenuItem[]; 
  }
  
  export class DmsRewriteUrl extends EVA.Core.RequestMessageGeneric<EVA.DMS.DmsRewriteUrlResponse> {
    Url : string; 
    __response : EVA.DMS.DmsRewriteUrlResponse;
  }
  
  export class DmsRewriteUrlResponse extends EVA.Core.ResponseMessage {
    Url : string; 
  }
  
  export class DmsCreateContentEntry extends EVA.Core.CreateRequest<EVA.DMS.ContentEntryDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }
  
  export class ContentEntryDto {
    ID : number; // Int32
    Name : string; 
    ContentTypeID : number; // Int32
    ContentType : EVA.DMS.ContentTypeDto; 
    Fields : EVA.DMS.ContentEntryFieldDto[]; 
  }
  
  export class ContentEntryFieldDto {
    ID : number; // Int32
    Name : string; 
    Value : string; 
    ContentEntryID : number; // Int32
    ContentEntry : EVA.DMS.ContentEntryDto; 
    ContentTypeField : EVA.DMS.ContentTypeFieldDto; 
    ContentTypeFieldID : number; // Int32
  }
  
  export class DmsCreateContentType extends EVA.Core.CreateRequest<EVA.DMS.ContentTypeDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.CreateResponse> {
    __response : EVA.Core.CreateResponse;
  }
  
  export class DmsDeleteContentEntry extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsDeleteContentType extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsGetCompiledPage extends EVA.Core.RequestMessageGeneric<EVA.DMS.DmsGetCompiledPageResponse> {
    ID : number; // Int32, nullable
    Path : string; 
    __response : EVA.DMS.DmsGetCompiledPageResponse;
  }
  
  export class DmsGetCompiledPageResponse extends EVA.Core.ResponseMessage {
    Result : EVA.DMS.CompiledPageDto; 
  }
  
  export class CompiledPageDto {
    ID : number; // Int32
    Title : string; 
    BrowserTitle : string; 
    TitleOverride : boolean; 
    MetaDescription : string; 
    Slug : string; 
    RequestPath : string; 
    Widgets : EVA.DMS.CompiledPageWidgetDto[]; 
  }
  
  export class CompiledPageWidgetDto {
    ID : number; // Int32
    TypeID : number; // Int32
    Name : string; 
    SizeX : number; // Int32
    SizeY : number; // Int32
    Row : number; // Int32
    Column : number; // Int32
    Data : EVA.DMS.CompiledPageWidgetDataDto; 
  }
  
  export class CompiledPageWidgetDataDto {
    Html : string; 
    Js : string; 
    Css : string; 
    Data : string; 
  }
  
  export class DmsGetContentEntry extends EVA.Core.GetRequestGeneric<EVA.DMS.DmsGetContentEntryResponse> {
    __response : EVA.DMS.DmsGetContentEntryResponse;
  }
  
  export class DmsGetContentEntryResponse extends EVA.Core.GetResponse<EVA.DMS.ContentEntryDto> {
  }
  
  export class DmsGetContentType extends EVA.Core.GetRequestGeneric<EVA.DMS.DmsGetContentTypeResponse> {
    __response : EVA.DMS.DmsGetContentTypeResponse;
  }
  
  export class DmsGetContentTypeResponse extends EVA.Core.GetResponse<EVA.DMS.ContentTypeDto> {
  }
  
  export class DmsListContentEntries extends EVA.Core.PagedResultRequest<EVA.DMS.DmsListContentEntriesResponse> {
    __response : EVA.DMS.DmsListContentEntriesResponse;
  }
  
  export class DmsListContentEntriesResponse extends EVA.Core.PagedResultResponse<EVA.DMS.ContentEntryDto> {
  }
  
  export class DmsListContentTypes extends EVA.Core.PagedResultRequest<EVA.DMS.DmsListContentTypesResponse> {
    __response : EVA.DMS.DmsListContentTypesResponse;
  }
  
  export class DmsListContentTypesResponse extends EVA.Core.PagedResultResponse<EVA.DMS.ContentTypeDto> {
  }
  
  export class DmsUpdateContentEntry extends EVA.Core.UpdateRequest<EVA.DMS.ContentEntryDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DmsUpdateContentType extends EVA.Core.UpdateRequest<EVA.DMS.ContentTypeDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
}
/* tslint:disable */
declare module EVA.Devices.StatusChecker {
  
  export class ImAlive extends EVA.Core.RequestMessageWithEmptyResponse {
    MacAddress : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListOrganizationUnitsWithDeviceStatus extends EVA.Core.RequestMessageGeneric<EVA.Devices.StatusChecker.ListOrganizationUnitsWithDeviceStatusResponse> {
    __response : EVA.Devices.StatusChecker.ListOrganizationUnitsWithDeviceStatusResponse;
  }
  
  export class ListOrganizationUnitsWithDeviceStatusResponse extends EVA.Core.ResponseMessage {
    OrganizationUnits : EVA.Devices.StatusChecker.OrganizationUnitDeviceStatus[]; 
  }
  
  export class OrganizationUnitDeviceStatus {
    ApplicationID : number; // Int32
    ID : number; // Int32
    Type : EVA.Core.OrganizationUnitTypes; 
    Name : string; 
    Latitude : number; // Double, nullable
    Longitude : number; // Double, nullable
    Status : number; // Int32
    Devices : EVA.Devices.StatusChecker.DeviceStatusSummary[]; 
  }
  
  export class DeviceStatusSummary {
    ID : number; // Int32
    Name : string; 
    Type : string; 
    Status : number; // Int32
    ModificationTime : string; // DateTime, nullable
  }
  
  export class ListOrganizationUnitWithDeviceDetails extends EVA.Core.RequestMessageGeneric<EVA.Devices.StatusChecker.ListOrganizationUnitWithDeviceDetailsResponse> {
    ID : number; // Int32
    __response : EVA.Devices.StatusChecker.ListOrganizationUnitWithDeviceDetailsResponse;
  }
  
  export class ListOrganizationUnitWithDeviceDetailsResponse extends EVA.Core.ResponseMessage {
    OrganizationUnit : EVA.Devices.StatusChecker.OrganizationUnitDeviceStatus; 
  }
  
}
/* tslint:disable */
declare module EVA.DocumentSigning {
  
  export enum Fields {
    Signature = 0,
    Name = 1,
    Date = 2,
    Place = 3,
    Image = 4,
  }
  
  export class CompleteSignDocumentTask extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    TaskID : number; // Int32
    Location : string; 
    Signatures : EVA.DocumentSigning.Signature[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class Signature {
    Description : string; 
    SignatureData : number[]; 
    SignatureHash : string; 
    SignatureText : string; 
  }
  
  export class GetSigningCodeForOrder extends EVA.Core.RequestMessageGeneric<EVA.DocumentSigning.GetSigningCodeForOrderResponse> {
    OrderID : number; // Int32
    __response : EVA.DocumentSigning.GetSigningCodeForOrderResponse;
  }
  
  export class GetSigningCodeForOrderResponse extends EVA.Core.ResponseMessage {
    Code : string; 
    IsAlreadySigned : boolean; 
  }
  
  export class GetSigningDataForOrder extends EVA.Core.RequestMessageGeneric<EVA.DocumentSigning.GetSigningDataForOrderResponse> {
    Hash : string; 
    __response : EVA.DocumentSigning.GetSigningDataForOrderResponse;
  }
  
  export class GetSigningDataForOrderResponse extends EVA.Core.ResponseMessage {
    OrderID : number; // Int32
    CustomerReference : string; 
    CreationTime : string; // DateTime
    ShippingAddress : EVA.Core.AddressDto; 
    CustomerName : string; 
    CustomerPhonenumber : string; 
    CustomerEmailAddress : string; 
    ItemCount : number; // Int32
    TotalAmount : number; // Decimal
    TotalAmountInTax : number; // Decimal
    CurrencyID : string; 
    IsAlreadySigned : boolean; 
  }
  
  export class SignOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    Hash : string; 
    Signature : number[]; 
    MimeType : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class StartSignDocumentTask extends EVA.Core.RequestMessageGeneric<EVA.DocumentSigning.StartSignDocumentResponse> {
    TaskID : number; // Int32, nullable
    OrderLineID : number; // Int32, nullable
    __response : EVA.DocumentSigning.StartSignDocumentResponse;
  }
  
  export class StartSignDocumentResponse extends EVA.Core.ResponseMessage {
    WorkSet : EVA.DocumentSigning.StartSignDocumentWorkSet; 
  }
  
  export class StartSignDocumentWorkSet {
    DocumentID : string; 
    DocumentUrl : string; 
    SignatureHashSalt : string; 
    UserTaskID : number; // Int32
    Signatures : EVA.DocumentSigning.Signature[]; 
  }
  
}
/* tslint:disable */
declare module EVA.Intersolve {
  
  export class AddVoucherToShoppingCart extends EVA.Core.RequestMessageGeneric<EVA.Core.ShoppingCartResponse> {
    SessionID : string; 
    VoucherID : number; // Int64
    __response : EVA.Core.ShoppingCartResponse;
  }
  
  export class ListVoucherConfigurations extends EVA.Core.RequestMessageGeneric<EVA.Intersolve.ListVoucherConfigurationsResponse> {
    __response : EVA.Intersolve.ListVoucherConfigurationsResponse;
  }
  
  export class ListVoucherConfigurationsResponse extends EVA.Core.ResponseMessage {
    VoucherProviders : EVA.Intersolve.VoucherProvider[]; 
  }
  
  export class VoucherProvider {
    Options : EVA.Intersolve.VoucherOption[]; 
    Name : string; 
  }
  
  export class VoucherOption {
    Name : string; 
    VoucherID : number; // Int64
    EAN : string; 
    Value : number; // Decimal
    LayoutID : string; 
    Layout : string; 
    UnitCost : number; // Decimal
  }
  
}
/* tslint:disable */
declare module EVA.Kijkshop {
  
  export class KijkupProcessEmailExporterResult extends EVA.Core.RequestMessageWithEmptyResponse {
    Data : number[]; 
    FileName : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkshopGetProductGroups extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkshopGetProductGroupsResponse> {
    __response : EVA.Kijkshop.KijkshopGetProductGroupsResponse;
  }
  
  export class KijkshopGetProductGroupsResponse extends EVA.Core.ResponseMessage {
    ProductGroups : EVA.Kijkshop.ProductGroupDto[]; 
  }
  
  export class ProductGroupDto {
    ID : number; // Int32
    ParentID : number; // Int32, nullable
    Slug : string; 
    Level : number; // Int32
    Sequence : number; // Int32
    Name : string; 
    SubProductGroups : EVA.Kijkshop.ProductGroupDto[]; 
    Count : number; // Int32
    ImageID : string; 
  }
  
  export class KijkshopGetProductGroup extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkshopGetProductGroupResponse> {
    ID : number; // Int32
    __response : EVA.Kijkshop.KijkshopGetProductGroupResponse;
  }
  
  export class KijkshopGetProductGroupResponse extends EVA.Core.ResponseMessage {
    ImageID : string; 
  }
  
  export class KijkshopUpdateProductGroup extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    ImageID : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ReplenishStoresExcelSample extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    __response : EVA.Core.ResourceResponseMessage;
  }
  
  export class UploadReplenishStoresExcel extends EVA.Core.RequestMessageWithEmptyResponse {
    Data : number[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijGetAvailability extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijAvailabilityResponse> {
    UserID : number; // Int32
    __response : EVA.Kijkshop.KijkBijMijAvailabilityResponse;
  }
  
  export class KijkBijMijAvailabilityResponse extends EVA.Core.ResponseMessage {
    Sunday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    Monday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    Tuesday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    Wednesday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    Thursday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    Friday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    Saturday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    OtherDays : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
  }
  
  export class KijkBijMijAvailabilitySlot {
    ID : number; // Int32
    Date : string; // DateTime, nullable
    StartTime : any; // TimeSpan
    EndTime : any; // TimeSpan
  }
  
  export class KijkBijMijSetAvailability extends EVA.Core.RequestMessageWithEmptyResponse {
    Sunday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    Monday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    Tuesday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    Wednesday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    Thursday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    Friday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    Saturday : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    OtherDays : EVA.Kijkshop.KijkBijMijAvailabilitySlot[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijBlockUser extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijBlocksUser extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijBlocksUserResponse> {
    UserID : number; // Int32
    __response : EVA.Kijkshop.KijkBijMijBlocksUserResponse;
  }
  
  export class KijkBijMijBlocksUserResponse extends EVA.Core.ResponseMessage {
    Blocks : boolean; 
  }
  
  export class KijkBijMijUnblockUser extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijBlockedUsers extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijBlockedUsersResponse> {
    __response : EVA.Kijkshop.KijkBijMijBlockedUsersResponse;
  }
  
  export class KijkBijMijBlockedUsersResponse extends EVA.Core.ResponseMessage {
    UserIDs : number[]; 
  }
  
  export class KijkBijMijCallExpert extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijCallResponse> {
    UserID : number; // Int32
    ProductID : number; // Int32, nullable
    ProductGroupID : number; // Int32, nullable
    __response : EVA.Kijkshop.KijkBijMijCallResponse;
  }
  
  export class KijkBijMijCallResponse extends EVA.Core.ResponseMessage {
    SessionID : string; 
    Token : string; 
  }
  
  export class KijkBijMijJoinCall extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijCallResponse> {
    SessionID : string; 
    __response : EVA.Kijkshop.KijkBijMijCallResponse;
  }
  
  export class KijkBijMijDeclineCall extends EVA.Core.RequestMessageWithEmptyResponse {
    SessionID : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijTotalExpertCount extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijTotalExpertCountResponse> {
    __response : EVA.Kijkshop.KijkBijMijTotalExpertCountResponse;
  }
  
  export class KijkBijMijTotalExpertCountResponse extends EVA.Core.ResponseMessage {
    ExpertCount : number; // Int32
  }
  
  export class KijkBijMijAddProductExpertise extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijRemoveProductExpertise extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijAddProductGroupExpertise extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductGroupID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijRemoveProductGroupExpertise extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductGroupID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijIsExpertOnProduct extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijIsExpertResponse> {
    ProductID : number; // Int32
    __response : EVA.Kijkshop.KijkBijMijIsExpertResponse;
  }
  
  export class KijkBijMijIsExpertResponse extends EVA.Core.ResponseMessage {
    IsExpert : boolean; 
  }
  
  export class KijkBijMijIsExpertOnProductGroup extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijIsExpertResponse> {
    ProductGroupID : number; // Int32
    __response : EVA.Kijkshop.KijkBijMijIsExpertResponse;
  }
  
  export class KijkBijMijIsExpertOnProducts extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijIsExpertsResponse> {
    ProductIDs : number[]; 
    __response : EVA.Kijkshop.KijkBijMijIsExpertsResponse;
  }
  
  export class KijkBijMijIsExpertsResponse extends EVA.Core.ResponseMessage {
    IsExpert : { [ key : number ] : boolean }; 
  }
  
  export class KijkBijMijIsExpertOnProductGroups extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijIsExpertsResponse> {
    ProductGroupIDs : number[]; 
    __response : EVA.Kijkshop.KijkBijMijIsExpertsResponse;
  }
  
  export class KijkBijMijProductExperts extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijProductExpertsResponse> {
    ProductID : number; // Int32
    __response : EVA.Kijkshop.KijkBijMijProductExpertsResponse;
  }
  
  export class KijkBijMijProductExpertsResponse extends EVA.Core.ResponseMessage {
    ProductExperts : number[]; 
    ProductGroupExperts : number[]; 
  }
  
  export class KijkBijMijGetProductsStats extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijGetProductsStatsResponse> {
    ProductIDs : number[]; 
    __response : EVA.Kijkshop.KijkBijMijGetProductsStatsResponse;
  }
  
  export class KijkBijMijGetProductsStatsResponse extends EVA.Core.ResponseMessage {
    Stats : { [ key : number ] : EVA.Kijkshop.KijkBijMijProductStats }; 
  }
  
  export class KijkBijMijProductStats {
    BrandExperts : number; // Int32
    ProductExperts : number; // Int32
    ProductGroupExperts : number; // Int32
    TotalExperts : number; // Int32
    IsCurrentUserBrandExpert : boolean; 
    IsCurrentUserProductExpert : boolean; 
    IsCurrentUserProductGroupExpert : boolean; 
    Likes : number; // Int32
  }
  
  export class KijkBijMijProductGroupExperts extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijProductGroupExpertsResponse> {
    ProductGroupID : number; // Int32
    __response : EVA.Kijkshop.KijkBijMijProductGroupExpertsResponse;
  }
  
  export class KijkBijMijProductGroupExpertsResponse extends EVA.Core.ResponseMessage {
    ProductGroupExperts : number[]; 
  }
  
  export class KijkBijMijProductGroupExpertsPaged extends EVA.Core.PagedResultRequest<EVA.Kijkshop.KijkBijMijProductGroupExpertsPagedResponse> {
    ProductGroupID : number; // Int32
    __response : EVA.Kijkshop.KijkBijMijProductGroupExpertsPagedResponse;
  }
  
  export class KijkBijMijProductGroupExpertsPagedResponse extends EVA.Core.PagedResultResponse<number> {
  }
  
  export class KijkBijMijListHall extends EVA.Core.PagedResultRequest<EVA.Kijkshop.KijkBijMijListHallResponse> {
    __response : EVA.Kijkshop.KijkBijMijListHallResponse;
  }
  
  export class KijkBijMijListHallResponse extends EVA.Core.PagedResultResponse<EVA.Kijkshop.RankedUser> {
    CurrentUser : EVA.Kijkshop.RankedUser; 
  }
  
  export class RankedUser {
    UserID : number; // Int32
    UserFirstName : string; 
    AvatarID : string; 
    Ranking : number; // Int32
    Scans : number; // Int32
  }
  
  export class KijkBijMijLikeProduct extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijLikesProduct extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijLikesProductResponse> {
    ProductID : number; // Int32
    __response : EVA.Kijkshop.KijkBijMijLikesProductResponse;
  }
  
  export class KijkBijMijLikesProductResponse extends EVA.Core.ResponseMessage {
    Likes : boolean; 
  }
  
  export class KijkBijMijLikesProducts extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijLikesProductsResponse> {
    ProductIDs : number[]; 
    __response : EVA.Kijkshop.KijkBijMijLikesProductsResponse;
  }
  
  export class KijkBijMijLikesProductsResponse extends EVA.Core.ResponseMessage {
    Likes : { [ key : number ] : boolean }; 
  }
  
  export class KijkBijMijUnlikeProduct extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijLikedProducts extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijLikedProductsResponse> {
    __response : EVA.Kijkshop.KijkBijMijLikedProductsResponse;
  }
  
  export class KijkBijMijLikedProductsResponse extends EVA.Core.ResponseMessage {
    ProductIDs : number[]; 
  }
  
  export class KijkBijMijSubscribeToNotificationType extends EVA.Core.RequestMessageWithEmptyResponse {
    TypeID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijUnsubscribeFromNotificationType extends EVA.Core.RequestMessageWithEmptyResponse {
    TypeID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijGetNotificationSubscriptions extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijNotificationSubscriptionsResponse> {
    __response : EVA.Kijkshop.KijkBijMijNotificationSubscriptionsResponse;
  }
  
  export class KijkBijMijNotificationSubscriptionsResponse extends EVA.Core.ResponseMessage {
    Subscriptions : EVA.Kijkshop.KijkBijMijNotificationType[]; 
  }
  
  export class KijkBijMijNotificationType {
    ID : number; // Int32
    Name : string; 
    Description : string; 
  }
  
  export class KijkBijMijListNotifications extends EVA.Core.PagedResultRequest<EVA.Kijkshop.KijkBijMijListNotificationsResponse> {
    __response : EVA.Kijkshop.KijkBijMijListNotificationsResponse;
  }
  
  export class KijkBijMijListNotificationsResponse extends EVA.Core.PagedResultResponse<EVA.Kijkshop.KijkBijMijNotification> {
  }
  
  export class KijkBijMijNotification {
    ID : number; // Int32
    TypeID : number; // Int32
    Type : EVA.Kijkshop.KijkBijMijNotificationType; 
    Text : string; 
    Read : boolean; 
    CreationTime : string; // DateTime
  }
  
  export class KijkBijMijGetUnreadNotificationCount extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijUnreadNotificationCountResponse> {
    __response : EVA.Kijkshop.KijkBijMijUnreadNotificationCountResponse;
  }
  
  export class KijkBijMijUnreadNotificationCountResponse extends EVA.Core.ResponseMessage {
    Count : number; // Int32
  }
  
  export class KijkBijMijMarkNotificationAsRead extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijDeleteNotification extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijRateCaller extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    SessionID : string; 
    Rating : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijRateExpert extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    SessionID : string; 
    Rating1 : number; // Int32
    Rating2 : number; // Int32
    Rating3 : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijListRatings extends EVA.Core.PagedResultRequest<EVA.Kijkshop.KijkBijMijListRatingsResponse> {
    UserID : number; // Int32
    __response : EVA.Kijkshop.KijkBijMijListRatingsResponse;
  }
  
  export class KijkBijMijListRatingsResponse extends EVA.Core.PagedResultResponse<EVA.Kijkshop.KijkBijMijRating> {
  }
  
  export class KijkBijMijRating {
    ProductID : number; // Int32, nullable
    ProductGroupID : number; // Int32, nullable
    ProductDisplayValue : string; 
    Rating1 : number; // Int32
    Rating2 : number; // Int32
    Rating3 : number; // Int32
    UserID : number; // Int32
    UserFirstName : string; 
    AvatarID : string; 
    CreationTime : string; // DateTime
  }
  
  export class KijkBijMijReportUser extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    Reason : EVA.Kijkshop.KijkBijMijReportReasons; 
    ReasonDescription : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export enum KijkBijMijReportReasons {
    Harassment = 1,
    OffTopic = 2,
    Other = 3,
  }
  
  export class SetExpertForOrderLine extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderLineID : number; // Int32
    ExpertID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijGetExpertDetails extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijGetExpertDetailsResponse> {
    UserIDs : number[]; 
    __response : EVA.Kijkshop.KijkBijMijGetExpertDetailsResponse;
  }
  
  export class KijkBijMijGetExpertDetailsResponse extends EVA.Core.ResponseMessage {
    Details : EVA.Kijkshop.ExpertDetails[]; 
  }
  
  export class ExpertDetails {
    ID : number; // Int32
    FirstName : string; 
    LastName : string; 
    Gender : string; 
    AdvisorDescription : string; 
    AvatarID : string; 
    IsAvailable : boolean; 
    AverageRating : number; // Decimal, nullable
    LanguageProficiencies : { [ key : string ] : number }; 
  }
  
  export class KijkBijMijGetProfile extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijGetProfileResponse> {
    __response : EVA.Kijkshop.KijkBijMijGetProfileResponse;
  }
  
  export class KijkBijMijGetProfileResponse extends EVA.Core.ResponseMessage {
    AdvisorDescription : string; 
    AvatarID : string; 
    LanguageProficiencies : { [ key : string ] : number }; 
  }
  
  export class KijkBijMijUpdateProfile extends EVA.Core.RequestMessageWithEmptyResponse {
    AdvisorDescription : string; 
    AvatarID : string; 
    LanguageProficiencies : { [ key : string ] : number }; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export enum KijkBijMijUserCardTypes {
    Normal = 1,
    Payout = 2,
  }
  
  export class KijkBijMijGetCreditTotalsForUser extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijGetCreditTotalsForUserResponse> {
    __response : EVA.Kijkshop.KijkBijMijGetCreditTotalsForUserResponse;
  }
  
  export class KijkBijMijGetCreditTotalsForUserResponse extends EVA.Core.ResponseMessage {
    NormalCreditsTotal : number; // Decimal
    PayoutCreditsTotal : number; // Decimal
    NormalIncludingFutureCreditsTotal : number; // Decimal
    PayoutIncludingFutureCreditsTotal : number; // Decimal
  }
  
  export class KijkBijMijListCreditTransactions extends EVA.Core.PagedResultRequest<EVA.Kijkshop.KijkBijMijListCreditTransactionsResponse> {
    __response : EVA.Kijkshop.KijkBijMijListCreditTransactionsResponse;
  }
  
  export class KijkBijMijListCreditTransactionsResponse extends EVA.Core.PagedResultResponse<EVA.Kijkshop.KijkBijMijCreditTransaction> {
  }
  
  export class KijkBijMijCreditTransaction {
    CreationTime : string; // DateTime
    Amount : number; // Decimal
    Description : string; 
    Status : EVA.Core.UserCardMutationStatuses; 
    StartDate : string; // DateTime, nullable
    CreditType : EVA.Kijkshop.KijkBijMijUserCardTypes; 
    SessionID : string; 
    ProductID : number; // Int32
    ProductGroupID : number; // Int32, nullable
    AdvisedUserID : number; // Int32
  }
  
  export class KijkBijMijPayoutCredits extends EVA.Core.RequestMessageWithEmptyResponse {
    Amount : number; // Decimal
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class KijkBijMijScanMe extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijScanMeResponse> {
    ScannedUserID : number; // Int32
    __response : EVA.Kijkshop.KijkBijMijScanMeResponse;
  }
  
  export class KijkBijMijScanMeResponse extends EVA.Core.ResponseMessage {
    CreditsAlreadyReceived : boolean; 
  }
  
  export class KijkBijMijScanNewApp extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.KijkBijMijScanNewAppResponse> {
    ScannedUserID : number; // Int32
    __response : EVA.Kijkshop.KijkBijMijScanNewAppResponse;
  }
  
  export class KijkBijMijScanNewAppResponse extends EVA.Core.ResponseMessage {
    CreditsAlreadyReceived : boolean; 
  }
  
  export class FreeBeesGetCardBalance extends EVA.Core.RequestMessageGeneric<EVA.Kijkshop.FreeBeesGetCardBalanceResponse> {
    CardNumber : string; 
    __response : EVA.Kijkshop.FreeBeesGetCardBalanceResponse;
  }
  
  export class FreeBeesGetCardBalanceResponse extends EVA.Core.ResponseMessage {
    FreeBeesCount : number; // Int32
    Balance : number; // Decimal
    Status : EVA.Kijkshop.FreeBeesStatusCodes; 
  }
  
  export enum FreeBeesStatusCodes {
    Valid = 0,
    InvalidCardNumber = 1,
    InvalidCombination = 2,
    CardNotRegistered = 3,
    CardAlreadyRegistered = 4,
    NewsLetterNotSet = 5,
    InputParseError = 15,
    InvalidPassword = 16,
    InvalidActivationCode = 17,
    NoTransactionHistory = 18,
    InvalidNewPassword = 19,
    NotEnoughPoints = 20,
    NoValidTransactionID = 21,
    InvalidEmail = 22,
    NoEmailInDatabase = 23,
    CardNotUsedOnSite = 24,
    OperationRejected = 25,
    InvalidLocationCode = 26,
  }
  
  export enum KijkBijMijReportStatuses {
    New = 0,
    ContentRemoved = 1,
    Ignored = 2,
  }
  
}
/* tslint:disable */
declare module EVA.Kiyoh {
  
  export class GetShopReviewStats extends EVA.Core.RequestMessageGeneric<EVA.Kiyoh.GetShopReviewStatsResponse> {
    __response : EVA.Kiyoh.GetShopReviewStatsResponse;
  }
  
  export class GetShopReviewStatsResponse extends EVA.Core.ResponseMessage {
    Score : number; // Decimal
    Recommendation : number; // Decimal
    Total : number; // Int32
  }
  
  export class ListProductReviews extends EVA.Core.PagedResultRequest<EVA.Kiyoh.ListProductReviewsResponse> {
    __response : EVA.Kiyoh.ListProductReviewsResponse;
  }
  
  export class ListProductReviewsResponse extends EVA.Core.PagedResultResponse<EVA.Kiyoh.ProductReview> {
    Score : number; // Decimal
  }
  
  export class ProductReview {
    Name : string; 
    ProductID : number; // Int32
    Score : number; // Decimal
    Text : string; 
    Date : string; // DateTime
  }
  
  export class ListShopReviews extends EVA.Core.PagedResultRequest<EVA.Kiyoh.ListShopReviewsResponse> {
    __response : EVA.Kiyoh.ListShopReviewsResponse;
  }
  
  export class ListShopReviewsResponse extends EVA.Core.PagedResultResponse<EVA.Kiyoh.ShopReview> {
    Score : number; // Decimal
    Recommendation : number; // Decimal
  }
  
  export class ShopReview {
    Name : string; 
    Score : number; // Decimal
    Date : string; // DateTime
    Recommendation : boolean; 
    Positive : string; 
    Negative : string; 
    Purchase : string; 
    Reaction : string; 
  }
  
}
/* tslint:disable */
declare module EVA.KvK {
  
  export class SearchKvK extends EVA.Core.RequestMessageGeneric<EVA.KvK.SearchKvKResponse> {
    Query : string; 
    KvKNumber : string; 
    __response : EVA.KvK.SearchKvKResponse;
  }
  
  export class SearchKvKResponse extends EVA.Core.ResponseMessage {
    Result : any; 
  }
  
}
/* tslint:disable */
declare module EVA.Makeup {
  
  export class MakeupCreateBlock extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupCreateBlockResponse> {
    Block : EVA.Makeup.BlockDto; 
    __response : EVA.Makeup.MakeupCreateBlockResponse;
  }
  
  export class MakeupCreateBlockResponse extends EVA.Core.ResponseMessage {
    ID : string; 
  }
  
  export class BlockDto {
    ID : string; 
    Type : string; 
    Input : { [ key : string ] : EVA.Makeup.BlockInputDto }; 
    CssClasses : string[]; 
    Name : string; 
    Template : string; 
    Content : string; 
    Width : string; 
    Height : string; 
    CssStyles : string; 
    IsCurrent : boolean; 
    Version : number; // Int32
    VersionDescription : string; 
  }
  
  export class BlockInputDto {
    Value : any; 
    Description : string; 
    Type : string; 
    IsOptional : boolean; 
  }
  
  export class MakeupDeleteBlock extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string; 
    Version : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class MakeupGetBlockByID extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupGetBlockByIDResponse> {
    ID : string; 
    Version : number; // Int32, nullable
    __response : EVA.Makeup.MakeupGetBlockByIDResponse;
  }
  
  export class MakeupGetBlockByIDResponse extends EVA.Core.ResponseMessage {
    Block : EVA.Makeup.BlockDto; 
  }
  
  export class MakeupGetRenderedBlockByID extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupGetRenderedBlockByIDResponse> {
    ID : string; 
    Version : number; // Int32, nullable
    __response : EVA.Makeup.MakeupGetRenderedBlockByIDResponse;
  }
  
  export class MakeupGetRenderedBlockByIDResponse extends EVA.Core.ResponseMessage {
    Block : EVA.Makeup.BlockDto; 
  }
  
  export class MakeupListBlocks extends EVA.Core.PagedResultRequest<EVA.Makeup.MakeupListBlocksResponse> {
    Type : string; 
    __response : EVA.Makeup.MakeupListBlocksResponse;
  }
  
  export class MakeupListBlocksResponse extends EVA.Core.PagedResultResponse<EVA.Makeup.BlockDto> {
  }
  
  export class MakeupUpdateBlock extends EVA.Core.RequestMessageWithEmptyResponse {
    Block : EVA.Makeup.BlockDto; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class MakeupReplaceConfigurationProfile extends EVA.Core.RequestMessageWithEmptyResponse {
    Configuration : EVA.Makeup.ConfigurationProfileDto; 
    LanguageID : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ConfigurationProfileDto {
    SiteID : number; // Int32
    LanguageID : string; 
    AggregationConfigs : EVA.Makeup.ConfigurationProfileAggregationConfigDto[]; 
    DefaultAggregationOptions : { [ key : string ] : EVA.Core.AggregationFilterModel }; 
    ProductPropertyTypeMappings : EVA.Makeup.ProductPropertyTypeMappingDto[]; 
    DefaultFilters : { [ key : string ] : EVA.Core.FilterModel }; 
    DefaultPageLimit : EVA.Makeup.ConfigurationProfilePageLimitDto; 
    DefaultSort : EVA.Makeup.ConfigurationProfileSortOptionsDto[]; 
    DefaultIncludedFields : string[]; 
    AvailableSortOptions : EVA.Makeup.ConfigurationProfileSortOptionsDto[]; 
    AvailablePageLimits : EVA.Makeup.ConfigurationProfilePageLimitDto[]; 
  }
  
  export class ConfigurationProfileAggregationConfigDto {
    TypeID : string; 
    Type : string; 
    InitialShownItems : number; // Int32
    Sorting : string[][]; 
  }
  
  export class ProductPropertyTypeMappingDto {
    Key : string; 
    ProductPropertyTypeID : string; 
  }
  
  export class ConfigurationProfilePageLimitDto {
    Limit : number; // Int32
    LimitDisplay : string; 
  }
  
  export class ConfigurationProfileSortOptionsDto {
    FieldName : string; 
    SortDisplay : string; 
    Direction : EVA.Makeup.ConfigurationProfileSortOptionsDirection; 
  }
  
  export enum ConfigurationProfileSortOptionsDirection {
    Ascending = 0,
    Descending = 1,
  }
  
  export class MakeupGetPageMap extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupGetPageMapResponse> {
    LanguageID : string; 
    __response : EVA.Makeup.MakeupGetPageMapResponse;
  }
  
  export class MakeupGetPageMapResponse extends EVA.Core.ResponseMessage {
    PageMap : { [ key : string ] : EVA.Makeup.MakeupPageMapSection }; 
  }
  
  export class MakeupPageMapSection {
    Name : string; 
    Sections : EVA.Makeup.MakeupPageMapSection[]; 
    Description : string; 
    IsBase : boolean; 
    Pages : EVA.Makeup.MakeupPageMapSectionPage[]; 
  }
  
  export class MakeupPageMapSectionPage {
    ID : string; 
    Name : string; 
    Path : string; 
    IsBase : boolean; 
  }
  
  export class MakeupCreateMenu extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupCreateMenuResponse> {
    Menu : EVA.Makeup.MenuDto; 
    __response : EVA.Makeup.MakeupCreateMenuResponse;
  }
  
  export class MakeupCreateMenuResponse extends EVA.Core.ResponseMessage {
    ID : string; 
  }
  
  export class MenuDto {
    ID : string; 
    Name : string; 
    LanguageID : string; 
    Types : EVA.Makeup.MenuTypeDto[]; 
  }
  
  export class MenuTypeDto {
    Type : string; 
    Items : EVA.Makeup.MenuItemDto[]; 
  }
  
  export class MenuItemDto {
    Name : string; 
    Path : string; 
    ImageBlobID : string; 
    Items : EVA.Makeup.MenuItemDto[]; 
  }
  
  export class MakeupReplaceMenu extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string; 
    Menu : EVA.Makeup.MenuDto; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class MakeupCreatePage extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupCreatePageResponse> {
    Page : EVA.Makeup.PageDto; 
    __response : EVA.Makeup.MakeupCreatePageResponse;
  }
  
  export class MakeupCreatePageResponse extends EVA.Core.ResponseMessage {
    ID : string; 
  }
  
  export class PageDto {
    ID : string; 
    LanguageID : string; 
    Name : string; 
    Description : string; 
    Type : string; 
    SearchProductsRequest : EVA.Core.Services.SearchProducts; 
    Path : string; 
    Containers : EVA.Makeup.ContainerDto[]; 
    CssClasses : string[]; 
    MetaTags : EVA.Makeup.MetaTagDto[]; 
    Version : number; // Int32
    VersionDescription : string; 
    IsCurrent : boolean; 
    CssStyles : string; 
    StyleSheetBlobID : string; 
    Slug : string; 
    Blocks : EVA.Makeup.PageBlockDto[]; 
    Event : EVA.Makeup.EventDto; 
    EventID : number; // Int32, nullable
    RequiresAuthentication : boolean; 
    RequiredFunctionality : string; 
  }
  
  export class ContainerDto {
    CssClasses : string[]; 
    Children : EVA.Makeup.ContainerChildDto[]; 
    Width : string; 
    Height : string; 
  }
  
  export class ContainerChildDto {
    CssClasses : string[]; 
    Blocks : EVA.Makeup.PageBlockDto[]; 
    Width : string; 
    Height : string; 
  }
  
  export class PageBlockDto implements EVA.Makeup.IPageBlock {
    ID : string; 
    Type : string; 
    Input : { [ key : string ] : EVA.Makeup.BlockInputDto }; 
    CssClasses : string[]; 
    CssStyles : string; 
    Name : string; 
    Content : string; 
    Template : string; 
    Width : string; 
    Height : string; 
    Version : number; // Int32, nullable
  }
  
  export interface IPageBlock {
    ID : string; 
    Type : string; 
    CssClasses : string[]; 
    Name : string; 
    Template : string; 
    Width : string; 
    Height : string; 
    Version : number; // Int32, nullable
  }
  
  export class MetaTagDto {
    Attribute : string; 
    Content : string; 
    Type : string; 
  }
  
  export class EventDto {
    ID : number; // Int32
    Name : string; 
    StartDate : string; // DateTime, nullable
    EndDate : string; // DateTime, nullable
    IsActive : boolean; 
  }
  
  export class MakeupDeletePage extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string; 
    LanguageID : string; 
    Version : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class MakeupGetPageByID extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupGetPageByIdResponse> {
    ID : string; 
    LanguageID : string; 
    Version : number; // Int32, nullable
    __response : EVA.Makeup.MakeupGetPageByIdResponse;
  }
  
  export class MakeupGetPageByIdResponse extends EVA.Core.ResponseMessage {
    Page : EVA.Makeup.PageDto; 
  }
  
  export class MakeupGetPageByPath extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupGetPageByPathResponse> {
    Path : string; 
    LanguageID : string; 
    __response : EVA.Makeup.MakeupGetPageByPathResponse;
  }
  
  export class MakeupGetPageByPathResponse extends EVA.Core.ResponseMessage {
    Page : EVA.Makeup.PageDto; 
    PathContext : EVA.Makeup.PathContext; 
  }
  
  export class PathContext {
    Path : string; 
    Parameters : EVA.Makeup.PathParameter[]; 
  }
  
  export class PathParameter {
    Key : string; 
    Value : any; 
  }
  
  export class MakeupGetRenderedPageByID extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupGetRenderedPageByIDResponse> {
    ID : string; 
    LanguageID : string; 
    Version : number; // Int32, nullable
    __response : EVA.Makeup.MakeupGetRenderedPageByIDResponse;
  }
  
  export class MakeupGetRenderedPageByIDResponse extends EVA.Core.ResponseMessage {
    Page : EVA.Makeup.RenderedPageDto; 
  }
  
  export class RenderedPageDto {
    ID : string; 
    LanguageID : string; 
    Name : string; 
    Description : string; 
    Type : string; 
    SearchProductsRequest : EVA.Core.Services.SearchProducts; 
    Path : string; 
    Containers : EVA.Makeup.ContainerDto[]; 
    CssClasses : string[]; 
    MetaTags : EVA.Makeup.MetaTagDto[]; 
    StyleSheetBlobID : string; 
    Slug : string; 
    RequiresAuthentication : boolean; 
    RequiredFunctionality : string; 
  }
  
  export class MakeupGetRenderedPageByPath extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupGetRenderedPageByPathResponse> {
    Path : string; 
    LanguageID : string; 
    __response : EVA.Makeup.MakeupGetRenderedPageByPathResponse;
  }
  
  export class MakeupGetRenderedPageByPathResponse extends EVA.Core.ResponseMessage {
    Page : EVA.Makeup.RenderedPageDto; 
  }
  
  export class MakeupReplacePage extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string; 
    Page : EVA.Makeup.PageDto; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class MakeupGetCurrentPageVersion extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupGetCurrentPageVersionResponse> {
    ID : string; 
    LanguageID : string; 
    __response : EVA.Makeup.MakeupGetCurrentPageVersionResponse;
  }
  
  export class MakeupGetCurrentPageVersionResponse extends EVA.Core.ResponseMessage {
    Version : number; // Int32
    VersionDescription : string; 
  }
  
  export class MakeupGetRenderedPagesByPartialPath extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupGetRenderedPagesByPartialPathResponse> {
    PartialPath : string; 
    LanguageID : string; 
    __response : EVA.Makeup.MakeupGetRenderedPagesByPartialPathResponse;
  }
  
  export class MakeupGetRenderedPagesByPartialPathResponse extends EVA.Core.ResponseMessage {
    Pages : EVA.Makeup.RenderedPageDto[]; 
  }
  
  export class MakeupListPageVersions extends EVA.Core.PagedResultRequest<EVA.Makeup.MakeupListPageVersionsResponse> {
    ID : string; 
    LanguageID : string; 
    __response : EVA.Makeup.MakeupListPageVersionsResponse;
  }
  
  export class MakeupListPageVersionsResponse extends EVA.Core.PagedResultResponse<EVA.Makeup.PageVersionDto> {
  }
  
  export class PageVersionDto {
    ID : string; 
    Version : number; // Int32
    IsCurrent : boolean; 
    VersionDescription : string; 
  }
  
  export class MakeupPublishPageVersion extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string; 
    LanguageID : string; 
    Version : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class MakeupDeleteMenu extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string; 
    LanguageID : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class MakeupGetMenuByID extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupGetMenuByIDResponse> {
    ID : string; 
    LanguageID : string; 
    __response : EVA.Makeup.MakeupGetMenuByIDResponse;
  }
  
  export class MakeupGetMenuByIDResponse extends EVA.Core.ResponseMessage {
    Menu : EVA.Makeup.MenuDto; 
  }
  
  export class MakeupListMenus extends EVA.Core.PagedResultRequest<EVA.Makeup.MakeupListMenusResponse> {
    LanguageID : string; 
    __response : EVA.Makeup.MakeupListMenusResponse;
  }
  
  export class MakeupListMenusResponse extends EVA.Core.PagedResultResponse<EVA.Makeup.MenuDto> {
  }
  
  export class MakeupActivateEvent extends EVA.Core.RequestMessageWithEmptyResponse {
    EventID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class MakeupCreateEvent extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupCreateEventResponse> {
    Event : EVA.Makeup.CreateEventModel; 
    __response : EVA.Makeup.MakeupCreateEventResponse;
  }
  
  export class MakeupCreateEventResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class CreateEventModel {
    Name : string; 
    StartDate : string; // DateTime, nullable
    EndDate : string; // DateTime, nullable
    IsActive : boolean; 
  }
  
  export class MakeupDeactivateEvent extends EVA.Core.RequestMessageWithEmptyResponse {
    EventID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class MakeupDeleteEvent extends EVA.Core.RequestMessageWithEmptyResponse {
    EventID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class MakeupGetEventByID extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupGetEventByIDResponse> {
    ID : number; // Int32
    __response : EVA.Makeup.MakeupGetEventByIDResponse;
  }
  
  export class MakeupGetEventByIDResponse extends EVA.Core.ResponseMessage {
    Event : EVA.Makeup.EventDto; 
  }
  
  export class MakeupListEvents extends EVA.Core.PagedResultRequest<EVA.Makeup.MakeupListEventsResponse> {
    IsActive : boolean; 
    __response : EVA.Makeup.MakeupListEventsResponse;
  }
  
  export class MakeupListEventsResponse extends EVA.Core.PagedResultResponse<EVA.Makeup.EventDto> {
  }
  
  export class MakeupGetConfigurationProfile extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupGetConfigurationProfileResponse> {
    LanguageID : string; 
    __response : EVA.Makeup.MakeupGetConfigurationProfileResponse;
  }
  
  export class MakeupGetConfigurationProfileResponse extends EVA.Core.ResponseMessage {
    Configuration : EVA.Makeup.ConfigurationProfileDto; 
  }
  
  export class MakeupGetCurrentBlockVersion extends EVA.Core.RequestMessageGeneric<EVA.Makeup.MakeupGetCurrentBlockVersionResponse> {
    ID : string; 
    __response : EVA.Makeup.MakeupGetCurrentBlockVersionResponse;
  }
  
  export class MakeupGetCurrentBlockVersionResponse extends EVA.Core.ResponseMessage {
    Version : number; // Int32
    VersionDescription : string; 
  }
  
  export class MakeupListBlockVersions extends EVA.Core.PagedResultRequest<EVA.Makeup.MakeupListBlockVersionsResponse> {
    ID : string; 
    __response : EVA.Makeup.MakeupListBlockVersionsResponse;
  }
  
  export class MakeupListBlockVersionsResponse extends EVA.Core.PagedResultResponse<EVA.Makeup.BlockVersionDto> {
  }
  
  export class BlockVersionDto {
    ID : string; 
    Version : number; // Int32
    IsCurrent : boolean; 
    VersionDescription : string; 
  }
  
  export class MakeupPublishBlockVersion extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : string; 
    Version : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
}
/* tslint:disable */
declare module EVA.Media.ImageProvider {
  
  export enum PaddingOptions {
    PadNone = 0,
    PadWidth = 1,
    PadHeight = 2,
    PadBoth = 3,
  }
  
}
/* tslint:disable */
declare module EVA.Migrations {
  
  export enum MigrationDirection {
    Up = 1,
    Down = 2,
  }
  
  export enum Developers {
    Mark = 10000,
    Edwin = 11000,
    Julian = 20000,
    Arno = 21000,
    AartJan = 30000,
    Wytse = 40000,
    Casper = 50000,
    Fawad = 60000,
    Chris = 70000,
    Kees = 80000,
    Other = 90000,
  }
  
}
/* tslint:disable */
declare module EVA.Neo4j {
  
  export enum RunTypes {
    Read = 0,
    Write = 1,
  }
  
}
/* tslint:disable */
declare module EVA.Owin.Swagger {
  
  export enum SwaggerFunctionalities {
    AccessSwaggerDocumentation = 0,
  }
  
}
/* tslint:disable */
declare module EVA.Owin {
  
  export enum PipelinePriorities {
    NotSpecified = 0,
    Unimportant = 1,
    RarelyExecuted = 10,
    OftenExecuted = 100,
    NearlyAlwaysExecuted = 1000,
    ExecutedEveryRequest = 10000,
    HighPriority = 100000,
    DoesSetup = 1000000,
    FirstToExecute = 2147483647,
    LastToExecute = -2147483648,
  }
  
}
/* tslint:disable */
declare module EVA.PIM.Core {
  
  export class ApplyRevision extends EVA.Core.RequestMessageWithEmptyResponse {
    RevisionID : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateRevision extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.CreateRevisionResponse> {
    ApplicationID : number; // Int32, nullable
    Name : string; 
    __response : EVA.PIM.Core.CreateRevisionResponse;
  }
  
  export class CreateRevisionResponse extends EVA.Core.ResponseMessage {
    Result : EVA.PIM.Core.CreatedRevision; 
  }
  
  export class CreatedRevision {
    ID : number; // Int32
    Name : string; 
    ApplicationID : number; // Int32, nullable
  }
  
  export class GetRevisionStatus extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.GetRevisionStatusResponse> {
    RevisionID : number; // Int32
    __response : EVA.PIM.Core.GetRevisionStatusResponse;
  }
  
  export class GetRevisionStatusResponse extends EVA.Core.ResponseMessage {
    Status : EVA.PIM.Core.RevisionProgress; 
  }
  
  export class RevisionProgress {
    TotalItems : number; // Int32
    HandledItems : number; // Int32
    ValidationErrors : number; // Int64
  }
  
  export class ListRevisions extends EVA.Core.PagedResultRequest<EVA.PIM.Core.ListRevisionsResponse> {
    __response : EVA.PIM.Core.ListRevisionsResponse;
  }
  
  export class ListRevisionsResponse extends EVA.Core.PagedResultResponse<EVA.PIM.Core.RevisionDto> {
  }
  
  export class RevisionDto {
    ID : number; // Int32
    Name : string; 
    ApplicationID : number; // Int32, nullable
    Status : EVA.PIM.Core.RevisionStatus; 
    AppliedOn : string; // DateTime, nullable
    CreatedBy : EVA.PIM.Core.ListRevisionUser; 
    CreationTime : string; // DateTime
  }
  
  export enum RevisionStatus {
    Open = 1,
    Applied = 2,
    Inactive = 4,
    InProgress = 8,
  }
  
  export class ListRevisionUser {
    FullName : string; 
  }
  
  export class ListRevisionValidationErrors extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.ListRevisionValidationErrorsResponse> {
    RevisionID : number; // Int32
    Offset : number; // Int32, nullable
    Cursor : number; // Int32, nullable
    __response : EVA.PIM.Core.ListRevisionValidationErrorsResponse;
  }
  
  export class ListRevisionValidationErrorsResponse extends EVA.Core.ResponseMessage {
    Offset : number; // Int32, nullable
    Cursor : number; // Int32, nullable
    Errors : any[]; 
  }
  
  export class CreateNewSearchDataIndex extends EVA.Core.RequestMessageWithEmptyResponse {
    DeleteOldIndex : boolean; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class RequestReindexSearchData extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.RequestReindexSearchDataResponse> {
    Script : string; 
    __response : EVA.PIM.Core.RequestReindexSearchDataResponse;
  }
  
  export class RequestReindexSearchDataResponse extends EVA.Core.ResponseMessage {
  }
  
  export class AddReferenceDataToProduct extends EVA.Core.RequestMessageWithEmptyResponse {
    ProductID : number; // Int32
    Data : any; 
    Name : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateProduct extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.CreateProductResponse> {
    PrimitiveName : string; 
    ProductType : EVA.Core.ProductTypes; 
    TaxCodeID : number; // Int32
    BrandID : number; // Int32, nullable
    BackendID : string; 
    BackendSystemID : string; 
    OrganizationUnitID : number; // Int32, nullable
    CustomID : string; 
    __response : EVA.PIM.Core.CreateProductResponse;
  }
  
  export class CreateProductResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class EditProduct extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.EditProductResponse> {
    ID : number; // Int32
    RevisionID : number; // Int32, nullable
    Edits : EVA.PIM.Core.ProductEdit[]; 
    __response : EVA.PIM.Core.EditProductResponse;
  }
  
  export class EditProductResponse extends EVA.Core.ResponseMessage {
  }
  
  export class ProductEdit {
    LayerID : number; // Int32, nullable
    Content : any; 
    LanguageID : string; 
    CountryID : string; 
  }
  
  export class GetProductForEditByID extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.GetProductForEditByIDResponse> {
    ID : number; // Int32
    RevisionID : number; // Int32
    __response : EVA.PIM.Core.GetProductForEditByIDResponse;
  }
  
  export class GetProductForEditByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    CatalogID : number; // Int32
    DisplayValue : string; 
    LayersWithContent : EVA.PIM.Core.LayerWithContentDto[]; 
    Types : { [ key : string ] : any }; 
  }
  
  export class LayerWithContentDto {
    ID : number; // Int32
    Name : string; 
    Level : number; // Int32
    ApplicationID : number; // Int32, nullable
    LanguageID : string; 
    CountryID : string; 
    Content : any; 
    Description : string; 
    DisplayValue : string; 
  }
  
  export class GetProductForQuickEditByID extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.GetProductForQuickEditByIDResponse> {
    ID : number; // Int32
    __response : EVA.PIM.Core.GetProductForQuickEditByIDResponse;
  }
  
  export class GetProductForQuickEditByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    CatalogID : number; // Int32
    DisplayValue : string; 
    Content : any; 
    Types : { [ key : string ] : any }; 
  }
  
  export class GetReferenceDataForProduct extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.GetReferenceDataForProductResponse> {
    ProductID : number; // Int32
    __response : EVA.PIM.Core.GetReferenceDataForProductResponse;
  }
  
  export class GetReferenceDataForProductResponse extends EVA.Core.ResponseMessage {
    Data : { [ key : string ] : any }; 
  }
  
  export class PreviewProduct extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.PreviewProductResponse> {
    ID : number; // Int32
    RevisionID : number; // Int32, nullable
    Edits : EVA.PIM.Core.PreviewProductEdit[]; 
    DoPostProcessing : boolean; 
    __response : EVA.PIM.Core.PreviewProductResponse;
  }
  
  export class PreviewProductResponse extends EVA.Core.ResponseMessage {
    Result : any; 
    Types : { [ key : string ] : any }; 
  }
  
  export class PreviewProductEdit {
    LayerID : number; // Int32
    Content : any; 
  }
  
  export class ReindexProduct extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateProductPropertyType extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.CreateProductPropertyTypeResponse> {
    TypeID : string; 
    CategoryID : string; 
    Intent : EVA.PIM.Core.ProductPropertyTypeIntents; 
    DataType : EVA.PIM.Core.ProductPropertyTypeDataTypes; 
    SearchType : EVA.PIM.Core.ProductPropertyTypeSearchTypes; 
    IsArray : boolean; 
    IsEnum : boolean; 
    EditFunctionality : string; 
    __response : EVA.PIM.Core.CreateProductPropertyTypeResponse;
  }
  
  export class CreateProductPropertyTypeResponse extends EVA.Core.ResponseMessage {
  }
  
  export enum ProductPropertyTypeIntents {
    RichAttribute = 0,
    SimpleField = 1,
    RootLevelOnly = 2,
  }
  
  export enum ProductPropertyTypeDataTypes {
    None = 0,
    Integer = 1,
    Double = 2,
    Boolean = 3,
    String = 4,
    Blob = 5,
    Date = 6,
    RichText = 7,
  }
  
  export enum ProductPropertyTypeSearchTypes {
    None = 0,
    Keyword = 1,
    Text = 2,
    IsHidden = 4,
    IsAggregatable = 9,
    IncludeInAll = 16,
  }
  
  export class EditProductPropertyType extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.EditProductPropertyTypeResponse> {
    ID : string; 
    RevisionID : number; // Int32, nullable
    Edits : EVA.PIM.Core.ProductPropertyTypeEdit[]; 
    SearchType : EVA.PIM.Core.ProductPropertyTypeSearchTypes; 
    __response : EVA.PIM.Core.EditProductPropertyTypeResponse;
  }
  
  export class EditProductPropertyTypeResponse extends EVA.Core.ResponseMessage {
  }
  
  export class ProductPropertyTypeEdit {
    LayerID : number; // Int32
    Content : any; 
  }
  
  export class GetAvailableEnumValuesForProductPropertyType extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.GetAvailableEnumValuesForProductPropertyTypeResponse> {
    TypeID : string; 
    __response : EVA.PIM.Core.GetAvailableEnumValuesForProductPropertyTypeResponse;
  }
  
  export class GetAvailableEnumValuesForProductPropertyTypeResponse extends EVA.Core.ResponseMessage {
    Values : { [ key : number ] : string }; 
  }
  
  export class GetProductPropertyTypeByID extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.GetProductPropertyTypeByIDResponse> {
    ID : string; 
    RevisionID : number; // Int32
    __response : EVA.PIM.Core.GetProductPropertyTypeByIDResponse;
  }
  
  export class GetProductPropertyTypeByIDResponse extends EVA.Core.ResponseMessage {
    ID : string; 
    CatalogID : number; // Int32
    LayersWithContent : EVA.PIM.Core.LayerWithContentDto[]; 
    CategoryID : string; 
  }
  
  export class ListProductPropertyTypes extends EVA.Core.PagedResultRequest<EVA.PIM.Core.ListProductPropertyTypesResponse> {
    __response : EVA.PIM.Core.ListProductPropertyTypesResponse;
  }
  
  export class ListProductPropertyTypesResponse extends EVA.Core.PagedResultResponse<EVA.PIM.Core.ListProductPropertyTypesDto> {
  }
  
  export class ListProductPropertyTypesDto {
    ID : string; 
    DisplayName : string; 
    CategoryID : string; 
    CategoryDisplayName : string; 
    DataType : EVA.PIM.Core.ProductPropertyTypeDataTypes; 
  }
  
  export class PreviewProductPropertyType extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.PreviewProductPropertyTypeResponse> {
    ID : string; 
    RevisionID : number; // Int32
    Edits : EVA.PIM.Core.ProductPropertyTypeEdit[]; 
    __response : EVA.PIM.Core.PreviewProductPropertyTypeResponse;
  }
  
  export class PreviewProductPropertyTypeResponse extends EVA.Core.ResponseMessage {
    Result : any; 
  }
  
  export class GetProductPropertyTypeEnumValueByID extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.GetProductPropertyTypeEnumValueByIDResponse> {
    ID : number; // Int32
    __response : EVA.PIM.Core.GetProductPropertyTypeEnumValueByIDResponse;
  }
  
  export class GetProductPropertyTypeEnumValueByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    ProductPropertyTypeID : string; 
    CatalogID : number; // Int32
    Identifier : number; // Int32
    Value : string; 
    LanguageID : string; 
    CountryID : string; 
  }
  
  export class CreateProductPropertyTypeEnumValue extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.CreateProductPropertyTypeEnumValueResponse> {
    ProductPropertyTypeID : string; 
    Identifier : number; // Int32
    Value : string; 
    LanguageID : string; 
    CountryID : string; 
    __response : EVA.PIM.Core.CreateProductPropertyTypeEnumValueResponse;
  }
  
  export class CreateProductPropertyTypeEnumValueResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class UpdateProductPropertyTypeEnumValue extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Identifier : number; // Int32
    Value : string; 
    LanguageID : string; 
    CountryID : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteProductPropertyTypeEnumValue extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListProductPropertyTypeEnumValues extends EVA.Core.PagedResultRequest<EVA.PIM.Core.ListProductPropertyTypeEnumValuesResponse> {
    __response : EVA.PIM.Core.ListProductPropertyTypeEnumValuesResponse;
  }
  
  export class ListProductPropertyTypeEnumValuesResponse extends EVA.Core.PagedResultResponse<EVA.PIM.Core.ListProductPropertyTypeEnumValuesResponseProductPropertyTypeEnumValueDto> {
  }
  
  export class ListProductPropertyTypeEnumValuesResponseProductPropertyTypeEnumValueDto {
    ID : number; // Int32
    ProductPropertyTypeID : string; 
    Identifier : number; // Int32
    Value : string; 
    LanguageID : string; 
    CountryID : string; 
  }
  
  export class SearchProductPropertyTypes extends EVA.Core.PagedResultRequest<EVA.PIM.Core.SearchProductPropertyTypesResponse> {
    Query : string; 
    __response : EVA.PIM.Core.SearchProductPropertyTypesResponse;
  }
  
  export class SearchProductPropertyTypesResponse extends EVA.Core.PagedResultResponse<any> {
  }
  
  export class CreateProductPropertyCategory extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.CreateProductPropertyCategoryResponse> {
    CategoryID : string; 
    EditFunctionality : string; 
    __response : EVA.PIM.Core.CreateProductPropertyCategoryResponse;
  }
  
  export class CreateProductPropertyCategoryResponse extends EVA.Core.ResponseMessage {
  }
  
  export class EditProductPropertyCategory extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.EditProductPropertyCategoryResponse> {
    ID : string; 
    RevisionID : number; // Int32
    Edits : EVA.PIM.Core.ProductPropertyCategoryEdit[]; 
    __response : EVA.PIM.Core.EditProductPropertyCategoryResponse;
  }
  
  export class EditProductPropertyCategoryResponse extends EVA.Core.ResponseMessage {
  }
  
  export class ProductPropertyCategoryEdit {
    LayerID : number; // Int32
    Content : any; 
  }
  
  export class GetProductPropertyCategoryByID extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.GetProductPropertyCategoryByIDResponse> {
    ID : string; 
    RevisionID : number; // Int32
    __response : EVA.PIM.Core.GetProductPropertyCategoryByIDResponse;
  }
  
  export class GetProductPropertyCategoryByIDResponse extends EVA.Core.ResponseMessage {
    ID : string; 
    CatalogID : number; // Int32
    LayersWithContent : EVA.PIM.Core.LayerWithContentDto[]; 
  }
  
  export class ListProductPropertyCategories extends EVA.Core.PagedResultRequest<EVA.PIM.Core.ListProductPropertyCategoriesResponse> {
    __response : EVA.PIM.Core.ListProductPropertyCategoriesResponse;
  }
  
  export class ListProductPropertyCategoriesResponse extends EVA.Core.PagedResultResponse<EVA.PIM.Core.ListProductPropertyCategoriesDto> {
  }
  
  export class ListProductPropertyCategoriesDto {
    ID : string; 
    DisplayName : string; 
  }
  
  export class PreviewProductPropertyCategory extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.PreviewProductPropertyCategoryResponse> {
    ID : string; 
    RevisionID : number; // Int32
    Edits : EVA.PIM.Core.ProductPropertyCategoryEdit[]; 
    __response : EVA.PIM.Core.PreviewProductPropertyCategoryResponse;
  }
  
  export class PreviewProductPropertyCategoryResponse extends EVA.Core.ResponseMessage {
    Result : any; 
  }
  
  export class ListApplicationCultures extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.ListApplicationCulturesResponse> {
    __response : EVA.PIM.Core.ListApplicationCulturesResponse;
  }
  
  export class ListApplicationCulturesResponse extends EVA.Core.ResponseMessage {
    Result : EVA.PIM.Core.ListApplicationContentCulture[]; 
  }
  
  export class ListApplicationContentCulture {
    ApplicationID : number; // Int32
    LanguageID : string; 
    CountryID : string; 
    Culture : string; 
  }
  
  export class CreateLayer extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.CreateLayerResponse> {
    ApplicationID : number; // Int32, nullable
    CountryID : string; 
    Description : string; 
    LanguageID : string; 
    Level : number; // Int32
    Name : string; 
    __response : EVA.PIM.Core.CreateLayerResponse;
  }
  
  export class CreateLayerResponse extends EVA.Core.ResponseMessage {
    Result : EVA.PIM.Core.CreatedLayer; 
  }
  
  export class CreatedLayer {
    ID : number; // Int32
    Name : string; 
    ApplicationID : number; // Int32, nullable
    Description : string; 
    Level : number; // Int32
    CountryID : string; 
  }
  
  export class GetLayerByID extends EVA.Core.RequestMessageGeneric<EVA.PIM.Core.GetLayerByIDResponse> {
    ID : number; // Int32
    __response : EVA.PIM.Core.GetLayerByIDResponse;
  }
  
  export class GetLayerByIDResponse extends EVA.Core.ResponseMessage {
    Layer : EVA.PIM.Core.LayerDto; 
  }
  
  export class LayerDto {
    ID : number; // Int32
    Description : string; 
    Level : number; // Int32
    ApplicationID : number; // Int32, nullable
    LanguageID : string; 
    CatalogID : number; // Int32
    RevisionID : number; // Int32, nullable
    Name : string; 
    CountryID : string; 
    Type : EVA.PIM.Core.ContentLayerTypes; 
  }
  
  export enum ContentLayerTypes {
    UserLayer = 0,
    SystemLayer = 1,
  }
  
  export class ListLayers extends EVA.Core.PagedResultRequest<EVA.PIM.Core.ListLayersResponse> {
    __response : EVA.PIM.Core.ListLayersResponse;
  }
  
  export class ListLayersResponse extends EVA.Core.PagedResultResponse<EVA.PIM.Core.LayerDto> {
  }
  
  export class UpdateLayer extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Name : string; 
    Description : string; 
    Level : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateBrand extends EVA.Core.RequestMessageWithEmptyResponse {
    BackendID : string; 
    Name : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetBrand extends EVA.Core.GetRequestGeneric<EVA.PIM.Core.GetBrandResponse> {
    __response : EVA.PIM.Core.GetBrandResponse;
  }
  
  export class GetBrandResponse extends EVA.Core.ResponseMessage {
    Result : EVA.PIM.Core.BrandDto; 
  }
  
  export class BrandDto {
    ID : number; // Int32
    Name : string; 
    BackendID : string; 
  }
  
  export class UpdateBrand extends EVA.Core.UpdateRequest<EVA.PIM.Core.BrandDto> implements EVA.Core.IRequestRespondsAs<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export enum ContentEditTypes {
    Product = 1,
    ProductPropertyType = 2,
    ProductPropertyCategory = 3,
  }
  
  export enum ContentMergeTypes {
    MergeRevisions = 0,
    MergeArrays = 1,
    MergeLayers = 2,
  }
  
  export enum ProductPropertyTypeInheritanceTypes {
    NormalInheritance = 0,
    NoInheritance = 1,
  }
  
  export enum ProductPropertyTypeRequired {
    NotRequired = 0,
    RequiredOnEdit = 1,
    RequireOnApplyRevision = 2,
  }
  
  export enum RevisionTypes {
    UserRevision = 0,
    SystemRevision = 1,
  }
  
  export class ConfigurableProductDto {
    ProductID : number; // Int32
    Type : EVA.Core.ProductTypes; 
    Status : EVA.Core.ProductStatus; 
    LogicalLevel : string; 
    ConfigurableProperty : string; 
    Value : any; 
    Values : any[]; 
    Children : EVA.PIM.Core.ConfigurableProductDto[]; 
    Properties : any; 
  }
  
}
/* tslint:disable */
declare module EVA.Payment.Acapture {
  
  export class ListAcaptureIdealBanks extends EVA.Core.RequestMessageGeneric<EVA.Payment.Acapture.ListAcaptureIdealBanksResponse> {
    __response : EVA.Payment.Acapture.ListAcaptureIdealBanksResponse;
  }
  
  export class ListAcaptureIdealBanksResponse extends EVA.Core.ResponseMessage {
    Banks : { [ key : string ] : string }; 
  }
  
}
/* tslint:disable */
declare module EVA.Payment.Cash {
  
  export class OpenCashDrawer extends EVA.Core.RequestMessageGeneric<EVA.Payment.Cash.OpenCashDrawerResponse> {
    StationID : number; // Int32, nullable
    __response : EVA.Payment.Cash.OpenCashDrawerResponse;
  }
  
  export class OpenCashDrawerResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Core.OpenCashDrawerResults; 
  }
  
}
/* tslint:disable */
declare module EVA.Payment.MultiSafepay {
  
  export class GetMultiSafepayGateways extends EVA.Core.RequestMessageGeneric<EVA.Payment.MultiSafepay.GetMultiSafepayGatewaysResponse> {
    OrderID : number; // Int32
    __response : EVA.Payment.MultiSafepay.GetMultiSafepayGatewaysResponse;
  }
  
  export class GetMultiSafepayGatewaysResponse extends EVA.Core.ResponseMessage {
    Gateways : { [ key : string ] : string }; 
  }
  
}
/* tslint:disable */
declare module EVA.Payment.UserCard {
  
  export class CancelPendingUserCardPayment extends EVA.Core.RequestMessageWithEmptyResponse {
    PaymentTransactionID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateUserCardMutation extends EVA.Core.RequestMessageWithEmptyResponse {
    UserCardID : number; // Int32
    Amount : number; // Decimal
    Description : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateUserCard extends EVA.Core.RequestMessageGeneric<EVA.Payment.UserCard.CreateUserCardResponse> {
    UserID : number; // Int32, nullable
    CurrencyID : string; 
    UserCardTypeID : number; // Int32
    __response : EVA.Payment.UserCard.CreateUserCardResponse;
  }
  
  export class CreateUserCardResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class GetUserCardBalance extends EVA.Core.RequestMessageGeneric<EVA.Payment.UserCard.GetUserCardBalanceResponse> {
    UserCardID : number; // Int32
    CurrencyID : string; 
    __response : EVA.Payment.UserCard.GetUserCardBalanceResponse;
  }
  
  export class GetUserCardBalanceResponse extends EVA.Core.ResponseMessage {
    CurrentBalance : EVA.Core.UserCardBalance; 
  }
  
  export class GetUserCardDetails extends EVA.Core.RequestMessageGeneric<EVA.Payment.UserCard.GetUserCardDetailsResponse> {
    UserCardID : number; // Int32, nullable
    CardNumber : string; 
    CurrencyID : string; 
    __response : EVA.Payment.UserCard.GetUserCardDetailsResponse;
  }
  
  export class GetUserCardDetailsResponse extends EVA.Core.ResponseMessage {
    UserCard : EVA.Core.UserCardDto; 
  }
  
  export class GetUserCardDiscounts extends EVA.Core.RequestMessageGeneric<EVA.Payment.UserCard.GetUserCardDiscountsResponse> {
    UserID : number; // Int32
    __response : EVA.Payment.UserCard.GetUserCardDiscountsResponse;
  }
  
  export class GetUserCardDiscountsResponse extends EVA.Core.ResponseMessage {
    UserCard : EVA.Core.DiscountDto[]; 
  }
  
  export class GetUserCardTypes extends EVA.Core.RequestMessageGeneric<EVA.Payment.UserCard.GetUserCardTypesResponse> {
    __response : EVA.Payment.UserCard.GetUserCardTypesResponse;
  }
  
  export class GetUserCardTypesResponse extends EVA.Core.ResponseMessage {
    Types : EVA.Core.UserCardTypeDto[]; 
  }
  
  export class ListUserCardMutations extends EVA.Core.PagedResultRequest<EVA.Payment.UserCard.ListUserCardMutationsResponse> {
    UserCardID : number; // Int32
    __response : EVA.Payment.UserCard.ListUserCardMutationsResponse;
  }
  
  export class ListUserCardMutationsResponse extends EVA.Core.PagedResultResponse<EVA.Payment.UserCard.ListUserCardMutationsDto> {
  }
  
  export class ListUserCardMutationsDto {
    Amount : number; // Decimal
    CreationTime : string; // DateTime
    Description : string; 
    Status : EVA.Core.UserCardMutationStatuses; 
  }
  
  export class ListUserCardsForUser extends EVA.Core.RequestMessageGeneric<EVA.Payment.UserCard.ListUserCardsForUserResponse> {
    UserID : number; // Int32, nullable
    CurrencyID : string; 
    __response : EVA.Payment.UserCard.ListUserCardsForUserResponse;
  }
  
  export class ListUserCardsForUserResponse extends EVA.Core.ResponseMessage {
    UserCards : EVA.Core.UserCardDto[]; 
  }
  
  export class ListUserCards extends EVA.Core.PagedResultRequest<EVA.Payment.UserCard.ListUserCardsResponse> {
    __response : EVA.Payment.UserCard.ListUserCardsResponse;
  }
  
  export class ListUserCardsResponse extends EVA.Core.PagedResultResponse<EVA.Payment.UserCard.ListUserCardDto> {
  }
  
  export class ListUserCardDto {
    Barcode : string; 
    ID : number; // Int32
    Type : EVA.Core.UserCardTypeDto; 
    UserFullName : string; 
  }
  
}
/* tslint:disable */
declare module EVA.Pin.PayPlaza2 {
  
  export class PrintLastReceiptCallback extends EVA.Core.RequestMessageWithEmptyResponse {
    StationID : number; // Int32
    ReceiptLines : string[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class PrintLastReceipt extends EVA.Core.RequestMessageGeneric<EVA.Pin.PayPlaza2.PrintLastReceiptResponse> {
    StationID : number; // Int32
    DeviceID : number; // Int32
    __response : EVA.Pin.PayPlaza2.PrintLastReceiptResponse;
  }
  
  export class PrintLastReceiptResponse extends EVA.Core.ResponseMessage {
    Success : boolean; 
  }
  
  export class PrintPinReceipt extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    ECRID : string; 
    OrderReference : string; 
    ReceiptLines : string[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
}
/* tslint:disable */
declare module EVA.Pin {
  
  export enum TransactionType {
    Purchase = 0,
    Refund = 1,
  }
  
  export class AbortTransaction extends EVA.Core.RequestMessageGeneric<EVA.Pin.AbortTransactionResponse> {
    StationID : number; // Int32, nullable
    HardwareID : string; 
    UseHardwareID : boolean; 
    __response : EVA.Pin.AbortTransactionResponse;
  }
  
  export class AbortTransactionResponse extends EVA.Core.ResponseMessage {
    ResultStatus : EVA.Core.OverallPinResultStatus; 
  }
  
  export class StartTransaction extends EVA.Core.RequestMessageGeneric<EVA.Pin.StartTransactionResponse> {
    PaymentTransactionID : number; // Int32
    HardwareID : string; 
    UseHardwareID : boolean; 
    StationID : number; // Int32, nullable
    __response : EVA.Pin.StartTransactionResponse;
  }
  
  export class StartTransactionResponse extends EVA.Core.ResponseMessage {
    ResultStatus : EVA.Core.OverallPinResultStatus; 
    ResultStatusString : string; 
    OpenAmount : number; // Decimal
    CardCircuit : string; 
    LocalTerminalAddress : string; 
  }
  
}
/* tslint:disable */
declare module EVA.Replenishment {
  
  export class ExportShelfTemplate extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    ShelfIDs : number[]; 
    __response : EVA.Core.ResourceResponseMessage;
  }
  
  export class ImportShelfTemplate extends EVA.Core.RequestMessageWithEmptyResponse {
    Data : number[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetOrganizationUnitDistributionTree extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.GetOrganizationUnitDistributionTreeResponse> {
    __response : EVA.Replenishment.GetOrganizationUnitDistributionTreeResponse;
  }
  
  export class GetOrganizationUnitDistributionTreeResponse extends EVA.Core.ResponseMessage {
    Tree : EVA.Replenishment.TreeNode; 
  }
  
  export class TreeNode {
    Fraction : number; // Decimal, nullable
    OrganizationUnitIDs : number[]; 
    OrganizationUnitTypeID : number; // Int32, nullable
    Negation : boolean; 
    Nodes : EVA.Replenishment.TreeNode[]; 
  }
  
  export class UpdateOrganizationUnitDistributionTree extends EVA.Core.RequestMessageWithEmptyResponse {
    Tree : EVA.Replenishment.TreeNode; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetOrganizationUnitShelfByID extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.GetOrganizationUnitShelfByIDResponse> {
    ID : number; // Int32
    __response : EVA.Replenishment.GetOrganizationUnitShelfByIDResponse;
  }
  
  export class GetOrganizationUnitShelfByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    ShelfID : number; // Int32
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnitTypeID : number; // Int32, nullable
  }
  
  export class CreateOrganizationUnitShelf extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.CreateOrganizationUnitShelfResponse> {
    ShelfID : number; // Int32
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnitTypeID : number; // Int32, nullable
    __response : EVA.Replenishment.CreateOrganizationUnitShelfResponse;
  }
  
  export class CreateOrganizationUnitShelfResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class UpdateOrganizationUnitShelf extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    ShelfID : number; // Int32
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnitTypeID : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteOrganizationUnitShelf extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListOrganizationUnitShelves extends EVA.Core.PagedResultRequest<EVA.Replenishment.ListOrganizationUnitShelvesResponse> {
    __response : EVA.Replenishment.ListOrganizationUnitShelvesResponse;
  }
  
  export class ListOrganizationUnitShelvesResponse extends EVA.Core.PagedResultResponse<EVA.Replenishment.ListOrganizationUnitShelvesResponseOrganizationUnitShelfDto> {
  }
  
  export class ListOrganizationUnitShelvesResponseOrganizationUnitShelfDto {
    ID : number; // Int32
    ShelfID : number; // Int32
    Shelf : EVA.Replenishment.ListOrganizationUnitShelvesResponseShelfDto; 
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnit : EVA.Core.OrganizationUnitDto; 
    OrganizationUnitTypeID : number; // Int32, nullable
  }
  
  export class ListOrganizationUnitShelvesResponseShelfDto {
    ID : number; // Int32
    Name : string; 
    Description : string; 
    StartDateTime : string; // DateTime
    EndDateTime : string; // DateTime, nullable
    TypeID : number; // Int32
    Type : EVA.Core.EnumDtoBase; 
    Height : number; // Int32
    Width : number; // Int32
    Depth : number; // Int32
  }
  
  export class GetProductRestrictionByID extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.GetProductRestrictionByIDResponse> {
    ID : number; // Int32
    __response : EVA.Replenishment.GetProductRestrictionByIDResponse;
  }
  
  export class GetProductRestrictionByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    ProductID : number; // Int32
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnitTypeID : number; // Int32, nullable
    MaximumReplenismentQuantity : number; // Int32, nullable
    MaximumStockQuantity : number; // Int32, nullable
  }
  
  export class CreateProductRestriction extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.CreateProductRestrictionResponse> {
    ProductID : number; // Int32
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnitTypeID : number; // Int32, nullable
    MaximumReplenismentQuantity : number; // Int32, nullable
    MaximumStockQuantity : number; // Int32, nullable
    __response : EVA.Replenishment.CreateProductRestrictionResponse;
  }
  
  export class CreateProductRestrictionResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class UpdateProductRestriction extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    ProductID : number; // Int32
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnitTypeID : number; // Int32, nullable
    MaximumReplenismentQuantity : number; // Int32, nullable
    MaximumStockQuantity : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteProductRestriction extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListProductRestrictions extends EVA.Core.PagedResultRequest<EVA.Replenishment.ListProductRestrictionsResponse> {
    __response : EVA.Replenishment.ListProductRestrictionsResponse;
  }
  
  export class ListProductRestrictionsResponse extends EVA.Core.PagedResultResponse<EVA.Replenishment.ListProductRestrictionsResponseProductRestrictionDto> {
  }
  
  export class ListProductRestrictionsResponseProductRestrictionDto {
    ID : number; // Int32
    ProductID : number; // Int32
    Product : EVA.Replenishment.ListProductRestrictionsResponseProductDto; 
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnitTypeID : number; // Int32, nullable
    MaximumReplenismentQuantity : number; // Int32, nullable
    MaximumStockQuantity : number; // Int32, nullable
  }
  
  export class ListProductRestrictionsResponseProductDto {
    BackendID : string; 
    DisplayValue : string; 
  }
  
  export class GetShelfBlobByID extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.GetShelfBlobByIDResponse> {
    ID : number; // Int32
    __response : EVA.Replenishment.GetShelfBlobByIDResponse;
  }
  
  export class GetShelfBlobByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    ShelfID : number; // Int32
    BlobID : string; 
  }
  
  export class CreateShelfBlob extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.CreateShelfBlobResponse> {
    ShelfID : number; // Int32
    BlobID : string; 
    __response : EVA.Replenishment.CreateShelfBlobResponse;
  }
  
  export class CreateShelfBlobResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class UpdateShelfBlob extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    ShelfID : number; // Int32
    BlobID : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteShelfBlob extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListShelfBlobs extends EVA.Core.PagedResultRequest<EVA.Replenishment.ListShelfBlobsResponse> {
    __response : EVA.Replenishment.ListShelfBlobsResponse;
  }
  
  export class ListShelfBlobsResponse extends EVA.Core.PagedResultResponse<EVA.Replenishment.ListShelfBlobsResponseShelfBlobDto> {
  }
  
  export class ListShelfBlobsResponseShelfBlobDto {
    ID : number; // Int32
    ShelfID : number; // Int32
    BlobID : string; 
  }
  
  export class GetShelfByID extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.GetShelfByIDResponse> {
    ID : number; // Int32
    __response : EVA.Replenishment.GetShelfByIDResponse;
  }
  
  export class GetShelfByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    Name : string; 
    Description : string; 
    StartDateTime : string; // DateTime
    EndDateTime : string; // DateTime, nullable
    TypeID : number; // Int32
    Height : number; // Int32
    Width : number; // Int32
    Depth : number; // Int32
  }
  
  export class CreateShelf extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.CreateShelfResponse> {
    Name : string; 
    Description : string; 
    StartDateTime : string; // DateTime
    EndDateTime : string; // DateTime, nullable
    TypeID : number; // Int32
    Height : number; // Int32
    Width : number; // Int32
    Depth : number; // Int32
    __response : EVA.Replenishment.CreateShelfResponse;
  }
  
  export class CreateShelfResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class UpdateShelf extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Name : string; 
    Description : string; 
    StartDateTime : string; // DateTime
    EndDateTime : string; // DateTime, nullable
    TypeID : number; // Int32
    Height : number; // Int32
    Width : number; // Int32
    Depth : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteShelf extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListShelves extends EVA.Core.PagedResultRequest<EVA.Replenishment.ListShelvesResponse> {
    __response : EVA.Replenishment.ListShelvesResponse;
  }
  
  export class ListShelvesResponse extends EVA.Core.PagedResultResponse<EVA.Replenishment.ListShelvesResponseShelfDto> {
  }
  
  export class ListShelvesResponseShelfDto {
    ID : number; // Int32
    Name : string; 
    Description : string; 
    StartDateTime : string; // DateTime
    EndDateTime : string; // DateTime, nullable
    TypeID : number; // Int32
    Type : EVA.Core.EnumDtoBase; 
    Height : number; // Int32
    Width : number; // Int32
    Depth : number; // Int32
  }
  
  export class DuplicateShelf extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.DuplicateShelfResponse> {
    ShelfID : number; // Int32
    Name : string; 
    StartDateTime : string; // DateTime
    EndDateTime : string; // DateTime, nullable
    __response : EVA.Replenishment.DuplicateShelfResponse;
  }
  
  export class DuplicateShelfResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class GetShelfLocationBlobByID extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.GetShelfLocationBlobByIDResponse> {
    ID : number; // Int32
    __response : EVA.Replenishment.GetShelfLocationBlobByIDResponse;
  }
  
  export class GetShelfLocationBlobByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    ShelfLocationID : number; // Int32
    BlobID : string; 
  }
  
  export class CreateShelfLocationBlob extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.CreateShelfLocationBlobResponse> {
    ShelfLocationID : number; // Int32
    BlobID : string; 
    __response : EVA.Replenishment.CreateShelfLocationBlobResponse;
  }
  
  export class CreateShelfLocationBlobResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class UpdateShelfLocationBlob extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    ShelfLocationID : number; // Int32
    BlobID : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteShelfLocationBlob extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListShelfLocationBlobs extends EVA.Core.PagedResultRequest<EVA.Replenishment.ListShelfLocationBlobsResponse> {
    __response : EVA.Replenishment.ListShelfLocationBlobsResponse;
  }
  
  export class ListShelfLocationBlobsResponse extends EVA.Core.PagedResultResponse<EVA.Replenishment.ListShelfLocationBlobsResponseShelfLocationBlobDto> {
  }
  
  export class ListShelfLocationBlobsResponseShelfLocationBlobDto {
    ID : number; // Int32
    ShelfLocationID : number; // Int32
    BlobID : string; 
  }
  
  export class GetShelfLocationByID extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.GetShelfLocationByIDResponse> {
    ID : number; // Int32
    __response : EVA.Replenishment.GetShelfLocationByIDResponse;
  }
  
  export class GetShelfLocationByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    ShelfID : number; // Int32
    ParentID : number; // Int32, nullable
    TemplateID : number; // Int32
    Name : string; 
  }
  
  export class CreateShelfLocation extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.CreateShelfLocationResponse> {
    ShelfID : number; // Int32
    ParentID : number; // Int32, nullable
    TemplateID : number; // Int32
    Name : string; 
    __response : EVA.Replenishment.CreateShelfLocationResponse;
  }
  
  export class CreateShelfLocationResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class UpdateShelfLocation extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    ParentID : number; // Int32, nullable
    TemplateID : number; // Int32
    Name : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteShelfLocation extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListShelfLocations extends EVA.Core.PagedResultRequest<EVA.Replenishment.ListShelfLocationsResponse> {
    __response : EVA.Replenishment.ListShelfLocationsResponse;
  }
  
  export class ListShelfLocationsResponse extends EVA.Core.PagedResultResponse<EVA.Replenishment.ListShelfLocationsResponseShelfLocationDto> {
  }
  
  export class ListShelfLocationsResponseShelfLocationDto {
    ID : number; // Int32
    ShelfID : number; // Int32
    ParentID : number; // Int32, nullable
    TemplateID : number; // Int32
    Name : string; 
  }
  
  export class GetShelfLocationProductByID extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.GetShelfLocationProductByIDResponse> {
    ID : number; // Int32
    __response : EVA.Replenishment.GetShelfLocationProductByIDResponse;
  }
  
  export class GetShelfLocationProductByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    ShelfLocationID : number; // Int32
    ProductID : number; // Int32
    MinimumQuantity : number; // Int32
    MaximumQuantity : number; // Int32
  }
  
  export class CreateShelfLocationProduct extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.CreateShelfLocationProductResponse> {
    ShelfLocationID : number; // Int32
    ProductID : number; // Int32
    MinimumQuantity : number; // Int32
    MaximumQuantity : number; // Int32
    __response : EVA.Replenishment.CreateShelfLocationProductResponse;
  }
  
  export class CreateShelfLocationProductResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class CreateShelfLocationProducts extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.CreateShelfLocationProductsResponse> {
    ShelfLocationID : number; // Int32
    Products : EVA.Replenishment.CreateShelfLocationProductsProduct[]; 
    __response : EVA.Replenishment.CreateShelfLocationProductsResponse;
  }
  
  export class CreateShelfLocationProductsResponse extends EVA.Core.ResponseMessage {
    IDs : number[]; 
  }
  
  export class CreateShelfLocationProductsProduct {
    ProductID : number; // Int32
    MinimumQuantity : number; // Int32
    MaximumQuantity : number; // Int32
  }
  
  export class UpdateShelfLocationProduct extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    MinimumQuantity : number; // Int32
    MaximumQuantity : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteShelfLocationProduct extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListShelfLocationProducts extends EVA.Core.PagedResultRequest<EVA.Replenishment.ListShelfLocationProductsResponse> {
    __response : EVA.Replenishment.ListShelfLocationProductsResponse;
  }
  
  export class ListShelfLocationProductsResponse extends EVA.Core.PagedResultResponse<EVA.Replenishment.ListShelfLocationProductsResponseShelfLocationProductDto> {
  }
  
  export class ListShelfLocationProductsResponseShelfLocationProductDto {
    ID : number; // Int32
    ShelfLocationID : number; // Int32
    ProductID : number; // Int32
    Product : EVA.Replenishment.ListShelfLocationProductsResponseShelfProductDto; 
    MinimumQuantity : number; // Int32
    MaximumQuantity : number; // Int32
  }
  
  export class ListShelfLocationProductsResponseShelfProductDto {
    BackendID : string; 
    CustomID : string; 
    DisplayValue : string; 
    DisplayPrice : number; // Decimal, nullable
  }
  
  export class UploadShelfLocationProducts extends EVA.Core.RequestMessageWithEmptyResponse {
    ShelfLocationID : number; // Int32
    Data : number[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DownloadShelfLocationProducts extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    ShelfLocationID : number; // Int32
    __response : EVA.Core.ResourceResponseMessage;
  }
  
  export class GetShelfLocationTemplateByID extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.GetShelfLocationTemplateByIDResponse> {
    ID : number; // Int32
    __response : EVA.Replenishment.GetShelfLocationTemplateByIDResponse;
  }
  
  export class GetShelfLocationTemplateByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    TypeID : number; // Int32
    Name : string; 
    ProductLimit : number; // Int32, nullable
    Height : number; // Int32
    Width : number; // Int32
    Depth : number; // Int32
  }
  
  export class CreateShelfLocationTemplate extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.CreateShelfLocationTemplateResponse> {
    TypeID : number; // Int32
    Name : string; 
    ProductLimit : number; // Int32, nullable
    Height : number; // Int32
    Width : number; // Int32
    Depth : number; // Int32
    __response : EVA.Replenishment.CreateShelfLocationTemplateResponse;
  }
  
  export class CreateShelfLocationTemplateResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class UpdateShelfLocationTemplate extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    TypeID : number; // Int32
    Name : string; 
    ProductLimit : number; // Int32, nullable
    Height : number; // Int32
    Width : number; // Int32
    Depth : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteShelfLocationTemplate extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListShelfLocationTemplates extends EVA.Core.PagedResultRequest<EVA.Replenishment.ListShelfLocationTemplatesResponse> {
    __response : EVA.Replenishment.ListShelfLocationTemplatesResponse;
  }
  
  export class ListShelfLocationTemplatesResponse extends EVA.Core.PagedResultResponse<EVA.Replenishment.ListShelfLocationTemplatesResponseShelfLocationTemplateDto> {
  }
  
  export class ListShelfLocationTemplatesResponseShelfLocationTemplateDto {
    ID : number; // Int32
    TypeID : number; // Int32
    Name : string; 
    ProductLimit : number; // Int32, nullable
    Height : number; // Int32
    Width : number; // Int32
    Depth : number; // Int32
  }
  
  export class GetShelfLocationTemplateTypeByID extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.GetShelfLocationTemplateTypeByIDResponse> {
    ID : number; // Int32
    __response : EVA.Replenishment.GetShelfLocationTemplateTypeByIDResponse;
  }
  
  export class GetShelfLocationTemplateTypeByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    Name : string; 
    Description : string; 
  }
  
  export class CreateShelfLocationTemplateType extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.CreateShelfLocationTemplateTypeResponse> {
    Name : string; 
    Description : string; 
    __response : EVA.Replenishment.CreateShelfLocationTemplateTypeResponse;
  }
  
  export class CreateShelfLocationTemplateTypeResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class UpdateShelfLocationTemplateType extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Description : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteShelfLocationTemplateType extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetShelfLocationTemplateTypes extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.GetShelfLocationTemplateTypesResponse> {
    __response : EVA.Replenishment.GetShelfLocationTemplateTypesResponse;
  }
  
  export class GetShelfLocationTemplateTypesResponse extends EVA.Core.ResponseMessage {
    ShelfLocationTemplateTypes : EVA.Replenishment.GetShelfLocationTemplateTypesResponseShelfLocationTemplateTypeDto[]; 
  }
  
  export class GetShelfLocationTemplateTypesResponseShelfLocationTemplateTypeDto {
    ID : number; // Int32
    Name : string; 
    Description : string; 
  }
  
  export class GetShelfTypeByID extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.GetShelfTypeByIDResponse> {
    ID : number; // Int32
    __response : EVA.Replenishment.GetShelfTypeByIDResponse;
  }
  
  export class GetShelfTypeByIDResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
    Name : string; 
    Description : string; 
  }
  
  export class CreateShelfType extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.CreateShelfTypeResponse> {
    Name : string; 
    Description : string; 
    __response : EVA.Replenishment.CreateShelfTypeResponse;
  }
  
  export class CreateShelfTypeResponse extends EVA.Core.ResponseMessage {
    ID : number; // Int32
  }
  
  export class UpdateShelfType extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    Description : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class DeleteShelfType extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetShelfTypes extends EVA.Core.RequestMessageGeneric<EVA.Replenishment.GetShelfTypesResponse> {
    __response : EVA.Replenishment.GetShelfTypesResponse;
  }
  
  export class GetShelfTypesResponse extends EVA.Core.ResponseMessage {
    ShelfTypes : EVA.Replenishment.GetShelfTypesResponseShelfTypeDto[]; 
  }
  
  export class GetShelfTypesResponseShelfTypeDto {
    ID : number; // Int32
    Name : string; 
    Description : string; 
  }
  
}
/* tslint:disable */
declare module EVA.Rituals {
  
  export class RitualsCreateCustomerReturn extends EVA.Core.RequestMessageGeneric<EVA.Rituals.RitualsCreateCustomerReturnResponse> {
    OrderID : number; // Int32
    Email : string; 
    SessionID : string; 
    Lines : EVA.Rituals.RitualsCreateCustomerReturnLineModel[]; 
    __response : EVA.Rituals.RitualsCreateCustomerReturnResponse;
  }
  
  export class RitualsCreateCustomerReturnResponse extends EVA.Core.ResponseMessage {
    OrderID : number; // Int32
  }
  
  export class RitualsCreateCustomerReturnLineModel {
    ID : number; // Int32
    QuantityToReturn : number; // Int32
    Reason : string; 
  }
  
  export class RitualsGetBlobsForReturn extends EVA.Core.RequestMessageGeneric<EVA.Rituals.RitualsGetBlobsForReturnResponse> {
    OrderID : number; // Int32
    Email : string; 
    __response : EVA.Rituals.RitualsGetBlobsForReturnResponse;
  }
  
  export class RitualsGetBlobsForReturnResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Rituals.RitualsGetBlobsForReturnResponseModel[]; 
  }
  
  export class RitualsGetBlobsForReturnResponseModel {
    Name : string; 
    MimeType : string; 
    BlobID : string; 
    Url : string; 
  }
  
  export class RitualsGetOrderForReturn extends EVA.Core.RequestMessageGeneric<EVA.Rituals.RitualsGetOrderForReturnResponse> {
    OrderID : string; 
    Email : string; 
    __response : EVA.Rituals.RitualsGetOrderForReturnResponse;
  }
  
  export class RitualsGetOrderForReturnResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Rituals.RitualsGetOrderForReturnResponseOrderModel; 
  }
  
  export class RitualsGetOrderForReturnResponseOrderModel {
    ID : number; // Int32
    Lines : EVA.Rituals.RitualsGetOrderForReturnResponseOrderLineModel[]; 
    CustomerID : number; // Int32
    CreationTime : string; // DateTime
    InvoiceNumbers : string[]; 
  }
  
  export class RitualsGetOrderForReturnResponseOrderLineModel extends EVA.Core.OrderLineDto {
    ReturnableQuantity : number; // Int32
    IsReturnable : boolean; 
  }
  
  export class RitualsListAvailablePickupStores extends EVA.Core.PagedResultRequest<EVA.Rituals.RitualsListAvailablePickupStoresResponse> {
    Products : EVA.Rituals.RitualsListAvailablePickupStoresProduct[]; 
    __response : EVA.Rituals.RitualsListAvailablePickupStoresResponse;
  }
  
  export class RitualsListAvailablePickupStoresResponse extends EVA.Core.PagedResultResponse<EVA.Rituals.RitualsListAvailablePickupStoresResponseModel> {
  }
  
  export class RitualsListAvailablePickupStoresResponseModel {
    ID : number; // Int32
    BackendID : string; 
    Name : string; 
    Address : EVA.Core.AddressDto; 
    Latitude : number; // Double
    Longitude : number; // Double
    EmailAddress : string; 
    PhoneNumber : string; 
    EstimatedPickupTime : string; // DateTime
    MerchantID : string; 
    OpeningHours : EVA.Rituals.RitualsListAvailablePickupStoresResponseOpeningHour[]; 
    DistanceInKm : number; // Double
    DistanceInMiles : number; // Double
  }
  
  export class RitualsListAvailablePickupStoresResponseOpeningHour {
    DayOfWeek : string; 
    StartTime : any; // TimeSpan
    EndTime : any; // TimeSpan
    Date : string; // DateTime, nullable
  }
  
  export class RitualsListAvailablePickupStoresProduct {
    Consumercode : string; 
    Quantity : number; // Int32
  }
  
  export class RitualsScanLoyaltyCard extends EVA.Core.RequestMessageGeneric<EVA.Rituals.RitualsScanLoyaltyCardResponse> {
    LoyaltyID : string; 
    __response : EVA.Rituals.RitualsScanLoyaltyCardResponse;
  }
  
  export class RitualsScanLoyaltyCardResponse extends EVA.Core.ResponseMessage {
    User : EVA.Core.UserDto; 
  }
  
  export class RitualsUpdateLoyalty extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    Enabled : boolean; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateDemandwareOrders extends EVA.Core.RequestMessageGeneric<EVA.Rituals.CreateDemandwareOrdersResponse> {
    Orders : EVA.Rituals.DemandwareOrders; 
    __response : EVA.Rituals.CreateDemandwareOrdersResponse;
  }
  
  export class CreateDemandwareOrdersResponse extends EVA.Core.ResponseMessage {
    OrderSets : EVA.Rituals.CreateDemandwareOrdersResponseOrderSetsModel; 
  }
  
  export class CreateDemandwareOrdersResponseOrderSetsModel {
    OrderSet : EVA.Rituals.CreateDemandwareOrdersResponseOrderSetModel[]; 
  }
  
  export class CreateDemandwareOrdersResponseOrderSetModel {
    EVAOrderID : number; // Int32
    DemandwareOrderNo : string; 
  }
  
  export class DemandwareOrders {
    Order : EVA.Rituals.Order[]; 
  }
  
  export class Order {
    Orderdate : string; 
    Createdby : string; 
    Originalorderno : string; 
    Currency : string; 
    Customerlocale : string; 
    Taxation : string; 
    Invoiceno : string; 
    Customer : EVA.Rituals.Customer; 
    Status : EVA.Rituals.Status; 
    Currentorderno : string; 
    Productlineitems : EVA.Rituals.Productlineitems; 
    Shippinglineitems : EVA.Rituals.Shippinglineitems; 
    Shipments : EVA.Rituals.Shipments; 
    Totals : EVA.Rituals.Totals; 
    Payments : EVA.Rituals.Payments; 
    Notes : EVA.Rituals.Notes; 
    Customattributes : EVA.Rituals.Customattributes; 
    Orderno : string; 
  }
  
  export class Customer {
    CustomerNo : string; 
    Customername : string; 
    Customeremail : string; 
    Billingaddress : EVA.Rituals.Billingaddress; 
  }
  
  export class Billingaddress implements EVA.Rituals.IDemandwareAddress {
    Salutation : string; 
    Firstname : string; 
    Secondname : string; 
    Lastname : string; 
    Companyname : string; 
    Address1 : string; 
    Address2 : string; 
    City : string; 
    Postalcode : string; 
    Statecode : string; 
    Countrycode : string; 
    Phone : string; 
    Customattributes : EVA.Rituals.Customattributes; 
  }
  
  export class Customattributes {
    Customattribute : EVA.Rituals.Customattribute[]; 
  }
  
  export class Customattribute {
    Attributeid : string; 
    Text : string; 
  }
  
  export interface IDemandwareAddress {
    Salutation : string; 
    Firstname : string; 
    Lastname : string; 
    Secondname : string; 
    Address1 : string; 
    Address2 : string; 
    City : string; 
    Postalcode : string; 
    Statecode : string; 
    Countrycode : string; 
    Phone : string; 
    Companyname : string; 
    Customattributes : EVA.Rituals.Customattributes; 
  }
  
  export class Status {
    Orderstatus : string; 
    Shippingstatus : string; 
    Confirmationstatus : string; 
    Paymentstatus : string; 
  }
  
  export class Productlineitems {
    Productlineitem : EVA.Rituals.Productlineitem[]; 
  }
  
  export class Productlineitem {
    Netprice : string; 
    Tax : string; 
    Grossprice : string; 
    Baseprice : string; 
    Lineitemtext : string; 
    Taxbasis : string; 
    Position : string; 
    Productid : string; 
    Productname : string; 
    Quantity : EVA.Rituals.Quantity; 
    Taxrate : string; 
    Shipmentid : string; 
    Options : EVA.Rituals.Optionlineitems; 
    Gift : string; 
    GiftMessage : string; 
    Customattributes : EVA.Rituals.Customattributes; 
    Priceadjustments : EVA.Rituals.Priceadjustments; 
  }
  
  export class Quantity {
    Unit : string; 
    Text : string; 
  }
  
  export class Optionlineitems {
    Items : EVA.Rituals.OptionLineItem[]; 
  }
  
  export class OptionLineItem {
    Netprice : string; 
    Tax : string; 
    Grossprice : string; 
    Baseprice : string; 
    Lineitemtext : string; 
    Taxbasis : string; 
    OptionId : string; 
    ValueId : string; 
    ProductId : string; 
    Customattributes : EVA.Rituals.Customattributes; 
  }
  
  export class Priceadjustments {
    Priceadjustment : EVA.Rituals.Priceadjustment[]; 
  }
  
  export class Priceadjustment {
    Netprice : string; 
    Tax : string; 
    Grossprice : string; 
    Baseprice : string; 
    Lineitemtext : string; 
    Taxbasis : string; 
    Promotionid : string; 
    Campaignid : string; 
    Customattributes : EVA.Rituals.Customattributes; 
  }
  
  export class Shippinglineitems {
    Shippinglineitem : EVA.Rituals.Shippinglineitem[]; 
  }
  
  export class Shippinglineitem {
    Netprice : string; 
    Tax : string; 
    Grossprice : string; 
    Baseprice : string; 
    Lineitemtext : string; 
    Taxbasis : string; 
    Itemid : string; 
    Shipmentid : string; 
    Taxrate : string; 
    Priceadjustments : EVA.Rituals.Priceadjustments; 
  }
  
  export class Shipments {
    Shipment : EVA.Rituals.Shipment[]; 
  }
  
  export class Shipment {
    Status : EVA.Rituals.Status; 
    Shippingmethod : string; 
    Shippingaddress : EVA.Rituals.Shippingaddress; 
    Gift : string; 
    GiftMessage : string; 
    Totals : EVA.Rituals.Totals; 
    Shipmentid : string; 
  }
  
  export class Shippingaddress implements EVA.Rituals.IDemandwareAddress {
    Salutation : string; 
    Firstname : string; 
    Secondname : string; 
    Lastname : string; 
    Companyname : string; 
    Address1 : string; 
    Address2 : string; 
    City : string; 
    Postalcode : string; 
    Statecode : string; 
    Countrycode : string; 
    Phone : string; 
    Customattributes : EVA.Rituals.Customattributes; 
  }
  
  export class Totals {
    Merchandizetotal : EVA.Rituals.Merchandizetotal; 
    Adjustedmerchandizetotal : EVA.Rituals.Adjustedmerchandizetotal; 
    Shippingtotal : EVA.Rituals.Shippingtotal; 
    Adjustedshippingtotal : EVA.Rituals.Adjustedshippingtotal; 
    Shipmenttotal : EVA.Rituals.Shipmenttotal; 
    Ordertotal : EVA.Rituals.Ordertotal; 
  }
  
  export class Merchandizetotal {
    Netprice : string; 
    Tax : string; 
    Grossprice : string; 
    Priceadjustments : EVA.Rituals.Priceadjustments; 
  }
  
  export class Adjustedmerchandizetotal {
    Netprice : string; 
    Tax : string; 
    Grossprice : string; 
  }
  
  export class Shippingtotal {
    Netprice : string; 
    Tax : string; 
    Grossprice : string; 
  }
  
  export class Adjustedshippingtotal {
    Netprice : string; 
    Tax : string; 
    Grossprice : string; 
  }
  
  export class Shipmenttotal {
    Netprice : string; 
    Tax : string; 
    Grossprice : string; 
  }
  
  export class Ordertotal {
    Netprice : string; 
    Tax : string; 
    Grossprice : string; 
  }
  
  export class Payments {
    Payment : EVA.Rituals.Payment[]; 
  }
  
  export class Payment {
    Custommethod : EVA.Rituals.Custommethod; 
    Amount : string; 
    Processorid : string; 
    Transactionid : string; 
  }
  
  export class Custommethod {
    Methodname : string; 
  }
  
  export class Notes {
    Note : EVA.Rituals.Note[]; 
  }
  
  export class Note {
    Subject : string; 
    Text : string; 
  }
  
  export class ArvatoCreatePurchaseOrderReceipt extends EVA.Core.RequestMessageWithEmptyResponse {
    BackendOrderID : string; 
    PurchaseOrderLines : EVA.Rituals.ArvatoCreatePurchaseOrderReceiptLine[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ArvatoCreatePurchaseOrderReceiptLine {
    BackendPurchaseOrderLineID : string; 
    Receipts : EVA.Rituals.ArvatoCreatePurchaseOrderReceiptLineReceipt[]; 
  }
  
  export class ArvatoCreatePurchaseOrderReceiptLineReceipt {
    QuantityReceived : number; // Int32
    StockLocationID : string; 
  }
  
  export class ArvatoCreateStockMutation extends EVA.Core.RequestMessageWithEmptyResponse {
    WarehouseID : string; 
    Mutations : EVA.Rituals.ArvatoStockMutation[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ArvatoStockMutation {
    EAN : string; 
    Quantity : number; // Int32
    Type : EVA.Rituals.ArvatoStockMovement; 
    SourceStorageLocation : string; 
    DestinationStorageLocation : string; 
  }
  
  export enum ArvatoStockMovement {
    Inbound = 101,
    Movement = 311,
    Outbound = 601,
    ReturnReceipt = 653,
    NegativeCycleCount = 711,
    PositiveCycleCount = 712,
  }
  
  export class ArvatoShipOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    ShippingConfirmations : EVA.Rituals.ArvatoShipOrderArvatoShipOrderConfirmation[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ArvatoShipOrderArvatoShipOrderConfirmation {
    EvaOrderID : number; // Int32
    BackendOrderLineID : string; 
    DeliveryNumber : string; 
    DateShipped : string; // DateTime
    Packages : EVA.Rituals.ArvatoShipOrderArvatoShipOrderPackage[]; 
  }
  
  export class ArvatoShipOrderArvatoShipOrderPackage {
    TrackingCode : string; 
    TrackingUrl : string; 
    CarrierCode : string; 
    OrderLines : EVA.Rituals.ArvatoShipOrderArvatoShipOrderPackageOrderLine[]; 
  }
  
  export class ArvatoShipOrderArvatoShipOrderPackageOrderLine {
    EvaOrderLineID : number; // Int32
    BackendOrderLineID : string; 
    QuantityShipped : number; // Int32
    SerialNumber : string; 
  }
  
  export class ArvatoUpdateOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    EvaOrderID : number; // Int32
    OrderLines : EVA.Rituals.ArvatoUpdateOrderLine[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ArvatoUpdateOrderLine {
    EvaOrderLineID : number; // Int32
    IsCancelled : boolean; 
    IsPicked : boolean; 
    IsPacked : boolean; 
  }
  
  export class ArvatoUpdateStock extends EVA.Core.RequestMessageWithEmptyResponse {
    WarehouseID : string; 
    Stock : EVA.Rituals.ArvatoUpdateStockLine[]; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ArvatoUpdateStockLine {
    BackendProductID : string; 
    EAN : string; 
    QuantityAvailable : number; // Int32
  }
  
}
/* tslint:disable */
declare module EVA.RoyalRepubliq {
  
  export class RoyalVerifyOrder extends EVA.Core.RequestMessageWithEmptyResponse {
    OrderID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
}
/* tslint:disable */
declare module EVA.Search.Users {
  
  export class RequestReindexUserSearchData extends EVA.Core.RequestMessageWithEmptyResponse {
    Script : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
}
/* tslint:disable */
declare module EVA.Social {
  
  export enum ActivityLedgerDirections {
    Creator = 0,
    Receiver = 1,
  }
  
  export class SocialGetProgressionByID extends EVA.Core.RequestMessageGeneric<EVA.Social.SocialGetProgressionByIDResponse> {
    ID : number; // Int32
    __response : EVA.Social.SocialGetProgressionByIDResponse;
  }
  
  export class SocialGetProgressionByIDResponse extends EVA.Core.ResponseMessage {
    Progression : EVA.Social.ProgressionDto; 
  }
  
  export class ProgressionDto {
    Level : number; // Int32, nullable
    Type : EVA.Social.SocialProgressionType; 
    Name : string; 
    ImageBlobID : string; 
    Steps : EVA.Social.ProgressionStepDto[]; 
    IsAchieved : boolean; 
    Rewards : EVA.Social.ProgressionRewardDto[]; 
  }
  
  export enum SocialProgressionType {
    Level = 0,
    Achievement = 1,
  }
  
  export class ProgressionStepDto {
    Description : string; 
    RequiredQuantity : number; // Int32
    CurrentQuantity : number; // Int32
    IsAchieved : boolean; 
  }
  
  export class ProgressionRewardDto {
    Category : string; 
    Description : string; 
    Type : string; 
    Capability : string; 
    Name : string; 
    BlobID : string; 
  }
  
  export class SocialGetProgressions extends EVA.Core.RequestMessageGeneric<EVA.Social.SocialGetProgressionsResponse> {
    UserID : number; // Int32
    Type : EVA.Social.SocialProgressionType; 
    __response : EVA.Social.SocialGetProgressionsResponse;
  }
  
  export class SocialGetProgressionsResponse extends EVA.Core.ResponseMessage {
    Progressions : EVA.Social.ProgressionDto[]; 
  }
  
}
/* tslint:disable */
declare module EVA.TokBox {
  
  export enum LedgerTypes {
    TokenCreated = 1,
    UserJoined = 2,
    UserLeft = 3,
    SessionEnded = 4,
    UserDeclined = 5,
    StreamStarted = 6,
    StreamEnded = 7,
  }
  
}
/* tslint:disable */
declare module EVA.UserTasks {
  
  export class CompleteValueAddedLogisticTask extends EVA.Core.RequestMessageWithEmptyResponse {
    UserTaskID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetValueAddedLogisticTasks extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.GetValueAddedLogisticTasksResponse> {
    OrderID : number; // Int32, nullable
    OrderLineIDs : number[]; 
    __response : EVA.UserTasks.GetValueAddedLogisticTasksResponse;
  }
  
  export class GetValueAddedLogisticTasksResponse extends EVA.Core.ResponseMessage {
    OrderTasks : EVA.UserTasks.GetValueAddedLogisticTasksResponseModel[]; 
    OrderLineTasks : EVA.UserTasks.GetValueAddedLogisticTasksResponseModel[]; 
  }
  
  export class GetValueAddedLogisticTasksResponseModel {
    OrderLineID : number; // Int32, nullable
    UserTaskID : number; // Int32
    Type : string; 
    Description : string; 
    Data : any; 
  }
  
  export class CancelUserTask extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.CancelUserTaskResponse> {
    TaskID : number; // Int32
    UserID : number; // Int32, nullable
    __response : EVA.UserTasks.CancelUserTaskResponse;
  }
  
  export class CancelUserTaskResponse extends EVA.Core.ResponseMessage {
    Success : boolean; 
  }
  
  export class CompleteUserTask extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    WorkSet : EVA.UserTasks.UserTaskWorkSet; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class UserTaskWorkSet {
    UserTaskID : number; // Int32
    StartTime : string; // DateTime
    Name : string; 
    Description : string; 
    CanBeIgnored : boolean; 
    Configuration : string; 
    ExpectedTimeToComplete : any; // TimeSpan, nullable
    Results : EVA.UserTasks.UserTaskResultDto[]; 
  }
  
  export class UserTaskResultDto implements EVA.Core.IUserTaskResult {
    Name : string; 
    Description : string; 
    Type : string; 
    Value : string; 
    Data : number[]; 
  }
  
  export class CreateUserTaskSchedule extends EVA.Core.RequestMessageWithEmptyResponse {
    TypeID : number; // Int32
    OrganizationUnitTypeID : number; // Int32, nullable
    OrganizationUnitID : number; // Int32, nullable
    Description : string; 
    Deadline : any; // TimeSpan
    CronExpression : string; 
    AttachToFinancialPeriod : boolean; 
    ApplicationID : number; // Int32, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateUserTask extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32, nullable
    OrganizationUnitID : number; // Int32
    AttachFinancialPeriod : boolean; 
    TypeID : number; // Int32
    Deadline : string; // DateTime, nullable
    ExpectedTimeToComplete : any; // TimeSpan, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateUserTaskType extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.CreateUserTaskTypeResponse> {
    Name : string; 
    Description : string; 
    Configuration : string; 
    __response : EVA.UserTasks.CreateUserTaskTypeResponse;
  }
  
  export class CreateUserTaskTypeResponse extends EVA.Core.ResponseMessage {
    UserTaskType : EVA.Core.UserTaskTypeDto; 
  }
  
  export class GetUserTaskDetails extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.GetUserTaskDetailsResponse> {
    UserTaskID : number; // Int32
    __response : EVA.UserTasks.GetUserTaskDetailsResponse;
  }
  
  export class GetUserTaskDetailsResponse extends EVA.Core.ResponseMessage {
    Details : EVA.UserTasks.UserTaskDetails; 
  }
  
  export class UserTaskSummary {
    ID : number; // Int32
    Description : string; 
    UserID : number; // Int32, nullable
    UserFullname : string; 
    IsCompleted : boolean; 
    Type : EVA.Core.UserTaskTypeDto; 
    FinancialPeriodID : number; // Int32, nullable
    FinancialPeriod : EVA.Core.FinancialPeriodDto; 
    IsActive : boolean; 
    ExpectedTimeToComplete : any; // TimeSpan, nullable
    StartTime : string; // DateTime, nullable
    CompletionTime : string; // DateTime, nullable
    Deadline : string; // DateTime, nullable
    Priority : number; // Int32
  }
  
  export class UserTaskDetails extends EVA.UserTasks.UserTaskSummary {
    Results : EVA.UserTasks.UserTaskResultDto[]; 
  }
  
  export class IgnoreUserTask extends EVA.Core.RequestMessageWithEmptyResponse {
    UserTaskID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListAvailableUserTasks extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.ListAvailableUserTasksResponse> {
    __response : EVA.UserTasks.ListAvailableUserTasksResponse;
  }
  
  export class ListAvailableUserTasksResponse extends EVA.Core.ResponseMessage {
    AvailableTasks : EVA.UserTasks.AvailableUserTask[]; 
  }
  
  export class AvailableUserTask {
    ID : number; // Int32
    Description : string; 
    TypeID : number; // Int32
    Type : EVA.Core.UserTaskTypeDto; 
    ExpectedTimeToComplete : any; // TimeSpan, nullable
    Deadline : string; // DateTime, nullable
    CanBeIgnored : boolean; 
    CreationTime : string; // DateTime
  }
  
  export class ListTasksForOrganization extends EVA.Core.PagedResultRequest<EVA.UserTasks.ListTasksForOrganizationResponse> {
    UserTaskTypes : string[]; 
    __response : EVA.UserTasks.ListTasksForOrganizationResponse;
  }
  
  export class ListTasksForOrganizationResponse extends EVA.Core.PagedResultResponse<EVA.Core.UserTaskDto> {
  }
  
  export class ListTasksThatBlockPeriodClosing extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.ListTasksThatBlockPeriodClosingResponse> {
    __response : EVA.UserTasks.ListTasksThatBlockPeriodClosingResponse;
  }
  
  export class ListTasksThatBlockPeriodClosingResponse extends EVA.Core.ResponseMessage {
    Tasks : EVA.Core.UserTaskDto[]; 
  }
  
  export class ListUserTaskTypes extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.ListUserTaskTypesResponse> {
    __response : EVA.UserTasks.ListUserTaskTypesResponse;
  }
  
  export class ListUserTaskTypesResponse extends EVA.Core.ResponseMessage {
    Types : EVA.Core.UserTaskTypeDto[]; 
  }
  
  export class PollTasks extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.PollTasksResponse> {
    UserTaskTypes : string[]; 
    __response : EVA.UserTasks.PollTasksResponse;
  }
  
  export class PollTasksResponse extends EVA.Core.ResponseMessage {
    NumberOfTasks : number; // Int32
  }
  
  export class SearchUserTasks extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.SearchUserTasksResponse> {
    Start : number; // Int32
    Limit : number; // Int32
    OrganizationUnitID : number; // Int32
    Filters : EVA.UserTasks.SearchUserTasksFilters; 
    __response : EVA.UserTasks.SearchUserTasksResponse;
  }
  
  export class SearchUserTasksResponse extends EVA.Core.ResponseMessage {
    Results : EVA.UserTasks.UserTaskSummary[]; 
  }
  
  export class SearchUserTasksFilters {
    ShowCompleted : boolean; 
  }
  
  export class StartUserTask extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.StartUserTaskResponse> {
    UserTaskID : number; // Int32
    __response : EVA.UserTasks.StartUserTaskResponse;
  }
  
  export class StartUserTaskResponse extends EVA.Core.ResponseMessage {
    WorkSet : EVA.UserTasks.UserTaskWorkSet; 
  }
  
  export class UpdateUserTask extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    ID : number; // Int32
    UserID : number; // Int32
    TypeID : number; // Int32
    Deadline : string; // DateTime
    ExpectedTimeToComplete : any; // TimeSpan
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class UpdateUserTaskType extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    ID : number; // Int32
    Name : string; 
    Description : string; 
    Configuration : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CompleteStockReservationTask extends EVA.Core.RequestMessageWithEmptyResponse {
    Task : EVA.UserTasks.StockReservationTaskDto; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class StockReservationTaskDto {
    UserTaskID : number; // Int32
    OrderID : number; // Int32
    Order : EVA.Core.OrderDto; 
    Lines : EVA.UserTasks.StockReservationTaskLineDto[]; 
  }
  
  export class StockReservationTaskLineDto {
    IsCancelled : boolean; 
    IsReserved : boolean; 
    Barcodes : string[]; 
    Product : EVA.Core.ProductDto; 
    ProductID : number; // Int32
    OrderLineID : number; // Int32
    QuantityOnHand : number; // Int32
    ForceComplete : boolean; 
    MustBeOrdered : boolean; 
    RequiredResourceTypes : EVA.Core.Services.StockResourceTypeDto[]; 
    ResourceID : number; // Int32, nullable
    Resources : { [ key : string ] : string }; 
  }
  
  export class StartStockReservation extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.StartStockReservationResponse> {
    TaskID : number; // Int32
    Force : boolean; 
    __response : EVA.UserTasks.StartStockReservationResponse;
  }
  
  export class StartStockReservationResponse extends EVA.Core.ResponseMessage {
    WorkSet : EVA.UserTasks.StockReservationWorkSet; 
  }
  
  export class StockReservationWorkSet {
    UserTaskID : number; // Int32
    OrderID : number; // Int32
    Order : EVA.Core.OrderDto; 
    Lines : EVA.UserTasks.StockReservationTaskLineDto[]; 
  }
  
  export class CompleteReservationDeviationTask extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.CompleteReservationDeviationTaskResponse> {
    WorkSet : EVA.UserTasks.ReservationDeviationWorkSet; 
    __response : EVA.UserTasks.CompleteReservationDeviationTaskResponse;
  }
  
  export class CompleteReservationDeviationTaskResponse extends EVA.Core.ResponseMessage {
    Retry : boolean; 
  }
  
  export class ReservationDeviationWorkSet {
    TaskID : number; // Int32
    ProductID : number; // Int32
    Orders : EVA.Core.OrderDto[]; 
    OrderLineIDs : number[]; 
    QuantityToCancel : number; // Int32
    Product : EVA.Core.ProductDto; 
    QuantityToMoveToSellable : number; // Int32
    OrderLinesToCancel : EVA.UserTasks.OrderLineToCancel[]; 
    OrderLinesToOrder : EVA.UserTasks.OrderLineToOrder[]; 
    QuantityMovedBack : number; // Int32
  }
  
  export class OrderLineToCancel {
    OrderLineID : number; // Int32
    QuantityToCancel : number; // Int32
  }
  
  export class OrderLineToOrder {
    OrderLineID : number; // Int32
    QuantityToOrder : number; // Int32
  }
  
  export class StartReservationDeviationTask extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.StartReservationDeviationTaskResponse> {
    TaskID : number; // Int32
    Force : boolean; 
    __response : EVA.UserTasks.StartReservationDeviationTaskResponse;
  }
  
  export class StartReservationDeviationTaskResponse extends EVA.Core.ResponseMessage {
    WorkSet : EVA.UserTasks.ReservationDeviationWorkSet; 
  }
  
  export class CompleteReservationCleanup extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.CompleteReservationCleanupResponse> {
    Task : EVA.UserTasks.ReservationCleanupWorkSet; 
    __response : EVA.UserTasks.CompleteReservationCleanupResponse;
  }
  
  export class CompleteReservationCleanupResponse extends EVA.Core.ResponseMessage {
  }
  
  export class ReservationCleanupWorkSet {
    UserTaskID : number; // Int32
    ReservationCleanupTaskID : number; // Int32
    Order : EVA.Core.OrderDto; 
    Lines : EVA.UserTasks.ReservationCleanupWorkSetOrderLine[]; 
  }
  
  export class ReservationCleanupWorkSetOrderLine {
    QuantityToReturn : number; // Int32
    QuantityReturned : number; // Int32
    NothingToReturn : boolean; 
    ReservationExpirationOverride : string; // DateTime, nullable
    OrderLine : EVA.Core.OrderLineDto; 
  }
  
  export class StartReservationCleanup extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.StartReservationCleanupResponse> {
    UserTaskID : number; // Int32
    __response : EVA.UserTasks.StartReservationCleanupResponse;
  }
  
  export class StartReservationCleanupResponse extends EVA.Core.ResponseMessage {
    Task : EVA.UserTasks.ReservationCleanupWorkSet; 
  }
  
  export class CompletePriceChange extends EVA.Core.RequestMessageWithEmptyResponse {
    Task : EVA.UserTasks.PriceChangeWorkSet; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class PriceChangeWorkSet {
    UserTaskID : number; // Int32
    PriceChangeTaskID : number; // Int32
    ProductID : number; // Int32
    ProductBackendID : string; 
    ProductName : string; 
    OriginalPrice : number; // Decimal
    CurrentPrice : number; // Decimal
    ProductCustomID : string; 
  }
  
  export class StartPriceChange extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.StartPriceChangeResponse> {
    UserTaskID : number; // Int32
    __response : EVA.UserTasks.StartPriceChangeResponse;
  }
  
  export class StartPriceChangeResponse extends EVA.Core.ResponseMessage {
    Task : EVA.UserTasks.PriceChangeWorkSet; 
  }
  
  export class CanProcessInitialCycleCount extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.CanProcessInitialCycleCountResponse> {
    InitialCycleCountID : number; // Int32
    __response : EVA.UserTasks.CanProcessInitialCycleCountResponse;
  }
  
  export class CanProcessInitialCycleCountResponse extends EVA.Core.ResponseMessage {
    CanProcess : boolean; 
  }
  
  export class CountProductForInitialCycleCount extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    LabelID : number; // Int32
    ProductID : number; // Int32
    Quantity : number; // Int32
    Resources : { [ key : string ] : string }; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateInitialCycleCount extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.CreateInitialCycleCountResponse> {
    __response : EVA.UserTasks.CreateInitialCycleCountResponse;
  }
  
  export class CreateInitialCycleCountResponse extends EVA.Core.ResponseMessage {
    Result : EVA.UserTasks.InitialCycleCountDto; 
  }
  
  export class InitialCycleCountDto {
    ID : number; // Int32
    Status : EVA.UserTasks.InitialCycleCountStatus; 
    OrganizationUnitID : number; // Int32
  }
  
  export enum InitialCycleCountStatus {
    New = 0,
    DetailCount = 1,
    Finished = 2,
  }
  
  export class DeleteInitialCycleCountResult extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    ProductID : number; // Int32
    StockLabel : number; // Int32
    ResourceID : number; // Int32, nullable
    LabelID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetCurrentInitialCycleCount extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.GetCurrentInitialCycleCountResponse> {
    __response : EVA.UserTasks.GetCurrentInitialCycleCountResponse;
  }
  
  export class GetCurrentInitialCycleCountResponse extends EVA.Core.ResponseMessage {
    Result : EVA.UserTasks.InitialCycleCountDto; 
  }
  
  export class GetInitialCycleCountLabel extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.GetInitialCycleCountLabelResponse> {
    LabelID : number; // Int32
    __response : EVA.UserTasks.GetInitialCycleCountLabelResponse;
  }
  
  export class GetInitialCycleCountLabelResponse extends EVA.Core.ResponseMessage {
    Label : EVA.UserTasks.InitialCycleCountLabelDto; 
  }
  
  export class InitialCycleCountLabelDto {
    ID : number; // Int32
    Number : number; // Int32
    Status : EVA.UserTasks.InitialCycleCountLabelStatus; 
    StockLabel : number; // Int32, nullable
    ItemPreCount : number; // Int32, nullable
    ItemEndCount : number; // Int32, nullable
    CreatedByID : number; // Int32
    CreationTime : string; // DateTime
    InitialCycleCount : EVA.UserTasks.InitialCycleCountDto; 
    PreCountedByFullName : string; 
    CountedByFullName : string; 
  }
  
  export enum InitialCycleCountLabelStatus {
    New = 0,
    PreCounted = 1,
    Counted = 2,
  }
  
  export class ListInitialCycleCountLabels extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.ListInitialCycleCountLabelsResponse> {
    InitialCycleCountID : number; // Int32
    Start : number; // Int32
    Limit : number; // Int32
    __response : EVA.UserTasks.ListInitialCycleCountLabelsResponse;
  }
  
  export class ListInitialCycleCountLabelsResponse extends EVA.Core.ResponseMessage {
    Result : EVA.UserTasks.InitialCycleCountLabelDto[]; 
    Total : number; // Int32
  }
  
  export class ListInitialCycleCountResults extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.ListInitialCycleCountResultsResponse> {
    Start : number; // Int32
    Limit : number; // Int32
    ShowAll : boolean; 
    ProductID : number; // Int32, nullable
    CustomItemNumber : string; 
    StockLabel : number; // Int32, nullable
    ResourceID : number; // Int32, nullable
    LabelID : number; // Int32, nullable
    __response : EVA.UserTasks.ListInitialCycleCountResultsResponse;
  }
  
  export class ListInitialCycleCountResultsResponse extends EVA.Core.ResponseMessage {
    Results : EVA.UserTasks.StockWithInitialCycleCountResultDto[]; 
    Total : number; // Int32
  }
  
  export class StockWithInitialCycleCountResultDto {
    ProductID : number; // Int32
    OrganizationUnitID : number; // Int32
    QuantityOnHand : number; // Int32
    StockLabelID : number; // Int32
    StockLabel : number; // Int32
    ResourceID : number; // Int32, nullable
    Quantity : number; // Int32
    BackendID : string; 
    LabelID : string; 
    LabelNumber : string; 
    ShortDescription : string; 
  }
  
  export class MissingProductForInitialCycleCount extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    LabelID : number; // Int32
    Barcode : string; 
    Quantity : number; // Int32
    Photo : number[]; 
    PhotoMimeType : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class PreCountInitialCycleCountLabel extends EVA.Core.RequestMessageWithEmptyResponse {
    LabelID : number; // Int32
    Quantity : number; // Int32
    StockLabel : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ProcessInitialCycleCountResults extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ProduceInitialCycleCountLabels extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.ProduceInitialCycleCountLabelsResponse> {
    Count : number; // Int32
    StationID : number; // Int32, nullable
    AsPDF : boolean; 
    ReprintLabels : boolean; 
    __response : EVA.UserTasks.ProduceInitialCycleCountLabelsResponse;
  }
  
  export class ProduceInitialCycleCountLabelsResponse extends EVA.Core.ResponseMessage {
    Count : number; // Int32
    Success : boolean; 
    PdfDownloadUrl : string; 
  }
  
  export class ValidatePreCount extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.ValidatePreCountResponse> {
    LabelID : number; // Int32
    ConfirmedQuantity : number; // Int32, nullable
    __response : EVA.UserTasks.ValidatePreCountResponse;
  }
  
  export class ValidatePreCountResponse extends EVA.Core.ResponseMessage {
    Result : EVA.UserTasks.ValidatePreCountResults; 
  }
  
  export enum ValidatePreCountResults {
    None = 0,
    Correct = 1,
    Deviation = 2,
    RedoDetailCount = 3,
  }
  
  export class CompleteCycleCount extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.CompleteCycleCountResponse> {
    WorkSet : EVA.UserTasks.CycleCountWorkSet; 
    __response : EVA.UserTasks.CompleteCycleCountResponse;
  }
  
  export class CompleteCycleCountResponse extends EVA.Core.ResponseMessage {
    Results : EVA.UserTasks.CompleteCycleCountStockLabelResult[]; 
  }
  
  export class CompleteCycleCountStockLabelResult {
    OverallResult : EVA.UserTasks.CycleCountAttemptResult; 
    StockLabel : number; // Int32
    ExpectedQuantity : number; // Int32, nullable
    CountedQuantity : number; // Int32
    Lines : EVA.UserTasks.CompleteCycleCountStockLabelResultLine[]; 
  }
  
  export enum CycleCountAttemptResult {
    None = 0,
    CountAgain = 1,
    Finished = 2,
    FinishedWithDeviation = 3,
    FinishedWithInvalidResources = 4,
    CompleteResource = 5,
  }
  
  export class CompleteCycleCountStockLabelResultLine {
    StockLabel : number; // Int32
    Result : EVA.UserTasks.CycleCountAttemptResult; 
    ExpectedQuantity : number; // Int32
    CountedQuantity : number; // Int32
    ResourceID : number; // Int32, nullable
  }
  
  export class CycleCountWorkSet {
    UserTaskID : number; // Int32
    ProductID : number; // Int32
    Product : EVA.Core.ProductDto; 
    OrganizationUnitID : number; // Int32
    OrganizationUnit : EVA.Core.OrganizationUnitDto; 
    RequiredResourceTypes : EVA.Core.Services.StockResourceTypeDto[]; 
    StockLabels : EVA.UserTasks.StockLabelToCycleCount[]; 
  }
  
  export class StockLabelToCycleCount {
    StockLabel : number; // Int32
    Lines : EVA.UserTasks.CycleCountWorkSetLine[]; 
  }
  
  export class CycleCountWorkSetLine {
    CountedQuantity : number; // Int32
    Resource : EVA.UserTasks.ResourceToCycleCount; 
    NewResources : { [ key : string ] : string }; 
  }
  
  export class ResourceToCycleCount {
    ResourceID : number; // Int32
    Resources : { [ key : string ] : string }; 
  }
  
  export class CreateManualCycleCount extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    ProductID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetCycleCountDetail extends EVA.Core.GetRequestGeneric<EVA.UserTasks.GetCycleCountDetailResponse> {
    __response : EVA.UserTasks.GetCycleCountDetailResponse;
  }
  
  export class GetCycleCountDetailResponse extends EVA.Core.ResponseMessage {
    Result : EVA.UserTasks.GetCycleCountDetailResponseCycleCountDto; 
  }
  
  export class GetCycleCountDetailResponseCycleCountDto {
    ID : number; // Int32
    StockLabel : number; // Int32
    ProductID : number; // Int32, nullable
    Product : EVA.Core.ProductDto; 
    UserTaskID : number; // Int32
    UserTask : EVA.Core.UserTaskDto; 
    IsCompleted : boolean; 
    UserID : number; // Int32, nullable
    ResourceID : number; // Int32, nullable
    Results : EVA.UserTasks.CycleCountResultDto[]; 
    Result : EVA.UserTasks.CycleCountResults; 
    IsActive : boolean; 
    CreationTime : string; // DateTime
  }
  
  export class CycleCountResultDto {
    CycleCountID : number; // Int32
    ExpectedQuantity : number; // Int32
    CountedQuantity : number; // Int32
    ResourceID : number; // Int32, nullable
    StockLabelID : number; // Int32
    StockLabel : number; // Int32
    ID : number; // Int32
    CreatedByID : number; // Int32, nullable
    CreatedBy : EVA.Core.UserDto; 
    CreationTime : string; // DateTime
    StockLabelDescription : string; 
  }
  
  export enum CycleCountResults {
    New = 0,
    InProgress = 1,
    Deviated = 2,
    Correct = 3,
    Unknown = 4,
  }
  
  export class ListCycleCounts extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.ListCycleCountsResponse> {
    ProductID : number; // Int32, nullable
    StockLabel : number; // Int32, nullable
    ResourceID : number; // Int32, nullable
    OrganizationUnitID : number; // Int32, nullable
    BackendID : string; 
    CreatedBy : string; 
    FromDate : string; // DateTime, nullable
    ToDate : string; // DateTime, nullable
    Result : EVA.UserTasks.CycleCountResults; 
    IsCompleted : boolean; 
    PageConfig : EVA.Core.PageConfig; 
    CustomID : string; 
    __response : EVA.UserTasks.ListCycleCountsResponse;
  }
  
  export class ListCycleCountsResponse extends EVA.Core.ResponseMessage {
    CycleCounts : EVA.Core.PagedResultGeneric<EVA.UserTasks.ListCycleCountsResponseCycleCountDto>; 
  }
  
  export class ListCycleCountsResponseCycleCountDto {
    ID : number; // Int32
    StockLabel : number; // Int32
    ProductID : number; // Int32, nullable
    Product : EVA.Core.ProductDto; 
    UserTaskID : number; // Int32
    UserTask : EVA.Core.UserTaskDto; 
    IsCompleted : boolean; 
    UserID : number; // Int32, nullable
    ResourceID : number; // Int32, nullable
    Results : EVA.UserTasks.CycleCountResultDto[]; 
    Result : EVA.UserTasks.CycleCountResults; 
    IsActive : boolean; 
    CreationTime : string; // DateTime
  }
  
  export class ListUsersWithCycleCountResults extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.ListUsersWithCycleCountResultsResponse> {
    __response : EVA.UserTasks.ListUsersWithCycleCountResultsResponse;
  }
  
  export class ListUsersWithCycleCountResultsResponse extends EVA.Core.ResponseMessage {
    Users : EVA.Core.UserDto[]; 
  }
  
  export class StartCycleCount extends EVA.Core.RequestMessageGeneric<EVA.UserTasks.StartCycleCountResponse> {
    TaskID : number; // Int32
    __response : EVA.UserTasks.StartCycleCountResponse;
  }
  
  export class StartCycleCountResponse extends EVA.Core.ResponseMessage {
    WorkSet : EVA.UserTasks.CycleCountWorkSet; 
  }
  
}
/* tslint:disable */
declare module EVA.Workforce {
  
  export class ListAvailabilityForTimeslot extends EVA.Core.RequestMessageGeneric<EVA.Workforce.ListAvailabilityForTimeslotResponse> {
    OrganizationUnitID : number; // Int32
    StartDateTime : string; // DateTime
    EndDateTime : string; // DateTime
    __response : EVA.Workforce.ListAvailabilityForTimeslotResponse;
  }
  
  export class ListAvailabilityForTimeslotResponse extends EVA.Core.ResponseMessage {
    Availability : EVA.Workforce.ConsecutiveTimeChunkWithUser[]; 
  }
  
  export class ConsecutiveTimeChunkWithUser {
    UserID : number; // Int32
    FullName : string; 
    Date : string; // DateTime
    StartTime : any; // TimeSpan
    EndTime : any; // TimeSpan
    IsAvailable : boolean; 
    BadgeIDs : number[]; 
    Duration : any; // TimeSpan
    StartDateTime : string; // DateTime
    EndDateTime : string; // DateTime
  }
  
  export class ListPlanning extends EVA.Core.RequestMessageGeneric<EVA.Workforce.ListPlanningResponse> {
    OrganizationUnitID : number; // Int32, nullable
    StartDate : string; // DateTime
    EndDate : string; // DateTime
    __response : EVA.Workforce.ListPlanningResponse;
  }
  
  export class ListPlanningResponse extends EVA.Core.ResponseMessage {
    Items : EVA.Workforce.ListPlanningResponsePlanning[]; 
  }
  
  export class ListPlanningResponsePlanning {
    OrganizationUnit : EVA.Core.OrganizationUnitDto; 
    DateTime : string; // DateTime
    Result : number; // Int32
  }
  
  export class ClockEmployeeOutAsAbsent extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    UserID : number; // Int32
    FinancialPeriodID : number; // Int32, nullable
    AbsentFrom : string; // DateTime
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CorrectWorkedHours extends EVA.Core.RequestMessageWithEmptyResponse {
    ID : number; // Int32
    ClockInDateTime : string; // DateTime, nullable
    ClockOutDateTime : string; // DateTime, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class CreateWorkedHours extends EVA.Core.RequestMessageWithEmptyResponse {
    UserID : number; // Int32
    Date : string; // DateTime
    ClockInTime : any; // TimeSpan
    ClockOutTime : any; // TimeSpan
    OrganizationUnitID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListClockedInEmployeesForFinancialPeriod extends EVA.Core.RequestMessageGeneric<EVA.Workforce.ListClockedInEmployeesForFinancialPeriodResponse> {
    PeriodID : number; // Int32
    __response : EVA.Workforce.ListClockedInEmployeesForFinancialPeriodResponse;
  }
  
  export class ListClockedInEmployeesForFinancialPeriodResponse extends EVA.Core.ResponseMessage {
    Employees : EVA.Workforce.ListClockedInEmployeesForFinancialPeriodResponseClockedInUser[]; 
  }
  
  export class ListClockedInEmployeesForFinancialPeriodResponseClockedInUser {
    User : EVA.Core.UserDto; 
    ClockedIn : string; // DateTime
    ClockedOut : string; // DateTime, nullable
    IsAbsent : boolean; 
  }
  
  export class ListUnrosteredWorkedHours extends EVA.Core.RequestMessageGeneric<EVA.Workforce.ListUnrosteredWorkedHoursResponse> {
    UserID : number; // Int32
    StartDate : string; // DateTime
    EndDate : string; // DateTime
    OrganizationUnitID : number; // Int32, nullable
    __response : EVA.Workforce.ListUnrosteredWorkedHoursResponse;
  }
  
  export class ListUnrosteredWorkedHoursResponse extends EVA.Core.ResponseMessage {
    WorkedHours : EVA.Workforce.WorkedPeriod[]; 
  }
  
  export class WorkedPeriod {
    StartDate : string; // DateTime
    EndDate : string; // DateTime, nullable
  }
  
  export class ListWorkedHoursForCurrentEmployee extends EVA.Core.RequestMessageGeneric<EVA.Workforce.ListWorkedHoursForCurrentEmployeeResponse> {
    __response : EVA.Workforce.ListWorkedHoursForCurrentEmployeeResponse;
  }
  
  export class ListWorkedHoursForCurrentEmployeeResponse extends EVA.Core.ResponseMessage {
    WorkedHours : EVA.Workforce.WorkedHoursDto[]; 
  }
  
  export class WorkedHoursDto {
    ID : number; // Int32
    UserID : number; // Int32
    User : EVA.Core.UserDto; 
    OrganizationUnitID : number; // Int32
    OrganizationUnit : EVA.Core.OrganizationUnitDto; 
    Date : string; // DateTime
    ClockInTime : any; // TimeSpan
    ClockOutTime : any; // TimeSpan, nullable
    ClockInDateTime : string; // DateTime
    ClockOutDateTime : string; // DateTime, nullable
    IsExported : boolean; 
  }
  
  export class ListWorkedHours extends EVA.Core.RequestMessageGeneric<EVA.Workforce.ListWorkedHoursResponse> {
    UserIDs : number[]; 
    StartDate : string; // DateTime
    EndDate : string; // DateTime
    OrganizationUnitID : number; // Int32, nullable
    __response : EVA.Workforce.ListWorkedHoursResponse;
  }
  
  export class ListWorkedHoursResponse extends EVA.Core.ResponseMessage {
    WorkedPeriods : { [ key : number ] : EVA.Workforce.ListWorkedHoursResponseWorkedPeriod[] }; 
  }
  
  export class ListWorkedHoursResponseWorkedPeriod {
    StartDate : string; // DateTime
    StartID : number; // Int32
    EndDate : string; // DateTime, nullable
    ClockedOut : boolean; 
  }
  
  export class DeleteRosterItem extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    ID : number; // Int32
    ExpireDate : string; // DateTime, nullable
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListOccupiedPeriods extends EVA.Core.RequestMessageGeneric<EVA.Workforce.ListOccupiedPeriodsResponse> {
    UserID : number; // Int32
    StartDate : string; // DateTime
    EndDate : string; // DateTime
    __response : EVA.Workforce.ListOccupiedPeriodsResponse;
  }
  
  export class ListOccupiedPeriodsResponse extends EVA.Core.ResponseMessage {
    Absence : EVA.Workforce.ListOccupiedPeriodsResponseOccupiedPeriod[]; 
    Leave : EVA.Workforce.ListOccupiedPeriodsResponseOccupiedPeriod[]; 
  }
  
  export class ListOccupiedPeriodsResponseOccupiedPeriod {
    StartDate : string; // DateTime
    EndDate : string; // DateTime, nullable
    TypeDescription : string; 
    Reason : string; 
  }
  
  export class ListRosterableUsersForOrganizationUnit extends EVA.Core.RequestMessageGeneric<EVA.Workforce.ListRosterableUsersForOrganizationUnitResponse> {
    OrganizationUnitID : number; // Int32
    From : string; // DateTime
    To : string; // DateTime
    __response : EVA.Workforce.ListRosterableUsersForOrganizationUnitResponse;
  }
  
  export class ListRosterableUsersForOrganizationUnitResponse extends EVA.Core.ResponseMessage {
    Users : EVA.Core.UserDto[]; 
  }
  
  export class ListRoster extends EVA.Core.RequestMessageGeneric<EVA.Workforce.ListRosterResponse> {
    Types : number[]; 
    UserID : number; // Int32, nullable
    BadgeID : number; // Int32, nullable
    OrganizationUnitID : number; // Int32, nullable
    StartDate : string; // DateTime
    EndDate : string; // DateTime
    __response : EVA.Workforce.ListRosterResponse;
  }
  
  export class ListRosterResponse extends EVA.Core.ResponseMessage {
    Items : EVA.Workforce.ListRosterResponseRosterItem[]; 
  }
  
  export class ListRosterResponseRosterItem {
    TypeID : number; // Int32
    OrganizationUnitID : number; // Int32, nullable
    OrganizationUnitName : string; 
    UserID : number; // Int32, nullable
    BadgeID : number; // Int32, nullable
    FullName : string; 
    Date : string; // DateTime
    StartTime : any; // TimeSpan, nullable
    EndTime : any; // TimeSpan, nullable
    DayOfWeekID : number; // Int32, nullable
    ID : number; // Int32
    StartDateTime : string; // DateTime, nullable
    EndDateTime : string; // DateTime, nullable
    Description : string; 
    AllDay : boolean; 
  }
  
  export class SaveRosterItem extends EVA.Core.RequestMessageGeneric<EVA.Core.EmptyResponseMessage> {
    ID : number; // Int32
    TypeID : number; // Int32
    OrganizationUnitID : number; // Int32, nullable
    UserID : number; // Int32, nullable
    BadgeID : number; // Int32, nullable
    Date : string; // DateTime, nullable
    DayOfWeekID : number; // Int32, nullable
    AllDay : boolean; 
    AvailabilityID : number; // Int32, nullable
    SlotID : number; // Int32, nullable
    StartDateTime : string; // DateTime, nullable
    EndDateTime : string; // DateTime, nullable
    Description : string; 
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ExportPayrollPeriod extends EVA.Core.RequestMessageWithEmptyResponse {
    PayrollPeriodID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class GetPayrollPeriodReport extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    PayrollPeriodID : number; // Int32
    __response : EVA.Core.ResourceResponseMessage;
  }
  
  export class GetPayrollPeriodWorkedHoursReport extends EVA.Core.RequestMessageGeneric<EVA.Core.ResourceResponseMessage> {
    PayrollPeriodID : number; // Int32
    __response : EVA.Core.ResourceResponseMessage;
  }
  
  export class ListPayrollPeriods extends EVA.Core.PagedResultRequest<EVA.Workforce.ListPayrollPeriodsResponse> {
    __response : EVA.Workforce.ListPayrollPeriodsResponse;
  }
  
  export class ListPayrollPeriodsResponse extends EVA.Core.PagedResultResponse<EVA.Workforce.ListPayrollPeriodsResponsePayrollPeriodDto> {
  }
  
  export class ListPayrollPeriodsResponsePayrollPeriodDto {
    ID : number; // Int32
    PreviousPeriodID : number; // Int32, nullable
    StartDate : string; // DateTime
    EndDate : string; // DateTime
    Weeks : number; // Int32
    IsExported : boolean; 
  }
  
  export class ListSalaryComponents extends EVA.Core.PagedResultRequest<EVA.Workforce.ListSalaryComponentsResponse> {
    __response : EVA.Workforce.ListSalaryComponentsResponse;
  }
  
  export class ListSalaryComponentsResponse extends EVA.Core.PagedResultResponse<EVA.Workforce.ListSalaryComponentsResponseSalaryComponentDto> {
  }
  
  export class ListSalaryComponentsResponseSalaryComponentDto {
    PayrollPeriodID : number; // Int32
    UserID : number; // Int32
    User : EVA.Core.UserDto; 
    TypeID : number; // Int32
    Param1 : number; // Decimal, nullable
    Param2 : number; // Decimal, nullable
    Param3 : number; // Decimal, nullable
    Reason : string; 
    IsExported : boolean; 
  }
  
  export class ListSalaryComponentTypes extends EVA.Core.RequestMessageGeneric<EVA.Workforce.ListSalaryComponentTypesResponse> {
    __response : EVA.Workforce.ListSalaryComponentTypesResponse;
  }
  
  export class ListSalaryComponentTypesResponse extends EVA.Core.ResponseMessage {
    Result : EVA.Workforce.ListSalaryComponentTypesResponseSalaryComponentTypeDto[]; 
  }
  
  export class ListSalaryComponentTypesResponseSalaryComponentTypeDto {
    ID : number; // Int32
    Name : string; 
    Description : string; 
    Code : string; 
    ExportNextPeriod : boolean; 
  }
  
  export class RecalculatePayrollPeriod extends EVA.Core.RequestMessageWithEmptyResponse {
    PayrollPeriodID : number; // Int32
    __response : EVA.Core.EmptyResponseMessage;
  }
  
  export class ListLeaveBalancesForUser extends EVA.Core.RequestMessageGeneric<EVA.Workforce.ListLeaveBalancesForUserResponse> {
    UserID : number; // Int32
    __response : EVA.Workforce.ListLeaveBalancesForUserResponse;
  }
  
  export class ListLeaveBalancesForUserResponse extends EVA.Core.ResponseMessage {
    Items : EVA.Workforce.ListLeaveBalancesForUserResponseLeaveBalanceDto[]; 
  }
  
  export class ListLeaveBalancesForUserResponseLeaveBalanceDto {
    LeaveType : string; 
    Balance : number; // Decimal
  }
  
  export enum FailedClockOutReasons {
    None = 0,
    AfterFinancialPeriod = 1,
    OutsideSubnet = 2,
  }
  
  export enum RosterTypes {
    UserAvailable = 1,
    UserUnavailable = 2,
    TimeSlot = 3,
    Planned = 4,
    AbsenceRequested = 5,
  }
  
  export enum UserTimeLedgerTypes {
    ActualUserTaskTime = 1,
    ExpectedUserTaskTime = 2,
    TimeSpentOnInterruptedUserTask = 3,
    ExpectedSalesTime = 4,
    ActualWorkedHours = 5,
  }
  
  export enum LeaveStatus {
    Requested = 0,
    Approved = 1,
  }
  
  export enum WorkedHoursLedgerType {
    ClockIn = 1,
    ClockOut = 2,
    ClockInCorrection = 3,
    ClockOutCorrection = 4,
    ClockedOutInPeriodClosing = 5,
    DaySplit = 6,
  }
  
}
/* tslint:disable */
declare module System.Private.CoreLib {
  
  export enum DayOfWeek {
    Sunday = 0,
    Monday = 1,
    Tuesday = 2,
    Wednesday = 3,
    Thursday = 4,
    Friday = 5,
    Saturday = 6,
  }
  
}
/* tslint:disable */
declare module mscorlib {
  
  export enum DayOfWeek {
    Sunday = 0,
    Monday = 1,
    Tuesday = 2,
    Wednesday = 3,
    Thursday = 4,
    Friday = 5,
    Saturday = 6,
  }
  
}